@@ -19,13 +19,19 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 // cl_main.c  -- client main loop
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "client.h"
-#ifdef _WINDOWS
+#if defined WIN32_VARIANT
 #include <winsock.h>
 #endif
 
-#ifdef __unix__
+#if defined UNIX_VARIANT
+#if defined HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <sys/socket.h>
 #include <sys/time.h>
 #include <netinet/in.h>
@@ -36,6 +42,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <errno.h>
 #endif
 
+#if defined HAVE_PUTENV && !defined HAVE__PUTENV
+#define _putenv putenv
+#endif
+
+
 cvar_t	*freelook;
 
 cvar_t	*adr0;
@@ -65,6 +76,7 @@ cvar_t  *cl_brass;
 cvar_t  *cl_showPlayerNames;
 cvar_t	*cl_playtaunts;
 cvar_t	*cl_centerprint;
+cvar_t	*cl_precachecustom;
 
 cvar_t	*cl_paindist;
 cvar_t	*cl_explosiondist;
@@ -84,6 +96,7 @@ cvar_t	*cl_timedemo;
 cvar_t	*lookspring;
 cvar_t	*lookstrafe;
 cvar_t	*sensitivity;
+cvar_t	*menu_sensitivity;
 
 cvar_t	*m_smoothing;
 cvar_t	*m_pitch;
@@ -106,6 +119,7 @@ cvar_t	*gender;
 cvar_t	*gender_auto;
 
 cvar_t	*cl_vwep;
+cvar_t	*cl_vehicle_huds;
 
 cvar_t  *background_music;
 cvar_t	*background_music_vol;
@@ -129,10 +143,6 @@ cvar_t  *cl_noblood;
 //beam color for disruptor
 cvar_t  *cl_disbeamclr;
 
-//IRC
-cvar_t	*cl_IRC_connect_at_startup;
-cvar_t	*cl_IRC_server;
-
 //Stats
 cvar_t  *cl_stats_server;
 
@@ -154,7 +164,7 @@ extern	char map_music[128];
 extern void RS_FreeAllScripts(void);
 
 typedef struct _PLAYERINFO {
-	char playername[16];
+	char playername[PLAYERNAME_SIZE]; // TODO: verify 2010-11 was 16
 	int ping;
 	int score;
 } PLAYERINFO;
@@ -175,6 +185,19 @@ SERVERINFO servers[64];
 int numServers = 0;
 extern unsigned int starttime;
 
+static size_t szr; // just for unused result warnings
+
+//
+// Fonts
+//
+FNT_auto_t			CL_gameFont;
+static struct FNT_auto_s	_CL_gameFont;
+FNT_auto_t			CL_centerFont;
+static struct FNT_auto_s	_CL_centerFont;
+FNT_auto_t			CL_consoleFont;
+static struct FNT_auto_s	_CL_consoleFont;
+
+
 //======================================================================
 
 
@@ -195,8 +218,8 @@ void CL_WriteDemoMessage (void)
 	if (!swlen)
 		return;
 
-	fwrite (&swlen, 4, 1, cls.demofile);
-	fwrite (net_message.data+8,	len, 1, cls.demofile);
+	szr = fwrite (&swlen, 4, 1, cls.demofile);
+	szr = fwrite (net_message.data+8,	len, 1, cls.demofile);
 }
 
 
@@ -219,7 +242,7 @@ void CL_Stop_f (void)
 
 // finish up
 	len = -1;
-	fwrite (&len, 4, 1, cls.demofile);
+	szr = fwrite (&len, 4, 1, cls.demofile);
 	fclose (cls.demofile);
 	cls.demofile = NULL;
 	cls.demorecording = false;
@@ -284,7 +307,7 @@ void CL_Record_f (void)
 	//
 	// write out messages to hold the startup information
 	//
-	SZ_Init (&buf, buf_data, sizeof(buf_data));
+	SZ_Init (&buf, (byte *)buf_data, sizeof(buf_data));
 	SZ_SetName ( &buf, "CL_Record_f", false );
 
 	// send the serverdata
@@ -305,8 +328,8 @@ void CL_Record_f (void)
 			if (buf.cursize + strlen (cl.configstrings[i]) + 32 > buf.maxsize)
 			{	// write it out
 				len = LittleLong (buf.cursize);
-				fwrite (&len, 4, 1, cls.demofile);
-				fwrite (buf.data, buf.cursize, 1, cls.demofile);
+				szr = fwrite (&len, 4, 1, cls.demofile);
+				szr = fwrite (buf.data, buf.cursize, 1, cls.demofile);
 				buf.cursize = 0;
 			}
 
@@ -328,8 +351,8 @@ void CL_Record_f (void)
 		if (buf.cursize + 64 > buf.maxsize)
 		{	// write it out
 			len = LittleLong (buf.cursize);
-			fwrite (&len, 4, 1, cls.demofile);
-			fwrite (buf.data, buf.cursize, 1, cls.demofile);
+			szr = fwrite (&len, 4, 1, cls.demofile);
+			szr = fwrite (buf.data, buf.cursize, 1, cls.demofile);
 			buf.cursize = 0;
 		}
 
@@ -343,8 +366,8 @@ void CL_Record_f (void)
 	// write it to the demo file
 
 	len = LittleLong (buf.cursize);
-	fwrite (&len, 4, 1, cls.demofile);
-	fwrite (buf.data, buf.cursize, 1, cls.demofile);
+	szr = fwrite (&len, 4, 1, cls.demofile);
+	szr = fwrite (buf.data, buf.cursize, 1, cls.demofile);
 
 	// the rest of the demo file will be individual frames
 }
@@ -398,7 +421,7 @@ void CL_Setenv_f( void )
 			strcat( buffer, " " );
 		}
 
-		putenv( buffer );
+		_putenv( buffer );
 	}
 	else if ( argc == 2 )
 	{
@@ -478,10 +501,8 @@ void CL_Drop (void)
 {
 	if (cls.state == ca_uninitialized)
 		return;
-	if (cls.state == ca_disconnected)
-		return;
-
-	CL_Disconnect ();
+	if (cls.state != ca_disconnected)
+		CL_Disconnect ();
 
 	// drop loading plaque unless this is the initial game start
 	if (cls.disable_servercount != -1)
@@ -701,6 +722,7 @@ This is also called on Com_Error, so it shouldn't cause any errors
 void CL_Disconnect (void)
 {
 	byte	final[32];
+	int repeat;
 
 	if (cls.state == ca_disconnected)
 		return;
@@ -728,9 +750,8 @@ void CL_Disconnect (void)
 	// send a disconnect message to the server
 	final[0] = clc_stringcmd;
 	strcpy ((char *)final+1, "disconnect");
-	Netchan_Transmit (&cls.netchan, strlen(final), final);
-	Netchan_Transmit (&cls.netchan, strlen(final), final);
-	Netchan_Transmit (&cls.netchan, strlen(final), final);
+	for ( repeat = 3 ; repeat-- ;)
+		Netchan_Transmit( &cls.netchan, (int)strlen( (char*)final ), final );
 
 	CL_ClearState ();
 
@@ -744,6 +765,12 @@ void CL_Disconnect (void)
 	}
 
 	cls.state = ca_disconnected;
+
+/*
+** From Max's timedemo benchmarks:
+**	For automated test runs using demos, can exit here by calling CL_Quit_f()
+*/
+
 }
 
 void CL_Disconnect_f (void)
@@ -761,6 +788,8 @@ packet <destination> <contents>
 Contents allows \n escape character
 ====================
 */
+#if 0
+// disabled, not used
 void CL_Packet_f (void)
 {
 	char	send[2048];
@@ -803,6 +832,7 @@ void CL_Packet_f (void)
 
 	NET_SendPacket (NS_CLIENT, out-send, send, adr);
 }
+#endif
 
 /*
 =================
@@ -1080,7 +1110,8 @@ void CL_ConnectionlessPacket (void)
 
 	Com_Printf ("%s: %s\n", NET_AdrToString (net_from), c);
 
-	if(!strncmp(c, "servers", 7)) {
+	if(!strncmp(c, "servers", 7)) 
+	{
 		CL_ParseGetServersResponse();
 		return;
 	}
@@ -1244,9 +1275,10 @@ void CL_FixUpGender(void)
 	char *p;
 	char sk[80];
 
-	if (gender_auto->value) {
-
-		if (gender->modified) {
+	if (gender_auto->value) 
+	{
+		if (gender->modified) 
+		{
 			// was set directly, don't override the user
 			gender->modified = false;
 			return;
@@ -1255,9 +1287,9 @@ void CL_FixUpGender(void)
 		strncpy(sk, skin->string, sizeof(sk) - 1);
 		if ((p = strchr(sk, '/')) != NULL)
 			*p = 0;
-		if (Q_stricmp(sk, "male") == 0 || Q_stricmp(sk, "cyborg") == 0)
+		if (Q_strcasecmp(sk, "male") == 0 || Q_strcasecmp(sk, "cyborg") == 0)
 			Cvar_Set ("gender", "male");
-		else if (Q_stricmp(sk, "female") == 0 || Q_stricmp(sk, "crackhor") == 0)
+		else if (Q_strcasecmp(sk, "female") == 0 || Q_strcasecmp(sk, "crackhor") == 0)
 			Cvar_Set ("gender", "female");
 		else
 			Cvar_Set ("gender", "none");
@@ -1326,21 +1358,39 @@ void CL_RequestNextDownload (void)
 		precache_check = CS_MODELS+2; // 0 isn't used
 		if (allow_download_maps->value)
 			if (!CL_CheckOrDownloadFile(cl.configstrings[CS_MODELS+1]))
-				return; // started a download		
+				return; // started a download
 	}
 
-redoSkins:;
-	if (precache_check >= CS_MODELS && precache_check < CS_MODELS+MAX_MODELS) {
-		if (allow_download_models->value) {
-			while (precache_check < CS_MODELS+MAX_MODELS &&
-				cl.configstrings[precache_check][0]) {
+redoSkins:
+	if (precache_check >= CS_MODELS && precache_check < CS_MODELS+MAX_MODELS) 
+	{
+		if (allow_download_models->value) 
+		{			
+			while (precache_check < CS_MODELS+MAX_MODELS &&	
+				cl.configstrings[precache_check][0]) 
+			{
 				if (cl.configstrings[precache_check][0] == '*' ||
-					cl.configstrings[precache_check][0] == '#') {
+					cl.configstrings[precache_check][0] == '#') 
+				{
 					precache_check++;
 					continue;
 				}
-				if (precache_model_skin == 0) {
-					if (!CL_CheckOrDownloadFile(cl.configstrings[precache_check])) {
+				//do not download player models from this section
+				else if (cl.configstrings[precache_check][0] == 'p' &&
+					cl.configstrings[precache_check][1] == 'l' &&
+					cl.configstrings[precache_check][2] == 'a' &&
+					cl.configstrings[precache_check][3] == 'y' &&
+					cl.configstrings[precache_check][4] == 'e' &&
+					cl.configstrings[precache_check][5] == 'r' &&
+					cl.configstrings[precache_check][6] == 's')
+				{
+					precache_check++;
+					continue;
+				}
+				if (precache_model_skin == 0) 
+				{
+					if (!CL_CheckOrDownloadFile(cl.configstrings[precache_check])) 
+					{
 						precache_model_skin = 1;
 						return; // started a download
 					}
@@ -1348,15 +1398,17 @@ redoSkins:;
 				}
 
 				// checking for skins in the model
-				if (!precache_model) {
-
+				if (!precache_model) 
+				{
 					FS_LoadFile (cl.configstrings[precache_check], (void **)&precache_model);
-					if (!precache_model) {
+					if (!precache_model) 
+					{
 						precache_model_skin = 0;
 						precache_check++;
 						continue; // couldn't load it
 					}
-					if (LittleLong(*(unsigned *)precache_model) != IDALIASHEADER) {
+					if (LittleLong(*(unsigned *)precache_model) != IDALIASHEADER) 
+					{
 						// not an alias model
 						FS_FreeFile(precache_model);
 						precache_model = 0;
@@ -1365,7 +1417,8 @@ redoSkins:;
 						continue;
 					}
 					pheader = (dmdl_t *)precache_model;
-					if (LittleLong (pheader->version) != ALIAS_VERSION) {
+					if (LittleLong (pheader->version) != ALIAS_VERSION) 
+					{
 						precache_check++;
 						precache_model_skin = 0;
 						continue; // couldn't load it
@@ -1374,16 +1427,19 @@ redoSkins:;
 
 				pheader = (dmdl_t *)precache_model;
 
-				while (precache_model_skin - 1 < LittleLong(pheader->num_skins)) {
+				while (precache_model_skin - 1 < LittleLong(pheader->num_skins)) 
+				{
 					if (!CL_CheckOrDownloadFile((char *)precache_model +
 						LittleLong(pheader->ofs_skins) +
-						(precache_model_skin - 1)*MAX_SKINNAME)) {
+						(precache_model_skin - 1)*MAX_SKINNAME)) 
+					{
 						precache_model_skin++;
 						return; // started a download
 					}
 					precache_model_skin++;
 				}
-				if (precache_model) {
+				if (precache_model) 
+				{
 					FS_FreeFile(precache_model);
 					precache_model = 0;
 				}
@@ -1401,13 +1457,17 @@ redoSkins:;
 		precache_check = CS_SOUNDS;
 	}
 
-	if (precache_check >= CS_SOUNDS && precache_check < CS_SOUNDS+MAX_SOUNDS) {
-		if (allow_download_sounds->value) {
+	if (precache_check >= CS_SOUNDS && precache_check < CS_SOUNDS+MAX_SOUNDS) 
+	{
+		if (allow_download_sounds->value) 
+		{
 			if (precache_check == CS_SOUNDS)
 				precache_check++; // zero is blank
-			while (precache_check < CS_SOUNDS+MAX_SOUNDS &&
-				cl.configstrings[precache_check][0]) {
-				if (cl.configstrings[precache_check][0] == '*') {
+			while (precache_check < CS_SOUNDS+MAX_SOUNDS &&	
+				cl.configstrings[precache_check][0]) 
+			{
+				if (cl.configstrings[precache_check][0] == '*') 
+				{
 					precache_check++;
 					continue;
 				}
@@ -1418,30 +1478,33 @@ redoSkins:;
 		}
 		precache_check = CS_IMAGES;
 	}
-	if (precache_check >= CS_IMAGES && precache_check < CS_IMAGES+MAX_IMAGES) {
+	if (precache_check >= CS_IMAGES && precache_check < CS_IMAGES+MAX_IMAGES) 
+	{
 		if (precache_check == CS_IMAGES)
 			precache_check++; // zero is blank
 		while (precache_check < CS_IMAGES+MAX_IMAGES &&
-			cl.configstrings[precache_check][0]) {
+			cl.configstrings[precache_check][0]) 
+		{
 			Com_sprintf(fn, sizeof(fn), "pics/%s.tga", cl.configstrings[precache_check++]);
 			if (!CL_CheckOrDownloadFile(fn))
 				return; // started a download
 		}
 		precache_check = CS_PLAYERSKINS;
 	}
-	// skins are special, since a player has three things to download:
-	// model, weapon model and skin
-	// so precache_check is now *3
-	if (precache_check >= CS_PLAYERSKINS && precache_check < CS_PLAYERSKINS + MAX_CLIENTS * PLAYER_MULT) {
-		if (allow_download_players->value) {
-			while (precache_check < CS_PLAYERSKINS + MAX_CLIENTS * PLAYER_MULT) {
+	if (precache_check >= CS_PLAYERSKINS && precache_check < CS_PLAYERSKINS + MAX_CLIENTS * PLAYER_MULT) 
+	{
+		if (allow_download_players->value) 
+		{
+			while (precache_check < CS_PLAYERSKINS + MAX_CLIENTS * PLAYER_MULT) 
+			{
 				int i, n;
 				char model[MAX_QPATH], skin[MAX_QPATH], *p;
 
 				i = (precache_check - CS_PLAYERSKINS)/PLAYER_MULT;
 				n = (precache_check - CS_PLAYERSKINS)%PLAYER_MULT;
 
-				if (!cl.configstrings[CS_PLAYERSKINS+i][0]) {
+				if (!cl.configstrings[CS_PLAYERSKINS+i][0]) 
+				{
 					precache_check = CS_PLAYERSKINS + (i + 1) * PLAYER_MULT;
 					continue;
 				}
@@ -1454,57 +1517,63 @@ redoSkins:;
 				p = strchr(model, '/');
 				if (!p)
 					p = strchr(model, '\\');
-				if (p) {
+				if (p) 
+				{
 					*p++ = 0;
 					strcpy(skin, p);
 				} else
 					*skin = 0;
 
-				switch (n) {
-				case 0: // model
-					Com_sprintf(fn, sizeof(fn), "players/%s/tris.md2", model);
-					if (!CL_CheckOrDownloadFile(fn)) {
-						precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 1;
-						return; // started a download
-					}
-					n++;
-					/*FALL THROUGH*/
+				switch (n) 
+				{
+					case 0: // model
+						Com_sprintf(fn, sizeof(fn), "players/%s/tris.iqm", model);
+						if (!CL_CheckOrDownloadFile(fn)) 
+						{
+							precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 1;
+							return; // started a download
+						}
+						n++;
+						/*FALL THROUGH*/
 
-				case 1: // weapon model
-					Com_sprintf(fn, sizeof(fn), "players/%s/weapon.md2", model);
-					if (!CL_CheckOrDownloadFile(fn)) {
-						precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 2;
-						return; // started a download
-					}
-					n++;
-					/*FALL THROUGH*/
+					case 1: // weapon model
+						Com_sprintf(fn, sizeof(fn), "players/%s/weapon.iqm", model);
+						if (!CL_CheckOrDownloadFile(fn)) {
+							precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 2;
+							return; // started a download
+						}
+						n++;
+						/*FALL THROUGH*/
 
-				case 2: // weapon skin
-					Com_sprintf(fn, sizeof(fn), "players/%s/weapon.tga", model);
-					if (!CL_CheckOrDownloadFile(fn)) {
-						precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 3;
-						return; // started a download
-					}
-					n++;
-					/*FALL THROUGH*/
+					case 2: // weapon skin
+						Com_sprintf(fn, sizeof(fn), "players/%s/weapon.jpg", model);
+						if (!CL_CheckOrDownloadFile(fn)) 
+						{
+							precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 3;
+							return; // started a download
+						}
+						n++;
+						/*FALL THROUGH*/
+				
+					case 3: // skin
+						Com_sprintf(fn, sizeof(fn), "players/%s/%s.jpg", model, skin);
+						if (!CL_CheckOrDownloadFile(fn)) 
+						{
+							precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 4;
+							return; // started a download
+						}
+						n++;
+						/*FALL THROUGH*/
 
-				case 3: // skin
-					Com_sprintf(fn, sizeof(fn), "players/%s/%s.jpg", model, skin);
-					if (!CL_CheckOrDownloadFile(fn)) {
-						precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 4;
-						return; // started a download
-					}
-					n++;
-					/*FALL THROUGH*/
-
-				case 4: // skin_i
-					Com_sprintf(fn, sizeof(fn), "players/%s/%s_i.jpg", model, skin);
-					if (!CL_CheckOrDownloadFile(fn)) {
-						precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 5;
-						return; // started a download
-					}
-					// move on to next model
-					precache_check = CS_PLAYERSKINS + (i + 1) * PLAYER_MULT;
+					case 4: // skin_i
+						Com_sprintf(fn, sizeof(fn), "players/%s/%s_i.jpg", model, skin);
+						if (!CL_CheckOrDownloadFile(fn)) 
+						{
+							precache_check = CS_PLAYERSKINS + i * PLAYER_MULT + 5;
+							return; // started a download
+						}					
+						// move on to next model
+						precache_check = CS_PLAYERSKINS + (i + 1) * PLAYER_MULT;
 				}
 			}
 		}
@@ -1512,21 +1581,26 @@ redoSkins:;
 		precache_check = ENV_CNT;
 	}
 
-	if (precache_check == ENV_CNT) {
+	if (precache_check == ENV_CNT) 
+	{
 		precache_check = ENV_CNT + 1;
 
 		CM_LoadMap (cl.configstrings[CS_MODELS+1], true, &map_checksum);
 
-		if (map_checksum != atoi(cl.configstrings[CS_MAPCHECKSUM])) {
+		if (map_checksum != atoi(cl.configstrings[CS_MAPCHECKSUM])) 
+		{
 			Com_Error (ERR_DROP, "Local map version differs from server: %i != '%s'\n",
 				map_checksum, cl.configstrings[CS_MAPCHECKSUM]);
 			return;
 		}
 	}
 
-	if (precache_check > ENV_CNT && precache_check < TEXTURE_CNT) {
-			if (allow_download->value && allow_download_maps->value) {
-				while (precache_check < TEXTURE_CNT) {
+	if (precache_check > ENV_CNT && precache_check < TEXTURE_CNT) 
+	{
+			if (allow_download->value && allow_download_maps->value) 
+			{
+				while (precache_check < TEXTURE_CNT) 
+				{
 					int n = precache_check++ - ENV_CNT - 1;
 
 					Com_sprintf(fn, sizeof(fn), "env/%s%s.tga",
@@ -1537,19 +1611,23 @@ redoSkins:;
 			}
 			precache_check = TEXTURE_CNT;
 	}
-	if (precache_check == TEXTURE_CNT) {
+	if (precache_check == TEXTURE_CNT) 
+	{
 		precache_check = TEXTURE_CNT+1;
 		precache_tex = 0;
 	}
 
 	// confirm existance of textures, download any that don't exist
-	if (precache_check == TEXTURE_CNT+1) {
+	if (precache_check == TEXTURE_CNT+1) 
+	{
 		// from qcommon/cmodel.c
 		extern int			numtexinfo;
 		extern mapsurface_t	map_surfaces[];
 
-		if (allow_download->value && allow_download_maps->value) {
-			while (precache_tex < numtexinfo) {
+		if (allow_download->value && allow_download_maps->value) 
+		{
+			while (precache_tex < numtexinfo) 
+			{
 				char fn[MAX_OSPATH];
 
 				sprintf(fn, "textures/%s.tga", map_surfaces[precache_tex++].rname);
@@ -1561,15 +1639,17 @@ redoSkins:;
 	}
 
 	//get map related scripts
-	if (precache_check == SCRIPT_CNT) { 
+	if (precache_check == SCRIPT_CNT) 
+	{
 		precache_check = SCRIPT_CNT+1;
-		if (allow_download_maps->value) {			
-
+		if (allow_download_maps->value) 
+		{
 			//get fog files
 			COM_StripExtension ( cl.configstrings[CS_MODELS+1], fn );
 
 			//remove "maps/" from string
-			for(i = 5, j = 0; i < strlen(fn); i++, j++) {
+			for(i = 5, j = 0; i < strlen(fn); i++, j++) 
+			{
 				map[j] = fn[i];
 			}
 			map[i-5] = 0;
@@ -1577,44 +1657,45 @@ redoSkins:;
 			Com_sprintf(script, sizeof(script), "maps/scripts/%s.fog", map);
 			if (!CL_CheckOrDownloadFile(script))
 				return; // started a download
-		}		
+		}
 	}
 
-	if (precache_check == SCRIPT_CNT+1) { 
+	if (precache_check == SCRIPT_CNT+1) 
+	{
 		precache_check = SCRIPT_CNT+2;
-		if (allow_download_maps->value) {			
-
+		if (allow_download_maps->value) 
+		{
 			//get mus files
 			COM_StripExtension ( cl.configstrings[CS_MODELS+1], fn );
 
 			//remove "maps/" from string
-			for(i = 5, j = 0; i < strlen(fn); i++, j++) {
+			for(i = 5, j = 0; i < strlen(fn); i++, j++) 
 				map[j] = fn[i];
-			}
 			map[i-5] = 0;
 
 			Com_sprintf(script, sizeof(script), "maps/scripts/%s.mus", map);
 			if (!CL_CheckOrDownloadFile(script))
 				return; // started a download
-		}		
+		}
 	}
 
-	if (precache_check == SCRIPT_CNT+2) { 
+	if (precache_check == SCRIPT_CNT+2) 
+	{
 		precache_check = SCRIPT_CNT+3;
-		if (allow_download_maps->value) {						
+		if (allow_download_maps->value) 
+		{
 			//get rscript files
 			COM_StripExtension ( cl.configstrings[CS_MODELS+1], fn );
 
 			//remove "maps/" from string
-			for(i = 5, j = 0; i < strlen(fn); i++, j++) {
+			for(i = 5, j = 0; i < strlen(fn); i++, j++)
 				map[j] = fn[i];
-			}
 			map[i-5] = 0;
 
 			Com_sprintf(script, sizeof(script), "scripts/maps/%s.rscript", map);
 			if (!CL_CheckOrDownloadFile(script))
 				return; // started a download
-		}		
+		}
 	}
 
 //ZOID
@@ -1638,7 +1719,8 @@ void CL_Precache_f (void)
 {
 	//Yet another hack to let old demos work
 	//the old precache sequence
-	if (Cmd_Argc() < 2) {
+	if (Cmd_Argc() < 2) 
+	{
 		unsigned	map_checksum;		// for detecting cheater maps
 
 		CM_LoadMap (cl.configstrings[CS_MODELS+1], true, &map_checksum);
@@ -1655,9 +1737,13 @@ void CL_Precache_f (void)
 	CL_RequestNextDownload();
 }
 
- #ifdef __unix__
- void CL_Shell_f (void) {
-	if(Cmd_Argc() < 2) {
+/*
+ * TODO: Removing pending review. May not be safe.
+#if defined UNIX_VARIANT
+void CL_Shell_f (void)
+{
+	if(Cmd_Argc() < 2)
+	{
 		Com_Printf("Usage: shell command");
 		return;
 	}
@@ -1669,6 +1755,7 @@ void CL_Precache_f (void)
 	pclose(fp);
  }
  #endif
+*/
 
 /*
 =================
@@ -1680,15 +1767,11 @@ void CL_InitLocal (void)
 	cls.state = ca_disconnected;
 	cls.realtime = Sys_Milliseconds ();
 
-	CL_InitInput ();	
+	CL_InitInput ();
 
 	CL_InitHttpDownload();
 
-	cl_IRC_connect_at_startup = Cvar_Get("cl_IRC_connect_at_startup", "1", CVAR_ARCHIVE);
-	cl_IRC_server = Cvar_Get("cl_IRC_server", "irc.efnet.org", CVAR_ARCHIVE);
-
-	if(cl_IRC_connect_at_startup->value)
-		CL_InitIRC();
+	CL_IRCSetup( );
 
 	adr0 = Cvar_Get( "adr0", "", CVAR_ARCHIVE );
 	adr1 = Cvar_Get( "adr1", "", CVAR_ARCHIVE );
@@ -1725,6 +1808,7 @@ void CL_InitLocal (void)
 	cl_brass = Cvar_Get ("cl_brass", "1", CVAR_ARCHIVE);
 	cl_playtaunts = Cvar_Get ("cl_playtaunts", "1", CVAR_ARCHIVE);
 	cl_centerprint = Cvar_Get ("cl_centerprint", "1", CVAR_ARCHIVE);
+	cl_precachecustom = Cvar_Get ("cl_precachecustom", "0", CVAR_ARCHIVE);
 
 	cl_paindist = Cvar_Get ("cl_paindist", "1", CVAR_ARCHIVE);
 	cl_explosiondist = Cvar_Get ("cl_explosiondist", "1", CVAR_ARCHIVE);
@@ -1740,11 +1824,13 @@ void CL_InitLocal (void)
 	freelook = Cvar_Get( "freelook", "0", CVAR_ARCHIVE );
 	lookspring = Cvar_Get ("lookspring", "0", CVAR_ARCHIVE);
 	lookstrafe = Cvar_Get ("lookstrafe", "0", CVAR_ARCHIVE);
+	m_accel	= Cvar_Get ("m_accel", "1",	CVAR_ARCHIVE);
 	sensitivity = Cvar_Get ("sensitivity", "3", CVAR_ARCHIVE);
+	menu_sensitivity = Cvar_Get("menu_sensitivity", "3", CVAR_ARCHIVE);
 
 	m_smoothing = Cvar_Get("m_smoothing", "0", CVAR_ARCHIVE);
 	m_pitch = Cvar_Get ("m_pitch", "0.022", CVAR_ARCHIVE);
-	m_yaw = Cvar_Get ("m_yaw", "0.022", 0);
+	m_yaw = Cvar_Get ("m_yaw", "0.022", CVAR_ARCHIVE);
 	m_forward = Cvar_Get ("m_forward", "1", 0);
 	m_side = Cvar_Get ("m_side", "1", 0);
 
@@ -1764,6 +1850,9 @@ void CL_InitLocal (void)
 	info_password = Cvar_Get ("password", "", CVAR_USERINFO);
 	info_spectator = Cvar_Get ("spectator", "0", CVAR_USERINFO);
 	name = Cvar_Get ("name", "unnamed", CVAR_USERINFO | CVAR_ARCHIVE);
+	/* */
+	ValidatePlayerName( name->string, (strlen(name->string)+1) );
+	/* */
 	skin = Cvar_Get ("skin", "male/grunt", CVAR_USERINFO | CVAR_ARCHIVE);
 	rate = Cvar_Get ("rate", "25000", CVAR_USERINFO | CVAR_ARCHIVE);	// FIXME
 	msg = Cvar_Get ("msg", "1", CVAR_USERINFO | CVAR_ARCHIVE);
@@ -1774,6 +1863,7 @@ void CL_InitLocal (void)
 	gender->modified = false; // clear this so we know when user sets it manually
 
 	cl_vwep = Cvar_Get ("cl_vwep", "1", CVAR_ARCHIVE);
+	cl_vehicle_huds = Cvar_Get ("cl_vehicle_huds", "1", CVAR_ARCHIVE);
 
 	cl_master = Cvar_Get ("cl_master", "master.corservers.com", CVAR_ARCHIVE);
 	cl_master2 = Cvar_Get ("cl_master2", "master2.corservers.com", CVAR_ARCHIVE);
@@ -1816,12 +1906,13 @@ void CL_InitLocal (void)
 
 	Cmd_AddCommand ("download", CL_Download_f);
 
-	#ifdef __unix__
-	Cmd_AddCommand ("shell", CL_Shell_f);
-	#endif
+// TODO: Removing this pending review. it may not be safe.
+//#if defined UNIX_VARIANT
+//	Cmd_AddCommand ("shell", CL_Shell_f);
+//#endif
 
 	Cmd_AddCommand ("irc_connect", CL_InitIRC);
-	Cmd_AddCommand ("irc_quit", CL_IRCShutdown);
+	Cmd_AddCommand ("irc_quit", CL_IRCInitiateShutdown);
 	Cmd_AddCommand ("irc_say", CL_IRCSay);
 
 	//
@@ -1886,6 +1977,10 @@ void CL_InitLocal (void)
 	R_RegisterPic("m_main_mont3");
 	R_RegisterPic("m_main_mont4");
 	R_RegisterPic("m_main_mont5");
+	R_RegisterPic("hud_bomber");
+	R_RegisterPic("hud_strafer");
+	R_RegisterPic("hud_hover");
+	R_RegisterPic("blood_ring");
 }
 
 
@@ -1905,7 +2000,7 @@ void CL_WriteConfiguration (void)
 	if (cls.state == ca_uninitialized)
 		return;
 
-	Com_sprintf (path, sizeof(path),"%s/config.cfg",FS_Gamedir());
+	FS_FullWritePath( path, sizeof(path), "config.cfg");
 	f = fopen (path, "w");
 	if (!f)
 	{
@@ -1913,7 +2008,7 @@ void CL_WriteConfiguration (void)
 		return;
 	}
 
-	fprintf (f, "// generated by quake, do not modify\n");
+	fprintf (f, "// generated by Alien Arena. Use autoexec.cfg for custom settings.\n");
 	Key_WriteBindings (f);
 	fclose (f);
 
@@ -1974,6 +2069,13 @@ void CL_FixCvarCheats (void)
 	// make sure they are all set to the proper values
 	for (i=0, var = cheatvars ; i<numcheatvars ; i++, var++)
 	{
+		if ( cl.attractloop &&
+			(!strcmp( var->name, "timedemo" )
+			||
+			!strcmp( var->name, "timescale"))
+			)
+			continue; // allow these when running a .dm2 demo
+
 		if ( strcmp (var->var->string, var->value) )
 		{
 			Cvar_Set (var->name, var->value);
@@ -2127,16 +2229,31 @@ void CL_Init (void)
 	if (dedicated->value)
 		return;		// nothing running on the client
 
+	// Initialise fonts
+	CL_gameFont = &_CL_gameFont;
+	FNT_AutoInit( CL_gameFont , "default" , 0 , 65 , 8 , 48 );
+	CL_gameFont->faceVar = Cvar_Get( "fnt_game" , "creativeblock" , CVAR_ARCHIVE );
+	CL_gameFont->sizeVar = Cvar_Get( "fnt_game_size" , "0" , CVAR_ARCHIVE );
+	FNT_AutoRegister( CL_gameFont );
+
+	CL_centerFont = &_CL_centerFont;
+	FNT_AutoInit( CL_centerFont , "default" , 0 , 45 , 16 , 64 );
+	CL_centerFont->faceVar = CL_gameFont->faceVar;
+	CL_centerFont->sizeVar = Cvar_Get( "fnt_center_size" , "0" , CVAR_ARCHIVE );
+	FNT_AutoRegister( CL_centerFont );
+
+	CL_consoleFont = &_CL_consoleFont;
+	FNT_AutoInit( CL_consoleFont , "default" , 0 , 52 , 8 , 48 );
+	CL_consoleFont->faceVar = Cvar_Get( "fnt_console" , "freemono" , CVAR_ARCHIVE );
+	CL_consoleFont->sizeVar = Cvar_Get( "fnt_console_size" , "0" , CVAR_ARCHIVE );
+	FNT_AutoRegister( CL_consoleFont );
+
 	// all archived variables will now be loaded
 
-	Con_Init ();
-#if defined __unix__ || defined __sgi
+	CON_Initialise( );
+
+	VID_Init ();
 	S_Init ();
-	VID_Init ();
-#else
-	VID_Init ();
-	S_Init ();	// sound must be initialized after window is created
-#endif
 
 	V_Init ();
 
@@ -2151,10 +2268,14 @@ void CL_Init (void)
 	CL_InitLocal ();
 	IN_Init ();
 
-//	Cbuf_AddText ("exec autoexec.cfg\n");
-	FS_ExecAutoexec ();
+	FS_ExecAutoexec (); // add commands from autoexec.cfg
 	Cbuf_Execute ();
 
+	if ( name && name->string[0] )
+	{
+		ValidatePlayerName( name->string, (strlen(name->string)+1) );
+	}
+
 }
 
 
@@ -2177,13 +2298,14 @@ void CL_Shutdown(void)
 	}
 	isdown = true;
 
+	CL_IRCInitiateShutdown();
 	CL_ShutdownHttpDownload();
-	CL_IRCShutdown();
 	CL_WriteConfiguration ();
 
 	S_Shutdown();
 	IN_Shutdown ();
-	VID_Shutdown();	
+	VID_Shutdown();
+	CL_IRCWaitShutdown( );
 
 	NET_Shutdown();
 
