@@ -19,6 +19,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 // cl_parse.c  -- parse a message received from the server
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "client.h"
 
 char *svc_strings[256] =
@@ -48,6 +52,8 @@ char *svc_strings[256] =
 	"svc_frame"
 };
 
+static size_t szr; // just for unused result warnings
+
 /*
 ==============
 Q_strncpyz
@@ -55,10 +61,11 @@ Q_strncpyz
 */
 void Q_strncpyz( char *dest, const char *src, size_t size )
 {
-#ifdef HAVE_STRLCPY
+#if defined HAVE_STRLCPY
 	strlcpy( dest, src, size );
 #else
-	if( size ) {
+	if( size )
+	{
 		while( --size && (*dest++ = *src++) );
 		*dest = '\0';
 	}
@@ -69,10 +76,7 @@ void Q_strncpyz( char *dest, const char *src, size_t size )
 
 void CL_DownloadFileName(char *dest, int destlen, char *fn)
 {
-	if (strncmp(fn, "players", 7) == 0)
-		Com_sprintf (dest, destlen, "%s/%s", BASEDIRNAME, fn);
-	else
-		Com_sprintf (dest, destlen, "%s/%s", FS_Gamedir(), fn);
+	Com_sprintf (dest, destlen, "%s/%s", FS_Gamedir(), fn);
 }
 
 /*
@@ -88,7 +92,7 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 	FILE *fp;
 	char	name[MAX_OSPATH];
 	char	shortname[MAX_OSPATH];
-	qboolean	modelskin = false;
+	char    shortname2[MAX_OSPATH];
 	qboolean	jpg = false;
 
 	if (strstr (filename, ".."))
@@ -96,39 +100,38 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 		Com_Printf ("Refusing to download a path with ..\n");
 		return true;
 	}
-	
-    //if pcx, strip extension and change to .tga, we never dl .pcx anymore
-    if(filename[strlen(filename)-1] == 'x') {
-		modelskin = true;
-		//if this is coming from a player model don't bother
-		if(filename[0] != 'm' && filename[0] != 'v')
+
+    //if pcx, strip extension and change to .jpg, we do not use .pcx anymore
+    if(filename[strlen(filename)-1] == 'x')
+	{
+		//Filter out any potentially screwed up texture paths(meshes only reside in these folders)
+		if (strncmp(filename, "models", 6) && strncmp(filename, "vehicles", 8)
+			&& strncmp(filename, "maps", 4))
 			return true;
+
 		COM_StripExtension ( filename, shortname );
-		sprintf(filename, "%s.tga", shortname);
+		sprintf(filename, "%s.jpg", shortname);
 	}
 
-	//if jpg, be sure to also try tga (player skin situation)
+	//if jpg, be sure to also try tga
     if(filename[strlen(filename)-2] == 'p' && filename[strlen(filename)-1] == 'g')
 		jpg = true;
-	
-	if (FS_LoadFile (filename, NULL) != -1)	{
+
+	if (FS_LoadFile (filename, NULL) != -1)
+	{
 		// it exists, no need to download
 		return true;
 	}
-	else if(modelskin){
-		//try for .jpg
+
+	if(jpg)
+	{
+		//didn't find .jpg skin, try for .tga skin
+		//check for presence of a local .tga(but leave filename as original extension)
+		//if we find a .tga, don't try to download anything
 		COM_StripExtension ( filename, shortname );
-		sprintf(filename, "%s.jpg", shortname);	
-		if (FS_LoadFile (filename, NULL) != -1)	{
-			// it exists, no need to download
-			return true;
-		}
-	}
-	else if(jpg) { //didn't find .jpg skin, try for .tga skin, convoluted, yes indeed.
-		//try for .tga
-		COM_StripExtension ( filename, shortname );
-		sprintf(filename, "%s.tga", shortname);	
-		if (FS_LoadFile (filename, NULL) != -1)	{
+		sprintf(shortname2, "%s.tga", shortname);
+		if (FS_LoadFile (shortname2, NULL) != -1)
+		{
 			// it exists, no need to download
 			return true;
 		}
@@ -143,9 +146,8 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 	strcat (cls.downloadtempname, ".tmp");
 
 	// attempt an http download if available(never try to dl game model skins here)
-	if(cls.downloadurl[0] && CL_HttpDownload())  
+	if(cls.downloadurl[0] && CL_HttpDownload())
 			return false;
-	
 
 //ZOID
 	// check to see if we already have a tmp for this file, if so, try to resume
@@ -155,11 +157,11 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 //	FS_CreatePath (name);
 
 	fp = fopen (name, "r+b");
-	if (fp) { // it exists
+	if (fp)
+	{ // it exists
 		int len;
-		fseek(fp, 0, SEEK_END);
-		len = ftell(fp);
 
+		len = FS_filelength( fp );
 		cls.download = fp;
 
 		// give the server an offset to start the download
@@ -167,7 +169,8 @@ qboolean	CL_CheckOrDownloadFile (char *filename)
 		MSG_WriteByte (&cls.netchan.message, clc_stringcmd);
 		MSG_WriteString (&cls.netchan.message,
 			va("download %s %i", cls.downloadname, len));
-	} else {
+	} else
+	{
 		Com_Printf ("Downloading %s\n", cls.downloadname);
 		MSG_WriteByte (&cls.netchan.message, clc_stringcmd);
 		MSG_WriteString (&cls.netchan.message,
@@ -191,7 +194,8 @@ void	CL_Download_f (void)
 {
 	char filename[MAX_OSPATH];
 
-	if (Cmd_Argc() != 2) {
+	if (Cmd_Argc() != 2)
+	{
 		Com_Printf("Usage: download <filename>\n");
 		return;
 	}
@@ -267,7 +271,7 @@ void CL_ParseDownload (void)
 	if (size < 0) //fix issues with bad data being dl'd
 	{
 		Com_Printf ("Server does not have file %s.\n", cls.downloadname);
-		
+
 		//nuke the temp filename, we don't want that getting left around.
 		cls.downloadtempname[0] = 0;
 		cls.downloadname[0] = 0;
@@ -288,7 +292,7 @@ void CL_ParseDownload (void)
 		CL_DownloadFileName(name, sizeof(name), cls.downloadtempname);
 
 		FS_CreatePath (name);
- 
+
 		cls.download = fopen (name, "wb");
 		if (!cls.download)
 		{
@@ -299,7 +303,7 @@ void CL_ParseDownload (void)
 		}
 	}
 
-	fwrite (net_message.data + net_message.readcount, 1, size, cls.download);
+	szr = fwrite (net_message.data + net_message.readcount, 1, size, cls.download);
 	net_message.readcount += size;
 
 	if (percent != 100)
@@ -352,7 +356,7 @@ CL_ParseServerData
 */
 void CL_ParseServerData (void)
 {
-	extern cvar_t	*fs_gamedirvar;
+	 extern cvar_t	*fs_gamedirvar;
 	char	*str;
 	int		i;
 
@@ -381,6 +385,10 @@ void CL_ParseServerData (void)
 	str = MSG_ReadString (&net_message);
 	strncpy (cl.gamedir, str, sizeof(cl.gamedir)-1);
 
+	// 2010-11 TODO: make sense of this.
+	//  changing game from server will require updating file system search paths
+	//    and other things.
+
 	// set gamedir
 	if ((*str && (!fs_gamedirvar->string || !*fs_gamedirvar->string || strcmp(fs_gamedirvar->string, str))) || (!*str && (fs_gamedirvar->string || *fs_gamedirvar->string)))
 		Cvar_Set("game", str);
@@ -413,7 +421,7 @@ void CL_ParseBaseline (void)
 
 	memset (&nullstate, 0, sizeof(nullstate));
 
-	newnum = CL_ParseEntityBits (&bits);
+	newnum = CL_ParseEntityBits ( (unsigned *)&bits );
 	es = &cl_entities[newnum].baseline;
 	CL_ParseDelta (&nullstate, es, newnum, bits);
 }
@@ -471,7 +479,8 @@ void CL_LoadClientinfo (clientinfo_t *ci, char *s)
 		ci->model = R_RegisterModel (model_filename);
 		ci->helmet = R_RegisterModel("players/martianenforcer/helmet.md2");
 		// weapon file
-		for (i = 0; i < num_cl_weaponmodels; i++) {
+		for (i = 0; i < num_cl_weaponmodels; i++)
+		{
 			Com_sprintf (weapon_filename, sizeof(weapon_filename), "players/martianenforcer/%s", cl_weaponmodels[i]);
 			ci->weaponmodel[i] = R_RegisterModel(weapon_filename);
 			if (!cl_vwep->value)
@@ -502,14 +511,16 @@ void CL_LoadClientinfo (clientinfo_t *ci, char *s)
 
 		// if don't have a skin, it means that the model didn't have
 		// it, so default
-		if (!ci->skin) {
-			Com_sprintf (skin_filename, sizeof(skin_filename), "players/%s/default.pcx", model_name, skin_name);
-			ci->skin = R_RegisterSkin (skin_filename);
+		if (!ci->skin)
+		{
 			strcpy(skin_name, "default");
+			Com_sprintf (skin_filename, sizeof(skin_filename), "players/%s/default.pcx", model_name);
+			ci->skin = R_RegisterSkin (skin_filename);			
 		}
 
 		// weapon file
-		for (i = 0; i < num_cl_weaponmodels; i++) {
+		for (i = 0; i < num_cl_weaponmodels; i++)
+		{
 			Com_sprintf (weapon_filename, sizeof(weapon_filename), "players/%s/%s", model_name, cl_weaponmodels[i]);
 			ci->weaponmodel[i] = R_RegisterModel(weapon_filename);
 			if (!ci->weaponmodel[i] == 0) {
@@ -535,13 +546,14 @@ void CL_LoadClientinfo (clientinfo_t *ci, char *s)
 		model_filename[i] = tolower(model_filename[i]);
 	while (model_filename[i++]);
 
-	FS_FOpenFile (model_filename, &file); 
-	if(file) {
+	FS_FOpenFile (model_filename, &file);
+	if(file)
+	{
 		//exists
 		fclose(file);
-		ci->lod1 = R_RegisterModel(model_filename);	
+		ci->lod1 = R_RegisterModel(model_filename);
 	}
-	else 
+	else
 		ci->lod1 = NULL;
 
 	Com_sprintf(model_filename, sizeof(model_filename), "players/%s/lod2.md2", model_name);
@@ -550,15 +562,16 @@ void CL_LoadClientinfo (clientinfo_t *ci, char *s)
 		model_filename[i] = tolower(model_filename[i]);
 	while (model_filename[i++]);
 
-	FS_FOpenFile (model_filename, &file); 
-	if(file) {
+	FS_FOpenFile (model_filename, &file);
+	if(file)
+	{
 		//exists
 		fclose(file);
-		ci->lod2 = R_RegisterModel(model_filename);		
+		ci->lod2 = R_RegisterModel(model_filename);
 	}
 	else
 		ci->lod2 = NULL;
-	
+
 	// must have loaded all data types to be valid
 	if (!ci->skin || !ci->icon || !ci->model || !ci->weaponmodel[0])
 	{
@@ -590,7 +603,7 @@ void CL_ParseClientinfo (int player)
 	CL_LoadClientinfo (ci, s);
 }
 
-void CL_ParseTaunt( char *s) 
+void CL_ParseTaunt( char *s)
 {
 	int l, j;
 	char tauntsound[MAX_OSPATH];
@@ -603,16 +616,17 @@ void CL_ParseTaunt( char *s)
 		scr_playericon[j] = tolower(scr_playericon[j]);
 
 	Com_sprintf(scr_playericon, sizeof(scr_playericon), "%s_i", scr_playericon);
-	
-	strcpy( tauntsound, COM_Parse( &s ) );
-	
-	strcpy( scr_playername, COM_Parse( &s ) ); //fix	
 
-	if(cl_playtaunts->value) {
-		S_StartSound (NULL, 0, 0, S_RegisterSound (tauntsound), 1, ATTN_NONE, 0);		
+	strcpy( tauntsound, COM_Parse( &s ) );
+
+	Q_strncpyz2( scr_playername, COM_Parse( &s ), sizeof(scr_playername) );
+
+	if(cl_playtaunts->value)
+	{
+		S_StartSound (NULL, 0, 0, S_RegisterSound (tauntsound), 1, ATTN_NONE, 0);
 		scr_playericonalpha = 2.0;
 	}
-	
+
 }
 
 /*
@@ -650,6 +664,7 @@ void CL_ParseConfigString (void)
 		}
 		else
 		{
+			// Alien Arena client/server protocol depends on MAX_QPATH being 64
 			if (length >= MAX_QPATH)
 				Com_Printf ("WARNING: Configstring %d of length %d exceeds MAX_QPATH.\n", i, length);
 			Q_strncpyz (cl.configstrings[i], s, sizeof(cl.configstrings[i])-1);
@@ -838,7 +853,8 @@ void CL_ParseServerMessage (void)
 		case svc_reconnect:
 			Com_Printf ("Server disconnected, reconnecting\n");
 			// stop download
-				if(cls.download){
+				if(cls.download)
+				{
 					if(cls.downloadhttp)  // clean up http downloads
 						CL_HttpDownloadCleanup();
 					else  // or just stop legacy ones
@@ -854,10 +870,8 @@ void CL_ParseServerMessage (void)
 			if (i == PRINT_CHAT)
 			{
 				S_StartLocalSound ("misc/talk.wav");
-				con.ormask = 128;
 			}
 			Com_Printf ("%s", MSG_ReadString (&net_message));
-			con.ormask = 0;
 			break;
 
 		case svc_centerprint:
