@@ -31,6 +31,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
   */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "client.h"
 #include "qmenu.h"
 
@@ -55,6 +59,7 @@ cvar_t		*scr_debuggraph;
 cvar_t		*scr_graphheight;
 cvar_t		*scr_graphscale;
 cvar_t		*scr_graphshift;
+cvar_t      *scr_timerefcount; // for timerefresh command
 
 cvar_t		*scr_consize;
 
@@ -63,15 +68,8 @@ cvar_t		*cl_drawtimer;
 
 cvar_t		*cl_drawtime;
 
-typedef struct
-{
-	int		x1, y1, x2, y2;
-} dirty_t;
-
-dirty_t		scr_dirty, scr_old_dirty[2];
-
 char		crosshair_pic[MAX_QPATH];
-int			crosshair_width, crosshair_height;
+int		crosshair_width, crosshair_height;
 
 void SCR_TimeRefresh_f (void);
 void SCR_Loading_f (void);
@@ -171,7 +169,7 @@ void SCR_DrawDebugGraph (void)
 
 		if (v < 0)
 			v += scr_graphheight->value * (1+(int)(-v/scr_graphheight->value));
-		h = (int)v % (int)scr_graphheight->value;
+		h = (int)v % scr_graphheight->integer;
 		Draw_Fill (x+w-1-a, y - h, 1,	h, color);
 	}
 }
@@ -223,53 +221,25 @@ void SCR_CenterPrint (char *str)
 
 void SCR_DrawCenterString (void)
 {
-	char	*start;
-	int		l;
-	int		j;
-	int		x, y;
-	int		remaining;
-	int		charscale;
+	FNT_font_t		font;
+	struct FNT_window_s	box;
+	float			colors[ 8 ] = { 1, 1, 1, 1, 0.25, 1, 0.25, 1 };
 
-// the finale prints the characters one at a time
-	remaining = 9999;
+	if ( scr_centertime_off <= scr_centertime->value / 5.0 ) {
+		colors[ 3 ] = colors[ 7 ] = scr_centertime_off * 5.0 / scr_centertime->value;
+	}
 
-	scr_erase_center = 0;
-	start = scr_centerstring;
+	box.x = 0;
+	if ( scr_center_lines <= 4 ) {
+		box.y = viddef.height * 0.35;
+	} else {
+		box.y = 48;
+	}
+	box.height = viddef.height - box.y;
+	box.width = viddef.width;
 
-	charscale = (float)(viddef.height)*8/400;; //make these a litter larger
-	if(charscale < 8)
-		charscale = 8;
-
-	if (scr_center_lines <= 4)
-		y = viddef.height*0.35;
-	else
-		y = 48;
-
-	do
-	{
-	// scan the width of the line
-		for (l=0 ; l<40 ; l++)
-			if (start[l] == '\n' || !start[l])
-				break;
-		x = (viddef.width - l*charscale)/2;
-		SCR_AddDirtyPoint (x, y);
-		for (j=0 ; j<l ; j++, x+=charscale)
-		{
-			Draw_ScaledChar (x, y, start[j], charscale, false);
-			if (!remaining--)
-				return;
-		}
-		SCR_AddDirtyPoint (x, y+charscale);
-
-		y += charscale;
-
-		while (*start && *start != '\n')
-			start++;
-
-		if (!*start)
-			break;
-		start++;		// skip the \n
-	} while (1);
+	font = FNT_AutoGet( CL_centerFont );
+	FNT_BoundedPrint( font , scr_centerstring , FNT_CMODE_TWO , FNT_ALIGN_CENTER , &box , colors );
 }
 
 void SCR_CheckDrawCenterString (void)
@@ -293,10 +263,22 @@ IRC PRINTING
 ===============================================================================
 */
 
-char		scr_IRCstring[5][1024];
-float		scr_IRCtime_start;	// for slow victory printing
-float		scr_IRCtime_off;
+extern vec4_t		Color_Table[8];
+
+#define SCR_IRC_LINES	5
+#define SCR_IRC_LENGTH	1024
+#define SCR_IRC_INDENT	8
+
+#define SCR_IRC_DISPLAY_HIDE 0		// During line bumping
+#define SCR_IRC_DISPLAY_PARTIAL 1	// When a new line is being added
+#define SCR_IRC_DISPLAY_FULL 2		// No problemo
+
+char			scr_IRCstring_contents[ SCR_IRC_LINES ][ SCR_IRC_LENGTH ];
+char *			scr_IRCstring[ SCR_IRC_LINES ];
+float			scr_IRCtime_start;	// for slow victory printing
+float			scr_IRCtime_off;
 int			scr_IRC_lines = -1;
+int			scr_IRC_display = SCR_IRC_DISPLAY_FULL;
 
 /*
 ==============
@@ -306,103 +288,83 @@ Called for IRC messages
 ==============
 */
 
-void IRC_BumpMsg(void)
+
+void IRC_SetNextLine( int len , const char *buffer )
 {
+	char * to_set;
 	int i;
 
-	for(i = 0; i < scr_IRC_lines; i++)		
-		strcpy(scr_IRCstring[i], scr_IRCstring[i+1]);
+	// Access the correct line buffer
+	scr_IRC_display = SCR_IRC_DISPLAY_HIDE;
+	if ( scr_IRC_lines < SCR_IRC_LINES - 1 ) {
+		scr_IRC_lines ++;
+		to_set = scr_IRCstring_contents[ scr_IRC_lines ];
+	} else {
+		to_set = scr_IRCstring[ 0 ];
+		for ( i = 0 ; i < SCR_IRC_LINES - 1 ; i ++ )
+			scr_IRCstring[ i ] = scr_IRCstring[ i + 1 ];
+	}
+	scr_IRCstring[ scr_IRC_lines ] = to_set;
+	scr_IRC_display = SCR_IRC_DISPLAY_PARTIAL;
+
+	// Copy string
+	Q_strncpyz2( to_set , buffer , SCR_IRC_LENGTH );
+
+	// Restore IRC display and update time-related variables
+	scr_IRCtime_off = 15;
+	scr_IRCtime_start = cl.time;
+	scr_IRC_display = SCR_IRC_DISPLAY_FULL;
 }
 
-void SCR_IRCPrintf (char *fmt, ...)	
+
+void SCR_IRCPrintf (char *fmt, ...)
 {
 	va_list		argptr;
 	char		msg[1024];
+	int		len;
 
 	va_start (argptr,fmt);
-	vsnprintf(msg, sizeof(msg), fmt, argptr);
+	len = vsnprintf(msg, sizeof(msg), fmt, argptr);
 	va_end (argptr);
 
-	scr_IRCtime_off = 15;
-	scr_IRCtime_start = cl.time;
+	if ( len >= sizeof(msg) )
+		len = sizeof( msg ) - 1;
 
-	// count the number of lines
-	if(scr_IRC_lines < 4)
-		scr_IRC_lines += 1;
-	else
-		IRC_BumpMsg();
-
-	strncpy (scr_IRCstring[scr_IRC_lines], msg, sizeof(scr_IRCstring[scr_IRC_lines])-1);
+	IRC_SetNextLine( len , msg );
 }
 
-extern vec4_t	Color_Table[8];
-
-void SCR_DrawColorString ( int x, int y, const char *str )
-{
-	int		num;
-	vec4_t	scolor;
-	int	charscale;
-
-	charscale = (float)(viddef.height)*8/600;
-	if(charscale < 8)
-		charscale = 8;
-
-	scolor[0] = 0; 
-	scolor[1] = 1;
-	scolor[2] = 0;
-	scolor[3] = 1;
-
-	while (*str) {
-		if ( Q_IsColorString( str ) ) {
-			VectorCopy ( Color_Table[ColorIndex(str[1])], scolor );
-			str += 2;
-			continue;
-		}
-		
-		Draw_ScaledColorChar (x, y, *str, scolor, charscale, false); //this is only ever used for names.
-		
-		num = *str++;
-		num &= 255;
-			
-		if ( (num&127) == 32 ) { //spaces reset colors
-			scolor[0] = 0;
-			scolor[1] = 1;
-			scolor[2] = 0;
-			scolor[3] = 1;
-		}
-
-		x += charscale;
-	}
-}
-void SCR_DrawIRCString (int lineNum)
-{
-	int		x, y;
-	int		charscale;
-
-	charscale = (float)(viddef.height)*8/600;
-	if(charscale < 8)
-		charscale = 8;
-
-	y = charscale*5 + lineNum*charscale;
-	x = 0;
-
-	SCR_AddDirtyPoint (x, y);
-	SCR_DrawColorString (x, y, scr_IRCstring[lineNum]);
-	SCR_AddDirtyPoint (x, y+charscale);
-
-}
 
 void SCR_CheckDrawIRCString (void)
 {
-	int i;
+	FNT_font_t		font;
+	struct FNT_window_s	box;
+	int			i , last_line;
+	static float		color[ 4 ] = { 1 , 1 , 1 , 1 };
 
 	scr_IRCtime_off -= cls.frametime;
-
-	if (scr_IRCtime_off <= 0)
+	if (scr_IRCtime_off <= 0 || scr_IRC_display == SCR_IRC_DISPLAY_HIDE)
 		return;
 
-	for(i = 0; i <= scr_IRC_lines; i++)
-		SCR_DrawIRCString (i);
+	last_line = ( scr_IRC_display == SCR_IRC_DISPLAY_FULL ) ? scr_IRC_lines : ( scr_IRC_lines - 1 );
+	if ( last_line == -1 )
+		return;
+
+	font = FNT_AutoGet( CL_gameFont );
+
+	box.x = 0;
+	box.y = font->size * 5;
+	for ( i = 0 ; i <= last_line ; i++ ) {
+		box.width = viddef.width;
+		box.height = font->size * 15 - box.y;
+
+		FNT_WrappedPrint( font , scr_IRCstring[ i ] , FNT_CMODE_QUAKE , FNT_ALIGN_LEFT ,
+			SCR_IRC_INDENT , &box , color );
+
+		box.y += box.height;
+		if ( box.y >= font->size * 15 ) {
+			break;
+		}
+	}
 }
 
 //=============================================================================
@@ -485,6 +447,8 @@ void SCR_Init (void)
 	scr_graphheight = Cvar_Get ("graphheight", "32", 0);
 	scr_graphscale = Cvar_Get ("graphscale", "1", 0);
 	scr_graphshift = Cvar_Get ("graphshift", "0", 0);
+	// configurable number of frames for timerefresh command
+	scr_timerefcount = Cvar_Get("scr_timerefcount", "128", 0 );
 
 	cl_drawfps = Cvar_Get ("cl_drawfps", "0", CVAR_ARCHIVE);
 	cl_drawtimer = Cvar_Get("cl_drawtimer", "0", CVAR_ARCHIVE);
@@ -589,16 +553,15 @@ void SCR_DrawRotatingIcon( void )
 	if (yaw > 360)
 		yaw = 0;
 
-	//i think this is where it's getting blown out, the model keeps getting overwritten or lost at map load
 	entity.model = R_RegisterModel( "models/objects/icon/tris.md2" );
-		
+
 	entity.flags = RF_FULLBRIGHT | RF_MENUMODEL;
 	entity.origin[0] = 80;
 	entity.origin[1] = 30;
 	entity.origin[2] = -5;
-	
+
 	VectorCopy( entity.origin, entity.oldorigin );
-	
+
 	entity.frame = 0;
 	entity.oldframe = 0;
 	entity.backlerp = 0.0;
@@ -629,11 +592,11 @@ void SCR_DrawLoadingBar (int percent, int scale)
 	if (R_RegisterPic("bar_background") && R_RegisterPic("bar_loading"))
 	{
 		Draw_StretchPic (
-			viddef.width/2-scale*15 + 1*hudscale,viddef.height/2 + scale*5+1*hudscale,
-			scale*30-2*hudscale, scale*10-2*hudscale, "bar_background");
+			viddef.width/2-scale*15 + 1*hudscale,viddef.height/2 + scale*5.4,
+			scale*30-2*hudscale, scale*10, "bar_background");
 		Draw_StretchPic (
-			viddef.width/2-scale*15 + 1*hudscale,viddef.height/2 + scale*5+8*hudscale,
-			(scale*30-2*hudscale)*percent/100, scale*2-2*hudscale, "bar_loading");
+			viddef.width/2-scale*15 + 1*hudscale,viddef.height/2 + scale*6.2,
+			(scale*30-2*hudscale)*percent/100, scale*2, "bar_loading");
 	}
 	else
 	{
@@ -645,25 +608,21 @@ void SCR_DrawLoadingBar (int percent, int scale)
 			(scale*30-2)*percent/100, scale*2-2, 7);
 	}
 }
-extern void Menu_DrawString( int x, int y, const char *string);
-int stringLen (char *string)
-{
-	return strlen(string);
-}
+
+
+
 void SCR_DrawLoading (void)
 {
-	char	mapfile[32];
-	qboolean isMap = false;
-	int		font_size, kb;
-	float	hudscale;
+	FNT_font_t		font;
+	struct FNT_window_s	box;
+	char			mapfile[32];
+	qboolean		isMap = false;
+	float			hudscale;
 
 	if (!scr_draw_loading)
 		return;
 	scr_draw_loading = false;
-
-	font_size = (float)(viddef.height)*8/600;
-	if(font_size < 8)
-		font_size = 8;
+	font = FNT_AutoGet( CL_gameFont );
 
 	hudscale = (float)(viddef.height)/600;
 	if(hudscale < 1)
@@ -686,45 +645,38 @@ void SCR_DrawLoading (void)
 	else
 		Draw_Fill (0, 0, viddef.width, viddef.height, 0);
 
+#if 0
+	// no m_background pic, but a pic here over-writes the levelshot
 	Draw_StretchPic (0, 0, viddef.width, viddef.height, "m_background");
+#endif
 
 	//loading message stuff...
 	if (isMap)
 	{
-		char *mapmsg;
+		char loadMessage[ MAX_QPATH * 6 ];
+		int i;
 
-		mapmsg = va("Loading Map [%s]", mapfile);
-		DrawString(
-			viddef.width/2 - font_size/2*stringLen(mapmsg),
-			viddef.height/2 - font_size*5,
-			mapmsg);
+		Com_sprintf( loadMessage , sizeof( loadMessage ) , "Loading Map [%s]\n^3%s" , mapfile , cl.configstrings[CS_NAME] );
 
-		mapmsg = va("[%s]", cl.configstrings[CS_NAME]);
-		DrawString(
-			viddef.width/2 - font_size/2*stringLen(mapmsg),
-			viddef.height/2 - font_size*4,
-			mapmsg);
+		box.x = 0;
+		box.y = viddef.height / 2 - font->size * 5;
+		box.width = viddef.width;
+		box.height = 0;
+		FNT_BoundedPrint( font , loadMessage , FNT_CMODE_QUAKE , FNT_ALIGN_CENTER , &box , FNT_colors[ 7 ] );
 
-		DrawString(
-			viddef.width/2 - font_size*15,
-			viddef.height/2 - font_size*1,
-			loadingMessages[0]);
-		DrawString(
-			viddef.width/2 - font_size*15,
-			viddef.height/2 - font_size*0,
-			loadingMessages[1]);
-		DrawString(
-			viddef.width/2 - font_size*15,
-			viddef.height/2 + font_size*1,
-			loadingMessages[2]);
-		DrawString(
-			viddef.width/2 - font_size*15,
-			viddef.height/2 + font_size*2,
-			loadingMessages[3]);
-		DrawString(
-			viddef.width/2 - font_size*15,
-			viddef.height/2 + font_size*3,
-			loadingMessages[4]);
+		box.y += font->size * 4;
+		for ( i = 0 ; i < 5 ; i ++ ) {
+			box.x = viddef.width / 2 - font->size * 15;
+			box.width = box.height = 0;
+			FNT_BoundedPrint( font , loadingMessages[i][0] , FNT_CMODE_QUAKE , FNT_ALIGN_LEFT , &box , FNT_colors[ 7 ] );
+
+			box.x += box.width + font->size;
+			box.width = viddef.width / 2 + font->size * 15 - box.x;
+			box.height = 0;
+			FNT_BoundedPrint( font , loadingMessages[i][1] , FNT_CMODE_QUAKE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 7 ] );
+
+			box.y += font->size;
+		}
 
 		//check for instance of icons we would like to show in loading process, ala q3
 		if(rocketlauncher) {
@@ -807,22 +759,20 @@ void SCR_DrawLoading (void)
 	}
 	else
 	{
-		char *msg = va("Awaiting Connection...");
-
-		//draw centered
-		DrawString(
-				viddef.width/2 - font_size/2*stringLen(msg),
-				viddef.height/2 - font_size/2,
-				msg);
+		box.x = 0;
+		box.y = ( viddef.height - font->size ) / 2;
+		box.width = viddef.width;
+		box.height = 0;
 
+		FNT_BoundedPrint( font , "Awaiting Connection ..." , FNT_CMODE_NONE , FNT_ALIGN_CENTER , &box , FNT_colors[ 7 ] );
 	}
 
 	// Add Download info stuff...
-	if (cls.download && (kb = (int)ftell(cls.download)))
+	if (cls.download && ( (int)ftell( cls.download ) / 1024 ) != 0 )
 	{
 		if ( cls.key_dest != key_console ) //drop the console because of CURL's readout
 		{
-			Con_ToggleConsole_f();
+			CON_ToggleConsole();
 		}
 	}
 	else if (isMap) //loading bar...
@@ -830,12 +780,14 @@ void SCR_DrawLoading (void)
 		//to do - fix
 		//SCR_DrawRotatingIcon();
 
-		SCR_DrawLoadingBar(loadingPercent, font_size);
+		SCR_DrawLoadingBar(loadingPercent, font->size);
 
-		DrawString(
-			viddef.width/2 - font_size*3,
-			viddef.height/2 + (int)(font_size*6.3),
-			va("%3d%%", (int)loadingPercent));
+		box.x = 0;
+		box.y = 2 + viddef.height / 2 + font->size * 6.3;
+		box.width = viddef.width;
+		box.height = 0;
+
+		FNT_BoundedPrint( font , va("%3d%%", (int)loadingPercent) , FNT_CMODE_NONE , FNT_ALIGN_CENTER , &box , FNT_colors[ 7 ] );
 	}
 }
 
@@ -880,39 +832,37 @@ SCR_DrawConsole
 float sendBubbleNow;
 void SCR_DrawConsole (void)
 {
-	Con_CheckResize ();
-
 	if (cls.state == ca_disconnected || cls.state == ca_connecting)
 	{	// forced full screen console
-		Con_DrawConsole (scr_consize->value);
+		CON_DrawConsole( scr_consize->value );
 		return;
 	}
 
 	if (cls.state != ca_active || !cl.refresh_prepped)
 	{	// connected, but can't render
-		Con_DrawConsole (scr_consize->value);
+		CON_DrawConsole( scr_consize->value );
 		Draw_Fill (0, viddef.height/2, viddef.width, viddef.height/2, 0);
 		return;
 	}
 
 	if (scr_con_current)
 	{
-		Con_DrawConsole (scr_con_current);
+		CON_DrawConsole( scr_con_current );
 	}
 	else
 	{
-		if (cls.key_dest == key_game || cls.key_dest == key_message) 
-			Con_DrawNotify ();	// only draw notify in game
+		if (cls.key_dest == key_game || cls.key_dest == key_message)
+			CON_DrawNotify ();	// only draw notify in game
 	}
 
-	//draw chat bubble 
-	if(cls.key_dest == key_message || scr_con_current) { 
+	//draw chat bubble
+	if(cls.key_dest == key_message || scr_con_current) {
 		//only send this every couple of seconds no need to flood
 		sendBubbleNow += cls.frametime;
 		if(sendBubbleNow >= 1) {
-			Cbuf_AddText("chatbubble\n"); 
+			Cbuf_AddText("chatbubble\n");
 			Cbuf_Execute ();
-			sendBubbleNow = 0; 
+			sendBubbleNow = 0;
 		}
 	}
 }
@@ -935,9 +885,6 @@ void SCR_BeginLoadingPlaque (void)
 	S_StopAllSounds ();
 	cl.sound_prepped = false;		// don't play ambients
 
-	if (developer->value)
-		return;
-
 	scr_draw_loading = 1;
 
 	SCR_UpdateScreen ();
@@ -955,7 +902,7 @@ void SCR_EndLoadingPlaque (void)
 {
 	cls.disable_screen = 0;
 	scr_draw_loading = 0;
-	Con_ClearNotify ();
+	CON_ClearNotify( );
 
 	Cvar_Set ("paused", "0");
 }
@@ -985,76 +932,86 @@ int entitycmpfnc( const entity_t *a, const entity_t *b )
 	}
 }
 
-
-/*
-================
-SCR_TimeRefresh_f
-================
-*/
-void SCR_TimeRefresh_f (void)
+/**
+ * \brief  Rendering performance test.
+ *
+ * Target of 'timerefresh' command. When invoked with an argument, end of
+ * frame flush and page flipping are not done. Modified 2011-02 with
+ * additional info in result. Use 'viewpos' (also modified) command
+ * for repeatable, consistent positioning.
+ */
+void SCR_TimeRefresh_f( void )
 {
-	int		i;
-	int		start, stop;
-	float	time;
+	int   start, stop;
+	float time;
+	float frames_per_sec;
+	float msec_per_frame;
+	float save_yaw;
+	int   frame_count;
+	float num_frames;
+	float yaw_increment;
+	float frame_yaw;
 
 	if ( cls.state != ca_active )
 		return;
 
-	start = Sys_Milliseconds ();
+	save_yaw = cl.refdef.viewangles[YAW];
 
-	if (Cmd_Argc() == 2)
-	{	// run without page flipping
+	num_frames = scr_timerefcount->value;
+	frame_count = scr_timerefcount->integer;
+	if ( frame_count < 1 || frame_count > 720 )
+	{ // silently protect against unreasonable setting
+		num_frames = 128.0f;
+		frame_count = 128;
+	}
+
+	frame_yaw = save_yaw; // start at original yaw
+	yaw_increment = 360.0f / num_frames;
+	start = Sys_Milliseconds();
+	if ( Cmd_Argc() == 2 )
+	{ // run without page flipping.
 		R_BeginFrame( 0 );
-		for (i=0 ; i<128 ; i++)
+		while ( --frame_count )
 		{
-			cl.refdef.viewangles[1] = i/128.0*360.0;
-			R_RenderFrame (&cl.refdef);
+			cl.refdef.viewangles[YAW] = frame_yaw;
+			R_RenderFrame( &cl.refdef );
+			frame_yaw += yaw_increment;
 		}
+		// last frame restores original yaw
+		cl.refdef.viewangles[YAW] = save_yaw;
+		R_RenderFrame( &cl.refdef );
 		R_EndFrame();
+
 	}
 	else
 	{
-		for (i=0 ; i<128 ; i++)
+		while ( --frame_count )
 		{
-			cl.refdef.viewangles[1] = i/128.0*360.0;
-
+			cl.refdef.viewangles[YAW] = frame_yaw;
 			R_BeginFrame( 0 );
-			R_RenderFrame (&cl.refdef);
+			R_RenderFrame( &cl.refdef );
 			R_EndFrame();
+			frame_yaw += yaw_increment;
 		}
+		// last frame restores original yaw
+		cl.refdef.viewangles[YAW] = save_yaw;
+		R_BeginFrame( 0 );
+		R_RenderFrame( &cl.refdef );
+		R_EndFrame();
 	}
+	stop = Sys_Milliseconds();
+	time = (float)(stop - start);
 
-	stop = Sys_Milliseconds ();
-	time = (stop-start)/1000.0;
-	Com_Printf ("%f seconds (%f fps)\n", time, 128/time);
-}
+	msec_per_frame = time / num_frames;
+	time /= 1000.0f;
+	frames_per_sec = num_frames / time;
+	Com_Printf( "%1.0f frames, %1.3f sec, %1.3f msec/frame, %1.1f FPS\n",
+			num_frames, time, msec_per_frame, frames_per_sec );
 
-/*
-=================
-SCR_AddDirtyPoint
-=================
-*/
-void SCR_AddDirtyPoint (int x, int y)
-{
-	if (x < scr_dirty.x1)
-		scr_dirty.x1 = x;
-	if (x > scr_dirty.x2)
-		scr_dirty.x2 = x;
-	if (y < scr_dirty.y1)
-		scr_dirty.y1 = y;
-	if (y > scr_dirty.y2)
-		scr_dirty.y2 = y;
-}
-
-void SCR_DirtyScreen (void)
-{
-	SCR_AddDirtyPoint (0, 0);
-	SCR_AddDirtyPoint (viddef.width-1, viddef.height-1);
 }
 
 //===============================================================
 
-
 #define STAT_MINUS		10	// num frame for '-' stats digit
 char		*sb_nums[2][11] =
 {
@@ -1170,9 +1127,6 @@ void SCR_DrawField (int x, int y, int color, int width, int value, float scale)
 	if (width > 5)
 		width = 5;
 
-	SCR_AddDirtyPoint (x, y);
-	SCR_AddDirtyPoint (x+width*CHAR_WIDTH+2, y+23);
-
 	Com_sprintf (num, sizeof(num), "%i", value);
 	l = strlen(num);
 	if (l > width)
@@ -1228,15 +1182,17 @@ SCR_ExecuteLayoutString
 */
 void SCR_ExecuteLayoutString (char *s)
 {
-	int		x, y, ny; //ny is coordinates used for new sb layout client tags only
-	int		value;
-	char	*token;
-	int		width;
-	int		index;
-	clientinfo_t	*ci;
-	int		charscale;
-	float	scale;
-	qboolean newSBlayout = false;
+	FNT_font_t		font;
+	struct FNT_window_s	box;
+	int			x, y, ny=0; //ny is coordinates used for new sb layout client tags only
+	int			value;
+	char *			token;
+	int			width;
+	int			index;
+	clientinfo_t *		ci;
+	int			charscale;
+	float			scale;
+	qboolean		newSBlayout = false;
 
 	if (cls.state != ca_active || !cl.refresh_prepped)
 		return;
@@ -1247,15 +1203,9 @@ void SCR_ExecuteLayoutString (char *s)
 	x = 0;
 	y = 0;
 	width = 3;
-	scale = (float)(viddef.height)/600;
-
-	if(scale < 1)
-		scale = 1;
-
-	charscale = (float)(viddef.height)*8/600;
-
-	if(charscale < 8)
-		charscale = 8;
+	font = FNT_AutoGet( CL_gameFont );
+	charscale = font->size;
+	scale = charscale * 0.125;
 
 	while (s)
 	{
@@ -1306,10 +1256,8 @@ void SCR_ExecuteLayoutString (char *s)
 				value = cl.frame.playerstate.stats[atoi(token)];
 				if (value >= MAX_IMAGES)
 					Com_Error (ERR_DROP, "Pic >= MAX_IMAGES");
-				if (cl.configstrings[CS_IMAGES+value])
+				if( cl.configstrings[CS_IMAGES+value][0] )
 				{
-					SCR_AddDirtyPoint (x, y);
-					SCR_AddDirtyPoint (x+23*scale, y+23*scale);
 					Draw_ScaledPic (x, y, scale, cl.configstrings[CS_IMAGES+value]);
 				}
 			}
@@ -1318,45 +1266,50 @@ void SCR_ExecuteLayoutString (char *s)
 		}
 
 		if (!strcmp(token, "newsb"))
-		{		
+		{
 			//print header here
 			x = viddef.width/2 - 160*scale;
 			y = viddef.height/2 - 64*scale;
 
-			DrawString (x+2*scale, y, va("Player"));
-			DrawString (x+176*scale, y, va("Score"));
-			DrawString (x+232*scale, y, va("Ping"));
-			DrawString (x+280*scale, y, va("time"));
+			box.x = x + 4 * scale , box.y = y;
+			FNT_RawPrint( font , "Player" , 6 , false , box.x , box.y , FNT_colors[ 7 ] );
+			box.x += 160 * scale , box.width = 56 * scale , box.height = 0;
+			FNT_BoundedPrint( font , "Score" , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 7 ] );
+			box.x += 56 * scale , box.width = 48 * scale , box.height = 0;
+			FNT_BoundedPrint( font , "Ping" , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 7 ] );
+			box.x += 48 * scale , box.width = 48 * scale , box.height = 0;
+			FNT_BoundedPrint( font , "Time" , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 7 ] );
 
 			newSBlayout = true;
 			continue;
 		}
 
 		if (!strcmp(token, "newctfsb"))
-		{		
+		{
 			//print header here
-			x = viddef.width/2 - 160*scale;
+			x = viddef.width/2 - 256*scale;
 			y = viddef.height/2 - 72*scale;
 
-			//team 1
-			DrawString (x-82*scale, y, va("Player"));
-			DrawString (x+76*scale, y, va("Score"));
-			DrawString (x+124*scale, y, va("Ping"));
-
-			x += 190*scale;
-
-			//team 2
-			DrawString (x-16*scale, y, va("Player"));
-			DrawString (x+142*scale, y, va("Score"));
-			DrawString (x+190*scale, y, va("Ping"));
+			while ( x <= viddef.width/2 ) {
+				box.x = x + 14 * scale , box.y = y;
+				FNT_RawPrint( font , "Player" , 6 , false , box.x , box.y , FNT_colors[ 7 ] );
+				box.x += 118 * scale , box.width = 56 * scale , box.height = 0;
+				FNT_BoundedPrint( font , "Score" , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 7 ] );
+				box.x += 56 * scale , box.width = 48 * scale , box.height = 0;
+				FNT_BoundedPrint( font , "Ping" , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 7 ] );
+				x += 256 * scale;
+			}
 
 			newSBlayout = true;
 			continue;
 		}
 
-		if (!strcmp(token, "client"))
+		if (!strcmp(token, "client") || !strcmp(token, "queued"))
 		{	// draw a deathmatch client block
+			qboolean	isQueued = ( token[ 0 ] == 'q' );
 			int		score, ping, time;
+			const char *	timeMessage;
+			int		timeColor;
 
 			token = COM_Parse (&s);
 			x = viddef.width/2 - 160*scale + atoi(token)*scale;
@@ -1365,8 +1318,6 @@ void SCR_ExecuteLayoutString (char *s)
 				y = viddef.height/2 - 100*scale + atoi(token)*scale/2;
 			else
 				y = viddef.height/2 - 100*scale + atoi(token)*scale;
-			SCR_AddDirtyPoint (x, y);
-			SCR_AddDirtyPoint (x+159*scale, y+31*scale);
 
 			token = COM_Parse (&s);
 			value = atoi(token);
@@ -1379,78 +1330,57 @@ void SCR_ExecuteLayoutString (char *s)
 
 			token = COM_Parse (&s);
 			ping = atoi(token);
- 
+
 			token = COM_Parse (&s);
 			time = atoi(token);
 
+			if ( isQueued ) {
+				COM_Parse (&s);
+				timeMessage = "Queue:";
+				timeColor = 1;
+			} else {
+				timeMessage = "Time:";
+				timeColor = 7;
+			}
+
 			if(newSBlayout) { //new scoreboard layout
 
-				Draw_ColorString (x+2*scale, y+34*scale, ci->name, 1.2);
-				DrawAltString (x+176*scale, y+34*scale, va("%i", score));
-				DrawString (x+232*scale, y+34*scale, va("%i", ping));
-				DrawString (x+280*scale, y+34*scale, va("%i", time));
+				box.x = x + 4 * scale , box.y = y + 34 * scale;
+				box.width = 160 * scale , box.height = 0;
+				FNT_BoundedPrint( font , ci->name , FNT_CMODE_QUAKE_SRS , FNT_ALIGN_LEFT , &box , FNT_colors[ 2 ] );
+				box.x += 160 * scale , box.width = 56 * scale , box.height = 0;
+				FNT_BoundedPrint( font , va( "%i" , score ) , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 2 ] );
+				box.x += 56 * scale , box.width = 48 * scale , box.height = 0;
+				FNT_BoundedPrint( font , va( "%i" , ping ) , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 7 ] );
+				box.x += 48 * scale , box.width = 48 * scale , box.height = 0;
+				FNT_BoundedPrint( font , va( "%i" , time ) , FNT_CMODE_QUAKE , FNT_ALIGN_RIGHT , &box , FNT_colors[ timeColor ] );
 			}
 			else
 			{
-				Draw_ColorString (x+32*scale, y, ci->name, 1);
-				DrawString (x+32*scale, y+8*scale,  "Score: ");
-				DrawAltString (x+32*scale+7*charscale, y+8*scale,  va("%i", score));
-				DrawString (x+32*scale, y+16*scale, va("Ping:  %i", ping));
-				DrawString (x+32*scale, y+24*scale, va("Time:  %i", time));
+				box.x = x + 32 * scale , box.y = y;
+				box.width = 288 * scale , box.height = 0;
+				FNT_BoundedPrint( font , ci->name , FNT_CMODE_QUAKE_SRS , FNT_ALIGN_LEFT , &box , FNT_colors[ 2 ] );
 
-				if (!ci->icon)
-					ci = &cl.baseclientinfo;
-				Draw_ScaledPic (x, y, scale/2, ci->iconname);
-			}
+				box.y += 8 * scale;
+				box.width = 100 * scale , box.height = 0;
+				FNT_BoundedPrint( font , "Score:" , FNT_CMODE_NONE , FNT_ALIGN_LEFT , &box , FNT_colors[ 7 ] );
+				box.x += box.width;
+				box.width = 100 * scale - box.width , box.height = 0;
+				FNT_BoundedPrint( font , va( "%i" , score ) , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 2 ] );
 
-			continue;
-		}
-		if (!strcmp(token, "queued"))
-		{	// draw a deathmatch client block
-			int		score, ping, time;
+				box.y += 8 * scale , box.x = x + 32 * scale;
+				box.width = 100 * scale , box.height = 0;
+				FNT_BoundedPrint( font , "Ping:" , FNT_CMODE_NONE , FNT_ALIGN_LEFT , &box , FNT_colors[ 7 ] );
+				box.x += box.width;
+				box.width = 100 * scale - box.width , box.height = 0;
+				FNT_BoundedPrint( font , va( "%i" , ping ) , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 7 ] );
 
-			token = COM_Parse (&s);
-			x = viddef.width/2 - 160*scale + atoi(token)*scale;
-			token = COM_Parse (&s);
-			if(newSBlayout)
-				y = viddef.height/2 - 100*scale + atoi(token)*scale/2;
-			else
-				y = viddef.height/2 - 100*scale + atoi(token)*scale;
-			SCR_AddDirtyPoint (x, y);
-			SCR_AddDirtyPoint (x+159*scale, y+31*scale);
-
-			token = COM_Parse (&s);
-			value = atoi(token);
-			if (value >= MAX_CLIENTS || value < 0)
-				Com_Error (ERR_DROP, "client >= MAX_CLIENTS");
-			ci = &cl.clientinfo[value];
-
-			token = COM_Parse (&s);
-			score = atoi(token);
-
-			token = COM_Parse (&s);
-			ping = atoi(token);
-
-			token = COM_Parse (&s);
-			time = atoi(token);
-
-			token = COM_Parse (&s);
-
-			if(newSBlayout) { //new scoreboard layout
-
-				Draw_ColorString (x+2*scale, y+34*scale, ci->name, 1.2);
-				DrawAltString (x+176*scale, y+34*scale, va("%i", score));
-				DrawString (x+232*scale, y+34*scale, va("%i", ping));
-				Draw_ColorString (x+280*scale, y+34*scale, va("^1%i", time), 1.2);
-
-			}
-			else {
-
-				Draw_ColorString (x+32*scale, y, ci->name, 1);
-				DrawString (x+32*scale, y+8*scale,  "Score: ");
-				DrawAltString (x+32*scale+7*charscale, y+8*scale,  va("%i", score));
-				DrawString (x+32*scale, y+16*scale, va("Ping:  %i", ping));
-				Draw_ColorString (x+32*scale, y+24*scale, va("^1Queue:  ^1%i", time), 1);
+				box.y += 8 * scale , box.x = x + 32 * scale;
+				box.width = 100 * scale , box.height = 0;
+				FNT_BoundedPrint( font , timeMessage , FNT_CMODE_NONE , FNT_ALIGN_LEFT , &box , FNT_colors[ timeColor ] );
+				box.x += box.width;
+				box.width = 100 * scale - box.width , box.height = 0;
+				FNT_BoundedPrint( font , va( "%i" , time ) , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ timeColor ] );
 
 				if (!ci->icon)
 					ci = &cl.baseclientinfo;
@@ -1473,8 +1403,6 @@ void SCR_ExecuteLayoutString (char *s)
 				team = 1;
 			token = COM_Parse (&s);
 			y = viddef.height/2 - 100*scale + atoi(token)*scale;
-			SCR_AddDirtyPoint (x, y);
-			SCR_AddDirtyPoint (x+159*scale, y+31*scale);
 
 			token = COM_Parse (&s);
 			value = atoi(token);
@@ -1491,19 +1419,24 @@ void SCR_ExecuteLayoutString (char *s)
 				ping = 999;
 
 			if(newSBlayout) {
-				Draw_ColorString (x+16, y, ci->name, 1.2);
-				DrawAltString (x+172*scale, y+1*scale, va("%i", score));
-				DrawString (x+220*scale, y+1*scale, va("%i", ping));
+				box.x = x + 14 * scale , box.y = y + 2 * scale;
+				box.width = 118 * scale , box.height = 0;
+				FNT_BoundedPrint( font , ci->name , FNT_CMODE_QUAKE_SRS , FNT_ALIGN_LEFT , &box , FNT_colors[ 2 ] );
+				box.x += 120 * scale , box.width = 56 * scale , box.height = 0;
+				FNT_BoundedPrint( font , va( "%i" , score ) , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 2 ] );
+				box.x += 56 * scale , box.width = 48 * scale , box.height = 0;
+				FNT_BoundedPrint( font , va( "%i" , ping ) , FNT_CMODE_NONE , FNT_ALIGN_RIGHT , &box , FNT_colors[ 7 ] );
 
 				if(team) { //draw pic on left side(done client side to save packetsize
 					Draw_ScaledPic (x, y-2*scale, scale, "/pics/blueplayerbox");
 				}
-				else 
+				else
 					Draw_ScaledPic(x, y-2*scale, scale, "/pics/redplayerbox");
 			}
 			else {
 				sprintf(block, "%3d %3d %s", score, ping, ci->name);
-				Draw_ColorString (x, y, block, 1);
+				box.x = x , box.y = y , box.width = 256 , box.height = 0;
+				FNT_BoundedPrint( font , block , FNT_CMODE_QUAKE_SRS , FNT_ALIGN_LEFT , &box , FNT_colors[ 2 ] );
 			}
 
 			continue;
@@ -1513,13 +1446,9 @@ void SCR_ExecuteLayoutString (char *s)
 		{	// draw a pic from a name
 			token = COM_Parse (&s);
 			if(newSBlayout && !strcmp(token, "playerbox")) { //cannot simply fill y = ny here
-				SCR_AddDirtyPoint (x, ny+32*scale);
-				SCR_AddDirtyPoint (x+23*scale, ny+55*scale);
 				Draw_ScaledPic (x, ny+32*scale, scale, token);
 			}
 			else {
-				SCR_AddDirtyPoint (x, y);
-				SCR_AddDirtyPoint (x+23*scale, y+23*scale);
 				Draw_ScaledPic (x, y, scale, token);
 			}
 			continue;
@@ -1554,7 +1483,7 @@ void SCR_ExecuteLayoutString (char *s)
 
 				SCR_DrawField (x, y, color, width, value, scale);
 			}
-	
+
 			//draw the zoom scope pic if we are using the zoom alt-fire of disruptor
 			if (cl.frame.playerstate.stats[STAT_ZOOMED])
 			{
@@ -1614,7 +1543,9 @@ void SCR_ExecuteLayoutString (char *s)
 			index = cl.frame.playerstate.stats[index];
 			if (index < 0 || index >= MAX_CONFIGSTRINGS)
 				Com_Error (ERR_DROP, "Bad stat_string index");
-			DrawString (x, y, cl.configstrings[index]);
+
+			FNT_RawPrint( font , cl.configstrings[index] , strlen( cl.configstrings[index] ) ,
+				false , x , y , FNT_colors[ 7 ] );
 			continue;
 		}
 
@@ -1631,7 +1562,7 @@ void SCR_ExecuteLayoutString (char *s)
 			//this line is an Alien Arena specific hack of sorts, remove if needed
 			if(!strcmp(token, "Vote"))
 				Draw_ScaledPic (viddef.width/2 - 85*scale, y-8*scale, scale, "votebox");
-			DrawString (x, y, token);			
+			FNT_RawPrint( font , token , strlen( token ) , false , x , y , FNT_colors[ 7 ] );
 			continue;
 		}
 
@@ -1645,7 +1576,7 @@ void SCR_ExecuteLayoutString (char *s)
 		if (!strcmp(token, "string2"))
 		{
 			token = COM_Parse (&s);
-			DrawString (x, y, token);
+			FNT_RawPrint( font , token , strlen( token ) , false , x , y , FNT_colors[ 7 ] );
 			continue;
 		}
 
@@ -1702,12 +1633,13 @@ SCR_DrawPlayerIcon
 =================
 */
 char		scr_playericon[MAX_OSPATH];
-char		scr_playername[32];
+char		scr_playername[PLAYERNAME_SIZE];
 float		scr_playericonalpha;
 void SCR_DrawPlayerIcon(void) {
-	
-	int w, h;
-	float scale, iconPos;
+	FNT_font_t		font;
+	struct FNT_window_s	box;
+	int			w, h;
+	float			scale, iconPos;
 
 	if (cls.key_dest == key_menu || cls.key_dest == key_console)
 		return;
@@ -1732,7 +1664,13 @@ void SCR_DrawPlayerIcon(void) {
 	h*=scale;
 
 	Draw_AlphaStretchPlayerIcon( -w+(w*iconPos), viddef.height/2 + h/2, w, h, scr_playericon, scr_playericonalpha);
-	SCR_DrawColorString ( -w+(w*iconPos), viddef.height/2 + h + 32*scale, scr_playername);
+
+	font = FNT_AutoGet( CL_gameFont );
+	box.x = -w+(w*iconPos);
+	box.y = viddef.height/2 + h + 32*scale;
+	box.width = viddef.width - box.x;
+	box.height = 0;
+	FNT_BoundedPrint( font , scr_playername , FNT_CMODE_QUAKE , FNT_ALIGN_LEFT , &box , FNT_colors[ 2 ] );
 }
 
 /*
@@ -1742,20 +1680,16 @@ SCR_showTimer
 
 ================
 */
-char		temptime[32];
-int		timecounter;
-int		seconds, minutes;
+int	seconds, minutes;
 void SCR_showTimer(void)
 {
-	float scale;
+	static char		temptime[ 32 ];
+	static int		timecounter;
+	FNT_font_t		font;
 
 	if (cls.key_dest == key_menu || cls.key_dest == key_console)
 		return;
 
-	scale = (float)(viddef.height)/600;
-	if(scale < 1)
-		scale = 1;
-
 	if ((cls.realtime + 2000) < timecounter)
 		timecounter = cl.time + 1000;
 
@@ -1766,13 +1700,14 @@ void SCR_showTimer(void)
 			minutes++;
 			seconds = 0;
 		}
-		Com_sprintf(temptime, sizeof(temptime),"%i:%2i", minutes, seconds);
+		Com_sprintf(temptime, sizeof(temptime),"%i:%2.2i", minutes, seconds);
 		timecounter = cls.realtime + 1000;
 	}
 
-	Draw_StretchPic (viddef.width - 104*scale, viddef.height -42*scale, 32*scale, 32*scale, "timer");
-
-	DrawString(viddef.width - 64*scale, viddef.height - 32*scale, temptime);
+	font = FNT_AutoGet( CL_gameFont );
+	Draw_StretchPic( viddef.width - 13 * font->size , viddef.height - 5.25 * font->size , 4 * font->size , 4 * font->size , "timer");
+	FNT_RawPrint( font , temptime , strlen( temptime ) , false ,
+		viddef.width - 8 * font->size , viddef.height - 3.75 * font->size , FNT_colors[ 7 ] );
 }
 
 /*
@@ -1784,59 +1719,61 @@ SCR_showFPS
 */
 
 int		fpscounter;
-char		temp[32];
 
 void SCR_showFPS(void)
 {
-	float scale;
-	static qboolean restart = true;
-	static float update_trigger = 0.0f;
-	static float framecounter = 0.0f;	
-	static int start_msec;
-	int end_msec;
-	float time_sec;
-	float framerate;
+	static qboolean		restart		= true;
+	static float		update_trigger	= 0.0f;
+	static float		framecounter	= 0.0f;
+	static int		start_msec;
+	static char		fps_text[32];
 
-	if (cls.key_dest == key_menu || cls.key_dest == key_console)
-	{
+	FNT_font_t		font;
+	int			end_msec;
+	float			time_sec;
+	float			framerate;
+
+	if (cls.key_dest == key_menu || cls.key_dest == key_console) {
 		restart = true;
 		return;
-	}		
+	}
 
-	if( restart )
-	{
-		start_msec = cls.realtime; 
+	if( restart ) {
+		start_msec = Sys_Milliseconds();
 		framecounter = 0.0f;
 		update_trigger = 10.0f; // initial delay to update
-		temp[0] = 0; // blank the text buffer
+		fps_text[0] = 0; // blank the text buffer
 		restart = false;
-	}
-	else
-	{
-		framecounter += 1.0f;
-		if( framecounter >= update_trigger )
-		{
-			// calculate frames-per-second, using client frame current time
-			end_msec = cls.realtime;
-			time_sec = ((float)(end_msec - start_msec)) / 1000.0f;
-			framerate = framecounter / time_sec ;
-			
-			// update text buffer for display
-			Com_sprintf( temp, sizeof(temp), "%3.0ffps", framerate );
-			
-			// setup for next update
-			framecounter = 0.0f;
-			start_msec = end_msec;
-			update_trigger = framerate / 2.0 ; // for .5 sec update interval
-		}
+		return;
 	}
 
-	scale = (float)(viddef.height)/600;
-	if(scale < 1)
-		scale = 1;
-	
-	DrawString(viddef.width - 64*scale, viddef.height - 24*scale, temp);
-	
+	framecounter += 1.0f;
+	if( framecounter >= update_trigger ) {
+		// calculate frames-per-second
+		end_msec = Sys_Milliseconds();
+		time_sec = ((float)(end_msec - start_msec)) / 1000.0f;
+		framerate = framecounter / time_sec ;
+
+		// update text buffer for display
+		if ( cl_drawfps->integer == 2 )
+		{ // for developers
+			Com_sprintf( fps_text, sizeof(fps_text), "%3.1ffps", framerate );
+		}
+		else
+		{
+			Com_sprintf( fps_text, sizeof(fps_text), "%3.0ffps", framerate );
+		}
+
+		// setup for next update
+		framecounter = 0.0f;
+		start_msec = end_msec;
+		update_trigger = framerate / 2.0 ; // for .5 sec update interval
+	}
+
+	font = FNT_AutoGet( CL_gameFont );
+
+	FNT_RawPrint( font , fps_text , strlen( fps_text ) , false ,
+		viddef.width - 8 * font->size , viddef.height - 2.0 * font->size , FNT_colors[ 2 ] );
 }
 
 /*
@@ -1845,21 +1782,30 @@ void SCR_showFPS(void)
  */
 void SCR_showRSpeeds( void )
 {
-	char prtstring[32];
- 	float scale;
- 	extern int c_brush_polys;
- 	extern int c_alias_polys;
- 
+ 	extern int		c_brush_polys;
+ 	extern int		c_alias_polys;
+
+	FNT_font_t		font;
+	struct FNT_window_s	box;
+	char			prtstring[32];
+ 	float			scale;
+
  	if (cls.key_dest == key_menu || cls.key_dest == key_console)
  		return;
- 
+
  	scale = (float)(viddef.height)/600;
  	if(scale < 1)
  		scale = 1;
- 
+
  	Com_sprintf( prtstring, sizeof( prtstring ),
  		"%5.5i wpoly %5.5i epoly",  c_brush_polys, c_alias_polys );
- 	DrawString(	viddef.width/2, viddef.height - 48*scale,	prtstring );
+
+	font = FNT_AutoGet( CL_consoleFont );
+	box.x = 0;
+	box.y = viddef.height - 6 * font->size;
+	box.width = viddef.width;
+	box.height = 0;
+	FNT_BoundedPrint( font , prtstring , FNT_CMODE_NONE , FNT_ALIGN_CENTER , &box , FNT_colors[ 7 ] );
 }
 
 /*
@@ -1876,8 +1822,6 @@ void SCR_UpdateScreen (void)
 	int i;
 	float separation[2] = { 0, 0 };
 
-	// if the screen is disabled (loading plaque is up, or vid mode changing)
-	// do nothing at all
 	// if the screen is disabled (loading plaque is up, or vid mode changing)
 	// do nothing at all
 	if (cls.disable_screen)
@@ -1891,7 +1835,8 @@ void SCR_UpdateScreen (void)
 		scr_draw_loading = 2;
 	}
 
-	if (!scr_initialized || !con.initialized)
+
+	if (!scr_initialized)
 		return;				// not initialized yet
 
 	/*
@@ -1927,16 +1872,15 @@ void SCR_UpdateScreen (void)
 
 			if (cls.disable_screen)
 				scr_draw_loading = 2;
-	
+
 			//NO CONSOLE!!!
 			continue;
-		}		
+		}
 		else
 		{
 			// do 3D refresh drawing, and then update the screen
 			SCR_CalcVrect ();
 
-			need_free_vbo = true;
 			V_RenderView ( separation[i] );
 
 			SCR_DrawStats ();
@@ -1959,9 +1903,6 @@ void SCR_UpdateScreen (void)
 
 			SCR_DrawConsole ();
 
-			if (need_free_vbo)		
-				R_VCFreeFrame();
-
 			M_Draw ();
 
 			SCR_DrawLoading ();
