@@ -19,6 +19,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 // cl_tent.c -- client side temporary entities
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "client.h"
 
 cl_sustain_t	cl_sustains[MAX_SUSTAINS];
@@ -134,7 +138,7 @@ void CL_ParseSteam (void)
 				r = 0xd2; //lime green
 				break;
 			case 2:
-				r = 0x74; //blue 
+				r = 0x74; //blue
 				break;
 			case 3:
 				r = 0xe8; //red
@@ -276,7 +280,7 @@ CL_ParseTEnt
 =================
 */
 static byte splash_color[] = {0x00, 0xe0, 0xb0, 0x50, 0xd0, 0xe0, 0xe8};
-
+extern void R_ApplyForceToRagdolls(vec3_t origin, float force);
 void CL_ParseTEnt (void)
 {
 	int		type;
@@ -285,8 +289,8 @@ void CL_ParseTEnt (void)
 	int		color;
 	int		r;
 	trace_t	trace;
-	static vec3_t mins = { -8, -8, -8 }; 
-    static vec3_t maxs = { 8, 8, 8 }; 
+	static vec3_t mins = { -8, -8, -8 };
+    static vec3_t maxs = { 8, 8, 8 };
 
 	type = MSG_ReadByte (&net_message);
 
@@ -310,9 +314,11 @@ void CL_ParseTEnt (void)
 
 		if (type == TE_GUNSHOT) {
 			CL_ParticleEffect (pos, dir, 425, 10);
-			trace = CL_Trace ( pos, mins, maxs, pos, -1, MASK_SOLID, true, NULL); 
-			if(trace.contents)
+			trace = CL_Trace ( pos, mins, maxs, pos, -1, MASK_SOLID, true, NULL);
+			if(trace.contents) {
 				CL_BulletMarks(pos, dir);
+				R_ApplyForceToRagdolls(pos, 40);
+			}
 		}
 		else
 			CL_ParticleEffect (pos, dir, 425, 2);	// bullets, color is 0xe0
@@ -337,9 +343,11 @@ void CL_ParseTEnt (void)
 		MSG_ReadPos (&net_message, pos);
 		MSG_ReadDir (&net_message, dir);
 		if (type == TE_SCREEN_SPARKS) {
-			trace = CL_Trace ( pos, mins, maxs, pos, -1, MASK_SOLID, true, NULL); 
-			if(trace.contents)
+			trace = CL_Trace ( pos, mins, maxs, pos, -1, MASK_SOLID, true, NULL);
+			if(trace.contents) {
 				CL_BeamgunMark(pos, dir, 0.8, false);
+				R_ApplyForceToRagdolls(pos, 40);
+			}
 			CL_LaserSparks (pos, dir, 0xd0, 20);
 		}
 		else
@@ -362,7 +370,7 @@ void CL_ParseTEnt (void)
 			color = 0x00;
 		else
 			color = splash_color[r];
-		
+
 		CL_SplashEffect (pos, dir, color, cnt);
 
 		if (r == SPLASH_SPARKS)
@@ -389,6 +397,7 @@ void CL_ParseTEnt (void)
 		MSG_ReadPos (&net_message, pos);
 		MSG_ReadDir (&net_message, dir);
 		CL_BlasterParticles (pos, dir);
+		R_ApplyForceToRagdolls(pos, 100);
 
 		break;
 
@@ -396,9 +405,11 @@ void CL_ParseTEnt (void)
 		MSG_ReadPos (&net_message, pos);
 		MSG_ReadPos (&net_message, pos2);
 		CL_DisruptorBeam (pos, pos2);
-		trace = CL_Trace ( pos, mins, maxs, pos2, -1, MASK_SOLID, true, NULL); 
-		if(trace.contents)
+		trace = CL_Trace ( pos, mins, maxs, pos2, -1, MASK_SOLID, true, NULL);
+		if(trace.contents) {
 			CL_BeamgunMark(pos2, trace.plane.normal, 0.4, true);
+			R_ApplyForceToRagdolls(pos2, 100);
+		}
 		S_StartSound (pos, 0, 0, cl_sfx_railg, 1, ATTN_NORM, 0);
 		CL_PlasmaFlashParticle(pos, cl.refdef.viewangles, false);
 		break;
@@ -421,12 +432,14 @@ void CL_ParseTEnt (void)
 			S_StartSound (pos, 0, 0, cl_sfx_watrexp, 1, ATTN_NORM, 0);
 		else
 			S_StartSound (pos, 0, 0, cl_sfx_rockexp, 1, ATTN_NORM, 0);
+		R_ApplyForceToRagdolls(pos, 100);
 
 		break;
 
 	case TE_BFG_BIGEXPLOSION:
 		MSG_ReadPos (&net_message, pos);
 		CL_BFGExplosionParticles (pos);
+		R_ApplyForceToRagdolls(pos, 200);
 		break;
 
 	case TE_BUBBLETRAIL:
@@ -457,9 +470,9 @@ void CL_ParseTEnt (void)
 		MSG_ReadPos (&net_message, pos);
 		MSG_ReadPos (&net_message, pos2);
 		CL_VaporizerBeam (pos, pos2);
-		trace = CL_Trace ( pos, mins, maxs, pos2, -1, MASK_SOLID, true, NULL); 
+		trace = CL_Trace ( pos, mins, maxs, pos2, -1, MASK_SOLID, true, NULL);
 		if(trace.contents)
-			CL_VaporizerMarks(pos2, trace.plane.normal);	
+			CL_VaporizerMarks(pos2, trace.plane.normal);
 		break;
 
 	case TE_STEAM:
@@ -521,9 +534,11 @@ void CL_ParseTEnt (void)
 		MSG_ReadPos (&net_message, pos);
 		MSG_ReadPos (&net_message, pos2);
 		CL_BlasterBeam (pos, pos2);
-		trace = CL_Trace ( pos, mins, maxs, pos2, -1, MASK_SOLID, true, NULL); 
-		if(trace.contents)
+		trace = CL_Trace ( pos, mins, maxs, pos2, -1, MASK_SOLID, true, NULL);
+		if(trace.contents) {
 			CL_BlasterMark(pos2, trace.plane.normal);
+			R_ApplyForceToRagdolls(pos2, 100);
+		}
 		break;
 
 	default:
@@ -542,12 +557,14 @@ void CL_ProcessSustain ()
 	for (i=0, s=cl_sustains; i< MAX_SUSTAINS; i++, s++)
 	{
 		if (s->id)
+		{
 			if ((s->endtime >= cl.time) && (cl.time >= s->nextthink))
 			{
 				s->think (s);
 			}
 			else if (s->endtime < cl.time)
 				s->id = 0;
+		}
 	}
 }
 
