@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -19,6 +19,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 // cl_view.c -- player rendering positioning
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "client.h"
 
 //=============
@@ -37,8 +41,6 @@ grass_t r_grasses[MAX_GRASSES];
 int r_numbeams;
 beam_t	r_beams[MAX_BEAMS];
 
-qboolean need_free_vbo;
-
 //=============
 extern cvar_t *cl_showPlayerNames;
 extern cvar_t *name;
@@ -66,7 +68,7 @@ int			r_numviewentities;
 entity_t	r_viewentities[MAX_ENTITIES];
 
 int			r_numparticles;
-particle_t	r_particles[MAX_PARTICLES];
+particle_t	*r_particles[MAX_PARTICLES];
 
 lightstyle_t	r_lightstyles[MAX_LIGHTSTYLES];
 
@@ -122,22 +124,12 @@ V_AddParticle
 
 =====================
 */
-void V_AddParticle (vec3_t org, vec3_t angle, int color, int type, int texnum, int blenddst, int blendsrc, float alpha, float scale)
+void V_AddParticle (particle_t	*p)
 {
-	particle_t	*p;
 
 	if (r_numparticles >= MAX_PARTICLES)
 		return;
-	p = &r_particles[r_numparticles++];
-	VectorCopy (org, p->origin);
-	VectorCopy (angle, p->angle);
-	p->color = color;
-	p->alpha = alpha;
-	p->type = type;
-	p->texnum = texnum;
-	p->blenddst = blenddst;
-	p->blendsrc = blendsrc;
-	p->scale = scale;
+	r_particles[r_numparticles++] = p;
 }
 
 /*
@@ -210,6 +202,8 @@ If cl_testparticles is set, create 4096 particles in the view
 */
 void V_TestParticles (void)
 {
+#if 0
+//TODO: this will probably need moving to cl_fx.c and to use new_particle
 	particle_t	*p;
 	int			i, j;
 	float		d, r, u;
@@ -223,12 +217,13 @@ void V_TestParticles (void)
 		p = &r_particles[i];
 
 		for (j=0 ; j<3 ; j++)
-			p->origin[j] = cl.refdef.vieworg[j] + cl.v_forward[j]*d +
+			p->current_origin[j] = cl.refdef.vieworg[j] + cl.v_forward[j]*d +
 			cl.v_right[j]*r + cl.v_up[j]*u;
 
-		p->color = 8;
-		p->alpha = cl_testparticles->value;
+		p->current_color = 8;
+		p->current_alpha = cl_testparticles->value;
 	}
+#endif
 }
 
 /*
@@ -307,7 +302,7 @@ Call before entering a new level, or after changing dlls
 */
 qboolean needLoadingPlaque (void);
 extern int	seconds, minutes;
-void CL_PrepRefresh ()
+void CL_PrepRefresh ( void )
 {
 	char		mapname[32];
 	int			i, max;
@@ -315,7 +310,7 @@ void CL_PrepRefresh ()
 	float		rotate;
 	vec3_t		axis;
 	qboolean	newPlaque = needLoadingPlaque();
-	
+
 	loadingPercent = 0;
 	rocketlauncher = 0;
 	rocketlauncher_drawn = 0;
@@ -349,18 +344,16 @@ void CL_PrepRefresh ()
 
 	if (!cl.configstrings[CS_MODELS+1][0])
 		return;		// no map loaded
-    
+
 	if (newPlaque)
 		SCR_BeginLoadingPlaque();
 
 	loadingMessage = true;
-	Com_sprintf (loadingMessages[0], sizeof(loadingMessages[0]), "loading map...");
-	Com_sprintf (loadingMessages[1], sizeof(loadingMessages[1]), "loading models...");
-	Com_sprintf (loadingMessages[2], sizeof(loadingMessages[2]), "loading pics...");
-	Com_sprintf (loadingMessages[3], sizeof(loadingMessages[3]), "loading clients...");
-
-	SCR_AddDirtyPoint (0, 0);
-	SCR_AddDirtyPoint (viddef.width-1, viddef.height-1);
+	memset( loadingMessages , 0 , sizeof( loadingMessages ) );
+	Com_sprintf (loadingMessages[0][0], CL_LOADMSG_LENGTH, "Loading map...");
+	Com_sprintf (loadingMessages[1][0], CL_LOADMSG_LENGTH, "Loading models...");
+	Com_sprintf (loadingMessages[2][0], CL_LOADMSG_LENGTH, "Loading pics...");
+	Com_sprintf (loadingMessages[3][0], CL_LOADMSG_LENGTH, "Loading clients...");
 
 	// let the render dll load the map
 	strcpy (mapname, cl.configstrings[CS_MODELS+1] + 5);	// skip "maps/"
@@ -370,17 +363,23 @@ void CL_PrepRefresh ()
 
 	//this was moved here, to prevent having a pic loaded over and over again, which was
 	//totally killing performance after a dozen or so maps.
-	map_pic_loaded = (ptrdiff_t)(R_RegisterPic(va("/levelshots/%s.pcx", mapname)));
-	
-	Com_Printf ("Map: %s\r", mapname); 
+	// 2010-10 modified on suspicion of affecting possible compiler bug. see R_RegisterPic()
+	map_pic_loaded = false;
+	if ( R_RegisterPic( va("/levelshots/%s.pcx", mapname)) != NULL )
+	{
+		map_pic_loaded = true;
+	}
+
+	Com_Printf ("Map: %s\r", mapname);
+	Com_sprintf( loadingMessages[0][1] , CL_LOADMSG_LENGTH , "^3in progress" );
 	SCR_UpdateScreen ();
 	R_BeginRegistration (mapname);
 	Com_Printf ("                                     \r");
-	Com_sprintf (loadingMessages[0], sizeof(loadingMessages[0]), "loading map...done");
+	Com_sprintf (loadingMessages[0][1], CL_LOADMSG_LENGTH, "^2done");
 	loadingPercent += 20;
-	
+
 	// precache status bar pics
-	Com_Printf ("pics\r"); 
+	Com_Printf ("pics\r");
 	SCR_UpdateScreen ();
 	SCR_TouchPics ();
 	Com_Printf ("                                     \r");
@@ -390,17 +389,18 @@ void CL_PrepRefresh ()
 
 	for (i=1, max=0 ; i<MAX_MODELS && cl.configstrings[CS_MODELS+i][0] ; i++)
 		max++;
+
 	for (i=1 ; i<MAX_MODELS && cl.configstrings[CS_MODELS+i][0] ; i++)
 	{
 		strcpy (name, cl.configstrings[CS_MODELS+i]);
-		name[37] = 0;	// never go beyond one line
+		// name[37] = 0; 2010-10 archaic line length truncates log lines
+
 		if (name[0] != '*')
 		{
 			Com_Printf ("%s\r", name);
 
 			//only make max of 20 chars long
-			Com_sprintf (loadingMessages[1], sizeof(loadingMessages[1]), "loading models...%s", 
-				(strlen(name)>20)? &name[strlen(name)-20]: name);
+			Com_sprintf( loadingMessages[1][1] , CL_LOADMSG_LENGTH , "^1%s" , name );
 
 			//check for types
 			if(!strcmp(name, "models/weapons/g_rocket/tris.md2"))
@@ -434,7 +434,7 @@ void CL_PrepRefresh ()
 		}
 
 		SCR_UpdateScreen ();
-	
+
 		Sys_SendKeyEvents ();	// pump message loop
 		if (name[0] == '#')
 		{
@@ -444,8 +444,9 @@ void CL_PrepRefresh ()
 				strncpy(cl_weaponmodels[num_cl_weaponmodels], cl.configstrings[CS_MODELS+i]+1,
 					sizeof(cl_weaponmodels[num_cl_weaponmodels]) - 1);
 				num_cl_weaponmodels++;
+
 			}
-		} 
+		}
 		else
 		{
 			cl.model_draw[i] = R_RegisterModel (cl.configstrings[CS_MODELS+i]);
@@ -453,69 +454,79 @@ void CL_PrepRefresh ()
 				cl.model_clip[i] = CM_InlineModel (cl.configstrings[CS_MODELS+i]);
 			else
 				cl.model_clip[i] = NULL;
-		}
+			}
 		if (name[0] != '*')
 			Com_Printf ("                                     \r");
 
 		loadingPercent += 60.0f/(float)max;
 	}
-	Com_sprintf (loadingMessages[1], sizeof(loadingMessages[1]), "loading models...done");
-	
 
+	Com_sprintf (loadingMessages[1][1], CL_LOADMSG_LENGTH, "^3precaching");
 
-	Com_Printf ("images\r", i); 
+	SCR_UpdateScreen ();
+
+	R_RegisterBasePlayerModels();
+	if(cl_precachecustom->value)
+		R_RegisterCustomPlayerModels();
+
+	Com_sprintf (loadingMessages[1][1], CL_LOADMSG_LENGTH, "^2done");
+
+	Com_Printf ("images\r", i);
 	SCR_UpdateScreen ();
 
 	for (i=1, max=0 ; i<MAX_IMAGES && cl.configstrings[CS_IMAGES+i][0] ; i++)
 		max++;
+
 	for (i=1 ; i<MAX_IMAGES && cl.configstrings[CS_IMAGES+i][0] ; i++)
 	{
 		cl.image_precache[i] = R_RegisterPic (cl.configstrings[CS_IMAGES+i]);
-		Sys_SendKeyEvents ();	// pump message loop		
+		Sys_SendKeyEvents ();	// pump message loop
 		loadingPercent += 10.0f/(float)max;
 	}
-	Com_sprintf (loadingMessages[2], sizeof(loadingMessages[2]), "loading pics...done");
+	Com_sprintf (loadingMessages[2][1], CL_LOADMSG_LENGTH, "^2done");
 
 	Com_Printf ("                                     \r");
 
-	//refresh the player model/skin info 
+	//refresh the player model/skin info
 	CL_LoadClientinfo (&cl.baseclientinfo, va("unnamed\\%s\\%s", DEFAULTMODEL, DEFAULTSKIN));
 
 	for (i=1, max=0 ; i<MAX_CLIENTS ; i++)
 		if (cl.configstrings[CS_PLAYERSKINS+i][0])
 			max++;
+
 	for (i=0 ; i<MAX_CLIENTS ; i++)
 	{
 		if (!cl.configstrings[CS_PLAYERSKINS+i][0])
 			continue;
 
-		Com_sprintf (loadingMessages[3], sizeof(loadingMessages[3]), "loading clients...%i", i);
-		Com_Printf ("client %i\r", i); 
+		Com_sprintf (loadingMessages[3][1], CL_LOADMSG_LENGTH, "^3%i" , i);
+		Com_Printf ("client %i\r", i);
 		SCR_UpdateScreen ();
 		Sys_SendKeyEvents ();	// pump message loop
+
 		CL_ParseClientinfo (i);
 		Com_Printf ("                                     \r");
 		loadingPercent += 10.0f/(float)max;
 	}
-	Com_sprintf (loadingMessages[3], sizeof(loadingMessages[3]), "loading clients...done");
+	Com_sprintf (loadingMessages[3][1], CL_LOADMSG_LENGTH, "^2done");
 
 	//hack hack hack - psychospaz
 	loadingPercent = 100;
 
 	// set sky textures and speed
-	Com_Printf ("sky\r", i); 
+	Com_Printf ("sky\r", i);
 	SCR_UpdateScreen ();
 	rotate = atof (cl.configstrings[CS_SKYROTATE]);
-	sscanf (cl.configstrings[CS_SKYAXIS], "%f %f %f", 
+	sscanf(	cl.configstrings[CS_SKYAXIS], "%f %f %f",
 		&axis[0], &axis[1], &axis[2]);
-	R_SetSky (cl.configstrings[CS_SKY], rotate, axis);
+	R_SetSky( cl.configstrings[CS_SKY], rotate, axis );
 	Com_Printf ("                                     \r");
 
 	// the renderer can now free unneeded stuff
 	R_EndRegistration ();
 
 	// clear any lines of console text
-	Con_ClearNotify ();
+	CON_ClearNotify( );
 
 	SCR_UpdateScreen ();
 	cl.refresh_prepped = true;
@@ -571,9 +582,9 @@ float CalcFov (float fov_x, float width, float height)
 	if (fov_x < 1 || fov_x > 179)
 		Com_Error (ERR_DROP, "Bad fov: %f", fov_x);
 
-	x = width/tan(fov_x/360*M_PI);
-    a = atan (height/x);   
-    a = a*360/M_PI; 
+	x = width/tanf(fov_x/360*M_PI);
+    a = atan (height/x);
+    a = a*360/M_PI;
 
 	return a;
 }
@@ -606,162 +617,181 @@ qboolean InFront (vec3_t target)
 	vec3_t	vec;
 	float	dot;
 	vec3_t	forward;
-	
+
 	AngleVectors (cl.refdef.viewangles, forward, NULL, NULL);
 	VectorSubtract (target, cl.refdef.vieworg, vec);
 	VectorNormalize (vec);
 	dot = DotProduct (vec, forward);
-	
+
 	if (dot > 0.3)
 		return true;
 	return false;
 }
-//============== 
+//==============
 //SCR_DrawPlayerNamesCenter
-// shows player names at center of screen 
-//============== 
-void SCR_DrawPlayerNamesCenter( void ) 
-{ 
-   int         i; 
-   centity_t   *cent; 
-   float      dist, mindist; 
-   trace_t   trace;
-   vec3_t vecdist; 
-   vec3_t temp; 
-   vec3_t axis[3]; 
-   static vec3_t mins = { -8, -8, -8 }; 
-   static vec3_t maxs = { 8, 8, 8 }; 
-   int closest;
+// shows player names at center of screen
+//==============
+void SCR_DrawPlayerNamesCenter( void )
+{
+	static vec3_t		mins = { -8, -8, -8 };
+	static vec3_t		maxs = { 8, 8, 8 };
+	FNT_font_t		font;
+	struct FNT_window_s	box;
+	int			i;
+	centity_t *		cent;
+	float			dist, mindist;
+	trace_t			trace;
+	vec3_t			vecdist;
+	vec3_t			temp;
+	vec3_t			axis[3];
+	int			closest;
 
-   if( !cl_showPlayerNames->integer ) 
-      return; 
+	if( !cl_showPlayerNames->integer )
+		return;
 
-   mindist = 1000;
-   closest = 0;
- 
-   for( i = 0; i < MAX_CLIENTS; i++ ) 
-   { 
-      
-	  cent = cl_entities + i + 1; 
-	
-	  if( !cent->current.modelindex ) 
-		 continue; 
-	 
-	  if(!strcmp(cl.clientinfo[i].name, name->string))
-		  continue;
+	mindist = 1000;
+	closest = 0;
 
-	  trace = CL_Trace ( cl.refdef.vieworg, mins, maxs, cent->current.origin, -1, MASK_PLAYERSOLID, true, NULL); 
-	  if (trace.fraction != 1.0)	
-		  continue;
+	for( i = 0; i < MAX_CLIENTS; i++ )
+	{
+		cent = cl_entities + i + 1;
 
-	  VectorSubtract(cent->current.origin, cl.refdef.vieworg, vecdist); 
-	  dist = VectorLength(vecdist); 
+		if( !cent->current.modelindex )
+			continue;
 
-	  if (dist >= 1000) 
-		  continue; 
+		if(!strcmp(cl.clientinfo[i].name, name->string))
+			continue;
 
-	  if(dist < mindist && (strlen(cl.clientinfo[i].name) > 1) && InFront(cent->current.origin) ) {
-		  mindist = dist;
-		  closest = i;
-	  }
-      
-	  VectorSubtract (cent->current.origin, cl.refdef.vieworg, temp); 
-	  VectorNormalize (temp); 
+		trace = CL_Trace ( cl.refdef.vieworg, mins, maxs, cent->current.origin, -1, MASK_PLAYERSOLID, true, NULL);
+		if (trace.fraction != 1.0)
+			continue;
 
-	  AngleVectors(cl.refdef.viewangles, axis[0], axis[1], axis[2]); 
+		VectorSubtract(cent->current.origin, cl.refdef.vieworg, vecdist);
+		dist = VectorLength(vecdist);
 
-	  if (DotProduct (temp, axis[0]) < 0) 
-	      continue; 
+		if (dist >= 1000)
+			continue;
+
+		if(dist < mindist && (strlen(cl.clientinfo[i].name) > 1) && InFront(cent->current.origin) ) {
+			mindist = dist;
+			closest = i;
+		}
+
+		VectorSubtract (cent->current.origin, cl.refdef.vieworg, temp);
+		VectorNormalize (temp);
+
+		AngleVectors(cl.refdef.viewangles, axis[0], axis[1], axis[2]);
+
+		if (DotProduct (temp, axis[0]) < 0)
+			continue;
+	}
+
+	if (!closest) {
+		return;
+	}
+
+	font = FNT_AutoGet( CL_gameFont );
+	box.x = (int)( ( cl.refdef.width - 200 ) / 2 );
+	box.y = (int)( cl.refdef.height / 1.8 );
+	box.width = 400;
+	box.height = 0;
+	FNT_BoundedPrint( font , cl.clientinfo[closest].name , FNT_CMODE_QUAKE_SRS ,
+		FNT_ALIGN_CENTER , &box , FNT_colors[ 2 ] );
 
-	  }
-	  if(closest)
-		  Draw_ColorString( (int)(cl.refdef.width/2 - strlen(cl.clientinfo[closest].name)*3), (int)(cl.refdef.height/1.8), cl.clientinfo[closest].name, 1);
-  		
 }
 
-//============== 
-//SCR_DrawPlayerNames 
-// shows player names at their feets. 
-//============== 
+//==============
+//SCR_DrawPlayerNames
+// shows player names at their feets.
+//==============
 extern void R_TransformVectorToScreen( refdef_t *rd, vec3_t in, vec2_t out );
-void SCR_DrawPlayerNames( void ) 
-{ 
-   static vec4_t   whiteTransparent = { 1.0f, 1.0f, 1.0f, 0.5f }; 
-   int         i; 
-   centity_t   *cent; 
-   float      dist; 
-   trace_t   trace;
-   vec2_t screen_pos; 
-   vec3_t vecdist; 
-   vec3_t temp; 
-   vec3_t axis[3]; 
-   int y; 
-   static vec3_t mins = { -4, -4, -4 }; 
-   static vec3_t maxs = { 4, 4, 4 }; 
+void SCR_DrawPlayerNames( void )
+{
+	// static vec4_t   whiteTransparent = { 1.0f, 1.0f, 1.0f, 0.5f };
+	FNT_font_t	font;
+	int		i;
+	centity_t *	cent;
+	float		dist;
+	trace_t		trace;
+	vec2_t		screen_pos;
+	vec3_t		vecdist;
+	vec3_t		temp;
+	vec3_t		axis[3];
+	static vec3_t mins = { -4, -4, -4 };
+	static vec3_t maxs = { 4, 4, 4 };
 
-   if( !cl_showPlayerNames->integer ) 
-      return; 
-  
-   for( i = 0; i < MAX_CLIENTS; i++ ) 
-   { 
-      
-	  cent = cl_entities + i + 1; 
-	
-	  if( !cent->current.modelindex ) 
-		 continue; 
-	 
-	  if(!strcmp(cl.clientinfo[i].name, name->string))
-		  continue;
-	
-	  trace = CL_Trace ( cl.refdef.vieworg, mins, maxs, cent->current.origin, -1, MASK_PLAYERSOLID, true, NULL); 
-	  if (trace.fraction != 1.0)	
-		  continue;
+	font = FNT_AutoGet( CL_gameFont );
+	for( i = 0; i < MAX_CLIENTS; i++ )
+	{
+		struct FNT_window_s	box;
 
-	  VectorSubtract(cent->current.origin, cl.refdef.vieworg, vecdist); 
-	  dist = VectorLength(vecdist); 
+		cent = cl_entities + i + 1;
 
-	  if (dist >= 1000 || !InFront(cent->current.origin)) 
-		  continue; 
-      
-	  VectorSubtract (cent->current.origin, cl.refdef.vieworg, temp); 
-	  VectorNormalize (temp); 
+		if( !cent->current.modelindex )
+			continue;
 
-	  AngleVectors(cl.refdef.viewangles, axis[0], axis[1], axis[2]); 
+		if(!strcmp(cl.clientinfo[i].name, name->string))
+			continue;
 
-	  if (DotProduct (temp, axis[0]) < 0) 
-	      continue; 
+		trace = CL_Trace ( cl.refdef.vieworg, mins, maxs, cent->current.origin, -1, MASK_PLAYERSOLID, true, NULL);
+		if (trace.fraction != 1.0)
+			continue;
 
-	  R_TransformVectorToScreen(&cl.refdef, cent->current.origin, screen_pos); 
-	  y = cl.refdef.height-(int)screen_pos[1]-cl.refdef.height/6; 
-	  Draw_ColorString ( (int)screen_pos[0], y, cl.clientinfo[i].name, 1 ); 
+		VectorSubtract(cent->current.origin, cl.refdef.vieworg, vecdist);
+		dist = VectorLength(vecdist);
 
-   } 
+		if (dist >= 1000 || !InFront(cent->current.origin))
+			continue;
+
+		VectorSubtract (cent->current.origin, cl.refdef.vieworg, temp);
+		VectorNormalize (temp);
+
+		AngleVectors(cl.refdef.viewangles, axis[0], axis[1], axis[2]);
+
+		if (DotProduct (temp, axis[0]) < 0)
+			continue;
+
+		R_TransformVectorToScreen(&cl.refdef, cent->current.origin, screen_pos);
+		box.x = (int)screen_pos[0];
+		box.y = cl.refdef.height-(int)screen_pos[1]-cl.refdef.height/6;
+		box.width = box.height = 0;
+		FNT_BoundedPrint( font , cl.clientinfo[i].name , FNT_CMODE_QUAKE_SRS ,
+			FNT_ALIGN_LEFT , &box , FNT_colors[ 2 ] );
+
+	}
 }
 
 void SCR_DrawBases (void)
 {
-	int			i;
-	entity_t	*ent;
-    vec2_t screen_pos; 
-    int y; 
+	FNT_font_t	font;
+	int		i;
+	entity_t *	ent;
+	vec2_t		screen_pos;
 
+	font = FNT_AutoGet( CL_gameFont );
 	for (i=0 ; i<cl.refdef.num_entities; i++)
 	{
-		ent = &r_entities[i];
+		struct FNT_window_s	box;
+		const char *		str;
 
+		ent = &r_entities[i];
 		if(!ent->team)
 			continue;
+		if (!InFront(ent->origin))
+			continue;
+
+		R_TransformVectorToScreen(&cl.refdef, ent->origin, screen_pos);
+		box.x = (int)screen_pos[0];
+		box.y = cl.refdef.height-(int)screen_pos[1]-cl.refdef.height/6;
+		box.width = box.height = 0;
 
-		if (!InFront(ent->origin)) 
-			continue; 
-    
-		R_TransformVectorToScreen(&cl.refdef, ent->origin, screen_pos); 
-		y = cl.refdef.height-(int)screen_pos[1]-cl.refdef.height/6; 
 		if(ent->team == 2)
-			Draw_ColorString ( (int)screen_pos[0], y, "^4Blue Flag", 1 ); 
+			str = "^4Blue Flag";
 		else if(ent->team == 1)
-			Draw_ColorString ( (int)screen_pos[0], y, "^1Red Flag", 1 );
-
+			str = "^1Red Flag";
+		else
+			str = "Flag";
+		FNT_BoundedPrint( font , str , FNT_CMODE_QUAKE_SRS , FNT_ALIGN_LEFT , &box , FNT_colors[ 2 ] );
 	}
 }
 
@@ -877,9 +907,6 @@ void V_RenderView( float stereo_separation )
 
 	cl.refdef.rdflags |= RDF_BLOOM;   //BLOOMS
 
-	R_VCFreeFrame();
-	need_free_vbo = false;
-
 	R_RenderFrame (&cl.refdef);
 	if (cl_stats->value)
 		Com_Printf ("ent:%i  lt:%i  part:%i\n", r_numentities, r_numdlights, r_numparticles);
@@ -887,10 +914,6 @@ void V_RenderView( float stereo_separation )
 		fprintf( log_stats_file, "%i,%i,%i,",r_numentities, r_numdlights, r_numparticles);
 
 
-	SCR_AddDirtyPoint (scr_vrect.x, scr_vrect.y);
-	SCR_AddDirtyPoint (scr_vrect.x+scr_vrect.width-1,
-		scr_vrect.y+scr_vrect.height-1);
-
 	SCR_DrawCrosshair ();
 
 	if(cl_showPlayerNames->integer) {
@@ -901,19 +924,21 @@ void V_RenderView( float stereo_separation )
 
 		SCR_DrawBases();
 	}
+
 }
 
-
-/*
-=============
-V_Viewpos_f
-=============
-*/
+/**
+ * \brief Console output of position and orientation
+ *
+ * Target of 'viewpos' command. Modified 2011-02. Added pitch.
+ * Helps with repeatable positioning for timerefresh command
+ * and other performance testing.
+ */
 void V_Viewpos_f (void)
 {
-	Com_Printf ("(%i %i %i) : %i\n", (int)cl.refdef.vieworg[0],
-		(int)cl.refdef.vieworg[1], (int)cl.refdef.vieworg[2], 
-		(int)cl.refdef.viewangles[YAW]);
+	Com_Printf ("x:%#1.0f y:%#1.0f z:%#1.0f yaw:%#1.0f pitch:%#1.0f\n",
+		cl.refdef.vieworg[0], cl.refdef.vieworg[1], cl.refdef.vieworg[2],
+		cl.refdef.viewangles[YAW], cl.refdef.viewangles[PITCH] );
 }
 
 /*
