@@ -28,6 +28,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <stdlib.h>
 
 #include "ref.h"
+#include "ref_gl/r_text.h"
 
 #include "vid.h"
 #include "screen.h"
@@ -62,6 +63,10 @@ typedef struct
 	vec3_t		lerp_origin;		// for trails (variable hz)
 
 	int			fly_stoptime;
+
+	float		frametime;
+	int			prevframe;
+
 } centity_t;
 
 #define MAX_CLIENTWEAPONMODELS		20		// PGM -- upped from 16 to fit the chainfist vwep
@@ -84,7 +89,7 @@ extern char cl_weaponmodels[MAX_CLIENTWEAPONMODELS][MAX_QPATH];
 extern int num_cl_weaponmodels;
 
 extern char		scr_playericon[MAX_OSPATH];
-extern char		scr_playername[32];
+extern char		scr_playername[PLAYERNAME_SIZE];
 extern float	scr_playericonalpha;
 
 #define	CMD_BACKUP		64	// allow a lot of command backups for very fast systems
@@ -151,6 +156,7 @@ typedef struct
 	char		gamedir[MAX_QPATH];
 	int			playernum;
 
+	// Alien Arena client/server protocol depends on MAX_QPATH being 64.
 	char		configstrings[MAX_CONFIGSTRINGS][MAX_QPATH];
 
 	//
@@ -212,12 +218,14 @@ typedef struct
 									// > cls.disable_servercount, clear disable_screen
 
 // connection information
+
 	char		servername[MAX_OSPATH];	// name of server from original connect
 	float		connect_time;		// for connection retransmits
 
 	int			quakePort;			// a 16 bit value that allows quake servers
 									// to work around address translating routers
 	netchan_t	netchan;
+
 	int			serverProtocol;		// in case we are doing some kind of version hack
 
 	int			challenge;			// from the server to use for connecting
@@ -231,8 +239,6 @@ typedef struct
 	char		downloadurl[MAX_OSPATH];  // for http downloads
 	qboolean	downloadhttp;
 
-	int			irc_connected;		//track irc connection
-
 // demo recording info must be here, so it isn't cleared on level change
 	qboolean	demorecording;
 	qboolean	demowaiting;	// don't record until a non-delta message is received
@@ -264,6 +270,7 @@ extern  cvar_t	*cl_disbeamclr;
 extern  cvar_t	*cl_brass;
 extern  cvar_t	*cl_playtaunts;
 extern	cvar_t	*cl_centerprint;
+extern	cvar_t	*cl_precachecustom;
 
 extern	cvar_t	*cl_paindist;
 extern	cvar_t	*cl_explosiondist;
@@ -285,7 +292,9 @@ extern	cvar_t	*cl_showclamp;
 
 extern	cvar_t	*lookspring;
 extern	cvar_t	*lookstrafe;
+extern  cvar_t	*m_accel;
 extern	cvar_t	*sensitivity;
+extern  cvar_t  *menu_sensitivity;
 
 extern	cvar_t	*m_smoothing;
 extern	cvar_t	*m_pitch;
@@ -299,11 +308,18 @@ extern	cvar_t	*cl_paused;
 extern	cvar_t	*cl_timedemo;
 
 extern	cvar_t	*cl_vwep;
+extern  cvar_t  *cl_vehicle_huds;
 
 extern  cvar_t  *background_music;
 
 extern  cvar_t	*cl_IRC_connect_at_startup;
 extern	cvar_t	*cl_IRC_server;
+extern	cvar_t	*cl_IRC_channel;
+extern	cvar_t	*cl_IRC_port;
+extern	cvar_t	*cl_IRC_override_nickname;
+extern	cvar_t	*cl_IRC_nickname;
+extern	cvar_t	*cl_IRC_kick_rejoin;
+extern	cvar_t	*cl_IRC_reconnect_delay;
 
 typedef struct
 {
@@ -330,9 +346,6 @@ extern	entity_state_t	cl_parse_entities[MAX_PARSE_ENTITIES];
 extern	netadr_t	net_from;
 extern	sizebuf_t	net_message;
 
-void DrawString (int x, int y, char *s);
-void DrawAltString (int x, int y, char *s);	// toggle high bit
-void Draw_ColorString ( int x, int y, char *str, float scale);
 qboolean	CL_CheckOrDownloadFile (char *filename);
 
 void CL_AddNetgraph (void);
@@ -357,47 +370,6 @@ typedef struct cl_sustain
 
 //=================================================
 
-// ========
-// PGM
-typedef struct
-{
-	qboolean	isactive;
-
-	vec3_t		lightcol;
-	float		light;
-	float		lightvel;
-} cplight_t;
-
-#define P_LIGHTS_MAX 8
-
-typedef struct particle_s
-{
-	struct particle_s	*next;
-
-	cplight_t	lights[P_LIGHTS_MAX];
-
-	float		time;
-
-	vec3_t		org;
-	vec3_t		angle;
-	vec3_t		vel;
-	vec3_t		accel;
-	vec3_t		end;
-	float		color;
-	float		colorvel;
-	float		alpha;
-	float		alphavel;
-	int			type;		// 0 standard, 1 smoke, etc etc...
-	int			texnum;
-	int			blenddst;
-	int			blendsrc;
-	float		scale;
-	float		scalevel;
-	qboolean	fromsustainedeffect;
-
-} cparticle_t;
-
-
 #define	PARTICLE_GRAVITY	40
 #define BLASTER_PARTICLE_COLOR		0xe0
 // PMM
@@ -413,6 +385,7 @@ typedef struct particle_s
 #define CLM_NOSHADOW	8
 #define CLM_STOPPED		16
 #define CLM_BRASS		32
+#define CLM_GLASS		64
 
 typedef struct clentity_s {
 	struct clentity_s *next;
@@ -556,21 +529,13 @@ float CL_KeyState (kbutton_t *key);
 char *Key_KeynumToString (int keynum);
 
 //cl_irc.c
-typedef struct IRCresponse_s
-{
-	char word[200][50];
-	int words;
-} IRCresponse_t;
-
-typedef struct user_s
-{
-	char nick[32]; 
-	char email[100];
-} user_t;
-
+void CL_IRCSetup(void);
 void CL_InitIRC(void);
-void CL_IRCShutdown(void);
+void CL_IRCInitiateShutdown(void);
+void CL_IRCWaitShutdown(void);
 void CL_IRCSay(void);
+qboolean CL_IRCIsConnected(void);
+qboolean CL_IRCIsRunning(void);
 
 //
 // cl_demo.c
@@ -601,7 +566,7 @@ void SCR_IRCPrintf (char *fmt, ...);
 //
 
 typedef struct _PLAYERSTATS {
-	char playername[32];
+	char playername[PLAYERNAME_SIZE];
 	int totalfrags;
 	double totaltime;
 	int ranking;
@@ -615,10 +580,10 @@ PLAYERSTATS getPlayerByRank ( int rank, PLAYERSTATS player );
 // cl_view.c
 //
 
-extern qboolean need_free_vbo;
+#define CL_LOADMSG_LENGTH 96
 
 qboolean loadingMessage;
-char loadingMessages[5][96];
+char loadingMessages[5][2][CL_LOADMSG_LENGTH];
 float loadingPercent;
 int rocketlauncher;
 int rocketlauncher_drawn;
@@ -646,11 +611,13 @@ int sproing;
 int sproing_drawn;
 int numitemicons;
 
+int vehicle_hud;
+
 void V_Init (void);
 void V_RenderView( float stereo_separation );
 void V_AddEntity (entity_t *ent);
 void V_AddViewEntity (entity_t *ent);
-void V_AddParticle (vec3_t org, vec3_t angle, int color, int type, int texnum, int blenddst, int blendsrc, float alpha, float scale);
+void V_AddParticle (particle_t	*p);
 void V_AddLight (vec3_t org, float intensity, float r, float g, float b);
 void V_AddTeamLight (vec3_t org, float intensity, float r, float g, float b, int team);
 void V_AddLightStyle (int style, float r, float g, float b);
@@ -719,7 +686,7 @@ unsigned long *x86_TimerGetHistogram( void );
 //
 // cl_view, cl_scrn
 //
-int map_pic_loaded;
+qboolean map_pic_loaded;
 int stringLen (char *string);
 //
 //mouse
@@ -738,3 +705,10 @@ void CL_HttpDownloadThink(void);
 void CL_ShutdownHttpDownload(void);
 
 
+//
+// Fonts used by various elements
+//
+
+extern FNT_auto_t	CL_gameFont;
+extern FNT_auto_t	CL_centerFont;
+extern FNT_auto_t	CL_consoleFont;
