@@ -1,22 +1,21 @@
 /*
- Copyright (C) 1997-2001 Id Software, Inc.
+Copyright (C) 2009 COR Entertainment, LLC.
 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation; either version 2
+of the License, or (at your option) any later version.
 
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
- See the GNU General Public License for more details.
+See the GNU General Public License for more details.
 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-
- */
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
 /*
  * snd_openal.c
  *
@@ -29,10 +28,29 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
+#if defined HAVE_MALLOC_H
 #include <malloc.h>
+#elif defined HAVE_MALLOC_MALLOC_H
+#include <malloc/malloc.h>
+#endif
 #include <string.h>
 
+#if defined HAVE_AL_H
+#include <al.h>
+#include <alc.h>
+#elif defined HAVE_AL_AL_H
+#include <AL/al.h>
+#include <AL/alc.h>
+#elif defined HAVE_OPENAL_AL_H
+#include <OpenAL/al.h>
+#include <OpenAL/alc.h>
+#endif
+
 #include "client.h"
 #include "qal.h"
 
@@ -81,7 +99,7 @@ typedef struct sfx_s
 	int oalFormat; //            file format code from OpenAL
 	ALuint oalBuffer; //         index into collection of OpenAL buffers
 	qboolean aliased; //         the file loaded is an alias for the truename
-	char name[MAX_QPATH]; //     full file path
+	char name[MAX_QPATH]; //     relative file path
 	char truename[MAX_QPATH]; // in case 'name' is an 'alias'
 } sfx_t;
 
@@ -1386,7 +1404,7 @@ void calEnumerateDevices( void )
 	{
 		oalDeviceList = qalcGetString( NULL, ALC_DEVICE_SPECIFIER );
 		pDeviceName = (ALCchar*)oalDeviceList;
-		while( (len = strlen( pDeviceName )) )
+		while( pDeviceName && (len = strlen( pDeviceName )) )
 		{
 			pDevice = qalcOpenDevice( pDeviceName );
 			calErrorCheckALC( pDevice, __LINE__ );  // clear any device error
