@@ -11,9 +11,9 @@
 //
 //	Please see liscense.txt in the source directory for the copyright
 //	information regarding those files belonging to Id Software, Inc.
-//	
+//
 //	Should you decide to release a modified version of ACE, you MUST
-//	include the following text (minus the BEGIN and END lines) in the 
+//	include the following text (minus the BEGIN and END lines) in the
 //	documentation for your modification.
 //
 //	--- BEGIN ---
@@ -24,7 +24,7 @@
 //	This program is a modification of the ACE Bot, and is therefore
 //	in NO WAY supported by Steve Yeager.
 
-//	This program MUST NOT be sold in ANY form. If you have paid for 
+//	This program MUST NOT be sold in ANY form. If you have paid for
 //	this product, you should contact Steve Yeager immediately, via
 //	the ACE Bot homepage.
 //
@@ -44,19 +44,23 @@
 //  Telefragged.com - For giving ACE a home.
 //  Microsoft       - For giving us such a wonderful crash free OS.
 //  id              - Need I say more.
-//  
+//
 //  And to all the other testers, pathers, and players and people
 //  who I can't remember who the heck they were, but helped out.
 //
 ///////////////////////////////////////////////////////////////////////
-	
+
 ///////////////////////////////////////////////////////////////////////
 //
 //  acebot_cmds.c - Main internal command processor
 //
 ///////////////////////////////////////////////////////////////////////
 
-#include "../g_local.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "game/g_local.h"
 #include "acebot.h"
 
 qboolean debug_mode=false;
@@ -71,25 +75,25 @@ qboolean ACECM_Commands(edict_t *ent)
 
 	cmd = gi.argv(0);
 
-	if(Q_stricmp (cmd, "addnode") == 0 && debug_mode)
-		ent->last_node = ACEND_AddNode(ent,atoi(gi.argv(1))); 
-	
-	else if(Q_stricmp (cmd, "removelink") == 0 && debug_mode)
+	if(Q_strcasecmp (cmd, "addnode") == 0 && debug_mode)
+		ent->last_node = ACEND_AddNode(ent,atoi(gi.argv(1)));
+
+	else if(Q_strcasecmp (cmd, "removelink") == 0 && debug_mode)
 		ACEND_RemoveNodeEdge(ent,atoi(gi.argv(1)), atoi(gi.argv(2)));
 
-	else if(Q_stricmp (cmd, "addlink") == 0 && debug_mode)
+	else if(Q_strcasecmp (cmd, "addlink") == 0 && debug_mode)
 		ACEND_UpdateNodeEdge(atoi(gi.argv(1)), atoi(gi.argv(2)));
-	
-	else if(Q_stricmp (cmd, "showpath") == 0 && debug_mode)
+
+	else if(Q_strcasecmp (cmd, "showpath") == 0 && debug_mode)
     	ACEND_ShowPath(ent,atoi(gi.argv(1)));
 
-	else if(Q_stricmp (cmd, "findnode") == 0 && debug_mode)
+	else if(Q_strcasecmp (cmd, "findnode") == 0 && debug_mode)
 	{
 		node = ACEND_FindClosestReachableNode(ent,NODE_DENSITY, NODE_ALL);
 		safe_bprintf(PRINT_MEDIUM,"node: %d type: %d x: %f y: %f z %f\n",node,nodes[node].type,nodes[node].origin[0],nodes[node].origin[1],nodes[node].origin[2]);
 	}
 
-	else if(Q_stricmp (cmd, "movenode") == 0 && debug_mode)
+	else if(Q_strcasecmp (cmd, "movenode") == 0 && debug_mode)
 	{
 		node = atoi(gi.argv(1));
 		nodes[node].origin[0] = atof(gi.argv(2));
@@ -114,16 +118,16 @@ void ACECM_Store()
 }
 
 ///////////////////////////////////////////////////////////////////////
-// These routines are bot safe print routines, all id code needs to be 
-// changed to these so the bots do not blow up on messages sent to them. 
-// Do a find and replace on all code that matches the below criteria. 
+// These routines are bot safe print routines, all id code needs to be
+// changed to these so the bots do not blow up on messages sent to them.
+// Do a find and replace on all code that matches the below criteria.
 //
 // (Got the basic idea from Ridah)
-//	
+//
 //  change: gi.cprintf to safe_cprintf
 //  change: gi.bprintf to safe_bprintf
 //  change: gi.centerprintf to safe_centerprintf
-// 
+//
 ///////////////////////////////////////////////////////////////////////
 
 ///////////////////////////////////////////////////////////////////////
@@ -136,15 +140,15 @@ void debug_printf(char *fmt, ...)
 	int		len;
 	va_list	argptr;
 	edict_t	*cl_ent;
-	
+
 	va_start (argptr,fmt);
 	len = vsnprintf (bigbuffer,sizeof(bigbuffer),fmt,argptr);
 	va_end (argptr);
 
-	if (dedicated->value)
+	if (g_dedicated->value)
 		gi.cprintf(NULL, PRINT_MEDIUM, "%s", bigbuffer);
 
-	for (i=0 ; i<maxclients->value ; i++)
+	for (i=0 ; i<g_maxclients->value ; i++)
 	{
 		cl_ent = g_edicts + 1 + i;
 		if (!cl_ent->inuse || cl_ent->is_bot)
@@ -172,7 +176,7 @@ void safe_cprintf (edict_t *ent, int printlevel, char *fmt, ...)
 	va_end (argptr);
 
 	gi.cprintf(ent, printlevel, "%s", bigbuffer);
-	
+
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -186,13 +190,13 @@ void safe_centerprintf (edict_t *ent, char *fmt, ...)
 
 	if (!ent->inuse || ent->is_bot)
 		return;
-	
+
 	va_start (argptr,fmt);
 	len = vsnprintf (bigbuffer,sizeof(bigbuffer),fmt,argptr);
 	va_end (argptr);
-	
+
 	gi.centerprintf(ent,"%s", bigbuffer);
-	
+
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -210,10 +214,10 @@ void safe_bprintf (int printlevel, char *fmt, ...)
 	len = vsnprintf (bigbuffer,sizeof(bigbuffer),fmt,argptr);
 	va_end (argptr);
 
-	if (dedicated->value)
+	if (g_dedicated->value)
 		gi.cprintf(NULL, printlevel, "%s", bigbuffer);
 
-	for (i=0 ; i<maxclients->value ; i++)
+	for (i=0 ; i<g_maxclients->value ; i++)
 	{
 		cl_ent = g_edicts + 1 + i;
 		if (!cl_ent->inuse || cl_ent->is_bot)
