@@ -11,9 +11,9 @@
 //
 //	Please see liscense.txt in the source directory for the copyright
 //	information regarding those files belonging to Id Software, Inc.
-//	
+//
 //	Should you decide to release a modified version of ACE, you MUST
-//	include the following text (minus the BEGIN and END lines) in the 
+//	include the following text (minus the BEGIN and END lines) in the
 //	documentation for your modification.
 //
 //	--- BEGIN ---
@@ -24,7 +24,7 @@
 //	This program is a modification of the ACE Bot, and is therefore
 //	in NO WAY supported by Steve Yeager.
 
-//	This program MUST NOT be sold in ANY form. If you have paid for 
+//	This program MUST NOT be sold in ANY form. If you have paid for
 //	this product, you should contact Steve Yeager immediately, via
 //	the ACE Bot homepage.
 //
@@ -44,7 +44,7 @@
 //  Telefragged.com - For giving ACE a home.
 //  Microsoft       - For giving us such a wonderful crash free OS.
 //  id              - Need I say more.
-//  
+//
 //  And to all the other testers, pathers, and players and people
 //  who I can't remember who the heck they were, but helped out.
 //
@@ -52,13 +52,17 @@
 
 ///////////////////////////////////////////////////////////////////////
 //
-//  acebot_items.c - This file contains all of the 
-//                   item handling routines for the 
+//  acebot_items.c - This file contains all of the
+//                   item handling routines for the
 //                   ACE bot, including fact table support
-//           
+//
 ///////////////////////////////////////////////////////////////////////
 
-#include "../g_local.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "game/g_local.h"
 #include "acebot.h"
 
 int num_items = 0;
@@ -90,7 +94,7 @@ qboolean ACEIT_IsReachable(edict_t *self, vec3_t goal)
 	v[2] += 18; // Stepsize
 
 	trace = gi.trace (self->s.origin, v, self->maxs, goal, self, BOTMASK_OPAQUE);
-	
+
 	// Yes we can see it
 	if (trace.fraction == 1.0)
 		return true;
@@ -100,14 +104,14 @@ qboolean ACEIT_IsReachable(edict_t *self, vec3_t goal)
 }
 
 ///////////////////////////////////////////////////////////////////////
-// Visiblilty check 
+// Visiblilty check
 ///////////////////////////////////////////////////////////////////////
 qboolean ACEIT_IsVisible(edict_t *self, vec3_t goal)
 {
 	trace_t trace;
-	
+
 	trace = gi.trace (self->s.origin, vec3_origin, vec3_origin, goal, self, BOTMASK_OPAQUE);
-	
+
 	// Yes we can see it
 	if (trace.fraction == 1.0)
 		return true;
@@ -123,10 +127,10 @@ qboolean ACEIT_ChangeWeapon (edict_t *ent, gitem_t *item)
 {
 	int			ammo_index;
 	gitem_t		*ammo_item;
-		
+
 	// see if we're already using it
 	if (item == ent->client->pers.weapon)
-		return true; 
+		return true;
 
 	// Has not picked up weapon yet
 	if(!ent->client->pers.inventory[ITEM_INDEX(item)])
@@ -172,7 +176,7 @@ qboolean ACEIT_CanUseArmor (gitem_t *item, edict_t *other)
 	// handle armor shards specially
 	if (item->tag == ARMOR_SHARD)
 		return true;
-	
+
 	// get info on old armor
 	if (old_armor_index == ITEM_INDEX(FindItem("Jacket Armor")))
 		oldinfo = &jacketarmor_info;
@@ -209,7 +213,7 @@ gitem_t	*ACEIT_WantedFlag (edict_t *self)
 
 	if (!ctf->value)
 		return NULL;
-	
+
 	//find out if the player has a flag, and what flag is it
 	if (redflag && self->client->pers.inventory[ITEM_INDEX(redflag)])
 		hasflag = true;
@@ -256,10 +260,10 @@ float ACEIT_ItemNeed(edict_t *self, int item)
 	switch(item)
 	{
 		// Health
-		case ITEMLIST_HEALTH_SMALL:	
+		case ITEMLIST_HEALTH_SMALL:
 		case ITEMLIST_HEALTH_MEDIUM:
-		case ITEMLIST_HEALTH_LARGE:	
-		case ITEMLIST_HEALTH_MEGA:	
+		case ITEMLIST_HEALTH_LARGE:
+		case ITEMLIST_HEALTH_MEGA:
 			if(self->health < 100)
 				return 1.0 - (float)self->health/100.0f; // worse off, higher priority
 			else
@@ -269,9 +273,9 @@ float ACEIT_ItemNeed(edict_t *self, int item)
 		case ITEMLIST_INVULNERABILITY:
 		case ITEMLIST_HASTE:
 		case ITEMLIST_SPROING:
-		case ITEMLIST_ADRENALINE:		
+		case ITEMLIST_ADRENALINE:
 			return 0.6;
-		
+
 		// Weapons
 		case ITEMLIST_ROCKETLAUNCHER:
 		case ITEMLIST_RAILGUN:
@@ -286,57 +290,57 @@ float ACEIT_ItemNeed(edict_t *self, int item)
 				return 0.0;
 
 		// Ammo
-		case ITEMLIST_SLUGS:			
+		case ITEMLIST_SLUGS:
 			if(self->client->pers.inventory[ITEMLIST_SLUGS] < self->client->pers.max_slugs)
-				return 0.4;  
+				return 0.4;
 			else
 				return 0.0;
-	
+
 		case ITEMLIST_BULLETS:
 			if(self->client->pers.inventory[ITEMLIST_BULLETS] < self->client->pers.max_bullets)
-				return 0.3;  
+				return 0.3;
 			else
 				return 0.0;
-	
+
 		case ITEMLIST_SHELLS:
 		   if(self->client->pers.inventory[ITEMLIST_SHELLS] < self->client->pers.max_shells)
-				return 0.3;  
+				return 0.3;
 			else
 				return 0.0;
-	
+
 		case ITEMLIST_CELLS:
 			if(self->client->pers.inventory[ITEMLIST_CELLS] <	self->client->pers.max_cells)
-				return 0.3;  
+				return 0.3;
 			else
 				return 0.0;
-	
+
 		case ITEMLIST_ROCKETS:
 			if(self->client->pers.inventory[ITEMLIST_ROCKETS] < self->client->pers.max_rockets)
-				return 1.5;  
+				return 1.5;
 			else
 				return 0.0;
-	
+
 		case ITEMLIST_GRENADES:
 			if(self->client->pers.inventory[ITEMLIST_GRENADES] < self->client->pers.max_grenades)
-				return 0.3;  
+				return 0.3;
 			else
 				return 0.0;
-	
+
 		case ITEMLIST_BODYARMOR:
 			if(ACEIT_CanUseArmor (FindItem("Body Armor"), self))
-				return 0.6;  
+				return 0.6;
 			else
 				return 0.0;
-	
+
 		case ITEMLIST_COMBATARMOR:
 			if(ACEIT_CanUseArmor (FindItem("Combat Armor"), self))
-				return 0.6;  
+				return 0.6;
 			else
 				return 0.0;
-	
+
 		case ITEMLIST_JACKETARMOR:
 			if(ACEIT_CanUseArmor (FindItem("Jacket Armor"), self))
-				return 0.6;  
+				return 0.6;
 			else
 				return 0.0;
 		//flags
@@ -353,23 +357,23 @@ float ACEIT_ItemNeed(edict_t *self, int item)
 			else
 				return 3.0;
 		//vehicles
-		case ITEMLIST_BOMBER:	
+		case ITEMLIST_BOMBER:
 		case ITEMLIST_STRAFER:
 		case ITEMLIST_HOVER:
 			if(!self->client->pers.inventory[item])
-				return 0.9; 
+				return 0.9;
 			else
 				return 0.0;
-	
+
 		//deathball
 		case ITEMLIST_DEATHBALL:
 			return 3.0;
 
 		default:
 			return 0.0;
-			
+
 	}
-		
+
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -381,15 +385,15 @@ float ACEIT_ItemNeed(edict_t *self, int item)
 ///////////////////////////////////////////////////////////////////////
 int ACEIT_ClassnameToIndex(char *classname)
 {
-	if(strcmp(classname,"item_armor_body")==0) 
+	if(strcmp(classname,"item_armor_body")==0)
 		return ITEMLIST_BODYARMOR;
-	
+
 	if(strcmp(classname,"item_armor_combat")==0)
 		return ITEMLIST_COMBATARMOR;
 
 	if(strcmp(classname,"item_armor_jacket")==0)
 		return ITEMLIST_JACKETARMOR;
-	
+
 	if(strcmp(classname,"item_armor_shard")==0)
 		return ITEMLIST_ARMORSHARD;
 
@@ -398,13 +402,13 @@ int ACEIT_ClassnameToIndex(char *classname)
 
 	if(strcmp(classname,"weapon_shotgun")==0)
 		return ITEMLIST_SHOTGUN;
-	
+
 	if(strcmp(classname,"weapon_supershotgun")==0)
 		return ITEMLIST_SUPERSHOTGUN;
-	
+
 	if(strcmp(classname,"weapon_chaingun")==0)
 		return ITEMLIST_CHAINGUN;
-	
+
 	if(strcmp(classname,"ammo_grenades")==0)
 		return ITEMLIST_GRENADES;
 
@@ -422,7 +426,7 @@ int ACEIT_ClassnameToIndex(char *classname)
 
 	if(strcmp(classname,"ammo_shells")==0)
 		return ITEMLIST_SHELLS;
-	
+
 	if(strcmp(classname,"ammo_bullets")==0)
 		return ITEMLIST_BULLETS;
 
@@ -434,13 +438,13 @@ int ACEIT_ClassnameToIndex(char *classname)
 
 	if(strcmp(classname,"ammo_slugs")==0)
 		return ITEMLIST_SLUGS;
-	
+
 	if(strcmp(classname,"item_quad")==0)
 		return ITEMLIST_QUADDAMAGE;
 
 	if(strcmp(classname,"item_invunerability")==0)
 		return ITEMLIST_INVULNERABILITY;
-	
+
 	if(strcmp(classname,"item_haste")==0)
 		return ITEMLIST_HASTE;
 
@@ -461,7 +465,7 @@ int ACEIT_ClassnameToIndex(char *classname)
 
 	if(strcmp(classname,"item_health_large")==0)
 		return ITEMLIST_HEALTH_LARGE;
-	
+
 	if(strcmp(classname,"item_health_mega")==0)
 		return ITEMLIST_HEALTH_MEGA;
 
@@ -473,13 +477,13 @@ int ACEIT_ClassnameToIndex(char *classname)
 
 	if(strcmp(classname, "item_bomber") == 0)
 		return ITEMLIST_BOMBER;
-	
+
 	if(strcmp(classname, "item_strafer") == 0)
 		return ITEMLIST_STRAFER;
 
 	if(strcmp(classname, "item_deathball") == 0)
 		return ITEMLIST_DEATHBALL;
-	
+
 	return INVALID;
 }
 
@@ -504,7 +508,7 @@ void ACEIT_BuildItemNodeTable (qboolean rebuild)
 	if((pOut = fopen("items.txt","wt"))==NULL)
 		return;
 #endif
-	
+
 	num_items = 0;
 
 	// Add game items
@@ -513,15 +517,15 @@ void ACEIT_BuildItemNodeTable (qboolean rebuild)
 		// filter out crap
 		if(items->solid == SOLID_NOT)
 			continue;
-		
+
 		if(!items->classname)
 			continue;
-		
+
 		/////////////////////////////////////////////////////////////////
 		// Items
 		/////////////////////////////////////////////////////////////////
 		item_index = ACEIT_ClassnameToIndex(items->classname);
-		
+
 		////////////////////////////////////////////////////////////////
 		// SPECIAL NAV NODE DROPPING CODE
 		////////////////////////////////////////////////////////////////
@@ -532,7 +536,7 @@ void ACEIT_BuildItemNodeTable (qboolean rebuild)
 				ACEND_AddNode(items,NODE_PLATFORM);
 			item_index = 99; // to allow to pass the item index test
 		}
-		
+
 		// Special node dropping for teleporters
 		if(strcmp(items->classname,"misc_teleporter_dest")==0 || strcmp(items->classname,"misc_teleporter")==0)
 		{
@@ -540,21 +544,21 @@ void ACEIT_BuildItemNodeTable (qboolean rebuild)
 				ACEND_AddNode(items,NODE_TELEPORTER);
 			item_index = 99;
 		}
-		
+
 		#ifdef DEBUG
 		if(item_index == INVALID)
 			fprintf(pOut,"Rejected item: %s node: %d pos: %f %f %f\n",items->classname,item_table[num_items].node,items->s.origin[0],items->s.origin[1],items->s.origin[2]);
 		else
 			fprintf(pOut,"item: %s node: %d pos: %f %f %f\n",items->classname,item_table[num_items].node,items->s.origin[0],items->s.origin[1],items->s.origin[2]);
-		#endif		
-	
+		#endif
+
 		if(item_index == INVALID)
 			continue;
 
 		// add a pointer to the item entity
 		item_table[num_items].ent = items;
 		item_table[num_items].item = item_index;
-	
+
 		// If new, add nodes for items
 		if(!rebuild)
 		{
@@ -562,30 +566,30 @@ void ACEIT_BuildItemNodeTable (qboolean rebuild)
 			item_table[num_items].node = ACEND_AddNode(items,NODE_ITEM);
 			num_items++;
 		}
-		else // Now if rebuilding, just relink ent structures 
+		else // Now if rebuilding, just relink ent structures
 		{
 			// Find stored location
-			for(i=0;i<numnodes;i++)
+			for(i=0;i<bot_numnodes;i++)
 			{
 				if(nodes[i].type == NODE_ITEM ||
 				   nodes[i].type == NODE_PLATFORM ||
 				   nodes[i].type == NODE_TELEPORTER) // valid types
 				{
 					VectorCopy(items->s.origin,v);
-					
+
 					// Add 16 to item type nodes
 					if(nodes[i].type == NODE_ITEM)
 						v[2] += 16;
-					
+
 					// Add 32 to teleporter
 					if(nodes[i].type == NODE_TELEPORTER)
 						v[2] += 32;
-					
+
 					if(nodes[i].type == NODE_PLATFORM)
 					{
 						VectorCopy(items->maxs,v1);
 						VectorCopy(items->mins,v2);
-		
+
 						// To get the center
 						v[0] = (v1[0] - v2[0]) / 2 + v2[0];
 						v[1] = (v1[1] - v2[1]) / 2 + v2[1];
@@ -598,16 +602,16 @@ void ACEIT_BuildItemNodeTable (qboolean rebuild)
 					{
 						// found a match now link to facts
 						item_table[num_items].node = i;
-			
+
 #ifdef DEBUG
 						fprintf(pOut,"Relink item: %s node: %d pos: %f %f %f\n",items->classname,item_table[num_items].node,items->s.origin[0],items->s.origin[1],items->s.origin[2]);
-#endif							
+#endif
 						num_items++;
 					}
 				}
 			}
 		}
-		
+
 
 	}
 
