@@ -11,9 +11,9 @@
 //
 //	Please see liscense.txt in the source directory for the copyright
 //	information regarding those files belonging to Id Software, Inc.
-//	
+//
 //	Should you decide to release a modified version of ACE, you MUST
-//	include the following text (minus the BEGIN and END lines) in the 
+//	include the following text (minus the BEGIN and END lines) in the
 //	documentation for your modification.
 //
 //	--- BEGIN ---
@@ -24,7 +24,7 @@
 //	This program is a modification of the ACE Bot, and is therefore
 //	in NO WAY supported by Steve Yeager.
 
-//	This program MUST NOT be sold in ANY form. If you have paid for 
+//	This program MUST NOT be sold in ANY form. If you have paid for
 //	this product, you should contact Steve Yeager immediately, via
 //	the ACE Bot homepage.
 //
@@ -44,37 +44,41 @@
 //  Telefragged.com - For giving ACE a home.
 //  Microsoft       - For giving us such a wonderful crash free OS.
 //  id              - Need I say more.
-//  
+//
 //  And to all the other testers, pathers, and players and people
 //  who I can't remember who the heck they were, but helped out.
 //
 ///////////////////////////////////////////////////////////////////////
 
-///////////////////////////////////////////////////////////////////////	
+///////////////////////////////////////////////////////////////////////
 //
-//  acebot_nodes.c -   This file contains all of the 
+//  acebot_nodes.c -   This file contains all of the
 //                     pathing routines for the ACE bot.
-// 
+//
 ///////////////////////////////////////////////////////////////////////
 
-#include "../g_local.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "game/g_local.h"
 #include "acebot.h"
 
 // flags
 qboolean newmap=true;
 
 // Total number of nodes that are items
-int numitemnodes; 
+int numitemnodes;
 
 // Total number of nodes
-int numnodes; 
+int bot_numnodes;
 
 // For debugging paths
 int show_path_from = -1;
 int show_path_to = -1;
 
 // array for node data
-node_t nodes[MAX_NODES]; 
+node_t nodes[MAX_NODES];
 short int path_table[MAX_NODES][MAX_NODES];
 
 ///////////////////////////////////////////////////////////////////////
@@ -90,7 +94,7 @@ int ACEND_FindCost(int from, int to)
 	int cost=1; // Shortest possible is 1
 
 	// If we can not get there then return invalid
-	if (path_table[from][to] == INVALID) 
+	if (path_table[from][to] == INVALID)
 	{
 		//if(debug_mode)
 		//		debug_printf("Found invalid path!");
@@ -107,7 +111,7 @@ int ACEND_FindCost(int from, int to)
 		{
 			//if(debug_mode)
 			//	debug_printf("Found invalid path!");
-	
+
 			return INVALID;
 		}
 		cost++;
@@ -117,14 +121,14 @@ int ACEND_FindCost(int from, int to)
 			break;
 		}
 	}
-	
+
 	return cost;
 }
 
 ///////////////////////////////////////////////////////////////////////
 // Find a close node to the player within dist.
 //
-// Faster than looking for the closest node, but not very 
+// Faster than looking for the closest node, but not very
 // accurate.
 ///////////////////////////////////////////////////////////////////////
 int ACEND_FindCloseReachableNode(edict_t *self, int range, int type)
@@ -136,11 +140,11 @@ int ACEND_FindCloseReachableNode(edict_t *self, int range, int type)
 
 	range *= range;
 
-	for(i=0;i<numnodes;i++)
+	for(i=0;i<bot_numnodes;i++)
 	{
 		if(type == NODE_ALL || type == nodes[i].type) // check node type
 		{
-		
+
 			VectorSubtract(nodes[i].origin,self->s.origin,v); // subtract first
 
 			dist = v[0]*v[0] + v[1]*v[1] + v[2]*v[2];
@@ -176,7 +180,7 @@ int ACEND_FindClosestReachableNode(edict_t *self, int range, int type)
 
 	VectorCopy(self->mins,mins);
 	VectorCopy(self->maxs,maxs);
-	
+
 	// For Ladders, do not worry so much about reachability
 	if(type == NODE_LADDER)
 	{
@@ -186,17 +190,17 @@ int ACEND_FindClosestReachableNode(edict_t *self, int range, int type)
 	else
 		mins[2] += 18; // Stepsize
 
-	rng = (float)(range * range); // square range for distance comparison (eliminate sqrt)	
-	
-	for(i=0;i<numnodes;i++)
-	{		
+	rng = (float)(range * range); // square range for distance comparison (eliminate sqrt)
+
+	for(i=0;i<bot_numnodes;i++)
+	{
 		if(type == NODE_ALL || type == nodes[i].type) // check node type
 		{
 			VectorSubtract(nodes[i].origin, self->s.origin,v); // subtract first
 
 			dist = v[0]*v[0] + v[1]*v[1] + v[2]*v[2];
-		
-			if(dist < closest && dist < rng) 
+
+			if(dist < closest && dist < rng)
 			{
 				// make sure it is visible
 				tr = gi.trace (self->s.origin, mins, maxs, nodes[i].origin, self, MASK_SOLID);
@@ -208,7 +212,7 @@ int ACEND_FindClosestReachableNode(edict_t *self, int range, int type)
 			}
 		}
 	}
-	
+
 	return node;
 }
 
@@ -225,14 +229,14 @@ void ACEND_SetGoal(edict_t *self, int goal_node)
 
 	self->goal_node = goal_node;
 	node = ACEND_FindClosestReachableNode(self, NODE_DENSITY*3, NODE_ALL);
-	
+
 	if(node == -1)
 		return;
-	
+
 	if(debug_mode)
 		debug_printf("%s new start node selected %d\n",self->client->pers.netname,node);
-	
-	
+
+
 	self->current_node = node;
 	self->next_node = self->current_node; // make sure we get to the nearest node first
 	self->node_timeout = 0;
@@ -246,9 +250,9 @@ void ACEND_SetGoal(edict_t *self, int goal_node)
 qboolean ACEND_FollowPath(edict_t *self)
 {
 	vec3_t v;
-	
+
 	//////////////////////////////////////////
-	// Show the path 
+	// Show the path
 	if(debug_mode) {
 		show_path_from = self->current_node;
 		show_path_to = self->goal_node;
@@ -264,11 +268,11 @@ qboolean ACEND_FollowPath(edict_t *self)
 		else
 			ACEND_SetGoal(self,self->goal_node);
 	}
-		
+
 	// Are we there yet?
 	VectorSubtract(self->s.origin,nodes[self->next_node].origin,v);
-	
-	if(VectorLength(v) < 32) 
+
+	if(VectorLength(v) < 32)
 	{
 		// reset timeout
 		self->node_timeout = 0;
@@ -276,8 +280,8 @@ qboolean ACEND_FollowPath(edict_t *self)
 		if(self->next_node == self->goal_node)
 		{
 			if(debug_mode)
-				debug_printf("%s reached goal!\n",self->client->pers.netname);	
-			
+				debug_printf("%s reached goal!\n",self->client->pers.netname);
+
 			ACEAI_PickLongRangeGoal(self); // Pick a new goal
 		}
 		else
@@ -286,13 +290,13 @@ qboolean ACEND_FollowPath(edict_t *self)
 			self->next_node = path_table[self->current_node][self->goal_node];
 		}
 	}
-	
+
 	if(self->current_node == -1 || self->next_node ==-1)
 		return false;
-	
+
 	// Set bot's movement vector
 	VectorSubtract (nodes[self->next_node].origin, self->s.origin , self->move_vector);
-	
+
 	return true;
 }
 
@@ -307,10 +311,10 @@ qboolean ACEND_FollowPath(edict_t *self)
 void ACEND_GrapFired(edict_t *self)
 {
 
-	
+
 	if(!self->owner)
 		return; // should not be here
-	
+
 	return;
 }
 
@@ -327,20 +331,20 @@ qboolean ACEND_CheckForLadder(edict_t *self)
 	{
 		//debug_printf("contents: %x\n",tr.contents);
 
-		closest_node = ACEND_FindClosestReachableNode(self,NODE_DENSITY,NODE_LADDER); 
+		closest_node = ACEND_FindClosestReachableNode(self,NODE_DENSITY,NODE_LADDER);
 		if(closest_node == -1)
 		{
 			closest_node = ACEND_AddNode(self,NODE_LADDER);
-	
+
 			// Now add link
-		    ACEND_UpdateNodeEdge(self->last_node,closest_node);	   
-			
+		    ACEND_UpdateNodeEdge(self->last_node,closest_node);
+
 			// Set current to last
 			self->last_node = closest_node;
 		}
 		else
 		{
-			ACEND_UpdateNodeEdge(self->last_node,closest_node);	   
+			ACEND_UpdateNodeEdge(self->last_node,closest_node);
 			self->last_node = closest_node; // set visited to last
 		}
 		return true;
@@ -366,7 +370,7 @@ void ACEND_PathMap(edict_t *self)
 	// Special node drawing code for debugging
     if(show_path_to != -1)
 		ACEND_DrawPath();
-	
+
 	////////////////////////////////////////////////////////
 	// Special check for ladder nodes
 	///////////////////////////////////////////////////////
@@ -384,7 +388,7 @@ void ACEND_PathMap(edict_t *self)
 	v[2] -= 18;
 	if(gi.pointcontents(v) & (CONTENTS_LAVA|CONTENTS_SLIME))
 		return; // no nodes in slime
-	
+
     ////////////////////////////////////////////////////////
 	// Jumping
 	///////////////////////////////////////////////////////
@@ -395,16 +399,16 @@ void ACEND_PathMap(edict_t *self)
 
 		if(closest_node == INVALID)
 			closest_node = ACEND_AddNode(self,NODE_JUMP);
-		
+
 		// Now add link
 		if(self->last_node != -1)
-			ACEND_UpdateNodeEdge(self->last_node, closest_node);	   
+			ACEND_UpdateNodeEdge(self->last_node, closest_node);
 
 		self->is_jumping = false;
 		return;
 	}
 
-	 
+
 	// Iterate through all nodes to make sure far enough apart
 	closest_node = ACEND_FindClosestReachableNode(self, NODE_DENSITY, NODE_ALL);
 
@@ -418,12 +422,12 @@ void ACEND_PathMap(edict_t *self)
 
 		// Here we want to add links
 		if(closest_node != self->last_node && self->last_node != INVALID)
-			ACEND_UpdateNodeEdge(self->last_node,closest_node);	   
+			ACEND_UpdateNodeEdge(self->last_node,closest_node);
 
 		self->last_node = closest_node; // set visited to last
 		return;
 	}
-	 
+
 	 ////////////////////////////////////////////////////////
 	 // Add Nodes as needed
 	 ////////////////////////////////////////////////////////
@@ -434,17 +438,17 @@ void ACEND_PathMap(edict_t *self)
 			closest_node = ACEND_AddNode(self,NODE_WATER);
 		else
 		    closest_node = ACEND_AddNode(self,NODE_MOVE);
-		
+
 		// Now add link
 		if(self->last_node != -1)
-			ACEND_UpdateNodeEdge(self->last_node, closest_node);	   
-			
+			ACEND_UpdateNodeEdge(self->last_node, closest_node);
+
 	 }
 	 else if(closest_node != self->last_node && self->last_node != INVALID)
-	 	ACEND_UpdateNodeEdge(self->last_node,closest_node);	   
-	
+	 	ACEND_UpdateNodeEdge(self->last_node,closest_node);
+
 	 self->last_node = closest_node; // set visited to last
-	
+
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -452,11 +456,11 @@ void ACEND_PathMap(edict_t *self)
 ///////////////////////////////////////////////////////////////////////
 void ACEND_InitNodes(void)
 {
-	numnodes = 1;
+	bot_numnodes = 1;
 	numitemnodes = 1;
 	memset(nodes,0,sizeof(node_t) * MAX_NODES);
 	memset(path_table,INVALID,sizeof(short int)*MAX_NODES*MAX_NODES);
-			
+
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -478,13 +482,13 @@ void ACEND_ShowNode(int node)
 		ent->s.renderfx = RF_SHELL_BLUE;
 	else if (nodes[node].type == NODE_WATER)
 		ent->s.renderfx = RF_SHELL_RED;
-	else			
+	else
 		ent->s.renderfx = RF_SHELL_GREEN; // action nodes
 
 	ent->s.modelindex = gi.modelindex ("models/items/ammo/grenades/medium/tris.md2");
 	ent->owner = ent;
 	ent->nextthink = level.time + 200000.0;
-	ent->think = G_FreeEdict;                
+	ent->think = G_FreeEdict;
 	ent->dmg = 0;
 
 	VectorCopy(nodes[node].origin,ent->s.origin);
@@ -518,7 +522,7 @@ void ACEND_DrawPath()
 }
 
 ///////////////////////////////////////////////////////////////////////
-// Turns on showing of the path, set goal to -1 to 
+// Turns on showing of the path, set goal to -1 to
 // shut off. (utility function)
 ///////////////////////////////////////////////////////////////////////
 void ACEND_ShowPath(edict_t *self, int goal_node)
@@ -533,23 +537,23 @@ void ACEND_ShowPath(edict_t *self, int goal_node)
 int ACEND_AddNode(edict_t *self, int type)
 {
 	vec3_t v1,v2;
-	
+
 	// Block if we exceed maximum
-	if (numnodes + 1 > MAX_NODES)
+	if (bot_numnodes + 1 > MAX_NODES)
 		return false;
-	
+
 	// Set location
-	VectorCopy(self->s.origin,nodes[numnodes].origin);
+	VectorCopy(self->s.origin,nodes[bot_numnodes].origin);
 
 	// Set type
-	nodes[numnodes].type = type;
+	nodes[bot_numnodes].type = type;
 
 	/////////////////////////////////////////////////////
 	// ITEMS
 	// Move the z location up just a bit.
 	if(type == NODE_ITEM)
 	{
-		nodes[numnodes].origin[2] += 16;
+		nodes[bot_numnodes].origin[2] += 16;
 		numitemnodes++;
 	}
 
@@ -557,21 +561,21 @@ int ACEND_AddNode(edict_t *self, int type)
 	if(type == NODE_TELEPORTER)
 	{
 		// Up 32
-		nodes[numnodes].origin[2] += 32;
+		nodes[bot_numnodes].origin[2] += 32;
 	}
 
 	if(type == NODE_LADDER)
 	{
-		nodes[numnodes].type = NODE_LADDER;
-				
+		nodes[bot_numnodes].type = NODE_LADDER;
+
 		if(debug_mode)
 		{
-			debug_printf("Node added %d type: Ladder\n",numnodes);
-			ACEND_ShowNode(numnodes);
+			debug_printf("Node added %d type: Ladder\n",bot_numnodes);
+			ACEND_ShowNode(bot_numnodes);
 		}
-		
-		numnodes++;
-		return numnodes-1; // return the node added
+
+		bot_numnodes++;
+		return bot_numnodes-1; // return the node added
 
 	}
 
@@ -580,56 +584,56 @@ int ACEND_AddNode(edict_t *self, int type)
 	{
 		VectorCopy(self->maxs,v1);
 		VectorCopy(self->mins,v2);
-		
-		// To get the center
-		nodes[numnodes].origin[0] = (v1[0] - v2[0]) / 2 + v2[0];
-		nodes[numnodes].origin[1] = (v1[1] - v2[1]) / 2 + v2[1];
-		nodes[numnodes].origin[2] = self->maxs[2];
-			
-		if(debug_mode)	
-			ACEND_ShowNode(numnodes);
-		
-		numnodes++;
 
-		nodes[numnodes].origin[0] = nodes[numnodes-1].origin[0];
-		nodes[numnodes].origin[1] = nodes[numnodes-1].origin[1];
-		nodes[numnodes].origin[2] = self->mins[2]+64;
-		
-		nodes[numnodes].type = NODE_PLATFORM;
+		// To get the center
+		nodes[bot_numnodes].origin[0] = (v1[0] - v2[0]) / 2 + v2[0];
+		nodes[bot_numnodes].origin[1] = (v1[1] - v2[1]) / 2 + v2[1];
+		nodes[bot_numnodes].origin[2] = self->maxs[2];
+
+		if(debug_mode)
+			ACEND_ShowNode(bot_numnodes);
+
+		bot_numnodes++;
+
+		nodes[bot_numnodes].origin[0] = nodes[bot_numnodes-1].origin[0];
+		nodes[bot_numnodes].origin[1] = nodes[bot_numnodes-1].origin[1];
+		nodes[bot_numnodes].origin[2] = self->mins[2]+64;
+
+		nodes[bot_numnodes].type = NODE_PLATFORM;
 
 		// Add a link
-		ACEND_UpdateNodeEdge(numnodes,numnodes-1);			
-		
+		ACEND_UpdateNodeEdge(bot_numnodes,bot_numnodes-1);
+
 		if(debug_mode)
 		{
-			debug_printf("Node added %d type: Platform\n",numnodes);
-			ACEND_ShowNode(numnodes);
+			debug_printf("Node added %d type: Platform\n",bot_numnodes);
+			ACEND_ShowNode(bot_numnodes);
 		}
 
-		numnodes++;
+		bot_numnodes++;
 
-		return numnodes -1;
+		return bot_numnodes -1;
 	}
-		
+
 	if(debug_mode)
 	{
-		if(nodes[numnodes].type == NODE_MOVE)
-			debug_printf("Node added %d type: Move\n",numnodes);
-		else if(nodes[numnodes].type == NODE_TELEPORTER)
-			debug_printf("Node added %d type: Teleporter\n",numnodes);
-		else if(nodes[numnodes].type == NODE_ITEM)
-			debug_printf("Node added %d type: Item\n",numnodes);
-		else if(nodes[numnodes].type == NODE_WATER)
-			debug_printf("Node added %d type: Water\n",numnodes);
-		else if(nodes[numnodes].type == NODE_GRAPPLE)
-			debug_printf("Node added %d type: Grapple\n",numnodes);
+		if(nodes[bot_numnodes].type == NODE_MOVE)
+			debug_printf("Node added %d type: Move\n",bot_numnodes);
+		else if(nodes[bot_numnodes].type == NODE_TELEPORTER)
+			debug_printf("Node added %d type: Teleporter\n",bot_numnodes);
+		else if(nodes[bot_numnodes].type == NODE_ITEM)
+			debug_printf("Node added %d type: Item\n",bot_numnodes);
+		else if(nodes[bot_numnodes].type == NODE_WATER)
+			debug_printf("Node added %d type: Water\n",bot_numnodes);
+		else if(nodes[bot_numnodes].type == NODE_GRAPPLE)
+			debug_printf("Node added %d type: Grapple\n",bot_numnodes);
 
-		ACEND_ShowNode(numnodes);
+		ACEND_ShowNode(bot_numnodes);
 	}
-		
-	numnodes++;
-	
-	return numnodes-1; // return the node added
+
+	bot_numnodes++;
+
+	return bot_numnodes-1; // return the node added
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -638,7 +642,7 @@ int ACEND_AddNode(edict_t *self, int type)
 void ACEND_UpdateNodeEdge(int from, int to)
 {
 	int i;
-	
+
 	if(from == -1 || to == -1 || from == to)
 		return; // safety
 
@@ -646,13 +650,15 @@ void ACEND_UpdateNodeEdge(int from, int to)
 	path_table[from][to] = to;
 
 	// Now for the self-referencing part, linear time for each link added
-	for(i=0;i<numnodes;i++)
+	for(i=0;i<bot_numnodes;i++)
 		if(path_table[i][from] != INVALID)
+		{
 			if(i == to)
 				path_table[i][to] = INVALID; // make sure we terminate
 			else
 				path_table[i][to] = path_table[i][from];
-		
+		}
+
 	if(debug_mode)
 		debug_printf("Link %d -> %d\n", from, to);
 }
@@ -664,13 +670,13 @@ void ACEND_RemoveNodeEdge(edict_t *self, int from, int to)
 {
 	int i;
 
-	if(debug_mode) 
+	if(debug_mode)
 		debug_printf("%s: Removing Edge %d -> %d\n", self->client->pers.netname, from, to);
-		
-	path_table[from][to] = INVALID; // set to invalid			
+
+	path_table[from][to] = INVALID; // set to invalid
 
 	// Make sure this gets updated in our path array
-	for(i=0;i<numnodes;i++)
+	for(i=0;i<bot_numnodes;i++)
 		if(path_table[from][i] == to)
 			path_table[from][i] = INVALID;
 }
@@ -683,11 +689,11 @@ void ACEND_ResolveAllPaths()
 {
 	int i, from, to;
 	int num=0;
-	
+
 	safe_bprintf(PRINT_HIGH,"Resolving all paths...");
 
-	for(from=0;from<numnodes;from++)
-	for(to=0;to<numnodes;to++)
+	for(from=0;from<bot_numnodes;from++)
+	for(to=0;to<bot_numnodes;to++)
 	{
 		// update unresolved paths
 		// Not equal to itself, not equal to -1 and equal to the last link
@@ -696,12 +702,14 @@ void ACEND_ResolveAllPaths()
 			num++;
 
 			// Now for the self-referencing part linear time for each link added
-			for(i=0;i<numnodes;i++)
+			for(i=0;i<bot_numnodes;i++)
 				if(path_table[i][from] != -1)
+				{
 					if(i == to)
 						path_table[i][to] = -1; // make sure we terminate
 					else
 						path_table[i][to] = path_table[i][from];
+				}
 		}
 	}
 
@@ -720,36 +728,42 @@ void ACEND_SaveNodes()
 {
 	FILE *pOut;
 	char filename[MAX_OSPATH];
+	char relative_path[MAX_QPATH];
 	int i,j;
 	int version = 1;
-	
+	size_t sz;
+
 	// Resolve paths
 	ACEND_ResolveAllPaths();
 
 	safe_bprintf(PRINT_MEDIUM,"Saving node table...");
 
-	strcpy(filename,"botinfo/nav/");
+	strcpy( relative_path, BOT_GAMEDATA"/nav/" );
+	strcat( relative_path, level.mapname );
+	strcat( relative_path, ".nod" );
 
-	strcat(filename,level.mapname);
-	strcat(filename,".nod");
+	gi.FullWritePath( filename, sizeof(filename), relative_path );
 
 	if((pOut = fopen(filename, "wb" )) == NULL)
-		return; // bail
-	
-	fwrite(&version,sizeof(int),1,pOut); // write version
-	fwrite(&numnodes,sizeof(int),1,pOut); // write count
-	fwrite(&num_items,sizeof(int),1,pOut); // write facts count
-	
-	fwrite(nodes,sizeof(node_t),numnodes,pOut); // write nodes
-	
-	for(i=0;i<numnodes;i++)
-		for(j=0;j<numnodes;j++)
-			fwrite(&path_table[i][j],sizeof(short int),1,pOut); // write count
-		
-	fwrite(item_table,sizeof(item_table_t),num_items,pOut); 		// write out the fact table
+	{
+		gi.dprintf("ACEND_SaveNodes: failed fopen for write: %s\n", filename );
+		return;
+	}
+
+	sz = fwrite(&version,sizeof(int),1,pOut); // write version
+	sz = fwrite(&bot_numnodes,sizeof(int),1,pOut); // write count
+	sz = fwrite(&num_items,sizeof(int),1,pOut); // write facts count
+
+	sz = fwrite(nodes,sizeof(node_t),bot_numnodes,pOut); // write nodes
+
+	for(i=0;i<bot_numnodes;i++)
+		for(j=0;j<bot_numnodes;j++)
+			sz = fwrite(&path_table[i][j],sizeof(short int),1,pOut); // write count
+
+	sz = fwrite(item_table,sizeof(item_table_t),num_items,pOut); 		// write out the fact table
 
 	fclose(pOut);
-	
+
 	safe_bprintf(PRINT_MEDIUM,"done.\n");
 }
 
@@ -760,12 +774,19 @@ void ACEND_LoadNodes(void)
 {
 	FILE *pIn;
 	int i,j;
+	char relative_path[MAX_QPATH];
 	char filename[MAX_OSPATH];
 	int version;
+	size_t sz;
 
-	strcpy(filename,BOTDIR"/botinfo/nav/");
-	strcat(filename,level.mapname);
-	strcat(filename,".nod");
+	strcpy( relative_path, BOT_GAMEDATA"/nav/" );
+	strcat( relative_path, level.mapname );
+	strcat( relative_path, ".nod" );
+
+	if ( !gi.FullPath( filename, sizeof(filename), relative_path ) )
+	{
+		gi.dprintf("ACEND_LoadNodes: not found: %s\n", filename );
+	}
 
 	if((pIn = fopen(filename, "rb" )) == NULL)
     {
@@ -773,26 +794,26 @@ void ACEND_LoadNodes(void)
 		gi.dprintf("ACE: No node file found, creating new one...");
 		ACEIT_BuildItemNodeTable(false);
 		safe_bprintf(PRINT_MEDIUM, "done.\n");
-		return; 
+		return;
 	}
 
 	// determine version
-	fread(&version,sizeof(int),1,pIn); // read version
-	
-	if(version == 1) 
+	sz = fread(&version,sizeof(int),1,pIn); // read version
+
+	if(version == 1)
 	{
 		gi.dprintf("ACE: Loading node table...");
 
-		fread(&numnodes,sizeof(int),1,pIn); // read count
-		fread(&num_items,sizeof(int),1,pIn); // read facts count
-		fread(nodes,sizeof(node_t),numnodes,pIn);
-	
-		for(i=0;i<numnodes;i++)
-			for(j=0;j<numnodes;j++)
-				fread(&path_table[i][j],sizeof(short int),1,pIn); // write count
-	
+		sz = fread(&bot_numnodes,sizeof(int),1,pIn); // read count
+		sz = fread(&num_items,sizeof(int),1,pIn); // read facts count
+		sz = fread(nodes,sizeof(node_t),bot_numnodes,pIn);
+
+		for(i=0;i<bot_numnodes;i++)
+			for(j=0;j<bot_numnodes;j++)
+				sz = fread(&path_table[i][j],sizeof(short int),1,pIn); // write count
+
 	    for(i=0;i<num_items;i++)
-			fread(item_table,sizeof(item_table_t),1,pIn);
+			sz = fread(item_table,sizeof(item_table_t),1,pIn);
 		fclose(pIn);
 	}
 	else
@@ -803,9 +824,9 @@ void ACEND_LoadNodes(void)
 		safe_bprintf(PRINT_MEDIUM, "done.\n");
 		return; // bail
 	}
-	
+
 	gi.dprintf("done.\n");
-	
+
 	ACEIT_BuildItemNodeTable(true);
 
 }
