@@ -17,6 +17,11 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "g_local.h"
 
 qboolean	Pickup_Weapon (edict_t *ent, edict_t *other);
@@ -83,7 +88,7 @@ gitem_t	*FindItemByClassname (char *classname)
 	{
 		if (!it->classname)
 			continue;
-		if (!Q_stricmp(it->classname, classname))
+		if (!Q_strcasecmp(it->classname, classname))
 			return it;
 	}
 
@@ -106,7 +111,7 @@ gitem_t	*FindItem (char *pickup_name)
 	{
 		if (!it->pickup_name)
 			continue;
-		if (!Q_stricmp(it->pickup_name, pickup_name))
+		if (!Q_strcasecmp(it->pickup_name, pickup_name))
 			return it;
 	}
 
@@ -173,10 +178,10 @@ qboolean Pickup_Powerup (edict_t *ent, edict_t *other)
 			randomSpawn = 10 + rand() % (30 - 10); //10 to 30 seconds randomness
 		else
 			randomSpawn = 0;
-		
+
 		if (!(ent->spawnflags & DROPPED_ITEM) )
 			SetRespawn (ent, ent->item->quantity + randomSpawn);
-		if (((int)dmflags->value & DF_INSTANT_ITEMS) || ((ent->item->use == Use_Quad) && (ent->spawnflags & DROPPED_PLAYER_ITEM)))
+		if ((dmflags->integer & DF_INSTANT_ITEMS) || (ent->item->use == Use_Quad && (ent->spawnflags & DROPPED_PLAYER_ITEM)))
 		{
 			if ((ent->item->use == Use_Quad) && (ent->spawnflags & DROPPED_PLAYER_ITEM))
 				quad_drop_timeout_hack = (ent->nextthink - level.time) / FRAMETIME;
@@ -408,7 +413,7 @@ qboolean Pickup_Ammo (edict_t *ent, edict_t *other)
 	qboolean		weapon;
 
 	weapon = (ent->item->flags & IT_WEAPON);
-	if ( (weapon) && ( (int)dmflags->value & DF_INFINITE_AMMO ) )
+	if ( weapon && ( dmflags->integer & DF_INFINITE_AMMO ) )
 		count = 1000;
 	else if (ent->count)
 		count = ent->count;
@@ -942,7 +947,7 @@ void SpawnItem (edict_t *ent, gitem_t *item)
 	// some items will be prevented in deathmatch
 	if (deathmatch->value)
 	{
-		if ( (int)dmflags->value & DF_NO_ARMOR )
+		if ( dmflags->integer & DF_NO_ARMOR )
 		{
 			if (item->pickup == Pickup_Armor)
 			{
@@ -950,7 +955,7 @@ void SpawnItem (edict_t *ent, gitem_t *item)
 				return;
 			}
 		}
-		if ( (int)dmflags->value & DF_NO_ITEMS )
+		if ( dmflags->integer & DF_NO_ITEMS )
 		{
 			if (item->pickup == Pickup_Powerup)
 			{
@@ -958,7 +963,7 @@ void SpawnItem (edict_t *ent, gitem_t *item)
 				return;
 			}
 		}
-		if ( (int)dmflags->value & DF_NO_HEALTH )
+		if ( dmflags->integer & DF_NO_HEALTH )
 		{
 			if (item->pickup == Pickup_Health || item->pickup == Pickup_Adrenaline)
 			{
@@ -966,7 +971,7 @@ void SpawnItem (edict_t *ent, gitem_t *item)
 				return;
 			}
 		}
-		if ( (int)dmflags->value & DF_INFINITE_AMMO )
+		if ( dmflags->integer & DF_INFINITE_AMMO )
 		{
 			if ( (item->flags == IT_AMMO) || (strcmp(ent->classname, "weapon_bfg") == 0) )
 			{
@@ -1015,7 +1020,7 @@ void SpawnItem (edict_t *ent, gitem_t *item)
 	else if((strcmp(ent->classname, "item_quad") == 0)) {
 		ent->s.modelindex2 = gi.modelindex("models/items/quaddama/unit.md2");
 	}
-	
+
 	if (ent->model)
 		gi.modelindex (ent->model);
 
@@ -1855,7 +1860,7 @@ gives +1 to maximum health
 		NULL,
 		NULL,
 		"items/powerup.wav",
-		NULL, 
+		NULL,
 		EF_ROTATE,
 		NULL,
 		NULL,
@@ -1869,7 +1874,7 @@ gives +1 to maximum health
 		0,
 /* precache */ "items/protect2.wav"
 	},
-	
+
 	// end of list marker
 	{NULL}
 };
@@ -1879,7 +1884,7 @@ gives +1 to maximum health
 */
 void SP_item_health (edict_t *self)
 {
-	if ( deathmatch->value && ((int)dmflags->value & DF_NO_HEALTH) )
+	if ( deathmatch->value && (dmflags->integer & DF_NO_HEALTH) )
 	{
 		G_FreeEdict (self);
 		return;
@@ -1895,7 +1900,7 @@ void SP_item_health (edict_t *self)
 */
 void SP_item_health_small (edict_t *self)
 {
-	if ( deathmatch->value && ((int)dmflags->value & DF_NO_HEALTH) )
+	if ( deathmatch->value && (dmflags->integer & DF_NO_HEALTH) )
 	{
 		G_FreeEdict (self);
 		return;
@@ -1913,7 +1918,7 @@ void SP_item_health_small (edict_t *self)
 */
 void SP_item_health_large (edict_t *self)
 {
-	if ( deathmatch->value && ((int)dmflags->value & DF_NO_HEALTH) )
+	if ( deathmatch->value && (dmflags->integer & DF_NO_HEALTH) )
 	{
 		G_FreeEdict (self);
 		return;
@@ -1930,7 +1935,7 @@ void SP_item_health_large (edict_t *self)
 */
 void SP_item_health_mega (edict_t *self)
 {
-	if ( deathmatch->value && ((int)dmflags->value & DF_NO_HEALTH) )
+	if ( deathmatch->value && (dmflags->integer & DF_NO_HEALTH) )
 	{
 		G_FreeEdict (self);
 		return;
