@@ -111,6 +111,24 @@ typedef enum
 } ammo_t;
 
 //teams
+typedef struct teamcensus_s
+{ // see p_client.c::TeamCensus()
+	int total;
+	int real;
+	int bots;
+	int red;
+	int blue;
+	int real_red;
+	int real_blue;
+	int bots_red;
+	int bots_blue;
+	int team_for_real;
+	int team_for_bot;
+} teamcensus_t;
+
+#define TEAM_GAME ( (dmflags->integer & (DF_SKINTEAMS)) \
+		|| ctf->integer || tca->integer || cp->integer )
+
 #define RED_TEAM				0
 #define BLUE_TEAM				1
 #define NO_TEAM					2
@@ -239,6 +257,7 @@ typedef struct
 #define WEAP_BLASTER			1
 #define WEAP_SMARTGUN			2
 #define WEAP_CHAINGUN			3
+#define WEAP_GRAPPLE			4
 #define WEAP_FLAMETHROWER		5
 #define WEAP_ROCKETLAUNCHER		8
 #define WEAP_DISRUPTOR			9
@@ -249,7 +268,7 @@ typedef struct
 #define WEAP_STRAFER			14
 #define WEAP_DEATHBALL			15
 #define WEAP_HOVER				16
-#define WEAP_GRAPPLE			16
+
 
 
 typedef struct gitem_s
@@ -307,9 +326,6 @@ typedef struct
 	// items
 	int			num_items;
 
-	//bots
-	int			num_bots;
-
 	qboolean	autosaved;
 } game_locals_t;
 
@@ -481,8 +497,6 @@ extern	g_vote_t		playervote;
 
 extern	int	sm_meat_index;
 
-extern	int red_team_cnt;
-extern  int blue_team_cnt;
 extern  int red_team_score;
 extern  int blue_team_score;
 extern  int reddiff;
@@ -553,7 +567,7 @@ extern	cvar_t	*password;
 extern	cvar_t	*spectator_password;
 extern	cvar_t	*needpass;
 extern	cvar_t	*g_select_empty;
-extern	cvar_t	*dedicated;
+extern	cvar_t	*g_dedicated;
 extern	cvar_t	*motdfile;
 
 extern	cvar_t	*filterban;
@@ -572,7 +586,7 @@ extern	cvar_t	*bob_pitch;
 extern	cvar_t	*bob_roll;
 
 extern	cvar_t	*sv_cheats;
-extern	cvar_t	*maxclients;
+extern	cvar_t	*g_maxclients;
 extern	cvar_t	*maxspectators;
 
 extern	cvar_t	*flood_msgs;
@@ -581,7 +595,7 @@ extern	cvar_t	*flood_waitdelay;
 
 extern	cvar_t	*sv_maplist;
 
-extern  cvar_t  *background_music;
+extern  cvar_t  *g_background_music;
 
 extern  cvar_t  *sv_botkickthreshold;
 extern  cvar_t	*sv_custombots;
@@ -729,7 +743,7 @@ void CTFScoreboardMessage (edict_t *ent, edict_t *killer, int mapvote);
 void CTFPrecache(void);
 void CTFFlagSetup (edict_t *ent);
 qboolean CTFPickup_Flag (edict_t *ent, edict_t *other);
-qboolean CTFDrop_Flag(edict_t *ent, gitem_t *item);
+void CTFDrop_Flag(edict_t *ent, gitem_t *item);
 
 //Vehicles
 void Reset_player(edict_t *ent);
@@ -740,14 +754,14 @@ qboolean Jet_AvoidGround( edict_t *ent );
 void VehicleDeadDrop(edict_t *self);
 void VehicleSetup (edict_t *ent);
 qboolean Get_in_vehicle (edict_t *ent, edict_t *other);
-qboolean Leave_vehicle(edict_t *ent, gitem_t *item);
+void Leave_vehicle(edict_t *ent, gitem_t *item);
 
 //deathball
 void ResetDeathball();
 void DeadDropDeathball(edict_t *self);
 void DeathballSetup (edict_t *ent);
 qboolean Pickup_deathball (edict_t *ent, edict_t *other);
-qboolean DeathballDrop(edict_t *ent, gitem_t *item);
+void DeathballDrop(edict_t *ent, gitem_t *item);
 
 //
 // g_utils.c
@@ -908,10 +922,13 @@ void InitClientPersistant (gclient_t *client);
 void InitClientResp (gclient_t *client);
 void InitBodyQue (void);
 void ClientBeginServerFrame (edict_t *ent);
-int Q2_FindFile (char *filename, FILE **file);
+void Q2_FindFile (char *filename, FILE **file);
 void ClientPlaceInQueue(edict_t *ent);
 void ClientCheckQueue(edict_t *ent);
 void MoveClientsDownQueue(edict_t *ent);
+void SaveClientData (void);
+void FetchClientEntData (edict_t *ent);
+void TeamCensus( teamcensus_t* team_census );
 
 //unlagged - g_unlagged.c
 void G_ResetHistory( edict_t *ent );
@@ -956,10 +973,6 @@ void DeathmatchScoreboardMessage (edict_t *client, edict_t *killer, int mapvote)
 //
 void P_ProjectSource (gclient_t *client, vec3_t point, vec3_t distance, vec3_t forward, vec3_t right, vec3_t result);
 void Weapon_Generic (edict_t *ent, int FRAME_ACTIVATE_LAST, int FRAME_FIRE_LAST, int FRAME_IDLE_LAST, int FRAME_DEACTIVATE_LAST, int *pause_frames, int *fire_frames, void (*fire)(edict_t *ent));
-
-//
-// g_pweapon.c
-//
 void PlayerNoise(edict_t *who, vec3_t where, int type);
 
 //
@@ -975,11 +988,6 @@ void M_ChangeYaw (edict_t *ent);
 //
 void G_RunEntity (edict_t *ent);
 
-//
-// g_main.c
-//
-void SaveClientData (void);
-void FetchClientEntData (edict_t *ent);
 
 //
 // g_chase.c
@@ -989,6 +997,12 @@ void ChaseNext(edict_t *ent);
 void ChasePrev(edict_t *ent);
 void GetChaseTarget(edict_t *ent);
 
+//
+// g_main.c
+//
+qboolean G_NameMatch( const char* netname, const char *kickname );
+
+
 //============================================================================
 
 // client_t->anim_priority
@@ -1012,7 +1026,10 @@ void GetChaseTarget(edict_t *ent);
 typedef struct
 {
 	char		userinfo[MAX_INFO_STRING];
-	char		netname[48];			// considering 1 colour change / character, that's 16
+
+	char netname[(PLAYERNAME_GLYPHS*3)+1]; // name from cvar
+			// room for "rainbow" name, but is truncated to PLAYERNAME_SIZE
+
 	int			hand;
 
 	qboolean	connected;			// a loadgame will leave valid entities that
@@ -1096,9 +1113,6 @@ typedef struct
 	int reward_pts;
 	qboolean powered;
 
-	//homing rocket limits
-	int	homing_shots;
-
 	//voting
 	qboolean voted;
 
@@ -1237,11 +1251,15 @@ struct gclient_s
 	//joust attempts - for limiting how many times you can joust at a time
 	int joustattempts;
 
+	//homing rocket limits
+	int	homing_shots;
+
 	//movetime - used for special moves
 	float lastmovetime;
 	int lastsidemove;
 	int dodge;
 	int moved;
+	float lastdodge;
 
 	float spawnprotecttime;
 	qboolean spawnprotected;
@@ -1251,7 +1269,7 @@ struct gclient_s
 
 	//taunt message
 	float lasttaunttime;
-	
+
 	//deathray immunity
 	qboolean rayImmunity;
 	float rayTime;
@@ -1536,8 +1554,3 @@ extern  cvar_t	*g_antilagdebug;
 #include "acesrc/acebot.h"
 // ACEBOT_END
 
-#ifdef __unix__
-void	FS_FreeFile (void *buffer);
-void	Z_Free (void *ptr);
-void	Com_Error (int code, char *fmt, ...);
-#endif
