@@ -18,6 +18,22 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#if defined HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+#if defined HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+
+#if !defined HAVE__STRDUP
+#define _strdup strdup
+#endif
+
 #include "g_local.h"
 
 game_locals_t	game;
@@ -110,11 +126,11 @@ cvar_t	*timelimit;
 cvar_t	*password;
 cvar_t	*spectator_password;
 cvar_t	*needpass;
-cvar_t	*maxclients;
+cvar_t	*g_maxclients;
 cvar_t	*maxspectators;
 cvar_t	*maxentities;
 cvar_t	*g_select_empty;
-cvar_t	*dedicated;
+cvar_t	*g_dedicated;
 cvar_t	*motdfile;
 
 cvar_t	*filterban;
@@ -142,7 +158,7 @@ cvar_t	*flood_waitdelay;
 
 cvar_t	*sv_maplist;
 
-cvar_t  *background_music;
+cvar_t  *g_background_music;
 
 cvar_t  *sv_botkickthreshold;
 cvar_t  *sv_custombots;
@@ -164,6 +180,42 @@ void G_RunFrame (void);
 int ACESP_FindBotNum(void);
 extern long filelength(int);
 
+static size_t szr;
+
+static int g_filelength( FILE *f )
+{
+	int length = -1;
+
+#if defined HAVE_FILELENGTH
+
+	length = filelength( fileno( f ) );
+
+#elif defined HAVE_FSTAT
+
+	struct stat statbfr;
+	int result;
+
+	result = fstat( fileno(f), &statbfr );
+	if ( result != -1 )
+	{
+		length = (int)statbfr.st_size;
+	}
+
+#else
+
+	long int pos;
+
+	pos = ftell( f );
+	fseek( f, 0L, SEEK_END );
+	length = ftell( f );
+	fseek( f, pos, SEEK_SET );
+
+#endif
+
+	return length;
+}
+
+
 //===================================================================
 
 
@@ -210,37 +262,6 @@ game_export_t *GetGameAPI (game_import_t *import)
 	return &globals;
 }
 
-#ifndef GAME_HARD_LINKED
-// this is only here so the functions in q_shared.c and q_shwin.c can link
-void Sys_Error (char *error, ...)
-{
-	va_list		argptr;
-	char		text[1024];
-
-	va_start (argptr, error);
-	vsnprintf(text, sizeof(text), error, argptr);
-	va_end (argptr);
-
-	gi.error (ERR_FATAL, "%s", text);
-}
-
-void Com_Printf (char *msg, ...)
-{
-	va_list		argptr;
-	char		text[1024];
-
-	va_start (argptr, msg);
-	vsnprintf(text, sizeof(text), msg, argptr);
-	va_end (argptr);
-
-	gi.dprintf ("%s", text);
-}
-
-#endif
-
-//======================================================================
-
-//#ifdef __unix__
 
 #define Z_MAGIC		0x1d1d
 
@@ -254,40 +275,7 @@ typedef struct zhead_s
 
 zhead_t		z_chain;
 int		z_count, z_bytes;
-void Z_Free (void *ptr);
-/*
-=============
-FS_FreeFile
-=============
-*/
-void FS_FreeFile (void *buffer)
-{
-	Z_Free (buffer);
-}
 
-/*
-========================
-Z_Free
-========================
-*/
-void Z_Free (void *ptr)
-{
-	zhead_t *z;
-
-	z = ((zhead_t *)ptr) - 1;
-
-	if (z->magic != Z_MAGIC)
-		Sys_Error (ERR_FATAL, "Z_Free: bad magic");
-
-	z->prev->next = z->next;
-	z->next->prev = z->prev;
-
-	z_count--;
-	z_bytes -= z->size;
-	free (z);
-}
-
-//#endif
 
 /*
 =================
@@ -301,7 +289,7 @@ void ClientEndServerFrames (void)
 
 	// calc the player views now that all pushing
 	// and damage has been added
-	for (i=0 ; i<maxclients->value ; i++)
+	for (i=0 ; i<g_maxclients->value ; i++)
 	{
 		ent = g_edicts + 1 + i;
 		if (!ent->inuse || !ent->client)
@@ -342,7 +330,7 @@ void EndDMLevel (void)
 	char *s, *t, *f;
 	static const char *seps = " ,\n\r";
 	char *buffer;
-	char  mapsname[1024];
+	char  mapsname[MAX_OSPATH];
 	int length;
 	static char **mapnames;
 	static int	  nummaps;
@@ -350,7 +338,7 @@ void EndDMLevel (void)
 	FILE *fp;
 
 	/* Search for dead players in order to remove DeathCam and free mem */
-	for (i=0 ; i<maxclients->value ; i++)
+	for (i=0 ; i<g_maxclients->value ; i++)
 	{
 		ent = g_edicts + i + 1;
 		if (!ent->inuse || ent->client->resp.spectator)
@@ -389,11 +377,11 @@ void EndDMLevel (void)
 			qboolean same = ( g_votesame ? (g_votesame->value == 1) : 1 );
 
 			memset( names, 0 , sizeof(names) );
-			s = strdup( sv_maplist->string );
+			s = _strdup( sv_maplist->string );
 			t = strtok( s, seps );
 			do {
 				// if using the same map is disallowed, skip it
-				if ( !Q_stricmp(t, level.mapname) )
+				if ( !Q_strcasecmp(t, level.mapname) )
 				{
 					if ( same_index == -1 )
 						same_index = n_maps;
@@ -404,7 +392,7 @@ void EndDMLevel (void)
 				// avoid duplicates
 				for ( i = 0 ; i < n_maps ; i ++ )
 				{
-					if ( ! Q_stricmp( t , names[i] ) )
+					if ( ! Q_strcasecmp( t , names[i] ) )
 						break;
 				}
 				if ( i < n_maps )
@@ -446,29 +434,30 @@ void EndDMLevel (void)
 	}
 
 	// stay on same level flag
-	if ((int)dmflags->value & DF_SAME_LEVEL)
+	if (dmflags->integer & DF_SAME_LEVEL)
 	{
 		BeginIntermission (CreateTargetChangeLevel (level.mapname) );
 		return;
 	}
 
-	if ((bot_won) && (!((int)(dmflags->value) & DF_BOT_LEVELAD)) && !ctf->value)
+	if (bot_won && !(dmflags->integer & DF_BOT_LEVELAD) && !ctf->value)
 	{
 		BeginIntermission (CreateTargetChangeLevel (level.mapname) );
 		return;
 	}
 
-	if((((int)(ctf->value) || (int)(cp->value))) && (!(int)(dedicated->value))) { //ctf will just stay on same level unless specified by dedicated list
+	if( ( ctf->integer || cp->integer ) && ! g_dedicated->integer )
+	{ //ctf will just stay on same level unless specified by dedicated list
 		BeginIntermission (CreateTargetChangeLevel (level.mapname));
 		return;
 	}
 	// see if it's in the map list
 	if (*sv_maplist->string) {
-		s = strdup(sv_maplist->string);
+		s = _strdup(sv_maplist->string);
 		f = NULL;
 		t = strtok(s, seps);
 		while (t != NULL) {
-			if (Q_stricmp(t, level.mapname) == 0) {
+			if (Q_strcasecmp(t, level.mapname) == 0) {
 				// it's in the list, go to the next one
 				t = strtok(NULL, seps);
 				if (t == NULL) { // end of list, go to first one
@@ -488,7 +477,7 @@ void EndDMLevel (void)
 		free(s);
 	}
 
-	if((int)(ctf->value)) { //wasn't in the dedicated list
+	if(ctf->integer) { //wasn't in the dedicated list
 		BeginIntermission (CreateTargetChangeLevel (level.mapname));
 		return;
 	}
@@ -499,25 +488,23 @@ void EndDMLevel (void)
 	/*
 	** load the list of map names
 	*/
-	Com_sprintf( mapsname, sizeof( mapsname ), "%s/maps.lst", "data1" );
+	if ( !gi.FullPath( mapsname, sizeof(mapsname), "maps.lst" ) )
+	{ // no maps.lst.
+		// note: originally this was looked for in "./data1/" only
+		//   hope it is ok to use FullPath() search path.
+		BeginIntermission (CreateTargetChangeLevel (level.mapname) );
+		return;
+	}
 	if ( ( fp = fopen( mapsname, "rb" ) ) == 0 )
 	{
 		BeginIntermission (CreateTargetChangeLevel (level.mapname) );
 			return;
 	}
-	else
-	{
-#ifdef _WIN32
-		length = filelength( fileno( fp  ) );
-#else
-		fseek(fp, 0, SEEK_END);
-		length = ftell(fp);
-		fseek(fp, 0, SEEK_SET);
-#endif
-		buffer = malloc( length + 1 );
-		fread( buffer, length, 1, fp );
-		buffer[length] = 0;
-	}
+
+	length = g_filelength( fp );
+	buffer = malloc( length + 1 );
+	szr = fread( buffer, length, 1, fp );
+	buffer[length] = 0;
 
 	s = buffer;
 
@@ -539,11 +526,14 @@ void EndDMLevel (void)
     char  shortname[MAX_TOKEN_CHARS];
     char  longname[MAX_TOKEN_CHARS];
 		char  scratch[200];
-		int		j, l;
+#if defined WIN32_VARIANT
+		int  j;
+#endif
+		int l;
 
 		strcpy( shortname, COM_Parse( &s ) );
 		l = strlen(shortname);
-#ifndef __unix__
+#if defined WIN32_VARIANT
 		for (j=0 ; j<l ; j++)
 			shortname[j] = toupper(shortname[j]);
 #endif
@@ -555,21 +545,13 @@ void EndDMLevel (void)
 	}
 	mapnames[nummaps] = 0;
 
-	if ( fp != 0 )
-	{
-		fp = 0;
-		free( buffer );
-	}
-
-	else
-	{
-		FS_FreeFile( buffer );
-	}
+	fclose(fp);
+	free( buffer );
 
 	//find map, goto next map - if one doesn't exist, repeat list
 	//stick something in here to filter out CTF, and just make it loop back
 	for (i = 0; i < nummaps; i++) {
-		if (Q_stricmp(mapnames[i], level.mapname) == 0) {
+		if (Q_strcasecmp(mapnames[i], level.mapname) == 0) {
 			if(mapnames[i+1][0])
 				BeginIntermission (CreateTargetChangeLevel (mapnames[i+1]) );
 			else if(mapnames[0][0]) //no more maps, repeat list
@@ -609,9 +591,9 @@ void CheckNeedPass (void)
 
 		need = 0;
 
-		if (*password->string && Q_stricmp(password->string, "none"))
+		if (*password->string && Q_strcasecmp(password->string, "none"))
 			need |= 1;
-		if (*spectator_password->string && Q_stricmp(spectator_password->string, "none"))
+		if (*spectator_password->string && Q_strcasecmp(spectator_password->string, "none"))
 			need |= 2;
 
 		gi.cvar_set("needpass", va("%d", need));
@@ -628,7 +610,7 @@ void ResetLevel (void) //for resetting players and items after warmup
 	edict_t	*ent;
 	gitem_t *item;
 
-	for (i=0 ; i<maxclients->value ; i++)
+	for (i=0 ; i<g_maxclients->value ; i++)
 	{
 		ent = g_edicts + i + 1;
 		if (!ent->inuse || ent->client->resp.spectator)
@@ -636,15 +618,20 @@ void ResetLevel (void) //for resetting players and items after warmup
 		// locate ent at a spawn point and reset everything
 		InitClientResp (ent->client);
 		if(ent->is_bot)
-			ACESP_PutClientInServer (ent,true,0);
+		{
+			// respawn bots after warmup
+			ACESP_PutClientInServer( ent, true );
+		}
 		else {
 			if(ent->deadflag)
 				DeathcamRemove (ent, "off");
 			PutClientInServer (ent);
-			ACESP_LoadBots(ent, 0);
 		}
-		ent->client->resp.homing_shots = 0;
+		ent->client->homing_shots = 0;
 	}
+
+	ACESP_SaveBots(); // update bots.tmp and client bot information
+
 	blue_team_score = 0;
 	red_team_score = 0;
 
@@ -676,11 +663,11 @@ void ResetLevel (void) //for resetting players and items after warmup
 	else
 		safe_bprintf(PRINT_HIGH, "Call voting is ^1DISABLED\n");
 
-	if(g_antilag->value) 
+	if(g_antilag->value)
 		safe_bprintf(PRINT_HIGH, "Antilag is ^2ENABLED\n");
-	else 
+	else
 		safe_bprintf(PRINT_HIGH, "Antilag is ^1DISABLED\n");
-	
+
 	return;
 }
 
@@ -696,46 +683,46 @@ void CheckDMRules (void)
 	gclient_t	*cl;
 	edict_t		*cl_ent;
 
-	if(!tca->value && !ctf->value && !cp->value && !((int)(dmflags->value) & DF_SKINTEAMS)) {
+	if(!tca->value && !ctf->value && !cp->value && !(dmflags->integer & DF_SKINTEAMS)) {
 		if(level.time <= warmuptime->value) {
-				if((warmuptime->value - level.time ) == 3) {
-					cl_ent = g_edicts + 1; //need only one for broadcast sound
-					if (cl_ent->inuse && !cl_ent->is_bot)
-						gi.sound (cl_ent, CHAN_AUTO, gi.soundindex("misc/three.wav"), 1, ATTN_NONE, 0);
-				}
-				if((warmuptime->value - level.time ) == 2) {
-					cl_ent = g_edicts + 1;
-					if (cl_ent->inuse && !cl_ent->is_bot)
-						gi.sound (cl_ent, CHAN_AUTO, gi.soundindex("misc/two.wav"), 1, ATTN_NONE, 0);
-				}
-				if((warmuptime->value - level.time ) == 1) {
-					cl_ent = g_edicts + 1;
-					if (cl_ent->inuse && !cl_ent->is_bot)
-						gi.sound (cl_ent, CHAN_AUTO, gi.soundindex("misc/one.wav"), 1, ATTN_NONE, 0);
-				}
-				if(level.time == warmuptime->value) {
-					cl_ent = g_edicts + 1;
-					if (cl_ent->inuse && !cl_ent->is_bot)
-						gi.sound (cl_ent, CHAN_AUTO, gi.soundindex("misc/fight.wav"), 1, ATTN_NONE, 0);
-						safe_centerprintf(cl_ent, "FIGHT!\n");
-					ResetLevel();
-				}
-				else if(level.time == ceil(level.time)){ //do only on the whole numer to avoid overflowing
-					for (i=0 ; i<maxclients->value ; i++)
-					{
-						cl_ent = g_edicts + 1 + i;
-						if (!cl_ent->inuse || cl_ent->is_bot)
-							continue;
-						int_time = warmuptime->value - level.time;
-						real_time = warmuptime->value - level.time;
-						if(int_time <= 3) {
-							if(int_time == real_time)
-								safe_centerprintf(cl_ent, "%i...\n", int_time);
-						}
-						else if(int_time/2 == real_time/2)
+			if((warmuptime->value - level.time ) == 3) {
+				cl_ent = g_edicts + 1; //need only one for broadcast sound
+				if (cl_ent->inuse && !cl_ent->is_bot)
+					gi.sound (cl_ent, CHAN_AUTO, gi.soundindex("misc/three.wav"), 1, ATTN_NONE, 0);
+			}
+			if((warmuptime->value - level.time ) == 2) {
+				cl_ent = g_edicts + 1;
+				if (cl_ent->inuse && !cl_ent->is_bot)
+					gi.sound (cl_ent, CHAN_AUTO, gi.soundindex("misc/two.wav"), 1, ATTN_NONE, 0);
+			}
+			if((warmuptime->value - level.time ) == 1) {
+				cl_ent = g_edicts + 1;
+				if (cl_ent->inuse && !cl_ent->is_bot)
+					gi.sound (cl_ent, CHAN_AUTO, gi.soundindex("misc/one.wav"), 1, ATTN_NONE, 0);
+			}
+			if(level.time == warmuptime->value) {
+				cl_ent = g_edicts + 1;
+				if (cl_ent->inuse && !cl_ent->is_bot)
+					gi.sound (cl_ent, CHAN_AUTO, gi.soundindex("misc/fight.wav"), 1, ATTN_NONE, 0);
+					safe_centerprintf(cl_ent, "FIGHT!\n");
+				ResetLevel();
+			}
+			else if(level.time == ceil(level.time)){ //do only on the whole numer to avoid overflowing
+				for (i=0 ; i<g_maxclients->value ; i++)
+				{
+					cl_ent = g_edicts + 1 + i;
+					if (!cl_ent->inuse || cl_ent->is_bot)
+						continue;
+					int_time = warmuptime->value - level.time;
+					real_time = warmuptime->value - level.time;
+					if(int_time <= 3) {
+						if(int_time == real_time)
 							safe_centerprintf(cl_ent, "%i...\n", int_time);
 					}
+					else if(int_time/2 == real_time/2)
+						safe_centerprintf(cl_ent, "%i...\n", int_time);
 				}
+			}
 		}
 	}
 
@@ -747,7 +734,7 @@ void CheckDMRules (void)
 
 	if (timelimit->value)
 	{
-		if (level.time >= timelimit->value*60 && ((tca->value || ctf->value  || cp->value || ((int)(dmflags->value) & DF_SKINTEAMS)) || level.time > warmuptime->value))
+		if (level.time >= timelimit->value*60 && ((tca->value || ctf->value  || cp->value || (dmflags->integer & DF_SKINTEAMS)) || level.time > warmuptime->value))
 		{
 			safe_bprintf (PRINT_HIGH, "Timelimit hit.\n");
 			EndDMLevel ();
@@ -755,11 +742,11 @@ void CheckDMRules (void)
 		}
 	}
 
-	if (fraglimit->value && ((tca->value || ctf->value || cp->value || ((int)(dmflags->value) & DF_SKINTEAMS)) || level.time > warmuptime->value))
+	if (fraglimit->value && ((tca->value || ctf->value || cp->value || (dmflags->integer & DF_SKINTEAMS)) || level.time > warmuptime->value))
 	{
 
 		//team scores
-		if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || cp->value) //it's all about the team!
+		if ((dmflags->integer & DF_SKINTEAMS) || ctf->value || cp->value) //it's all about the team!
 		{
 			if(blue_team_score >= fraglimit->value)
 			{
@@ -782,7 +769,7 @@ void CheckDMRules (void)
 		}
 		else {
 			top_score = 0;
-			for (i=0 ; i<maxclients->value ; i++)
+			for (i=0 ; i<g_maxclients->value ; i++)
 			{
 				cl = game.clients + i;
 				if (!g_edicts[i+1].inuse)
@@ -793,7 +780,6 @@ void CheckDMRules (void)
 
 				if (cl->resp.score >= fraglimit->value)
 				{
-
 					if(cl->is_bot){
 						bot_won = 1; //a bot has won the match
 						safe_bprintf (PRINT_HIGH, "Fraglimit hit by bot.\n");
@@ -801,10 +787,7 @@ void CheckDMRules (void)
 					else
 					{
 						bot_won = 0;
-
-
-					safe_bprintf (PRINT_HIGH, "Fraglimit hit.\n");
-
+						safe_bprintf (PRINT_HIGH, "Fraglimit hit.\n");
 					}
 
 					EndDMLevel ();
@@ -816,7 +799,7 @@ void CheckDMRules (void)
 				switch(i) {
 					case 3:
 						if(!print3){
-							for (i=0 ; i<maxclients->value ; i++)
+							for (i=0 ; i<g_maxclients->value ; i++)
 							{
 								cl_ent = g_edicts + 1 + i;
 								if (!cl_ent->inuse || cl_ent->is_bot)
@@ -830,7 +813,7 @@ void CheckDMRules (void)
 						break;
 					case 2:
 						if(!print2) {
-							for (i=0 ; i<maxclients->value ; i++)
+							for (i=0 ; i<g_maxclients->value ; i++)
 							{
 								cl_ent = g_edicts + 1 + i;
 								if (!cl_ent->inuse || cl_ent->is_bot)
@@ -844,7 +827,7 @@ void CheckDMRules (void)
 						break;
 					case 1:
 						if(!print1) {
-							for (i=0 ; i<maxclients->value ; i++)
+							for (i=0 ; i<g_maxclients->value ; i++)
 							{
 								cl_ent = g_edicts + 1 + i;
 								if (!cl_ent->inuse || cl_ent->is_bot)
@@ -900,7 +883,7 @@ void ExitLevel (void)
 		Com_sprintf (command, sizeof(command), "map \"%s\"\n", level.changemap);
 		gi.AddCommandString (command);
 	}
-	else 
+	else
 		stayed = true; //no need to reload map if staying on same level!
 
 	level.changemap = NULL;
@@ -910,45 +893,39 @@ void ExitLevel (void)
 	EndIntermission();
 
 	// clear some things before going to next level
-	for (i=0 ; i<maxclients->value ; i++)
+	for (i=0 ; i<g_maxclients->value ; i++)
 	{
 		ent = g_edicts + 1 + i;
 		if (!ent->inuse)
 			continue;
 		if (ent->health > ent->client->pers.max_health)
 			ent->health = ent->client->pers.max_health;
-		
+
 		if(stayed) {
 			ent->client->resp.score = 0;
 			ent->client->resp.deaths = 0;
 			ent->client->resp.reward_pts = 0;
-			ent->client->resp.homing_shots = 0;
-			if(!ent->is_bot) { //players
-				ent->takedamage = DAMAGE_AIM;
-				ent->solid = SOLID_BBOX;
-				ent->deadflag = DEAD_NO;	
+			ent->client->homing_shots = 0;
+			ent->takedamage = DAMAGE_AIM;
+			ent->solid = SOLID_BBOX;
+			ent->deadflag = DEAD_NO;
+			if(ent->is_bot) {
+				// when staying on same level, respawn current bots
+				ACESP_PutClientInServer( ent, true );
+			} else {
 				PutClientInServer (ent);
 			}
-			else { //reset various bot junk
-				ent->takedamage = DAMAGE_AIM;
-				ent->solid = SOLID_BBOX;
-				ent->deadflag = DEAD_NO;
-				ACESP_PutClientInServer (ent,true,0);
-			}
 			if(g_duel->value) {
 				ClientPlaceInQueue(ent);
-				ClientCheckQueue(ent);	
+				ClientCheckQueue(ent);
 			}
 		}
 	}
 	if(stayed) {
 		for (i=1, ent=g_edicts+i ; i < globals.num_edicts ; i++,ent++) {
 
-			if (!ent->inuse)
+			if (!ent->inuse || ent->client)
 				continue;
-			if(ent->client) {//not players
-				continue;
-			}
 			//remove podiums
 			if(!strcmp(ent->classname, "pad"))
 				G_FreeEdict(ent);
@@ -964,11 +941,8 @@ void ExitLevel (void)
 		red_team_score = 0;
 		blue_team_score = 0;
 	}
-	blue_team_cnt = 0;
-	red_team_cnt = 0; //reset everything now that we are done
 	print1 = print2 = print3 = false;
-	if(!stayed)
-		game.num_bots = 0; //do this *just* incase something got whacked or isn't getting set.
+
 }
 
 /*
@@ -1008,7 +982,7 @@ void G_Ban (char *ip)
 	}
 
 	fprintf (f, "sv addip %s\n", ip);
-	
+
 	fclose (f);
 
 	//add to current ban list
@@ -1024,11 +998,75 @@ void G_Ban (char *ip)
 		}
 		numipfilters++;
 	}
-	
+
 	if (!StringToFilter (ip, &ipfilters[i]))
 		ipfilters[i].compare = 0xffffffff;
 }
 
+/*
+================
+G_NameMatch
+
+ A name entered in the console may (unlikely) or may not have color codes.
+ This is a case-sensitive match, because a case-insensitive match would
+   complicate matters.
+
+ Used by sv removebot <name> and callvote kicks
+
+================
+*/
+qboolean G_NameMatch( const char* netname, const char *kickname )
+{
+	const char* p_netname = netname;
+	const char* p_kickname = kickname;
+	int char_count = 16;
+	int len_count = 49; // maximum length of 16 char color name (16 * 3 + nul)
+	qboolean matched = false;
+
+	while ( len_count > 0 && char_count > 0)
+	{
+		if ( *p_netname != *p_kickname )
+		{
+			if ( Q_IsColorString( p_netname ) )
+			{ // netname has color code, kickname does not, match still possible
+				p_netname += 2;
+				len_count -= 2;
+			}
+			else if ( Q_IsColorString( p_kickname ))
+			{ // kickname has color code, netname does not, match still possible
+				p_kickname += 2;
+				len_count -= 2;
+			}
+			else
+			{ // no match. mismatched chars, or end of one or the other
+				break;
+			}
+		}
+		else if ( !*p_netname && !*p_kickname )
+		{ // end of both strings,
+			matched = true;
+			break;
+		}
+		else
+		{ // chars matched
+			if ( Q_IsColorString( p_netname ) && Q_IsColorString( p_kickname ) )
+			{ // color does not have to match
+				p_netname += 2;
+				p_kickname += 2;
+				len_count -= 2;
+			}
+			else
+			{
+				++p_netname;
+				++p_kickname;
+				--len_count;
+				--char_count;
+			}
+		}
+	}
+
+	return matched;
+}
 
 /*
 ================
@@ -1037,6 +1075,31 @@ G_ParseVoteCommand
 Parse and execute command
 ================
 */
+// helper function
+static edict_t* find_kick_target( const char *name )
+{
+	edict_t* kick_target = NULL;
+	edict_t* ent;
+	int i;
+
+	for ( i = 1 ; i <= g_maxclients->integer ; i++ )
+	{
+		ent = &g_edicts[i];
+		if ( !ent->inuse )
+			continue;
+		if ( ent->client )
+		{
+			if ( G_NameMatch( ent->client->pers.netname, name ) )
+			{
+				kick_target = ent;
+				break;
+			}
+		}
+	}
+
+	return kick_target;
+}
+
 void G_ParseVoteCommand (void)
 {
 	int i, j;
@@ -1053,7 +1116,7 @@ void G_ParseVoteCommand (void)
 		if(playervote.command[i] == ' ')
 			donearg = true;
 
-		if(!donearg) 
+		if(!donearg)
 			command[i] = playervote.command[i];
 		else
 			command[i] = 0;
@@ -1065,52 +1128,58 @@ void G_ParseVoteCommand (void)
 		i++;
 	}
 
-	if(!strcmp(command, "kick")) { //kick player
-
-		//get the correct client
-		for (i=0 ; i<maxclients->value ; i++)
+	if ( !strcmp(command, "kick") )
+	{ // kick player or bot
+		ent = find_kick_target( args );
+		if ( ent )
 		{
-			ent = g_edicts + 1 + i;
-			if (!ent->inuse)
-				continue;
-
-			if(ent->client) {
-				if(!strcmp(ent->client->pers.netname, args)) {
-					if(ent->is_bot)
-						ACESP_KickBot(args);
-					else {
-						safe_bprintf(PRINT_HIGH, "%s was kicked\n", args);
-						ClientDisconnect (ent);
-					}
+			if ( ent->is_bot )
+			{
+				if ( sv_botkickthreshold && sv_botkickthreshold->integer )
+				{
+					safe_bprintf(PRINT_HIGH,
+						"Auto bot kick enabled, callvote kick <bot> disabled.\n%s not kicked.\n",
+						 ent->client->pers.netname);
 				}
-				
+				else
+				{
+					ACESP_KickBot( ent );
+				}
+			}
+			else
+			{
+				safe_bprintf(PRINT_HIGH, "%s was kicked\n", args);
+				ClientDisconnect (ent);
 			}
 		}
-	}
-	else if(!strcmp(command, "kickban")) { //kick and ban player from server
-	//get the correct client
-		for (i=0 ; i<maxclients->value ; i++)
+		else
 		{
-			ent = g_edicts + 1 + i;
-			if (!ent->inuse)
-				continue;
-
-			if(ent->client) {
-				if(!strcmp(ent->client->pers.netname, args)) {
-					if(ent->is_bot)
-						ACESP_KickBot(args);
-					else {
-						safe_bprintf(PRINT_HIGH, "%s was kickbanned\n", args);
-						ClientDisconnect (ent);
-					}
-					//now ban them
-					value = Info_ValueForKey (ent->client->pers.userinfo, "ip");
-					G_Ban(value);
-				}				
+			safe_bprintf( PRINT_HIGH, "Did not find %s here.\n", args );
+		}
+	}
+	else if ( !strcmp( command, "kickban") )
+	{ // kickban player
+		ent = find_kick_target( args );
+		if ( ent )
+		{
+			if ( ent->is_bot )
+			{ //
+				safe_bprintf(PRINT_HIGH,
+					"%s is a bot, use \"kick\", not \"kickban.\"\n", ent->client->pers.netname);
 			}
+			else
+			{
+				safe_bprintf(PRINT_HIGH, "%s was kickbanned\n", args);
+				ClientDisconnect (ent);
+				value = Info_ValueForKey (ent->client->pers.userinfo, "ip");
+				G_Ban(value);
+			}
+		}
+		else
+		{
+			safe_bprintf( PRINT_HIGH, "Did not find %s here.\n", args );
 		}
 	}
-
 	else if(!strcmp(command, "fraglimit")) { //change fraglimit
 		gi.cvar_set("fraglimit", args);
 		safe_bprintf(PRINT_HIGH, "Fraglimit changed to %s\n", args);
@@ -1160,8 +1229,8 @@ void G_RunFrame (void)
 	//
 	// treat each object in turn
 	// even the world gets a chance to think
-	//	
-	
+	//
+
 	ent = &g_edicts[0];
 	for (i=0 ; i<globals.num_edicts ; i++, ent++)
 	{
@@ -1182,14 +1251,14 @@ void G_RunFrame (void)
 			}
 		}
 
-		if (i > 0 && i <= maxclients->value)
+		if (i > 0 && i <= g_maxclients->value)
 		{
 			ClientBeginServerFrame (ent);
 		}
 
 		if(ent->inuse && ent->client && !ent->is_bot)
 		{
-			if ( ent->s.number <= maxclients->value )
+			if ( ent->s.number <= g_maxclients->value )
 			{ // count actual players, not deathcam entities
 				numActiveClients++;
 			}
@@ -1199,7 +1268,7 @@ void G_RunFrame (void)
 /*		if(ent->movetype & MOVETYPE_FLYMISSILE) {
 			//unlagged
 			if ( g_antilag->integer)
-				G_TimeShiftAllClients( level.previousTime, NULL );	
+				G_TimeShiftAllClients( level.previousTime, NULL );
 
 			G_RunEntity (ent);
 
@@ -1232,28 +1301,28 @@ void G_RunFrame (void)
 			//execute command if votes are sufficient
 			if(numActiveClients <= 2 && playervote.yay > playervote.nay+1) { //minimum of 2 votes to pass
 				safe_bprintf(PRINT_HIGH, "Vote ^2Passed\n");
-				
+
 				//parse command(we will allow kick, map, fraglimit, timelimit).
 				G_ParseVoteCommand();
-				
+
 			}
 			else if(playervote.yay > 2 && playervote.yay > playervote.nay+1) { //3-1 minimum to pass
 				safe_bprintf(PRINT_HIGH, "Vote ^2Passed\n");
-				
+
 				//parse command(we will allow kick, map, fraglimit, timelimit).
 				G_ParseVoteCommand();
-				
+
 			}
 			else
 				safe_bprintf(PRINT_HIGH, "Vote ^1Failed\n");
-		
+
 			//clear
 			playervote.called = false;
 			playervote.yay = playervote.nay = 0;
 			playervote.command[0] = 0;
 
 			//do each ent
-			for (i=0 ; i<maxclients->value ; i++)
+			for (i=0 ; i<g_maxclients->value ; i++)
 			{
 				ent = g_edicts + 1 + i;
 				if (!ent->inuse || ent->is_bot)
