@@ -18,12 +18,14 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "g_local.h"
 
 #define Function(f) {#f, f}
 
-int red_team_cnt;
-int blue_team_cnt;
 int red_team_score;
 int blue_team_score;
 int reddiff;
@@ -174,14 +176,14 @@ void InitGame (void)
 	sv_gravity = gi.cvar ("sv_gravity", "800", 0);
 
 	// noset vars
-	dedicated = gi.cvar ("dedicated", "0", CVAR_NOSET);
+	g_dedicated = gi.cvar ("dedicated", "0", CVAR_NOSET);
 
 	// latched vars
 	sv_cheats = gi.cvar ("cheats", "0", CVAR_SERVERINFO|CVAR_LATCH);
 	gi.cvar ("gamename", GAMEVERSION , CVAR_SERVERINFO | CVAR_LATCH);
 	gi.cvar ("gamedate", __DATE__ , CVAR_SERVERINFO | CVAR_LATCH);
 
-	maxclients = gi.cvar ("maxclients", "4", CVAR_SERVERINFO | CVAR_LATCH);
+	g_maxclients = gi.cvar ("maxclients", "4", CVAR_SERVERINFO | CVAR_LATCH);
 	maxspectators = gi.cvar ("maxspectators", "4", CVAR_SERVERINFO);
 	deathmatch = gi.cvar ("deathmatch", "0", CVAR_LATCH);
 	ctf = gi.cvar ("ctf", "0", CVAR_LATCH);
@@ -232,7 +234,7 @@ void InitGame (void)
 	g_randomquad = gi.cvar("g_randomquad", "0", CVAR_LATCH);
 
 	//warmup time
-	warmuptime = gi.cvar("warmuptime", "15", CVAR_LATCH);
+	warmuptime = gi.cvar("warmuptime", "30", CVAR_LATCH);
 
 	//spawn protection
 	g_spawnprotect = gi.cvar("g_spawnprotect", "2", CVAR_SERVERINFO);
@@ -257,7 +259,7 @@ void InitGame (void)
 
 	//antilag
 	g_antilag = gi.cvar("g_antilag", "1", CVAR_SERVERINFO);
-	g_antilagdebug = gi.cvar("g_antilagdebug", "0", CVAR_SERVERINFO);
+	g_antilagdebug = gi.cvar("g_antilagdebug", "0", 0 /*CVAR_SERVERINFO*/);
 
 	// change anytime vars
 	dmflags = gi.cvar ("dmflags", "0", CVAR_SERVERINFO);
@@ -277,7 +279,7 @@ void InitGame (void)
 	bob_pitch = gi.cvar ("bob_pitch", "0.002", 0);
 	bob_roll = gi.cvar ("bob_roll", "0.002", 0);
 
-	background_music = gi.cvar ("background_music", "1", CVAR_ARCHIVE);
+	g_background_music = gi.cvar ("background_music", "1", CVAR_ARCHIVE);
 
 	// flood control
 	flood_msgs = gi.cvar ("flood_msgs", "4", 0);
@@ -301,7 +303,7 @@ void InitGame (void)
 	globals.max_edicts = game.maxentities;
 
 	// initialize all clients for this game
-	game.maxclients = maxclients->value;
+	game.maxclients = g_maxclients->value;
 	game.clients = gi.TagMalloc (game.maxclients * sizeof(game.clients[0]), TAG_GAME);
 	globals.num_edicts = game.maxclients+1;
 
@@ -314,8 +316,6 @@ void InitGame (void)
 		red_team_score = 0;
 		blue_team_score = 0;
 	}
-	blue_team_cnt = 0;
-	red_team_cnt = 0;
 	print1 = print2 = print3 = false;
 
 }
