@@ -1,3 +1,26 @@
+/*
+Copyright (C) 1997-2001 Id Software, Inc.
+Copyright (C) 20?? COR Entertainment, LLC.
+
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation; either version 2
+of the License, or (at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+
+See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "g_local.h"
 
@@ -198,9 +221,9 @@ void ED_CallSpawn (edict_t *ent)
 			continue;
 
 		//-JD - removing old weapons, and in the case of the vaporizer, duplicates.
-		if(!Q_stricmp(ent->classname, "weapon_grenadelauncher"))
+		if(!Q_strcasecmp(ent->classname, "weapon_grenadelauncher"))
 			ent->classname = "weapon_rocketlauncher"; //hack to remove old weapons
-		if(!Q_stricmp(ent->classname, "weapon_machinegun"))
+		if(!Q_strcasecmp(ent->classname, "weapon_machinegun"))
 			ent->classname = "weapon_bfg"; //hack to remove old weapons
 
 		if (!strcmp(item->classname, ent->classname))
@@ -281,7 +304,7 @@ void ED_ParseField (char *key, char *value, edict_t *ent)
 
 	for (f=fields ; f->name ; f++)
 	{
-		if (!Q_stricmp(f->name, key))
+		if (!Q_strcasecmp(f->name, key))
 		{	// found it
 			if (f->flags & FFL_SPAWNTEMP)
 				b = (byte *)&st;
@@ -312,6 +335,7 @@ void ED_ParseField (char *key, char *value, edict_t *ent)
 				((float *)(b+f->ofs))[2] = 0;
 				break;
 			case F_IGNORE:
+			default:
 				break;
 			}
 			return;
@@ -483,7 +507,7 @@ void SpawnEntities (char *mapname, char *entities, char *spawnpoint)
 		entities = ED_ParseEdict (entities, ent);
 
 		// yet another map hack
-		if (!stricmp(level.mapname, "command") && !stricmp(ent->classname, "trigger_once") && !stricmp(ent->model, "*27"))
+		if (!Q_strcasecmp(level.mapname, "command") && !Q_strcasecmp(ent->classname, "trigger_once") && !Q_strcasecmp(ent->model, "*27"))
 			ent->spawnflags &= ~SPAWNFLAG_NOT_HARD;
 
 		// remove things (except the world) from different skill levels or deathmatch
@@ -799,10 +823,10 @@ void SP_worldspawn (edict_t *ent)
 	gi.configstring (CS_SKYAXIS, va("%f %f %f",
 		st.skyaxis[0], st.skyaxis[1], st.skyaxis[2]) );
 
-	gi.configstring (CS_MAXCLIENTS, va("%i", (int)(maxclients->value) ) );
+	gi.configstring (CS_MAXCLIENTS, va("%i", g_maxclients->integer ) );
 
 	// status bar program
-	if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value)
+	if ((dmflags->integer & DF_SKINTEAMS) || ctf->value || tca->value || cp->value)
 	{
 		gi.configstring (CS_STATUSBAR, team_statusbar);
 		if(ctf->value)
@@ -827,6 +851,8 @@ void SP_worldspawn (edict_t *ent)
 	else
 		gi.cvar_set("sv_gravity", st.gravity);
 
+	//prechaches
+
 	PrecacheItem (FindItem ("Blaster"));
 	PrecacheItem (FindItem ("Violator"));
 
@@ -836,7 +862,6 @@ void SP_worldspawn (edict_t *ent)
 	gi.soundindex ("misc/pc_up.wav");
 	gi.soundindex ("misc/talk1.wav");
 
-	// gibs
 	gi.soundindex ("items/respawn1.wav");
 
 	// sexed sounds
@@ -885,16 +910,57 @@ void SP_worldspawn (edict_t *ent)
 	gi.soundindex ("misc/rampage.wav");
 	gi.soundindex ("misc/fight.wav");
 
+	//precache all base player taunts
+	gi.soundindex ("taunts/martianenforcer/taunt1.wav");
+	gi.soundindex ("taunts/martianenforcer/taunt2.wav");
+	gi.soundindex ("taunts/martianenforcer/taunt3.wav");
+	gi.soundindex ("taunts/martianenforcer/taunt4.wav");
+	gi.soundindex ("taunts/martianenforcer/taunt5.wav");
+
+	gi.soundindex ("taunts/martiancyborg/taunt1.wav");
+	gi.soundindex ("taunts/martiancyborg/taunt2.wav");
+	gi.soundindex ("taunts/martiancyborg/taunt3.wav");
+	gi.soundindex ("taunts/martiancyborg/taunt4.wav");
+	gi.soundindex ("taunts/martiancyborg/taunt5.wav");
+
+	gi.soundindex ("taunts/commander/taunt1.wav");
+	gi.soundindex ("taunts/commander/taunt2.wav");
+	gi.soundindex ("taunts/commander/taunt3.wav");
+	gi.soundindex ("taunts/commander/taunt4.wav");
+	gi.soundindex ("taunts/commander/taunt5.wav");
+
+	gi.soundindex ("taunts/enforcer/taunt1.wav");
+	gi.soundindex ("taunts/enforcer/taunt2.wav");
+	gi.soundindex ("taunts/enforcer/taunt3.wav");
+	gi.soundindex ("taunts/enforcer/taunt4.wav");
+	gi.soundindex ("taunts/enforcer/taunt5.wav");
+
+	gi.soundindex ("taunts/slashbot/taunt1.wav");
+	gi.soundindex ("taunts/slashbot/taunt2.wav");
+	gi.soundindex ("taunts/slashbot/taunt3.wav");
+	gi.soundindex ("taunts/slashbot/taunt4.wav");
+	gi.soundindex ("taunts/slashbot/taunt5.wav");
+
+	gi.soundindex ("taunts/lauren/taunt1.wav");
+	gi.soundindex ("taunts/lauren/taunt2.wav");
+	gi.soundindex ("taunts/lauren/taunt3.wav");
+	gi.soundindex ("taunts/lauren/taunt4.wav");
+	gi.soundindex ("taunts/lauren/taunt5.wav");
+
+	gi.soundindex ("taunts/martiancyborg/taunt1.wav");
+	gi.soundindex ("taunts/martiancyborg/taunt2.wav");
+	gi.soundindex ("taunts/martiancyborg/taunt3.wav");
+	gi.soundindex ("taunts/martiancyborg/taunt4.wav");
+	gi.soundindex ("taunts/martiancyborg/taunt5.wav");
+
 	//precache any gibs
 	sm_meat_index = gi.modelindex ("models/objects/gibs/sm_meat/tris.md2");
 	gi.modelindex ("models/objects/gibs/mart_gut/tris.md2");
 	gi.modelindex ("models/objects/debris1/tris.md2");
 	gi.modelindex ("models/objects/debris3/tris.md2");
 
-//	gi.modelindex ("models/objects/laser/tris.md2");
-//	gi.modelindex ("models/objects/fireball/tris.md2");
-
 	//precache all base player models.  this eliminates "stutter" when a player joins the game
+	//this should be here for the cases of 7.45 clients and older
 	gi.modelindex ("players/martianenforcer/tris.md2");
 	gi.modelindex ("players/martiancyborg/tris.md2");
 	gi.modelindex ("players/enforcer/tris.md2");
@@ -903,8 +969,79 @@ void SP_worldspawn (edict_t *ent)
 	gi.modelindex ("players/commander/tris.md2");
 
 	//do the w_weps
-	// THIS ORDER MUST MATCH THE DEFINES IN g_local.h
-	// you can add more, max 15
+	gi.modelindex ("players/martianenforcer/weapon.md2");
+	gi.modelindex ("players/martianenforcer/w_blaster.md2");
+	gi.modelindex ("players/martianenforcer/w_shotgun.md2");
+	gi.modelindex ("players/martianenforcer/w_sshotgun.md2");
+	gi.modelindex ("players/martianenforcer/w_machinegun.md2");
+	gi.modelindex ("players/martianenforcer/w_chaingun.md2");
+	gi.modelindex ("players/martianenforcer/w_rlauncher.md2");
+	gi.modelindex ("players/martianenforcer/w_hyperblaster.md2");
+	gi.modelindex ("players/martianenforcer/w_railgun.md2");
+	gi.modelindex ("players/martianenforcer/w_bfg.md2");
+	gi.modelindex ("players/martianenforcer/w_violator.md2");
+
+	gi.modelindex ("players/martiancyborg/weapon.md2");
+	gi.modelindex ("players/martiancyborg/w_blaster.md2");
+	gi.modelindex ("players/martiancyborg/w_shotgun.md2");
+	gi.modelindex ("players/martiancyborg/w_sshotgun.md2");
+	gi.modelindex ("players/martiancyborg/w_machinegun.md2");
+	gi.modelindex ("players/martiancyborg/w_chaingun.md2");
+	gi.modelindex ("players/martiancyborg/w_rlauncher.md2");
+	gi.modelindex ("players/martiancyborg/w_hyperblaster.md2");
+	gi.modelindex ("players/martiancyborg/w_railgun.md2");
+	gi.modelindex ("players/martiancyborg/w_bfg.md2");
+	gi.modelindex ("players/martiancyborg/w_violator.md2");
+
+	gi.modelindex ("players/enforcer/weapon.md2");
+	gi.modelindex ("players/enforcer/w_blaster.md2");
+	gi.modelindex ("players/enforcer/w_shotgun.md2");
+	gi.modelindex ("players/enforcer/w_sshotgun.md2");
+	gi.modelindex ("players/enforcer/w_machinegun.md2");
+	gi.modelindex ("players/enforcer/w_chaingun.md2");
+	gi.modelindex ("players/enforcer/w_rlauncher.md2");
+	gi.modelindex ("players/enforcer/w_hyperblaster.md2");
+	gi.modelindex ("players/enforcer/w_railgun.md2");
+	gi.modelindex ("players/enforcer/w_bfg.md2");
+	gi.modelindex ("players/enforcer/w_violator.md2");
+
+	gi.modelindex ("players/lauren/weapon.md2");
+	gi.modelindex ("players/lauren/w_blaster.md2");
+	gi.modelindex ("players/lauren/w_shotgun.md2");
+	gi.modelindex ("players/lauren/w_sshotgun.md2");
+	gi.modelindex ("players/lauren/w_machinegun.md2");
+	gi.modelindex ("players/lauren/w_chaingun.md2");
+	gi.modelindex ("players/lauren/w_rlauncher.md2");
+	gi.modelindex ("players/lauren/w_hyperblaster.md2");
+	gi.modelindex ("players/lauren/w_railgun.md2");
+	gi.modelindex ("players/lauren/w_bfg.md2");
+	gi.modelindex ("players/lauren/w_violator.md2");
+
+	gi.modelindex ("players/slashbot/weapon.md2");
+	gi.modelindex ("players/slashbot/w_blaster.md2");
+	gi.modelindex ("players/slashbot/w_shotgun.md2");
+	gi.modelindex ("players/slashbot/w_sshotgun.md2");
+	gi.modelindex ("players/slashbot/w_machinegun.md2");
+	gi.modelindex ("players/slashbot/w_chaingun.md2");
+	gi.modelindex ("players/slashbot/w_rlauncher.md2");
+	gi.modelindex ("players/slashbot/w_hyperblaster.md2");
+	gi.modelindex ("players/slashbot/w_railgun.md2");
+	gi.modelindex ("players/slashbot/w_bfg.md2");
+	gi.modelindex ("players/slashbot/w_violator.md2");
+
+	gi.modelindex ("players/commander/weapon.md2");
+	gi.modelindex ("players/commander/w_blaster.md2");
+	gi.modelindex ("players/commander/w_shotgun.md2");
+	gi.modelindex ("players/commander/w_sshotgun.md2");
+	gi.modelindex ("players/commander/w_machinegun.md2");
+	gi.modelindex ("players/commander/w_chaingun.md2");
+	gi.modelindex ("players/commander/w_rlauncher.md2");
+	gi.modelindex ("players/commander/w_hyperblaster.md2");
+	gi.modelindex ("players/commander/w_railgun.md2");
+	gi.modelindex ("players/commander/w_bfg.md2");
+	gi.modelindex ("players/commander/w_violator.md2");
+	
+	//these are needed for custom player models for when they enter a game
 	gi.modelindex ("#w_blaster.md2");
 	gi.modelindex ("#w_shotgun.md2");
 	gi.modelindex ("#w_sshotgun.md2");
