@@ -18,6 +18,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "g_local.h"
 #include "m_player.h"
 
@@ -360,7 +364,7 @@ void SV_CalcGunOffset (edict_t *ent)
 		ent->client->ps.gunoffset[i] += up[i]* (-gun_z->value);
 
 	}
-	
+
 	//landing on jumps
 	if(ent->s.event == EV_FALLSHORT || ent->s.event == EV_FALL || ent->s.event == EV_FALLFAR) {
 		ent->client->ps.gunoffset[2] -=1.5;
@@ -426,7 +430,6 @@ void ResetWeaponModel (edict_t *ent)
 
 	sprintf(weaponmodel, "players/%s%s", weaponame, "weapon.md2"); //default
 
-#ifdef __unix__
 	if( !Q_strcasecmp( ent->client->pers.weapon->view_model, "models/weapons/v_violator/tris.md2" ))
 		sprintf(weaponmodel, "players/%s%s", weaponame, "w_violator.md2");
 	else if( !Q_strcasecmp( ent->client->pers.weapon->view_model, "models/weapons/v_rocket/tris.md2"))
@@ -447,41 +450,17 @@ void ResetWeaponModel (edict_t *ent)
 		sprintf(weaponmodel, "players/%s%s", weaponame, "w_chaingun.md2");
 	else if( !Q_strcasecmp(ent->client->pers.weapon->view_model, "vehicles/deathball/v_wep.md2"))
 		sprintf(weaponmodel, "players/%s%s", weaponame, "w_machinegun.md2");
-#else
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_violator/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_violator.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_rocket/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_rlauncher.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_blast/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_blaster.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_bfg/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_bfg.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_rail/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_railgun.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_shotg2/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_sshotgun.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_shotg/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_shotgun.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_hyperb/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_hyperblaster.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_chain/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_chaingun.md2");
-	if(ent->client->pers.weapon->view_model == "vehicles/deathball/v_wep.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_machinegun.md2");
-#endif
 
 	sprintf(weaponpath, "%s", weaponmodel);
 	Q2_FindFile (weaponpath, &file); //does it really exist?
-	if(!file) {
-#ifdef __unix__
+	if(!file)
+	{
 		sprintf(weaponpath, "%s%s", weaponame, "weapon.md2"); //no w_weaps, do we have this model?
-#else
-		sprintf(weaponpath, "%s", weaponame, "weapon.md2"); //no w_weaps, do we have this model?
-#endif
 		Q2_FindFile (weaponpath, &file);
 		if(!file) //server does not have this player model
 			sprintf(weaponmodel, "players/martianenforcer/weapon.md2");//default player(martian)
-		else { //have the model, but it has no w_weaps
+		else
+		{ //have the model, but it has no w_weaps
 			sprintf(weaponmodel, "players/%s%s", weaponame, "weapon.md2"); //custom weapon
 			fclose(file);
 		}
@@ -638,7 +617,7 @@ void P_FallingDamage (edict_t *ent)
 
 	if (ent->movetype == MOVETYPE_NOCLIP)
 		return;
-	
+
 	if(joustmode->value)
 		return;
 
@@ -676,7 +655,7 @@ void P_FallingDamage (edict_t *ent)
 // 		ent->s.event = EV_FOOTSTEP;
 // 		return;
 // 	}
-	
+
 	ent->client->fall_value = delta;
 	if (ent->client->fall_value > 20)
 		ent->client->fall_value = 20;
@@ -699,7 +678,7 @@ void P_FallingDamage (edict_t *ent)
 			damage = 10;
 		VectorSet (dir, 0, 0, 1);
 
-		if (!deathmatch->value || !((int)dmflags->value & DF_NO_FALLING) )
+		if (!deathmatch->value || !(dmflags->integer & DF_NO_FALLING) )
 			T_Damage (ent, world, world, dir, ent->s.origin, vec3_origin, damage, 0, 0, MOD_FALLING);
 	}
 	else
@@ -878,7 +857,7 @@ void G_SetClientEffects (edict_t *ent)
 	if(ctf->value)
 		CTFEffects(ent);
 
-	if (((int)(dmflags->value) & DF_SKINTEAMS) || ctf->value || tca->value || cp->value )
+	if ((dmflags->integer & DF_SKINTEAMS) || ctf->value || tca->value || cp->value )
 		TeamEffects(ent);
 
 	if (ent->client->quad_framenum > level.framenum)
@@ -910,7 +889,7 @@ void G_SetClientEffects (edict_t *ent)
 
 	//invisibility
 	if(ent->client->invis_framenum > level.framenum) {
-		ent->s.renderfx |= RF_TRANSLUCENT; 
+		ent->s.renderfx |= RF_TRANSLUCENT;
 		ent->s.modelindex2 = 0;
 	}
 
@@ -931,12 +910,12 @@ void G_SetClientEvent (edict_t *ent)
 	{
 		if ( (int)(current_client->bobtime+bobmove) != bobcycle )
 			ent->s.event = EV_FOOTSTEP;
-		
+
 		if ( ((ent->waterlevel == 1) || (ent->waterlevel == 2)) && (xyspeed > 100) )
 		{
 			if ( (int)(current_client->bobtime+bobmove) != bobcycle )
-			{				
-				ent->s.event = EV_WADE;	 
+			{
+				ent->s.event = EV_WADE;
 			}
 		}
 	}
@@ -1240,7 +1219,7 @@ void ClientEndServerFrame (edict_t *ent)
 	}
 	if (ent->client->chasetoggle == 1)
         CheckDeathcam_Viewent(ent);
-		
+
 	if ( g_antilag->integer)
 		G_StoreHistory( ent );
 }
