@@ -1,4 +1,27 @@
-// g_weapon.c
+/*
+Copyright (C) 1997-2001 Id Software, Inc.
+Copyright (C) 20?? COR Entertainment, LLC.
+
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License
+as published by the Free Software Foundation; either version 2
+of the License, or (at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+
+See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+*/
+// p_weapon.c
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "g_local.h"
 #include "m_player.h"
@@ -6,7 +29,7 @@
 
 static qboolean	is_quad;
 static byte		is_silenced;
-static qboolean altfire;
+// static qboolean altfire;
 
 float damage_buildup = 1.0;
 
@@ -110,7 +133,7 @@ qboolean Pickup_Weapon (edict_t *ent, edict_t *other)
 	if(instagib->value || rocket_arena->value)
 		return false; //why pick them up in these modes?
 
-	if ( ( ((int)(dmflags->value) & DF_WEAPONS_STAY))
+	if ( ( (dmflags->integer & DF_WEAPONS_STAY))
 		&& other->client->pers.inventory[index])
 	{
 		if (!(ent->spawnflags & (DROPPED_ITEM | DROPPED_PLAYER_ITEM) ) )
@@ -124,7 +147,7 @@ qboolean Pickup_Weapon (edict_t *ent, edict_t *other)
 	{
 		// give them some ammo with it
 		ammo = FindItem (ent->item->ammo);
-		if ( (int)dmflags->value & DF_INFINITE_AMMO )
+		if ( dmflags->integer & DF_INFINITE_AMMO )
 			Add_Ammo (other, ammo, 1000, true, true);
 		else if (ent->spawnflags & DROPPED_PLAYER_ITEM)
 			Add_Ammo (other, ammo, ammo->quantity, true, true); //DROPPED WEAPON give full ammo
@@ -135,14 +158,14 @@ qboolean Pickup_Weapon (edict_t *ent, edict_t *other)
 		{
 			if (deathmatch->value)
 			{
-				if ((int)(dmflags->value) & DF_WEAPONS_STAY)
+				if (dmflags->integer & DF_WEAPONS_STAY)
 					ent->flags |= FL_RESPAWN;
 				else {
 					//weapon = FindItem (ent->item->weapon);
 					if(ent->item->weapmodel == WEAP_VAPORIZER)
 						SetRespawn (ent, 10);
 					else
-						SetRespawn (ent, 5); 
+						SetRespawn (ent, 5);
 				}
 			}
 		}
@@ -158,50 +181,43 @@ qboolean Pickup_Weapon (edict_t *ent, edict_t *other)
 
 /*
 ===========
-FS_FOpenFile
+Q2_FindFile
 
 Finds the file in the search path.
-returns filesize and an open FILE *
-Used for streaming data out of either a pak file or
-a seperate file.
+Given a relative path, returns an open FILE* for reading
 ===========
 */
 
-int Q2_FindFile (char *filename, FILE **file)
+void Q2_FindFile (char *filename, FILE **file)
 {
-	char	name[MAX_OSPATH];
-	cvar_t	*game;
-	qboolean found = false;
+	char full_path[MAX_OSPATH];
+	cvar_t *dbg_developer;
 
-	game = gi.cvar("game", "", 0);
+	*file = NULL;
 
-	if (!*game->string) //if there is a gamedir try here first
-		sprintf (name, "%s/%s", GAMEVERSION, filename);
-	else
-		sprintf (name, "%s/%s", game->string, filename);
-
-	*file = fopen (name, "rb");
-	if (!*file) {
-		*file = NULL;
-		found = false;
+	dbg_developer = gi.cvar("developer", "0", 0 );
+	if ( dbg_developer && dbg_developer->integer == 2 )
+	{ // A prefix for FS_FullPath Com_DPrintf() tracing to show a call from game.
+		gi.dprintf("G: ");
 	}
-	else
-		return 1;
 
-	if(!found) { //try basedir
-		sprintf (name, "%s/%s", GAMEVERSION, filename);
-		*file = fopen (name, "rb");
-		if (!*file) {
-			*file = NULL;
-			return -1;
+	if ( gi.FullPath( full_path, sizeof(full_path), filename ) )
+	{
+		*file = fopen( full_path, "rb" );
+
+		if( *file == NULL )
+		{
+			gi.dprintf("Q2_FindFile: failed fopen for read: %s", full_path );
 		}
-		else
-			return 1;
 	}
-	else
-		return -1;
+
 }
 
+
+
+
+
+
 /*
 ===============
 ChangeWeapon
@@ -275,7 +291,6 @@ void ChangeWeapon (edict_t *ent)
 
 	sprintf(weaponmodel, "players/%s%s", weaponame, "weapon.md2"); //default
 
-#ifdef __unix__
 	if( !Q_strcasecmp(ent->client->pers.weapon->view_model,"models/weapons/v_violator/tris.md2"))
 		sprintf(weaponmodel, "players/%s%s", weaponame, "w_violator.md2");
 	else if( !Q_strcasecmp( ent->client->pers.weapon->view_model,"models/weapons/v_rocket/tris.md2"))
@@ -296,41 +311,17 @@ void ChangeWeapon (edict_t *ent)
 		sprintf(weaponmodel, "players/%s%s", weaponame, "w_chaingun.md2");
 	else if( !Q_strcasecmp(ent->client->pers.weapon->view_model,"vehicles/deathball/v_wep.md2"))
 		sprintf(weaponmodel, "players/%s%s", weaponame, "w_machinegun.md2");
-#else
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_violator/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_violator.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_rocket/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_rlauncher.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_blast/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_blaster.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_bfg/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_bfg.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_rail/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_railgun.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_shotg2/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_sshotgun.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_shotg/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_shotgun.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_hyperb/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_hyperblaster.md2");
-	if(ent->client->pers.weapon->view_model == "models/weapons/v_chain/tris.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_chaingun.md2");
-	if(ent->client->pers.weapon->view_model == "vehicles/deathball/v_wep.md2")
-		sprintf(weaponmodel, "players/%s%s", weaponame, "w_machinegun.md2");
-#endif
 
 	sprintf(weaponpath, "%s", weaponmodel);
 	Q2_FindFile (weaponpath, &file); //does it really exist?
-	if(!file) {
-#ifdef __unix__
+	if(!file)
+	{
 		sprintf(weaponpath, "%s%s", weaponame, "weapon.md2"); //no w_weaps, do we have this model?
-#else
-		sprintf(weaponpath, "%s", weaponame, "weapon.md2"); //no w_weaps, do we have this model?
-#endif
 		Q2_FindFile (weaponpath, &file);
 		if(!file) //server does not have this player model
 			sprintf(weaponmodel, "players/martianenforcer/weapon.md2");//default player(martian)
-		else { //have the model, but it has no w_weaps
+		else
+		{ //have the model, but it has no w_weaps
 			sprintf(weaponmodel, "players/%s%s", weaponame, "weapon.md2"); //custom weapon
 			fclose(file);
 		}
@@ -340,13 +331,9 @@ void ChangeWeapon (edict_t *ent)
 	ent->s.modelindex2 = gi.modelindex(weaponmodel);
 
 	//play a sound like in Q3, except for blaster, so it doesn't do it on spawn.
-#ifdef __unix__
 	if( Q_strcasecmp( ent->client->pers.weapon->view_model,"models/weapons/v_blast/tris.md2") )
 		gi.sound(ent, CHAN_VOICE, gi.soundindex("weapons/whoosh.wav"), 1, ATTN_NORM, 0);
-#else
-	if(!(ent->client->pers.weapon->view_model == "models/weapons/v_blast/tris.md2"))
-		gi.sound(ent, CHAN_VOICE, gi.soundindex("weapons/whoosh.wav"), 1, ATTN_NORM, 0);
-#endif
+
 	ent->client->anim_priority = ANIM_PAIN;
 	if(ent->client->ps.pmove.pm_flags & PMF_DUCKED)
 	{
@@ -496,7 +483,7 @@ void Drop_Weapon (edict_t *ent, gitem_t *item)
 {
 	int		index;
 
-	if (((int)(dmflags->value) & DF_WEAPONS_STAY) || instagib->value || rocket_arena->value)
+	if ((dmflags->integer & DF_WEAPONS_STAY) || instagib->value || rocket_arena->value)
 		return;
 
 	index = ITEM_INDEX(item);
@@ -750,7 +737,7 @@ void weapon_plasma_fire (edict_t *ent)
 	ent->client->ps.gunframe++;
 	PlayerNoise(ent, start, PNOISE_WEAPON);
 
-	if ((! ( (int)dmflags->value & DF_INFINITE_AMMO ) ) && !instagib->value )
+	if (! ( (dmflags->integer & DF_INFINITE_AMMO) || instagib->integer ) )
 		ent->client->pers.inventory[ent->client->ammo_index]= ent->client->pers.inventory[ent->client->ammo_index]-5;
 }
 
@@ -778,7 +765,7 @@ void weapon_energy_field_fire (edict_t *ent)
 
 	if (is_quad)
 	{
-		radius_damage *=2; 
+		radius_damage *=2;
 		damage *= 2;
 		kick *= 4;
 	}
@@ -825,13 +812,13 @@ void weapon_energy_field_fire (edict_t *ent)
 			forward[1] = forward[1] * 4.6;
 			forward[2] = forward[2] * 4.6;
 			fire_bomb (ent, start, forward, damage, 250, damage_radius, radius_damage, 8);
-			if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
+			if (! ( dmflags->integer & DF_INFINITE_AMMO ) )
 				ent->client->pers.inventory[ent->client->ammo_index]= ent->client->pers.inventory[ent->client->ammo_index]-1;
 
 		}
 		else {
 				fire_energy_field (ent, start, forward, damage, kick);
-				if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
+				if (! ( dmflags->integer & DF_INFINITE_AMMO ) )
 					ent->client->pers.inventory[ent->client->ammo_index]= ent->client->pers.inventory[ent->client->ammo_index]-2;
 		}
 
@@ -898,7 +885,7 @@ void weapon_flamethrower_fire (edict_t *ent)
 
 		PlayerNoise(ent, start, PNOISE_WEAPON);
 
-		if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) ) {
+		if (! ( dmflags->integer & DF_INFINITE_AMMO ) ) {
 			ent->client->pers.inventory[ent->client->ammo_index] -= ent->client->pers.weapon->quantity*10;
 			if(ent->client->pers.inventory[ent->client->ammo_index] < 0)
 				ent->client->pers.inventory[ent->client->ammo_index] = 0;
@@ -920,7 +907,7 @@ void weapon_flamethrower_fire (edict_t *ent)
 
 	PlayerNoise(ent, start, PNOISE_WEAPON);
 
-	if (is_quad) 
+	if (is_quad)
 		damage *= 2;
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
@@ -934,7 +921,7 @@ void weapon_flamethrower_fire (edict_t *ent)
 
 	PlayerNoise(ent, start, PNOISE_WEAPON);
 
-	if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) ) {
+	if (! ( dmflags->integer & DF_INFINITE_AMMO ) ) {
 		ent->client->pers.inventory[ent->client->ammo_index] -= ent->client->pers.weapon->quantity;
 		if(ent->client->pers.inventory[ent->client->ammo_index] < 0)
 			ent->client->pers.inventory[ent->client->ammo_index] = 0;
@@ -971,7 +958,7 @@ void Weapon_RocketLauncher_Fire (edict_t *ent)
 	damage_radius = 120;
 	if (is_quad)
 	{
-		damage *= 2; 
+		damage *= 2;
 		radius_damage *= 2;
 	}
 
@@ -985,14 +972,14 @@ void Weapon_RocketLauncher_Fire (edict_t *ent)
 
 	if(ent->client->buttons & BUTTON_ATTACK2) //alt fire
 	{
-		if(ent->client->resp.homing_shots < 5) {
+		if(ent->client->homing_shots < 5) {
 			if(excessive->value) //no homers in excessive!
 				fire_rocket (ent, start, forward, damage, 900, damage_radius, radius_damage);
 			else
 				fire_homingrocket (ent, start, forward, damage, 250, damage_radius, radius_damage);
 		}
 		else {
-			safe_cprintf(ent, PRINT_HIGH, "Exceeded max number of homing missiles for this round!\n");
+			safe_cprintf(ent, PRINT_HIGH, "Exceeded max number of homing missiles for this life!\n");
 			fire_rocket (ent, start, forward, damage, 900, damage_radius, radius_damage);
 		}
 	}
@@ -1009,7 +996,7 @@ void Weapon_RocketLauncher_Fire (edict_t *ent)
 
 	PlayerNoise(ent, start, PNOISE_WEAPON);
 
-	if ((! ( (int)dmflags->value & DF_INFINITE_AMMO ) ) && !rocket_arena->value)
+	if ((! ( dmflags->integer & DF_INFINITE_AMMO ) ) && !rocket_arena->value)
 		ent->client->pers.inventory[ent->client->ammo_index]--;
 }
 
@@ -1040,7 +1027,7 @@ void Blaster_Fire (edict_t *ent, vec3_t g_offset, int damage, qboolean hyper, in
 	vec3_t	offset;
 
 	if (is_quad)
-		damage *= 2; 
+		damage *= 2;
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
 
@@ -1090,7 +1077,7 @@ void Blaster_Fire (edict_t *ent, vec3_t g_offset, int damage, qboolean hyper, in
 		gi.WriteByte (MZ_BLASTER | is_silenced);
 	gi.multicast (ent->s.origin, MULTICAST_PVS);
 	PlayerNoise(ent, start, PNOISE_WEAPON);
-	
+
 	//create visual muzzle flash sprite!
 	if(!hyper || (ent->client->buttons & BUTTON_ATTACK2))
 	{
@@ -1139,7 +1126,7 @@ void Weapon_Bomber_Fire (edict_t *ent)
 	damage_radius = 250;
 	if (is_quad)
 	{
-		damage *= 2; 
+		damage *= 2;
 		radius_damage *= 2;
 	}
 
@@ -1150,7 +1137,7 @@ void Weapon_Bomber_Fire (edict_t *ent)
 
 	VectorSet(offset, 8, 8, ent->viewheight-4);
 	P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
-	
+
 	if(ent->client->buttons & BUTTON_ATTACK2 && ent->client->ps.gunframe != 12) {
 		fire_rocket (ent, start, forward, damage/3, 1400, damage_radius/2, radius_damage/2);
 		gi.sound (ent, CHAN_WEAPON, gi.soundindex("weapons/rocklr1b.wav"), 1, ATTN_NORM, 0);
@@ -1173,7 +1160,7 @@ void Weapon_Bomber_Fire (edict_t *ent)
 	ent->client->ps.gunframe++;
 
 	//might want to work with this some
-	if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
+	if (! ( dmflags->integer & DF_INFINITE_AMMO ) )
 		ent->client->pers.inventory[ent->client->ammo_index]--;
 }
 void Weapon_Bomber (edict_t *ent)
@@ -1205,7 +1192,7 @@ void Weapon_Strafer_Fire (edict_t *ent)
 		damage = 20;
 
 	if (is_quad)
-		damage *= 2; 
+		damage *= 2;
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
 
@@ -1219,7 +1206,7 @@ void Weapon_Strafer_Fire (edict_t *ent)
 
 	P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
 
-	if(ent->client->buttons & BUTTON_ATTACK2) 
+	if(ent->client->buttons & BUTTON_ATTACK2)
 		fire_rocket (ent, start, forward, damage, 1200, damage_radius, radius_damage);
 	else
 		fire_blaster_beam (ent, start, forward, damage, 0, true);
@@ -1254,7 +1241,7 @@ void Weapon_Strafer_Fire (edict_t *ent)
 		fire_rocket (ent, start, forward, damage, 1200, damage_radius, radius_damage);
 		gi.sound (ent, CHAN_WEAPON, gi.soundindex("weapons/rocklr1b.wav"), 1, ATTN_NORM, 0);
 	}
-	else {		
+	else {
 		fire_blaster_beam (ent, start, forward, damage, 0, true);
 		gi.sound (ent, CHAN_WEAPON, gi.soundindex("vehicles/shootlaser.wav"), 1, ATTN_NORM, 0);
 	}
@@ -1297,7 +1284,7 @@ void Weapon_Hover_Fire (edict_t *ent)
 		damage = 20;
 
 	if (is_quad)
-		damage *= 2; 
+		damage *= 2;
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);
 
@@ -1315,7 +1302,7 @@ void Weapon_Hover_Fire (edict_t *ent)
 	else if(ent->client->ps.gunframe == 6) {
 		fire_hover_beam (ent, start, forward, damage, 0, true);
 		gi.sound (ent, CHAN_WEAPON, gi.soundindex("weapons/biglaser.wav"), 1, ATTN_NORM, 0);
-		
+
 		VectorAdd(start, forward, start);
 		gi.WriteByte (svc_temp_entity);
 		gi.WriteByte (TE_CHAINGUNSMOKE);
@@ -1384,14 +1371,14 @@ void Weapon_Beamgun_Fire (edict_t *ent)
 				effect = EF_HYPERBLASTER;
 			else
 				effect = 0;
-		
+
 			if(excessive->value)
-				damage = 25;
+				damage = 20;
 			else
-				damage = 10; 
-					
+				damage = 7;
+
 			Blaster_Fire (ent, offset, damage, true, effect);
-			if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
+			if (! ( dmflags->integer & DF_INFINITE_AMMO ) )
 				ent->client->pers.inventory[ent->client->ammo_index]--;
 		}
 
@@ -1434,6 +1421,7 @@ void Machinegun_Fire (edict_t *ent)
 
 	if ((ent->client->ps.gunframe == 5) && !(ent->client->buttons & BUTTON_ATTACK || ent->client->buttons & BUTTON_ATTACK2))
 	{
+
 		ent->client->ps.gunframe = 14;
 		ent->client->weapon_sound = 0;
 		return;
@@ -1450,7 +1438,7 @@ void Machinegun_Fire (edict_t *ent)
 			return;
 		}
 		ent->altfire = true;
-		ent->client->ps.gunframe = 14;
+		ent->client->ps.gunframe++;
 	}
 	else if (ent->client->buttons & BUTTON_ATTACK2)
 	{
@@ -1485,13 +1473,13 @@ void Machinegun_Fire (edict_t *ent)
 
 	if (is_quad)
 	{
-		damage *= 2; 
+		damage *= 2;
 		kick *= 2;
 	}
 
 	AngleVectors (ent->client->v_angle, forward, right, NULL);//was up
 	if(ent->client->ps.gunframe == 6 || ent->client->ps.gunframe == 8 || ent->client->ps.gunframe == 10 || ent->client->ps.gunframe == 12)
-	{	
+	{
 		if(ent->altfire)
 			ent->client->kick_angles[0] = -3; /* Kick view up */
 		else
@@ -1534,7 +1522,7 @@ void Machinegun_Fire (edict_t *ent)
 		gi.WritePosition (start);
 		gi.multicast (start, MULTICAST_PVS);
 
-		if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
+		if (! ( dmflags->integer & DF_INFINITE_AMMO ) )
 			ent->client->pers.inventory[ent->client->ammo_index] -= 10;
 
 		//kick it ahead, we don't want spinning
@@ -1569,7 +1557,7 @@ void Machinegun_Fire (edict_t *ent)
 		gi.WriteByte (TE_CHAINGUNSMOKE);
 		gi.WritePosition (start);
 		gi.multicast (start, MULTICAST_PVS);
-		if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
+		if (! ( dmflags->integer & DF_INFINITE_AMMO ) )
 			ent->client->pers.inventory[ent->client->ammo_index] -= shots;
 	}
 
@@ -1597,7 +1585,7 @@ void weapon_floater_fire (edict_t *ent)
 	damage_radius = 120;
 	if (is_quad || excessive->value)
 	{
-		damage *= 2; 
+		damage *= 2;
 		radius_damage *= 2;
 	}
 
@@ -1640,7 +1628,7 @@ void weapon_floater_fire (edict_t *ent)
 	gi.WritePosition (start);
 	gi.multicast (start, MULTICAST_PVS);
 
-	if (! ( (int)dmflags->value & DF_INFINITE_AMMO ) )
+	if (! ( dmflags->integer & DF_INFINITE_AMMO ) )
 		ent->client->pers.inventory[ent->client->ammo_index]--;
 }
 
@@ -1727,7 +1715,7 @@ void Violator_Fire (edict_t *ent)
 		damage = 200;
 	else
 		damage = 40;
-	
+
 	if ((ent->client->ps.gunframe == 6) && !(ent->client->buttons & BUTTON_ATTACK || ent->client->buttons & BUTTON_ATTACK2))
 	{
 		ent->client->ps.gunframe = 14;
@@ -1759,7 +1747,7 @@ void Violator_Fire (edict_t *ent)
 	else
 		ent->client->ps.gunframe++;
 
-	if (is_quad) { 
+	if (is_quad) {
 		damage *= 2;
 		kick *=2;
 	}
@@ -1773,7 +1761,7 @@ void Violator_Fire (edict_t *ent)
 	VectorScale (forward, -10, back);
 
 	if(ent->client->ps.gunframe == 6 && ent->client->buttons & BUTTON_ATTACK2) {
-	
+
 		VectorSet(offset, 1, 1, ent->viewheight-0.5);
 		P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
 		fire_violator(ent, start, forward, damage/2, kick*20, 1);
@@ -1790,7 +1778,7 @@ void Violator_Fire (edict_t *ent)
 		gi.WriteShort (ent-g_edicts);
 		gi.WriteByte (MZ_RAILGUN | is_silenced);
 		gi.multicast (ent->s.origin, MULTICAST_PVS);
-		
+
 		VectorScale(forward, 1.4, forward);
 		VectorAdd(start, forward, start);
 		VectorScale(right, -0.5, right);
@@ -1831,7 +1819,7 @@ void Violator_Fire (edict_t *ent)
 		VectorAdd(start, forward, start);
 		VectorScale(right, -0.5, right);
 		VectorAdd(start, right, start);
-	
+
 		gi.WriteByte (svc_temp_entity);
 		gi.WriteByte (TE_VOLTAGE);
 		gi.WritePosition (start);
@@ -1853,7 +1841,7 @@ void Weapon_Violator (edict_t *ent)
 	static int	pause_frames[]	= {43, 0};
 	static int	fire_frames[]	= {5, 6, 7, 8, 9, 10, 11, 12, 13, 14};
 	static int	bot_fire_frames[] = {5, 6, 7, 8, 9, 10, 11, 12, 13};
-	if(ent->is_bot) //done because bots need one frame in which to "escape" from firing 
+	if(ent->is_bot) //done because bots need one frame in which to "escape" from firing
 		Weapon_Generic (ent, 4, 14, 43, 46, pause_frames, bot_fire_frames, Violator_Fire);
 	else
 		Weapon_Generic (ent, 4, 14, 43, 46, pause_frames, fire_frames, Violator_Fire);
