@@ -1,5 +1,6 @@
 /*
 Copyright (C) 1997-2001 Id Software, Inc.
+Copyright (C) 2010 COR Entertainment, LLC.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -8,17 +9,20 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
-
+You should have received a copy of the GNU General Public License along
+with this program; if not, write to the Free Software Foundation, Inc.,
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 // cvar.c -- dynamic variable tracking
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "qcommon.h"
 
 cvar_t	*cvar_vars;
@@ -48,7 +52,7 @@ static cvar_t *Cvar_FindVar (char *var_name)
 {
 	cvar_t		*var;
 	unsigned int	i, hash_key;
-	
+
 	COMPUTE_HASH_KEY( hash_key, var_name , i );
 	for (var=cvar_vars ; var && var->hash_key <= hash_key ; var=var->next)
 		if (var->hash_key == hash_key && !Q_strcasecmp (var_name, var->name))
@@ -65,7 +69,7 @@ Cvar_VariableValue
 float Cvar_VariableValue (char *var_name)
 {
 	cvar_t	*var;
-	
+
 	var = Cvar_FindVar (var_name);
 	if (!var)
 		return 0;
@@ -81,7 +85,7 @@ Cvar_VariableString
 char *Cvar_VariableString (char *var_name)
 {
 	cvar_t *var;
-	
+
 	var = Cvar_FindVar (var_name);
 	if (!var)
 		return "";
@@ -99,7 +103,7 @@ char *Cvar_CompleteVariable (char *partial)
 	cvar_t		*cvar;
 	int		len, i;
 	unsigned int	hash_key;
-	
+
 	len = strlen(partial);
 	if (!len)
 		return NULL;
@@ -119,6 +123,65 @@ char *Cvar_CompleteVariable (char *partial)
 }
 
 
+/*
+============
+Cvar_Allocate
+
+Creates a new variable's record
+============
+*/
+inline static cvar_t *Cvar_Allocate(char *var_name, char *var_value, int flags, unsigned int hash_key)
+{
+	cvar_t *nvar;
+
+	nvar = Z_Malloc (sizeof(cvar_t));
+	nvar->name = CopyString (var_name);
+	nvar->string = CopyString (var_value);
+	nvar->modified = true;
+	nvar->value = atof (nvar->string);
+	nvar->integer = atoi (nvar->string);
+	nvar->flags = flags;
+	nvar->hash_key = hash_key;
+
+	return nvar;
+}
+
+
+/*
+============
+Cvar_AddBetween
+
+Adds a variable between two others.
+============
+*/
+inline static cvar_t *Cvar_AddBetween(char *var_name, char *var_value, int flags, unsigned int hash_key,cvar_t **prev, cvar_t *next)
+{
+	cvar_t *nvar;
+
+	// variable needs to be created, check parameters
+	if (!var_value)
+		return NULL;
+
+	if (flags & (CVAR_USERINFO | CVAR_SERVERINFO))
+	{
+		if (!Cvar_InfoValidate (var_value))
+		{
+			Com_Printf("invalid info cvar value\n");
+			return NULL;
+		}
+	}
+
+	// create the variable
+	nvar = Cvar_Allocate( var_name , var_value , flags , hash_key );
+
+	// link the variable in
+	nvar->next = next;
+	*prev = nvar;
+
+	return nvar;
+}
+
+
 /*
 ============
 Cvar_Get
@@ -129,7 +192,7 @@ The flags will be or'ed in if the variable exists.
 */
 cvar_t *Cvar_Get (char *var_name, char *var_value, int flags)
 {
-	cvar_t		*var, **prev, *nvar;
+	cvar_t		*var, **prev;
 	unsigned int	i, hash_key;
 
 	// validate variable name
@@ -155,36 +218,45 @@ cvar_t *Cvar_Get (char *var_name, char *var_value, int flags)
 		prev = &( var->next );
 	}
 
-	// variable needs to be created, check parameters
-	if (!var_value)
-		return NULL;
+	return Cvar_AddBetween(var_name , var_value , flags , hash_key , prev , var);
+}
 
-	if (flags & (CVAR_USERINFO | CVAR_SERVERINFO))
+
+/*
+============
+Cvar_FindOrCreate
+
+This function is mostly similar to Cvar_Get(name,value,0). However, it starts
+by attempting to find the variable, as there are no flags. In addition, it
+returns a boolean depending on whether the variable was found or created, and
+sets the pointer to the variable through a parameter.
+============
+*/
+inline static qboolean Cvar_FindOrCreate (
+		char *var_name, char *var_value, int flags, cvar_t **found)
+{
+	cvar_t		*var, **prev;
+	unsigned int	i, hash_key;
+
+	// try finding the variable
+	prev = &cvar_vars;
+	COMPUTE_HASH_KEY( hash_key , var_name , i );
+	for (var = cvar_vars ; var && var->hash_key <= hash_key ; var=var->next)
 	{
-		if (!Cvar_InfoValidate (var_value))
+		if (var->hash_key == hash_key && !Q_strcasecmp (var_name, var->name))
 		{
-			Com_Printf("invalid info cvar value\n");
-			return NULL;
+			var->flags |= flags;
+			*found = var;
+			return true;
 		}
+		prev = &( var->next );
 	}
 
-	// create the variable
-	nvar = Z_Malloc (sizeof(cvar_t));
-	nvar->name = CopyString (var_name);
-	nvar->string = CopyString (var_value);
-	nvar->modified = true;
-	nvar->value = atof (nvar->string);
-	nvar->integer = atoi (nvar->string);
-	nvar->flags = flags;
-	nvar->hash_key = hash_key;
-
-	// link the variable in
-	nvar->next = var;
-	*prev = nvar;
-
-	return nvar;
+	*found = Cvar_AddBetween(var_name , var_value , flags , hash_key , prev , var);
+	return false;
 }
 
+
 /*
 ============
 Cvar_Set2
@@ -194,12 +266,9 @@ cvar_t *Cvar_Set2 (char *var_name, char *value, qboolean force)
 {
 	cvar_t	*var;
 
-	// FIXME: this bit is inefficient, it looks up the variable twice (BlackIce)
-	var = Cvar_FindVar (var_name);
-	if (!var)
-	{	// create it
-		return Cvar_Get (var_name, value, 0);
-	}
+	// Find the variable; if it does not exist, create it and return at once
+	if (!Cvar_FindOrCreate (var_name, value, 0, &var))
+		return var;
 
 	if (var->flags & (CVAR_USERINFO | CVAR_SERVERINFO))
 	{
@@ -234,13 +303,15 @@ cvar_t *Cvar_Set2 (char *var_name, char *value, qboolean force)
 
 			if (Com_ServerState())
 			{
-				Com_Printf ("%s will be changed for next game.\n", var_name);
+				Com_Printf ("%s cvar will be changed for next game.\n", var_name);
+				Com_Printf( " startmap <mapname> will start next game.\n");
 				var->latched_string = CopyString(value);
 			}
 			else
 			{
 				var->string = CopyString(value);
 				var->value = atof (var->string);
+				var->integer = atoi (var->string);
 				if (!Q_strcasecmp(var->name, "game"))
 				{
 					FS_SetGamedir (var->string);
@@ -266,9 +337,9 @@ cvar_t *Cvar_Set2 (char *var_name, char *value, qboolean force)
 
 	if (var->flags & CVAR_USERINFO)
 		userinfo_modified = true;	// transmit at next oportunity
-	
+
 	Z_Free (var->string);	// free the old value string
-	
+
 	var->string = CopyString(value);
 	var->value = atof (var->string);
 	var->integer = atoi(var->string);
@@ -304,21 +375,17 @@ Cvar_FullSet
 cvar_t *Cvar_FullSet (char *var_name, char *value, int flags)
 {
 	cvar_t	*var;
-	
-	// FIXME: this bit is inefficient, it looks up the variable twice (BlackIce)
-	var = Cvar_FindVar (var_name);
-	if (!var)
-	{	// create it
-		return Cvar_Get (var_name, value, flags);
-	}
+
+	if (!Cvar_FindOrCreate (var_name, value, flags, &var))
+		return var;
 
 	var->modified = true;
 
 	if (var->flags & CVAR_USERINFO)
 		userinfo_modified = true;	// transmit at next oportunity
-	
+
 	Z_Free (var->string);	// free the old value string
-	
+
 	var->string = CopyString(value);
 	var->value = atof (var->string);
 	var->integer = atoi(var->string);
@@ -359,6 +426,11 @@ void Cvar_GetLatchedVars (void)
 	{
 		if (!var->latched_string)
 			continue;
+
+		// observe when latched cvars are updated
+		Com_Printf("Updating latched cvar %s from %s to %s\n",
+				var->name, var->string, var->latched_string );
+
 		Z_Free (var->string);
 		var->string = var->latched_string;
 		var->latched_string = NULL;
@@ -387,7 +459,7 @@ qboolean Cvar_Command (void)
 	v = Cvar_FindVar (Cmd_Argv(0));
 	if (!v)
 		return false;
-		
+
 // perform a variable print or set
 	if (Cmd_Argc() == 1)
 	{
@@ -477,6 +549,7 @@ void Cvar_List_f (void)
 	i = 0;
 	for (var = cvar_vars ; var ; var = var->next, i++)
 	{
+
 		if (var->flags & CVAR_ARCHIVE)
 			Com_Printf ("*");
 		else
@@ -514,7 +587,9 @@ char	*Cvar_BitInfo (int bit)
 	for (var = cvar_vars ; var ; var = var->next)
 	{
 		if (var->flags & bit)
+		{
 			Info_SetValueForKey (info, var->name, var->string);
+		}
 	}
 	return info;
 }
