@@ -24,15 +24,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #ifndef __QGL_H__
 #define __QGL_H__
 
-#ifdef _WIN32
+#if defined WIN32_VARIANT
 #  include <windows.h>
 #endif
 
 #include <GL/gl.h>
-
-#ifdef __unix__
-//#include <GL/fxmesa.h>
-#include <GL/glx.h>
+#if defined WIN32_VARIANT
+# include "glext.h"
 #endif
 
 qboolean QGL_Init( const char *dllname );
@@ -386,9 +384,9 @@ extern	void ( APIENTRY * qglColorTableEXT)( int, int, int, int, int, const void
 extern	void ( APIENTRY * qglLockArraysEXT) (int , int);
 extern	void ( APIENTRY * qglUnlockArraysEXT) (void);
 
-extern	void ( APIENTRY * qglMTexCoord2fSGIS)( GLenum, GLfloat, GLfloat );
-extern	void ( APIENTRY * qglMTexCoord3fSGIS)( GLenum, GLfloat, GLfloat, GLfloat );
-extern	void ( APIENTRY * qglSelectTextureSGIS)( GLenum );
+extern	void ( APIENTRY * qglMTexCoord2fARB)( GLenum, GLfloat, GLfloat );
+extern	void ( APIENTRY * qglMTexCoord3fARB)( GLenum, GLfloat, GLfloat, GLfloat );
+extern	void ( APIENTRY * qglSelectTextureARB)( GLenum );
 
 extern	void ( APIENTRY * qglActiveTextureARB)( GLenum );
 extern	void ( APIENTRY * qglClientActiveTextureARB)( GLenum );
@@ -449,7 +447,8 @@ extern GLvoid			(APIENTRY * qglBufferSubDataARB)(GLenum target, GLintptrARB offs
 #endif
 //END VBO
 
-#ifndef __unix__ // FIXME: already have in GL/glx.h (all Unix or FreeBSD?)
+#if 0
+#if !defined UNIX_VARIANT
 // jitwater - fragment programs (pixel shaders)
 typedef void (APIENTRY * PFNGLPROGRAMSTRINGARBPROC) (GLenum target, GLenum format, GLsizei len, const GLvoid *string);
 typedef void (APIENTRY * PFNGLBINDPROGRAMARBPROC) (GLenum target, GLuint program);
@@ -488,7 +487,11 @@ typedef void (APIENTRY * PFNGLUNIFORM3FARBPROC) (GLint location, GLfloat v0, GLf
 typedef void (APIENTRY * PFNGLUNIFORM2FARBPROC) (GLint location, GLfloat v0, GLfloat v1);
 typedef void (APIENTRY * PFNGLUNIFORM1IARBPROC) (GLint location, GLint v0);
 typedef void (APIENTRY * PFNGLUNIFORM1FARBPROC) (GLint location, GLfloat v0);
-typedef void (APIENTRY * PFNGLUNIFORMMATRIX3FVARBPROC)(GLint location, GLsizei count, GLboolean transpose, GLfloat [3][3]); 
+typedef void (APIENTRY * PFNGLUNIFORMMATRIX3FVARBPROC) (GLint location, GLsizei count, GLboolean transpose, GLfloat [3][3]); 
+typedef void (APIENTRY * PFNGLVERTEXATTRIBPOINTERARBPROC) (GLuint, GLint, GLenum, GLboolean, GLsizei, const GLvoid *);
+typedef void (APIENTRY * PFNGLENABLEVERTEXATTRIBARRAYARBPROC) (GLuint);
+typedef void (APIENTRY * PFNGLBINDATTRIBLOCATIONARBPROC) (GLhandleARB programObj, GLuint index, const GLcharARB *name);
+#endif
 
 //Framebuffer objects
 typedef GLboolean (APIENTRY * PFNGLISRENDERBUFFEREXTPROC) (GLuint renderbuffer);
@@ -508,10 +511,13 @@ typedef void (APIENTRY * PFNGLFRAMEBUFFERTEXTURE3DEXTPROC) (GLenum target, GLenu
 typedef void (APIENTRY * PFNGLFRAMEBUFFERRENDERBUFFEREXTPROC) (GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
 typedef void (APIENTRY * PFNGLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC) (GLenum target, GLenum attachment, GLenum pname, GLint *params);
 typedef void (APIENTRY * PFNGLGENERATEMIPMAPEXTPROC) (GLenum target);
+typedef void (APIENTRY * PFNGLBLITFRAMEBUFFEREXTPROC) (GLint  srcX0, GLint  srcY0, GLint  srcX1, GLint  srcY1, GLint  dstX0, 
+			  GLint  dstY0, GLint  dstX1, GLint  dstY1, GLbitfield  mask, GLenum  filter);   
+
 
 #endif
 
-#ifdef _WIN32
+#if defined WIN32_VARIANT
 
 extern  int   ( WINAPI * qwglChoosePixelFormat )(HDC, CONST PIXELFORMATDESCRIPTOR *);
 extern  int   ( WINAPI * qwglDescribePixelFormat) (HDC, int, UINT, LPPIXELFORMATDESCRIPTOR);
@@ -549,10 +555,12 @@ extern BOOL ( WINAPI * qwglSetDeviceGammaRampEXT ) ( const unsigned char *pRed,
 
 #endif
 
-#ifdef __unix__
+#if defined UNIX_VARIANT
+
+#include <GL/glx.h>
 
 // local function in dll
-extern void *qwglGetProcAddress(char *symbol);
+extern void * (*qwglGetProcAddress) (const char*);
 
 extern void (*qgl3DfxSetPaletteEXT)(GLuint *);
 
@@ -600,7 +608,6 @@ void Fake_glColorTableEXT( GLenum target, GLenum internalformat,
 #define GL_TEXTURE0_ARB						0x84C0
 #define GL_TEXTURE1_ARB						0x84C1
 
-#ifdef __unix__
 #ifdef GL_TEXTURE0
 #undef GL_TEXTURE0
 #endif
@@ -625,7 +632,6 @@ void Fake_glColorTableEXT( GLenum target, GLenum internalformat,
 #ifdef GL_TEXTURE7
 #undef GL_TEXTURE7
 #endif
-#endif
 
 extern int GL_TEXTURE0, GL_TEXTURE1, GL_TEXTURE2, GL_TEXTURE3, GL_TEXTURE4, GL_TEXTURE5, GL_TEXTURE6, GL_TEXTURE7;
 
@@ -716,6 +722,9 @@ extern	PFNGLUNIFORM2FARBPROC				glUniform2fARB;
 extern	PFNGLUNIFORM1IARBPROC				glUniform1iARB;
 extern  PFNGLUNIFORM1FARBPROC				glUniform1fARB;
 extern  PFNGLUNIFORMMATRIX3FVARBPROC		glUniformMatrix3fvARB;
+extern	PFNGLVERTEXATTRIBPOINTERARBPROC		glVertexAttribPointerARB;
+extern	PFNGLENABLEVERTEXATTRIBARRAYARBPROC glEnableVertexAttribArrayARB;
+extern	PFNGLBINDATTRIBLOCATIONARBPROC		qglBindAttribLocationARB;
 
 //framebuffer objects
 #ifndef GL_EXT_framebuffer_object
@@ -816,4 +825,4 @@ extern void     (APIENTRY * qglGenerateMipmapEXT) (GLenum target);
 
 extern void		(APIENTRY * qglBlitFramebufferEXT) (GLint srcX0, GLint srcY0, GLint srcX1, GLint srcY1, GLint dstX0, GLint dstY0, GLint dstX1, GLint dstY1, GLbitfield mask, GLenum filter);
 
-#endif
+#endif /* __QGL_H__ */
