@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -20,17 +20,16 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 // r_draw.c
 
-#include "r_local.h"
-
-#ifdef __unix__
-#define min(a,b) ((a) < (b) ? (a) : (b))
+#ifdef HAVE_CONFIG_H
+#include "config.h"
 #endif
 
+#include "r_local.h"
+
 image_t		*draw_chars;
 image_t		*menu_chars;
 
 extern	qboolean	scrap_dirty;
-extern  void GL_BlendFunction (GLenum sfactor, GLenum dfactor);
 extern cvar_t *con_font;
 void Scrap_Upload (void);
 
@@ -70,7 +69,7 @@ void RefreshFont (void)
 			data[y][x][0] = 255;
 			data[y][x][1] = 255;
 			data[y][x][2] = 255;
-			data[y][x][3] = blanktexture[x][y]; 
+			data[y][x][3] = blanktexture[x][y];
 		}
 	}
 
@@ -95,7 +94,7 @@ void RefreshFont (void)
 		menu_chars = GL_LoadPic ("***font***", (byte *)data, 16, 16, it_pic, 32);
 
 	GL_Bind( menu_chars->texnum );
-	
+
 	con_font->modified = false;
 }
 
@@ -106,8 +105,6 @@ Draw_InitLocal
 */
 void Draw_InitLocal (void)
 {
-	image_t	*Draw_FindPic (char *name);
-
 	RefreshFont();
 }
 
@@ -126,7 +123,7 @@ void Draw_Char (int x, int y, int num)
 	float			frow, fcol, size;
 
 	num &= 255;
-	
+
 	if ( (num&127) == 32 )
 		return;		// space
 
@@ -181,7 +178,7 @@ void Draw_ColorChar (int x, int y, int num, vec4_t color)
 	colors[3] = R_FloatToByte( color[3] );
 
 	num &= 255;
-	
+
 	if ( (num&127) == 32 )
 		return;		// space
 
@@ -213,19 +210,19 @@ void Draw_ColorChar (int x, int y, int num, vec4_t color)
 }
 
 void Draw_ScaledChar (float x, float y, int num, float scale, int from_menu)
-					
+
 {
 	int				row, col;
 	float			frow, fcol, size;
 
 	num &= 255;
-	
+
 	if ( (num&127) == 32 )
 		return;		// space
 
 	if (y <= -8)
 		return;			// totally off screen
-	
+
 	row = num>>4;
 	col = num&15;
 
@@ -263,7 +260,7 @@ void Draw_ScaledColorChar (float x, float y, int num, vec4_t color, float scale,
 	colors[3] = R_FloatToByte( color[3] );
 
 	num &= 255;
-	
+
 	if ( (num&127) == 32 )
 		return;		// space
 
@@ -301,7 +298,7 @@ void Draw_ScaledColorChar (float x, float y, int num, vec4_t color, float scale,
 R_RegisterPic
 =============
 */
-image_t	*R_RegisterPic (char *name)
+image_t	*R_RegisterPic (const char *name)
 {
 	image_t *gl;
 	char	fullname[MAX_QPATH];
@@ -312,12 +309,17 @@ image_t	*R_RegisterPic (char *name)
 		gl = GL_FindImage (fullname, it_pic);
 	}
 	else
-		gl = GL_FindImage (name+1, it_pic);
+	{ // note: levelshot graphic is loaded here
+		strcpy( fullname, &name[1] );
+		gl = GL_FindImage( fullname, it_pic );
+		// gl = GL_FindImage (name+1, it_pic);
+		// sometimes gets "evelshot" instead of "levelshot", compiler bug???
+	}
 
 	return gl;
 }
 
-image_t	*R_RegisterParticlePic (char *name)
+image_t	*R_RegisterParticlePic (const char *name)
 {
 	image_t *gl;
 	char	fullname[MAX_QPATH];
@@ -328,12 +330,15 @@ image_t	*R_RegisterParticlePic (char *name)
 		gl = GL_FindImage (fullname, it_pic);
 	}
 	else
-		gl = GL_FindImage (name+1, it_pic);
+	{ // 2010-10 match above workaround (paranoid)
+		strcpy( fullname, &name[1] );
+		gl = GL_FindImage( fullname, it_pic );
+	}
 
 	return gl;
 }
 
-image_t	*R_RegisterParticleNormal (char *name)
+image_t	*R_RegisterParticleNormal (const char *name)
 {
 	image_t *gl;
 	char	fullname[MAX_QPATH];
@@ -341,15 +346,18 @@ image_t	*R_RegisterParticleNormal (char *name)
 	if (name[0] != '/' && name[0] != '\\')
 	{
 		Com_sprintf (fullname, sizeof(fullname), "particles/%s.tga", name);
-		gl = GL_FindImage (fullname, it_bump);
+		gl = GL_FindImage (fullname, it_pic);
 	}
 	else
-		gl = GL_FindImage (name+1, it_bump);
+	{ // 2010-10 match above workaround (paranoid)
+		strcpy( fullname, &name[1] );
+		gl = GL_FindImage( fullname, it_pic );
+	}
 
 	return gl;
 }
 
-image_t	*R_RegisterGfxPic (char *name)
+image_t	*R_RegisterGfxPic (const char *name)
 {
 	image_t *gl;
 	char	fullname[MAX_QPATH];
@@ -360,12 +368,16 @@ image_t	*R_RegisterGfxPic (char *name)
 		gl = GL_FindImage (fullname, it_pic);
 	}
 	else
-		gl = GL_FindImage (name+1, it_pic);
+	{ // 2010-10 match above workaround (paranoid)
+		strcpy( fullname, &name[1] );
+		gl = GL_FindImage( fullname, it_pic );
+	}
+
 
 	return gl;
 }
 
-image_t	*R_RegisterPlayerIcon (char *name)
+image_t	*R_RegisterPlayerIcon (const char *name)
 {
 	image_t *gl;
 	char	fullname[MAX_QPATH];
@@ -376,7 +388,10 @@ image_t	*R_RegisterPlayerIcon (char *name)
 		gl = GL_FindImage (fullname, it_pic);
 	}
 	else
-		gl = GL_FindImage (name+1, it_pic);
+	{ // 2010-10 match above workaround (paranoid)
+		strcpy( fullname, &name[1] );
+		gl = GL_FindImage( fullname, it_pic );
+	}
 
 	return gl;
 }
@@ -385,20 +400,7 @@ image_t	*R_RegisterPlayerIcon (char *name)
 Draw_GetPicSize
 =============
 */
-void ShaderResizePic( image_t *gl, int *w, int *h)
-{
-	rscript_t *rs = NULL;
-	char shortname[MAX_QPATH];
 
-	COM_StripExtension ( gl->name, shortname );
-	rs=RS_FindScript(shortname);
-	
-	if (!rs)
-		return;
-	if (!rs->picsize.enable)
-		return;
-
-}
 void Draw_GetPicSize (int *w, int *h, char *pic)
 {
 	image_t *gl;
@@ -411,7 +413,6 @@ void Draw_GetPicSize (int *w, int *h, char *pic)
 	}
 	*w = gl->width;
 	*h = gl->height;
-	ShaderResizePic(gl, w, h);
 }
 
 #define DIV254BY255 (0.9960784313725490196078431372549f)
@@ -431,9 +432,9 @@ void Draw_ShaderPic (image_t *gl, float alphaval)
 	else if(!strcmp(shortname, "pics/i_team2"))
 		r_teamColor = 2;
 
-	R_InitQuadVarrays(); 
-	
-	if (!rs) 
+	R_InitQuadVarrays();
+
+	if (!rs)
 	{
 		qglDisable (GL_ALPHA_TEST);
 		qglEnable (GL_BLEND);
@@ -445,14 +446,14 @@ void Draw_ShaderPic (image_t *gl, float alphaval)
 
 		//set color of hud by team
 		if(r_teamColor == 1) {
-			if(!strcmp(shortname, "pics/i_health")) 
+			if(!strcmp(shortname, "pics/i_health"))
 				qglColor4f(1, .2, .2, alphaval);
 		}
 		else if(r_teamColor == 2) {
-			if(!strcmp(shortname, "pics/i_health")) 
+			if(!strcmp(shortname, "pics/i_health"))
 				qglColor4f(.1, .4, .8, alphaval);
 		}
-			
+
 		VA_SetElem4(col_array[0], 1,1,1,1);
 		VA_SetElem4(col_array[1], 1,1,1,1);
 		VA_SetElem4(col_array[2], 1,1,1,1);
@@ -466,17 +467,17 @@ void Draw_ShaderPic (image_t *gl, float alphaval)
 		qglEnable (GL_ALPHA_TEST);
 		qglDisable (GL_BLEND);
 		R_KillVArrays();
-	} 
-	else 
+	}
+	else
 	{
 		RS_ReadyScript(rs);
 
 		stage=rs->stage;
-		while (stage) 
+		while (stage)
 		{
 			float red = 1, green = 1, blue = 1;
 
-			if (stage->blendfunc.blend) 
+			if (stage->blendfunc.blend)
 			{
 				GLSTATE_ENABLE_BLEND
 				GL_BlendFunction(stage->blendfunc.source,stage->blendfunc.dest);
@@ -487,13 +488,13 @@ void Draw_ShaderPic (image_t *gl, float alphaval)
 			}
 
 			alpha=1.0f;
-			if (stage->alphashift.min || stage->alphashift.speed) 
+			if (stage->alphashift.min || stage->alphashift.speed)
 			{
-				if (!stage->alphashift.speed && stage->alphashift.min > 0) 
+				if (!stage->alphashift.speed && stage->alphashift.min > 0)
 				{
 					alpha=stage->alphashift.min;
-				} 
-				else if (stage->alphashift.speed) 
+				}
+				else if (stage->alphashift.speed)
 				{
 					alpha=sin(rs_realtime * stage->alphashift.speed);
 					alpha=(alpha+1)*0.5f;
@@ -502,11 +503,11 @@ void Draw_ShaderPic (image_t *gl, float alphaval)
 				}
 			}
 
-			if (stage->alphamask) 
+			if (stage->alphamask)
 			{
 				GLSTATE_ENABLE_ALPHATEST
-			} 
-			else 
+			}
+			else
 			{
 				GLSTATE_DISABLE_ALPHATEST
 			}
@@ -803,104 +804,3 @@ void Draw_FadeScreen (void)
 }
 
 
-//====================================================================
-
-
-/*
-=============
-Draw_StretchRaw
-=============
-*/
-extern unsigned	r_rawpalette[256];
-
-void Draw_StretchRaw (int x, int y, int w, int h, int cols, int rows, byte *data)
-{
-	unsigned	image32[256*256];
-	unsigned char image8[256*256];
-	int			i, j, trows;
-	byte		*source;
-	int			frac, fracstep;
-	float		hscale;
-	int			row;
-	float		t;
-
-	GL_Bind (0);
-
-	if (rows<=256)
-	{
-		hscale = 1;
-		trows = rows;
-	}
-	else
-	{
-		hscale = rows/256.0;
-		trows = 256;
-	}
-	t = rows*hscale / 256;
-
-	if ( !qglColorTableEXT )
-	{
-		unsigned *dest;
-
-		for (i=0 ; i<trows ; i++)
-		{
-			row = (int)(i*hscale);
-			if (row > rows)
-				break;
-			source = data + cols*row;
-			dest = &image32[i*256];
-			fracstep = cols*0x10000/256;
-			frac = fracstep >> 1;
-			for (j=0 ; j<256 ; j++)
-			{
-				dest[j] = r_rawpalette[source[frac>>16]];
-				frac += fracstep;
-			}
-		}
-
-		qglTexImage2D (GL_TEXTURE_2D, 0, gl_tex_solid_format, 256, 256, 0, GL_RGBA, GL_UNSIGNED_BYTE, image32);
-	}
-	else
-	{
-		unsigned char *dest;
-
-		for (i=0 ; i<trows ; i++)
-		{
-			row = (int)(i*hscale);
-			if (row > rows)
-				break;
-			source = data + cols*row;
-			dest = &image8[i*256];
-			fracstep = cols*0x10000/256;
-			frac = fracstep >> 1;
-			for (j=0 ; j<256 ; j++)
-			{
-				dest[j] = source[frac>>16];
-				frac += fracstep;
-			}
-		}
-
-		qglTexImage2D( GL_TEXTURE_2D, 
-			           0, 
-					   GL_COLOR_INDEX8_EXT, 
-					   256, 256, 
-					   0, 
-					   GL_COLOR_INDEX, 
-					   GL_UNSIGNED_BYTE, 
-					   image8 );
-	}
-	qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-	qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
-
-	qglBegin (GL_QUADS);
-	qglTexCoord2f (0, 0);
-	qglVertex2f (x, y);
-	qglTexCoord2f (1, 0);
-	qglVertex2f (x+w, y);
-	qglTexCoord2f (1, t);
-	qglVertex2f (x+w, y+h);
-	qglTexCoord2f (0, t);
-	qglVertex2f (x, y+h);
-	qglEnd ();
-}
-
