@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -18,17 +18,20 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 // for jpeglib
 #define HAVE_PROTOTYPES
 
 #include "r_local.h"
-#ifdef _WIN32
+
+#if defined HAVE_JPEG_JPEGLIB_H
 #include "jpeg/jpeglib.h"
+#else
+#include "jpeglib.h"
 #endif
-#ifndef _WIN32
-#include <jpeglib.h>
-#endif
-#include <GL/glu.h>
 
 image_t		gltextures[MAX_GLTEXTURES];
 image_t		*r_mirrortexture;
@@ -53,6 +56,81 @@ int		gl_tex_alpha_format = 4;
 int		gl_filter_min = GL_LINEAR_MIPMAP_LINEAR;
 int		gl_filter_max = GL_LINEAR;
 
+void R_InitImageSubsystem(void)
+{
+	int		aniso_level, max_aniso;
+
+	if ( strstr( gl_config.extensions_string, "GL_ARB_multitexture" ) )
+	{
+		Com_Printf ("...using GL_ARB_multitexture\n" );
+		qglMTexCoord2fARB = ( void * ) qwglGetProcAddress( "glMultiTexCoord2fARB" );
+		qglMTexCoord3fARB = ( void * ) qwglGetProcAddress( "glMultiTexCoord3fARB" );
+		qglMultiTexCoord3fvARB = (void*)qwglGetProcAddress("glMultiTexCoord3fvARB");
+		qglActiveTextureARB = ( void * ) qwglGetProcAddress( "glActiveTextureARB" );
+		qglClientActiveTextureARB = ( void * ) qwglGetProcAddress( "glClientActiveTextureARB" );
+		GL_TEXTURE0 = GL_TEXTURE0_ARB;
+		GL_TEXTURE1 = GL_TEXTURE1_ARB;
+		GL_TEXTURE2 = GL_TEXTURE2_ARB;
+		GL_TEXTURE3 = GL_TEXTURE3_ARB;
+		GL_TEXTURE4 = GL_TEXTURE4_ARB;
+		GL_TEXTURE5 = GL_TEXTURE5_ARB;
+		GL_TEXTURE6 = GL_TEXTURE6_ARB;
+		GL_TEXTURE7 = GL_TEXTURE7_ARB;
+	}
+	else
+	{
+		Com_Printf ("...GL_ARB_multitexture not found\n" );
+	}
+	
+	gl_config.mtexcombine = false;
+	if ( strstr( gl_config.extensions_string, "GL_ARB_texture_env_combine" ) )
+	{
+		Com_Printf( "...using GL_ARB_texture_env_combine\n" );
+		gl_config.mtexcombine = true;
+	}
+	else
+	{
+		Com_Printf( "...GL_ARB_texture_env_combine not found\n" );
+	}
+	if ( !gl_config.mtexcombine )
+	{
+		if ( strstr( gl_config.extensions_string, "GL_EXT_texture_env_combine" ) )
+		{
+			Com_Printf( "...using GL_EXT_texture_env_combine\n" );
+			gl_config.mtexcombine = true;
+		}
+		else
+		{
+			Com_Printf( "...GL_EXT_texture_env_combine not found\n" );
+		}
+	}
+
+	if (strstr(gl_config.extensions_string, "GL_EXT_texture_filter_anisotropic"))
+	{
+		qglGetIntegerv(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT, &max_aniso);
+
+		r_ext_max_anisotropy = Cvar_Get("r_ext_max_anisotropy", "0", CVAR_ARCHIVE );
+		Cvar_SetValue("r_ext_max_anisotropy", max_aniso);
+
+		r_anisotropic = Cvar_Get("r_anisotropic", "16", CVAR_ARCHIVE);
+		if (r_anisotropic->value >= r_ext_max_anisotropy->value)
+			Cvar_SetValue("r_anisotropic", r_ext_max_anisotropy->value);
+
+		aniso_level = r_anisotropic->value;
+
+		if (r_anisotropic->value == 1)
+			Com_Printf("...ignoring GL_EXT_texture_filter_anisotropic\n");
+		else
+			Com_Printf("...using GL_EXT_texture_filter_anisotropic\n");
+	}
+	else
+	{
+		Com_Printf("...GL_EXT_texture_filter_anisotropic not found\n");
+		r_anisotropic = Cvar_Get("r_anisotropic", "0", CVAR_ARCHIVE);
+		r_ext_max_anisotropy = Cvar_Get("r_ext_max_anisotropy", "0", CVAR_ARCHIVE);
+	}
+}
+
 GLenum bFunc1 = -1;
 GLenum bFunc2 = -1;
 void GL_BlendFunction (GLenum sfactor, GLenum dfactor)
@@ -77,33 +155,9 @@ void GL_ShadeModel (GLenum mode)
 	}
 }
 
-
-void GL_SetTexturePalette( unsigned palette[256] )
-{
-	int i;
-	unsigned char temptable[768];
-
-	if ( qglColorTableEXT && gl_ext_palettedtexture->value )
-	{
-		for ( i = 0; i < 256; i++ )
-		{
-			temptable[i*3+0] = ( palette[i] >> 0 ) & 0xff;
-			temptable[i*3+1] = ( palette[i] >> 8 ) & 0xff;
-			temptable[i*3+2] = ( palette[i] >> 16 ) & 0xff;
-		}
-
-		qglColorTableEXT( GL_SHARED_TEXTURE_PALETTE_EXT,
-						   GL_RGB,
-						   256,
-						   GL_RGB,
-						   GL_UNSIGNED_BYTE,
-						   temptable );
-	}
-}
-
 void GL_EnableMultitexture( qboolean enable )
 {
-	if ( !qglSelectTextureSGIS && !qglActiveTextureARB )
+	if ( !qglActiveTextureARB )
 		return;
 
 	if ( enable )
@@ -142,7 +196,7 @@ void GL_SelectTexture( GLenum texture )
 {
 	int tmu;
 
-	if ( !qglSelectTextureSGIS && !qglActiveTextureARB )
+	if ( !qglActiveTextureARB )
 		return;
 
 	if ( texture == GL_TEXTURE0 )
@@ -161,11 +215,7 @@ void GL_SelectTexture( GLenum texture )
 
 	gl_state.currenttmu = tmu;
 
-	if ( qglSelectTextureSGIS )
-	{
-		qglSelectTextureSGIS( texture );
-	}
-	else if ( qglActiveTextureARB )
+	if ( qglActiveTextureARB )
 	{
 		qglActiveTextureARB( texture );
 		qglClientActiveTextureARB( texture );
@@ -271,7 +321,7 @@ void GL_TextureMode( char *string )
 
 	for (i=0 ; i< NUM_GL_MODES ; i++)
 	{
-		if ( !Q_stricmp( modes[i].name, string ) )
+		if ( !Q_strcasecmp( modes[i].name, string ) )
 			break;
 	}
 
@@ -307,7 +357,7 @@ void GL_TextureAlphaMode( char *string )
 
 	for (i=0 ; i< NUM_GL_ALPHA_MODES ; i++)
 	{
-		if ( !Q_stricmp( gl_alpha_modes[i].name, string ) )
+		if ( !Q_strcasecmp( gl_alpha_modes[i].name, string ) )
 			break;
 	}
 
@@ -331,7 +381,7 @@ void GL_TextureSolidMode( char *string )
 
 	for (i=0 ; i< NUM_GL_SOLID_MODES ; i++)
 	{
-		if ( !Q_stricmp( gl_solid_modes[i].name, string ) )
+		if ( !Q_strcasecmp( gl_solid_modes[i].name, string ) )
 			break;
 	}
 
@@ -497,7 +547,6 @@ void LoadPCX (char *filename, byte **pic, byte **palette, int *width, int *heigh
 	len = FS_LoadFile (filename, (void **)&raw);
 	if (!raw)
 	{
-		Com_DPrintf ("Bad pcx file %s\n", filename);
 		return;
 	}
 
@@ -597,11 +646,11 @@ int crjpg_fill_input_buffer(j_decompress_ptr cinfo)
 
 void crjpg_skip_input_data(j_decompress_ptr cinfo, long num_bytes)
 {
-        
+
     cinfo->src->next_input_byte += (size_t) num_bytes;
     cinfo->src->bytes_in_buffer -= (size_t) num_bytes;
 
-    if (cinfo->src->bytes_in_buffer < 0) 
+    if (cinfo->src->bytes_in_buffer < 0)
 		Com_Printf("Premature end of JPEG data\n");
 }
 
@@ -636,7 +685,7 @@ void LoadJPG (char *filename, byte **pic, int *width, int *height)
 	rawsize = FS_LoadFile(filename, (void **)&rawdata);
 	if (!rawdata)
 	{
-		return;	
+		return;
 	}
 
 	// Knightmare- check for bad data
@@ -768,7 +817,6 @@ void LoadTGA (char *name, byte **pic, int *width, int *height)
 	length = FS_LoadFile (name, (void **)&buffer);
 	if (!buffer)
 	{
-		Com_DPrintf ("Bad tga file %s\n", name);
 		return;
 	}
 
@@ -777,7 +825,7 @@ void LoadTGA (char *name, byte **pic, int *width, int *height)
 	targa_header.id_length = *buf_p++;
 	targa_header.colormap_type = *buf_p++;
 	targa_header.image_type = *buf_p++;
-	
+
 	tmp[0] = buf_p[0];
 	tmp[1] = buf_p[1];
 	targa_header.colormap_index = LittleShort ( *((short *)tmp) );
@@ -798,14 +846,14 @@ void LoadTGA (char *name, byte **pic, int *width, int *height)
 	targa_header.pixel_size = *buf_p++;
 	targa_header.attributes = *buf_p++;
 
-	if (targa_header.image_type!=2 
+	if (targa_header.image_type!=2
 		&& targa_header.image_type!=10) {
 		//Com_Error (ERR_DROP, "LoadTGA: Only type 2 and 10 targa RGB images supported\n");
 		FS_FreeFile (buffer);
 		return;
 	}
 
-	if (targa_header.colormap_type !=0 
+	if (targa_header.colormap_type !=0
 		|| (targa_header.pixel_size!=32 && targa_header.pixel_size!=24)) {
 		//Com_Error (ERR_DROP, "LoadTGA: Only 32 or 24 bit images supported (no colormaps)\n");
 		FS_FreeFile (buffer);
@@ -826,7 +874,7 @@ void LoadTGA (char *name, byte **pic, int *width, int *height)
 
 	if (targa_header.id_length != 0)
 		buf_p += targa_header.id_length;  // skip TARGA image comment
-	
+
 	if (targa_header.image_type==2) {  // Uncompressed, RGB images
 		for(row=rows-1; row>=0; row--) {
 			pixbuf = targa_rgba + row*columns*4;
@@ -834,7 +882,7 @@ void LoadTGA (char *name, byte **pic, int *width, int *height)
 				unsigned char red,green,blue,alphabyte;
 				switch (targa_header.pixel_size) {
 					case 24:
-							
+
 							blue = *buf_p++;
 							green = *buf_p++;
 							red = *buf_p++;
@@ -858,7 +906,7 @@ void LoadTGA (char *name, byte **pic, int *width, int *height)
 		}
 	}
 	else if (targa_header.image_type==10) {   // Runlength encoded RGB images
-		unsigned char red,green,blue,alphabyte,packetHeader,packetSize,j;
+		unsigned char red=0,green=0,blue=0,alphabyte=0,packetHeader,packetSize,j;
 		for(row=rows-1; row>=0; row--) {
 			pixbuf = targa_rgba + row*columns*4;
 			for(column=0; column<columns; ) {
@@ -879,7 +927,7 @@ void LoadTGA (char *name, byte **pic, int *width, int *height)
 								alphabyte = *buf_p++;
 								break;
 					}
-	
+
 					for(j=0;j<packetSize;j++) {
 						*pixbuf++=red;
 						*pixbuf++=green;
@@ -927,7 +975,7 @@ void LoadTGA (char *name, byte **pic, int *width, int *height)
 							else
 								goto breakOut;
 							pixbuf = targa_rgba + row*columns*4;
-						}						
+						}
 					}
 				}
 			}
@@ -1075,8 +1123,8 @@ void GL_ResampleTexture (unsigned *in, int inwidth, int inheight, unsigned *out,
 /*
 R_FilterTexture
 
-Applies brightness and contrast to the specified image while optionally computing 
-the image's average color.  Also handles image inversion and monochrome.  This is 
+Applies brightness and contrast to the specified image while optionally computing
+the image's average color.  Also handles image inversion and monochrome.  This is
 all munged into one function to reduce loops on level load.
 */
 void R_FilterTexture(unsigned *in, int width, int height)
@@ -1128,11 +1176,14 @@ void R_FilterTexture(unsigned *in, int width, int height)
 
 }
 
+static int	powers_of_two[] = {16,32,64,128,256,512,1024,2048,4096};
 int		upload_width, upload_height;
-qboolean uploaded_paletted;
+qboolean	uploaded_paletted;
+
 
 qboolean GL_Upload32 (unsigned *data, int width, int height,  qboolean mipmap, qboolean is_normalmap)
-{	int		samples;
+{
+	int		samples;
 	unsigned 	*scaled;
 	int		scaled_width, scaled_height;
 	int		i, c;
@@ -1142,95 +1193,87 @@ qboolean GL_Upload32 (unsigned *data, int width, int height,  qboolean mipmap, q
 	if(mipmap && !is_normalmap)
 		R_FilterTexture(data, width, height);
 
-    uploaded_paletted = false;    // scan the texture for any non-255 alpha 
-    c = width*height; 
-    scan = ((byte *)data) + 3; 
-    samples = gl_solid_format; 
-    for (i=0 ; i<c ; i++, scan += 4) 
-    { 
-        if ( *scan != 255 ) 
-        { 
-            samples = gl_alpha_format; 
-            break; 
-        } 
-    } 
-    comp = (samples == gl_solid_format) ? gl_tex_solid_format : gl_tex_alpha_format; 
+	uploaded_paletted = false;    // scan the texture for any non-255 alpha
+	c = width*height;
+	scan = ((byte *)data) + 3;
+	samples = gl_solid_format;
+	for (i=0 ; i<c ; i++, scan += 4)
+	{
+		if ( *scan != 255 )
+		{
+			samples = gl_alpha_format;
+			break;
+		}
+	}
+	comp = (samples == gl_solid_format) ? gl_tex_solid_format : gl_tex_alpha_format;
 
-    { 
-        int powers_of_two[] = {16,32,64,128,256,512,1024,2048,4096}; 
-        int max_size; 
-        int i; 
-        qglGetIntegerv(GL_MAX_TEXTURE_SIZE,&max_size); 
-        scaled_width = scaled_height = 0; 
+	{
+		int max_size;
+		int i;
+		qglGetIntegerv(GL_MAX_TEXTURE_SIZE,&max_size);
+		scaled_width = scaled_height = 0;
 
-        for (i=0; i<8; i++) 
-        { 
-            if (width >= powers_of_two[i] && width < powers_of_two[i+1]) { 
-                if (width > ((powers_of_two[i] + powers_of_two[i+1])/2)) 
-                    scaled_width = powers_of_two[i+1]; 
-                else 
-                    scaled_width = powers_of_two[i]; 
-            } else if (width == powers_of_two[i+1]) { 
-                scaled_width = powers_of_two[i+1]; 
-            } 
-            if (scaled_width && scaled_height) 
-                break; 
-            if (height >= powers_of_two[i] && height < powers_of_two[i+1]) { 
-                if (height > ((powers_of_two[i] + powers_of_two[i+1])/2)) 
-                    scaled_height = powers_of_two[i+1]; 
-                else 
-                    scaled_height = powers_of_two[i]; 
-            } else if (height == powers_of_two[i+1]) { 
-                scaled_height = powers_of_two[i+1]; 
-            }            if (scaled_width && scaled_height) 
-                break; 
-        } 
+		for (i=0; i<8; i++)
+		{
+			if (width >= powers_of_two[i] && width < powers_of_two[i+1]) {
+				if (width > ((powers_of_two[i] + powers_of_two[i+1])/2))
+					scaled_width = powers_of_two[i+1];
+				else
+					scaled_width = powers_of_two[i];
+			} else if (width == powers_of_two[i+1]) {
+				scaled_width = powers_of_two[i+1];
+			}
+
+			if (scaled_width && scaled_height)
+				break;
+			if (height >= powers_of_two[i] && height < powers_of_two[i+1]) {
+				if (height > ((powers_of_two[i] + powers_of_two[i+1])/2))
+					scaled_height = powers_of_two[i+1];
+				else
+					scaled_height = powers_of_two[i];
+			} else if (height == powers_of_two[i+1]) {
+				scaled_height = powers_of_two[i+1];
+			}
+			if (scaled_width && scaled_height)
+				break;
+		}
 		// let people sample down the world textures for speed
 		if (mipmap)
 		{
-			scaled_width >>= (int)gl_picmip->value;
-			scaled_height >>= (int)gl_picmip->value;
+			scaled_width >>= gl_picmip->integer;
+			scaled_height >>= gl_picmip->integer;
 		}
-        if (scaled_width > max_size) 
-            scaled_width = max_size; 
-        if (scaled_height > max_size) 
-            scaled_height = max_size; 
-    } 
+		if (scaled_width > max_size)
+			scaled_width = max_size;
+		if (scaled_height > max_size)
+			scaled_height = max_size;
+	}
 
-    if (scaled_width != width || scaled_height != height) { 
-        scaled=malloc((scaled_width * scaled_height) * 4); 
-        GL_ResampleTexture(data,width,height,scaled,scaled_width,scaled_height); 
-    } else { 
-        scaled_width=width; 
-        scaled_height=height; 
-        scaled=data; 
-    } 
+	if (scaled_width != width || scaled_height != height) {
+		scaled=malloc((scaled_width * scaled_height) * 4);
+		GL_ResampleTexture(data,width,height,scaled,scaled_width,scaled_height);
+	} else {
+		scaled=data;
+	}
 
-	if (mipmap) 
-        gluBuild2DMipmaps (GL_TEXTURE_2D, samples, scaled_width, scaled_height, GL_RGBA, GL_UNSIGNED_BYTE, scaled); 
-    else   
-        qglTexImage2D (GL_TEXTURE_2D, 0, comp, scaled_width, scaled_height, 0, GL_RGBA, GL_UNSIGNED_BYTE, scaled); 
-     
-    if (scaled_width != width || scaled_height != height) 
-        free(scaled); 
+	if (mipmap)
+		qglTexParameteri( GL_TEXTURE_2D, GL_GENERATE_MIPMAP, GL_TRUE );
+	qglTexImage2D (GL_TEXTURE_2D, 0, comp, scaled_width, scaled_height, 0, GL_RGBA, GL_UNSIGNED_BYTE, scaled);
 
-    upload_width =scaled_width; 
-	upload_height = scaled_height; 
-    if (mipmap) 
-    { 
-        qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, gl_filter_min); 
-        qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, gl_filter_max); 
-    } 
-    else 
-    {         
-        qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, gl_filter_max); 
-        qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, gl_filter_max); 
-    }     
+	if (scaled_width != width || scaled_height != height)
+		free(scaled);
 
+	upload_width = scaled_width;
+	upload_height = scaled_height;
+	if ( mipmap )
+		qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, gl_filter_min);
+	else
+		qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, gl_filter_max);
+	qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, gl_filter_max);
 	qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAX_ANISOTROPY_EXT, r_anisotropic->value);
 
-    return (samples == gl_alpha_format); 
-} 
+	return (samples == gl_alpha_format);
+}
 
 /*
 ===============
@@ -1249,58 +1292,35 @@ qboolean GL_Upload8 (byte *data, int width, int height,  qboolean mipmap, qboole
 
 	if (s > sizeof(trans)/4)
 		Com_Error (ERR_DROP, "GL_Upload8: too large");
+	
+	for (i=0 ; i<s ; i++)
+    {
+		p = data[i];
+        trans[i] = d_8to24table[p];
 
-	if ( qglColorTableEXT && 
-		 gl_ext_palettedtexture->value && 
-		 is_sky )
-	{
-		qglTexImage2D( GL_TEXTURE_2D,
-					  0,
-					  GL_COLOR_INDEX8_EXT,
-					  width,
-					  height,
-					  0,
-					  GL_COLOR_INDEX,
-					  GL_UNSIGNED_BYTE,
-					  data );
-
-		qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, gl_filter_max);
-		qglTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, gl_filter_max);
-
-		return false;
-	}
-	else
-	{
-		for (i=0 ; i<s ; i++)
-		{
-			p = data[i];
-			trans[i] = d_8to24table[p];
-
-			if (p == 255)
-			{	// transparent, so scan around for another color
-				// to avoid alpha fringes
-				// FIXME: do a full flood fill so mips work...
-				if (i > width && data[i-width] != 255)
-					p = data[i-width];
-				else if (i < s-width && data[i+width] != 255)
-					p = data[i+width];
-				else if (i > 0 && data[i-1] != 255)
-					p = data[i-1];
-				else if (i < s-1 && data[i+1] != 255)
-					p = data[i+1];
-				else
-					p = 0;
-				// copy rgb components
-				((byte *)&trans[i])[0] = ((byte *)&d_8to24table[p])[0];
-				((byte *)&trans[i])[1] = ((byte *)&d_8to24table[p])[1];
-				((byte *)&trans[i])[2] = ((byte *)&d_8to24table[p])[2];
-			}
-		}
-		return GL_Upload32 (trans, width, height, mipmap, false);
-	}
+        if (p == 255)
+        {   // transparent, so scan around for another color
+            // to avoid alpha fringes
+            // FIXME: do a full flood fill so mips work...
+            if (i > width && data[i-width] != 255)
+                p = data[i-width];
+            else if (i < s-width && data[i+width] != 255)
+                p = data[i+width];
+            else if (i > 0 && data[i-1] != 255)
+                p = data[i-1];
+            else if (i < s-1 && data[i+1] != 255)
+                p = data[i+1];
+            else
+                p = 0;
+            // copy rgb components
+            ((byte *)&trans[i])[0] = ((byte *)&d_8to24table[p])[0];
+            ((byte *)&trans[i])[1] = ((byte *)&d_8to24table[p])[1];
+            ((byte *)&trans[i])[2] = ((byte *)&d_8to24table[p])[2];
+        }
+    }
+    return GL_Upload32 (trans, width, height, mipmap, false);
 }
 
-
 /*
 ================
 GL_LoadPic
@@ -1329,7 +1349,14 @@ image_t *GL_LoadPic (char *name, byte *pic, int width, int height, imagetype_t t
 
 	if (strlen(name) >= sizeof(image->name))
 		Com_Error (ERR_DROP, "Draw_LoadPic: \"%s\" is too long", name);
+
 	strcpy (image->name, name);
+
+	if ( name[0] != '*' )
+	{ // not a special name, remove the path part
+		strcpy( image->bare_name, COM_SkipPath( name ) );
+	}
+
 	image->registration_sequence = registration_sequence;
 
 	image->width = width;
@@ -1367,13 +1394,13 @@ image_t *GL_LoadPic (char *name, byte *pic, int width, int height, imagetype_t t
 	}
 	else
 	{
-nonscrap: 
+nonscrap:
 		image->scrap = false;
 		image->texnum = TEXNUM_IMAGES + (image - gltextures);
 		GL_Bind(image->texnum);
-		if (bits == 8)
+		if (bits == 8) {
 			image->has_alpha = GL_Upload8 (pic, width, height, (image->type != it_pic && image->type != it_sky), image->type == it_sky );
-		else {
+		} else {
 			image->has_alpha = GL_Upload32 ((unsigned *)pic, width, height, (image->type != it_pic && image->type != it_sky), image->type == it_bump );
 		}
 		image->upload_width = upload_width;		// after power of 2 and scales
@@ -1404,7 +1431,6 @@ image_t *GL_LoadWal (char *name)
 	FS_LoadFile (name, (void **)&mt);
 	if (!mt)
 	{
-		Com_Printf ("GL_FindImage: can't load %s\n", name);
 		return r_notexture;
 	}
 
@@ -1419,6 +1445,53 @@ image_t *GL_LoadWal (char *name)
 	return image;
 }
 
+
+/*
+===============
+GL_GetImage
+
+Finds an image, do not attempt to load it
+===============
+*/
+image_t *GL_GetImage( const char * name )
+{
+	image_t *	image = NULL;
+	unsigned int	hash_key;
+	int		i;
+
+	COMPUTE_HASH_KEY( hash_key, name, i );
+	for ( i = 0, image=gltextures ; i<numgltextures ; i++,image++)
+	{
+		if (hash_key == image->hash_key && !strcmp(name, image->name))
+		{
+			image->registration_sequence = registration_sequence;
+			return image;
+		}
+	}
+
+	return NULL;
+}
+
+
+/*
+===============
+GL_FreeImage
+
+Frees an image slot and deletes the texture
+===============
+*/
+void GL_FreeImage( image_t * image )
+{
+	if ( ! image->texnum )
+		return;
+	qglDeleteTextures (1, (unsigned *)&image->texnum );
+	if ( gl_state.currenttextures[gl_state.currenttmu] == image->texnum ) {
+		gl_state.currenttextures[ gl_state.currenttmu ] = 0;
+	}
+	memset (image, 0, sizeof(*image));
+}
+
+
 /*
 ===============
 GL_FindImage
@@ -1426,17 +1499,13 @@ GL_FindImage
 Finds or loads the given image
 ===============
 */
-
-static double totalTimeFindImage = 0;
-static unsigned int totalCountFindImage = 0;
 image_t	*GL_FindImage (char *name, imagetype_t type)
 {
 	image_t		*image = NULL;
-	int		i, len;
+	int		len;
 	byte		*pic, *palette;
 	int		width, height;
 	char		shortname[MAX_QPATH];
-	unsigned int	hash_key;
 
 	if (!name)
 		goto ret_image;	//	Com_Error (ERR_DROP, "GL_FindImage: NULL name");
@@ -1445,21 +1514,15 @@ image_t	*GL_FindImage (char *name, imagetype_t type)
 		goto ret_image;	//	Com_Error (ERR_DROP, "GL_FindImage: bad name: %s", name);
 
 	//if HUD, then we want to load the one according to what it is set to.
-	if(!strcmp(name, "pics/i_health.pcx")) 
+	if(!strcmp(name, "pics/i_health.pcx"))
 			strcpy(name, cl_hudimage1->string);
-	if(!strcmp(name, "pics/i_score.pcx")) 
+	if(!strcmp(name, "pics/i_score.pcx"))
 			strcpy(name, cl_hudimage2->string);
 
 	// look for it
-	COMPUTE_HASH_KEY( hash_key, name, i );
-	for (i=0, image=gltextures ; i<numgltextures ; i++,image++)
-	{
-		if (hash_key == image->hash_key && !strcmp(name, image->name))
-		{
-			image->registration_sequence = registration_sequence;
-			goto ret_image;
-		}
-	}
+	image = GL_GetImage( name );
+	if ( image != NULL )
+		return image;
 
 	// strip off .pcx, .tga, etc...
 	COM_StripExtension ( name, shortname );
@@ -1467,26 +1530,25 @@ image_t	*GL_FindImage (char *name, imagetype_t type)
 	//
 	// load the pic from disk
 	//
-	image = NULL;
 	pic = NULL;
 	palette = NULL;
 
 	// try to load .tga first
 	LoadTGA (va("%s.tga", shortname), &pic, &width, &height);
-	if (pic) 
+	if (pic)
 	{
 		image = GL_LoadPic (name, pic, width, height, type, 32);
 		goto done;
 	}
 	LoadJPG (va("%s.jpg", shortname), &pic, &width, &height);
-	if (pic) 
+	if (pic)
 	{
 		image = GL_LoadPic (name, pic, width, height, type, 32);
 		goto done;
 	}
 	// then comes .pcx
 	LoadPCX (va("%s.pcx", shortname), &pic, &palette, &width, &height);
-	if (pic) 
+	if (pic)
 	{
 		image = GL_LoadPic (name, pic, width, height, type, 8);
 		goto done;
@@ -1503,7 +1565,7 @@ done:
 		free(palette);
 
 ret_image:
-	return image; 
+	return image;
 }
 
 
@@ -1532,72 +1594,23 @@ void GL_FreeUnusedImages (void)
 	int		i;
 	image_t	*image;
 
-	// never free r_notexture or particle textures
+	// never free r_notexture
 	r_notexture->registration_sequence = registration_sequence;
-	r_particletexture->registration_sequence = registration_sequence;
-    r_shelltexture->registration_sequence = registration_sequence;   
-	r_shelltexture2->registration_sequence = registration_sequence;
-	r_shellnormal->registration_sequence = registration_sequence;
-	r_reflecttexture->registration_sequence = registration_sequence;
-	r_mirrorspec->registration_sequence = registration_sequence;
-	r_flare->registration_sequence = registration_sequence;
-	r_smoketexture->registration_sequence = registration_sequence;
-  	r_explosiontexture->registration_sequence = registration_sequence;
-	r_explosion1texture->registration_sequence = registration_sequence;
-	r_explosion2texture->registration_sequence = registration_sequence;
-	r_explosion3texture->registration_sequence = registration_sequence;
-	r_explosion4texture->registration_sequence = registration_sequence;
-	r_explosion5texture->registration_sequence = registration_sequence;
-	r_explosion6texture->registration_sequence = registration_sequence;
-	r_explosion7texture->registration_sequence = registration_sequence;
-	r_bloodtexture->registration_sequence = registration_sequence;
-	r_pufftexture->registration_sequence = registration_sequence;
-	r_bflashtexture->registration_sequence = registration_sequence;
-	r_cflashtexture->registration_sequence = registration_sequence;
-	r_beamtexture->registration_sequence = registration_sequence;
-	r_beam2texture->registration_sequence = registration_sequence;
-	r_beam3texture->registration_sequence = registration_sequence;
-	r_leaderfieldtexture->registration_sequence = registration_sequence;
-	r_deathfieldtexture->registration_sequence = registration_sequence;
-	r_deathfieldtexture2->registration_sequence = registration_sequence;
-	r_hittexture->registration_sequence = registration_sequence;
-	r_bubbletexture->registration_sequence = registration_sequence;
-	r_shottexture->registration_sequence = registration_sequence;
-	r_bullettexture->registration_sequence = registration_sequence;
-	r_bulletnormal->registration_sequence = registration_sequence;
-	r_sayicontexture->registration_sequence = registration_sequence;
-	r_voltagetexture->registration_sequence = registration_sequence;
-	r_raintexture->registration_sequence = registration_sequence;
-	r_leaftexture->registration_sequence = registration_sequence;
-	r_splashtexture->registration_sequence = registration_sequence;
-	r_splash2texture->registration_sequence = registration_sequence;
-	r_flagtexture->registration_sequence = registration_sequence;
-	r_logotexture->registration_sequence = registration_sequence;
-	r_distort->registration_sequence = registration_sequence;
-	r_radarmap->registration_sequence = registration_sequence;
-	r_around->registration_sequence = registration_sequence;
-	sun_object->registration_sequence = registration_sequence;
-	sun1_object->registration_sequence = registration_sequence;
-	sun2_object->registration_sequence = registration_sequence;
-	r_dis1texture->registration_sequence = registration_sequence;
-	r_dis2texture->registration_sequence = registration_sequence;
-	r_dis3texture->registration_sequence = registration_sequence;
-
+	
 	for (i=0, image=gltextures ; i<numgltextures ; i++, image++)
 	{
 		if (image->registration_sequence == registration_sequence)
 			continue;		// used this sequence
 		if (!image->registration_sequence)
 			continue;		// free image_t slot
-		if (image->type == it_pic)
-			continue;		// don't free pics
+		if (image->type == it_pic || image->type == it_sprite)
+			continue;		// don't free pics or particles
 		// free it
-		qglDeleteTextures (1, &image->texnum);
+		qglDeleteTextures (1, (unsigned *)&image->texnum );
 		memset (image, 0, sizeof(*image));
 	}
 }
 
-
 /*
 ===============
 Draw_GetPalette
@@ -1622,7 +1635,7 @@ int Draw_GetPalette (void)
 		r = pal[i*3+0];
 		g = pal[i*3+1];
 		b = pal[i*3+2];
-		
+
 		v = (255<<24) + (r<<0) + (g<<8) + (b<<16);
 		d_8to24table[i] = LittleLong(v);
 	}
@@ -1653,7 +1666,7 @@ void R_InitDepthTextures( void )
 	byte	*data;
 	int		size, texture_height, texture_width;
 
-	//find closer power of 2 to screen size 
+	//find closer power of 2 to screen size
 	for (texture_width = 1;texture_width < viddef.width;texture_width *= 2);
 	for (texture_height = 1;texture_height < viddef.height;texture_height *= 2);
 
@@ -1662,14 +1675,14 @@ void R_InitDepthTextures( void )
 		texture_width = 2048;
 	if(texture_height > 2048)
 		texture_height = 2048;
-	
+
 	//init the framebuffer textures
 	size = texture_width * texture_height * 4;
 
 	data = malloc( size );
 	memset( data, 255, size );
 	r_depthtexture = GL_LoadPic( "***r_depthtexture***", (byte *)data, texture_width, texture_height, it_pic, 3 );
-	free ( data );	
+	free ( data );
 }
 
 
@@ -1687,13 +1700,6 @@ void	GL_InitImages (void)
 
 	Draw_GetPalette ();
 
-	if ( qglColorTableEXT )
-	{
-		FS_LoadFile( "pics/16to8.dat", &gl_state.d_16to8table );
-		if ( !gl_state.d_16to8table )
-			Sys_Error( ERR_FATAL, "Couldn't load pics/16to8.pcx");
-	}
-
 	R_InitBloomTextures();//BLOOMS
 	R_InitMirrorTextures();//MIRRORS
 	R_InitDepthTextures();//DEPTH(SHADOWMAPS)
@@ -1715,7 +1721,7 @@ void	GL_ShutdownImages (void)
 		if (!image->registration_sequence)
 			continue;		// free image_t slot
 		// free it
-		qglDeleteTextures (1, &image->texnum);
+		qglDeleteTextures (1, (unsigned *)&image->texnum);
 		memset (image, 0, sizeof(*image));
 	}
 }
