@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#ifdef _WIN32
+#if defined WIN32_VARIANT
 #  include <windows.h>
 #endif
 
@@ -28,18 +28,20 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <math.h>
 #include "glext.h"
 
-#ifndef __unix__
 #ifndef GL_COLOR_INDEX8_EXT
 #define GL_COLOR_INDEX8_EXT GL_COLOR_INDEX
 #endif
-#endif
 
-#include "../client/ref.h"
-#include "../client/vid.h"
+#include "client/ref.h"
+#include "client/vid.h"
 
 #include "qgl.h"
 #include "r_math.h"
 
+#if !defined min
+#define min(a,b) (((a)<(b)) ? (a) : (b))
+#endif
+
 // up / down
 #define	PITCH	0
 
@@ -95,14 +97,6 @@ extern	int c_beams;
 
 extern	int			gl_filter_min, gl_filter_max;
 
-//
-// view origin
-//
-extern	vec3_t	vup;
-extern	vec3_t	vpn;
-extern	vec3_t	vright;
-extern	vec3_t	r_origin;
-
 //
 // screen size info
 //
@@ -123,8 +117,6 @@ extern	cvar_t	*r_lightlevel;	// FIXME: This is a HACK to get the client's light
 extern  cvar_t  *r_wave; //water waves
 
 extern cvar_t	*gl_ext_swapinterval;
-extern cvar_t	*gl_ext_palettedtexture;
-extern cvar_t	*gl_ext_multitexture;
 extern cvar_t	*gl_ext_pointparameters;
 extern cvar_t	*gl_ext_compiled_vertex_array;
 
@@ -142,7 +134,6 @@ extern	cvar_t	*gl_lightmap;
 extern	cvar_t	*gl_shadows;
 extern	cvar_t	*gl_dynamic;
 extern	cvar_t	*gl_nobind;
-extern	cvar_t	*gl_round_down;
 extern	cvar_t	*gl_picmip;
 extern	cvar_t	*gl_skymip;
 extern	cvar_t	*gl_showtris;
@@ -151,36 +142,29 @@ extern	cvar_t	*gl_finish;
 extern	cvar_t	*gl_clear;
 extern	cvar_t	*gl_cull;
 extern	cvar_t	*gl_poly;
-extern	cvar_t	*gl_texsort;
 extern	cvar_t	*gl_polyblend;
-extern	cvar_t	*gl_flashblend;
-extern	cvar_t	*gl_lightmaptype;
 extern	cvar_t	*gl_modulate;
-extern	cvar_t	*gl_playermip;
 extern	cvar_t	*gl_drawbuffer;
-extern	cvar_t	*gl_3dlabs_broken;
 extern	cvar_t	*gl_driver;
 extern	cvar_t	*gl_swapinterval;
 extern	cvar_t	*gl_texturemode;
 extern	cvar_t	*gl_texturealphamode;
 extern	cvar_t	*gl_texturesolidmode;
 extern	cvar_t	*gl_lockpvs;
+extern	cvar_t	*gl_vlights;
+extern  cvar_t	*gl_usevbo;
 
 extern	cvar_t	*vid_fullscreen;
 extern	cvar_t	*vid_gamma;
 extern  cvar_t	*vid_contrast;
 
-extern	cvar_t	*intensity;
-
 extern cvar_t *r_anisotropic;
 extern cvar_t *r_ext_max_anisotropy;
 
 extern cvar_t	*r_overbrightbits;
-extern cvar_t	*gl_ext_mtexcombine;
 
 extern cvar_t	*gl_normalmaps;
 extern cvar_t	*gl_shadowmaps;
-extern cvar_t	*gl_parallaxmaps;
 extern cvar_t	*gl_glsl_postprocess;
 
 extern	cvar_t	*r_shaders;
@@ -189,6 +173,9 @@ extern	cvar_t	*r_lensflare;
 extern	cvar_t	*r_lensflare_intens;
 extern	cvar_t	*r_drawsun;
 
+extern  cvar_t	*r_ragdolls;
+extern  cvar_t  *r_ragdoll_debug;
+
 extern	qboolean	map_fog;
 extern	char		map_music[128];
 extern  unsigned	r_weather;
@@ -200,17 +187,16 @@ extern  cvar_t		*r_minimap_style;
 
 extern	cvar_t	*gl_mirror;
 
-extern	cvar_t	*gl_arb_fragment_program; 
+extern	cvar_t	*gl_arb_fragment_program;
 extern	cvar_t	*gl_glsl_shaders;
 
-
 extern	cvar_t	*sys_affinity;
 extern	cvar_t	*sys_priority;
 
 extern	cvar_t	*gl_screenshot_type;
 extern	cvar_t	*gl_screenshot_jpeg_quality;
 
-extern	cvar_t	*r_legacy;
+extern  cvar_t  *r_test;
 
 extern	int		gl_lightmap_format;
 extern	int		gl_solid_format;
@@ -222,103 +208,128 @@ extern	int		c_visible_lightmaps;
 extern	int		c_visible_textures;
 
 extern	float	r_world_matrix[16];
-extern float r_project_matrix[16];
-extern int	r_viewport[4];
-extern	float		r_farclip, r_farclip_min, r_farclip_bias;
-void GL_Bind (int texnum);
-void GL_MBind( GLenum target, int texnum );
-void GL_TexEnv( GLenum value );
-void GL_EnableMultitexture( qboolean enable );
-void GL_SelectTexture( GLenum );
-void vectoangles (vec3_t value1, vec3_t angles);
-void R_LightPoint (vec3_t p, vec3_t color, qboolean addDynamic);
-void R_PushDlights (void);
-void R_PushDlightsForBModel (entity_t *e);
-void SetVertexOverbrights (qboolean toggle);
-void RefreshFont (void);
+extern	float	r_project_matrix[16];
+extern	int		r_viewport[4];
+extern	float	r_farclip, r_farclip_min, r_farclip_bias;
+
+//Image
+extern void R_InitImageSubsystem(void);
+extern void GL_Bind (int texnum);
+extern void GL_MBind( GLenum target, int texnum );
+extern void GL_TexEnv( GLenum value );
+extern void GL_EnableMultitexture( qboolean enable );
+extern void GL_SelectTexture( GLenum );
+extern void vectoangles (vec3_t value1, vec3_t angles);
+extern void R_LightPoint (vec3_t p, vec3_t color, qboolean addDynamic);
+extern void R_PushDlights (void);
+extern void R_PushDlightsForBModel (entity_t *e);
+extern void SetVertexOverbrights (qboolean toggle);
+extern void RefreshFont (void);
 
 //====================================================================
-typedef struct
-{
-	vec3_t	origin;
-	vec3_t  angle;
-	float	alpha;
-	float	dist;
-	int		type;
-	int		texnum;
-	int		blenddst;
-	int		blendsrc;
-	int		color;
-	float   scale;
-} gparticle_t;
-
 extern	model_t	*r_worldmodel;
 
 extern	unsigned	d_8to24table[256];
 
 extern	int		registration_sequence;
 
+extern void V_AddBlend (float r, float g, float b, float a, float *v_blend);
 
-void V_AddBlend (float r, float g, float b, float a, float *v_blend);
+//Renderer main loop
+extern int	R_Init( void *hinstance, void *hWnd );
+extern void R_Shutdown( void );
 
-int	R_Init( void *hinstance, void *hWnd );
-void R_Shutdown( void );
+extern void R_RenderView (refdef_t *fd);
+extern void GL_ScreenShot_f (void);
+extern void R_DrawAliasModel (void);
+extern void R_DrawBrushModel (void);
+extern void R_DrawWorld (void);
+extern void R_RenderDlights (void);
+extern void R_DrawAlphaSurfaces (void);
+extern void R_DrawRSSurfaces(void);
+extern void R_InitParticleTexture (void);
+extern void R_DrawParticles (void);
+extern void R_DrawRadar(void);
+extern void R_DrawVehicleHUD (void);
+extern void R_ClearSkyBox (void);
+extern void R_DrawSkyBox (void);
+extern void Draw_InitLocal (void);
 
-void R_RenderView (refdef_t *fd);
-void GL_ScreenShot_f (void);
-void R_DrawAliasModel (entity_t *e);
-void R_DrawBrushModel (entity_t *e);
-void R_DrawBeam( entity_t *e );
-void R_DrawWorld (void);
-void R_RenderDlights (void);
-void R_DrawAlphaSurfaces (void);
-void R_RenderBrushPoly (msurface_t *fa);
-void R_DrawSpecialSurfaces(void);
-void R_InitParticleTexture (void);
-void R_DrawParticles (void);
-void GL_DrawRadar(void);
-void Draw_InitLocal (void);
-void GL_SubdivideSurface (msurface_t *fa);
-qboolean R_CullBox (vec3_t mins, vec3_t maxs);
-qboolean R_CullOrigin(vec3_t origin);
-void R_RotateForEntity (entity_t *e);
-void R_MarkLeaves (void);
-void R_AddSkySurface (msurface_t *fa);
-void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY);
-void R_ClearSkyBox (void);
-void R_DrawSkyBox (void);
-void R_MarkLights (dlight_t *light, int bit, mnode_t *node);
-float R_ShadowLight (vec3_t pos, vec3_t lightAdd, int type);
-#ifdef __unix__
-void R_ReadFogScript(char config_file[128]);
-void R_ReadMusicScript(char config_file[128]);
-#endif
+//Renderer utils
+extern void R_SubdivideSurface (msurface_t *fa);
+extern qboolean R_CullBox (vec3_t mins, vec3_t maxs);
+extern qboolean R_CullOrigin(vec3_t origin);
+extern qboolean R_CullSphere( const vec3_t centre, const float radius, const int clipflags );
+extern void R_RotateForEntity (entity_t *e);
+extern void R_MarkLeaves (void);
+extern void R_AddSkySurface (msurface_t *fa);
+extern void R_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY);
+extern void R_ReadFogScript(char config_file[128]);
+extern void R_ReadMusicScript(char config_file[128]);
+
+//Lights
+extern dlight_t *dynLight;
+extern vec3_t lightspot;
+extern void R_MarkLights (dlight_t *light, int bit, mnode_t *node);
+extern void  VLight_Init (void);
+extern float VLight_GetLightValue ( vec3_t normal, vec3_t dir, float apitch, float ayaw );
+
+//BSP 
+extern GLuint normalisationCubeMap;
+extern void BSP_DrawTexturelessPoly (msurface_t *fa);
+extern void BSP_DrawTexturelessBrushModel (entity_t *e);
+extern void BSP_RenderBrushPoly (msurface_t *fa);
+
+//Postprocess
 void R_GLSLPostProcess(void);
 void R_FB_InitTextures(void);
 
 //VBO
-void R_VCInit(void);
-void GL_BindVBO(vertCache_t *cache);
-vertCache_t *R_VCFindCache(vertStoreMode_t store, entity_t *ent);
-vertCache_t *R_VCLoadData(vertCacheMode_t mode, int size, void *buffer, vertStoreMode_t store, entity_t *ent);
-void R_VCShutdown(void);
+extern GLuint vboId;
+extern int totalVBOsize;
+extern void R_LoadVBOSubsystem(void);
+extern void R_VCShutdown(void);
+extern void VB_VCInit(void);
+extern void VB_BuildVBOBufferSize(msurface_t *surf);
+extern void VB_BuildWorldVBO(void);
 
-//BLOOMS[start]
-//
-// r_bloom.c
-//
-void R_BloomBlend( refdef_t *fd );
-void R_InitBloomTextures( void );
-//BLOOMS[end]
+//Light Bloom
+extern void R_BloomBlend( refdef_t *fd );
+extern void R_InitBloomTextures( void );
+
+//Flares and Sun
+int r_numflares;
+extern int c_flares;
+flare_t r_flares[MAX_FLARES];
+extern void Mod_AddFlareSurface (msurface_t *surf, int type );
+extern void R_RenderFlares (void);
+extern void R_ClearFlares(void);
 
-//FLARES and SUN
-void R_RenderFlares (void);
-void R_DrawVegetationSurface (void);
-void R_DrawBeamSurface ( void );
-void R_InitSun();
-void R_RenderSun();
 vec3_t sun_origin;
 qboolean spacebox;
+qboolean draw_sun;
+float sun_x;
+float sun_y;
+float sun_size;
+extern void R_InitSun();
+extern void R_RenderSun();
+
+//Vegetation
+int r_numgrasses;
+extern int c_grasses;
+grass_t r_grasses[MAX_GRASSES];
+extern void Mod_AddVegetationSurface (msurface_t *surf, int texnum, vec3_t color, float size, char name[MAX_QPATH], int type);
+extern void R_DrawVegetationSurface (void);
+extern void R_ClearGrasses(void);
+
+//Light beams/volumes
+int r_numbeams;
+extern int c_beams;
+beam_t r_beams[MAX_BEAMS];
+extern void Mod_AddBeamSurface (msurface_t *surf, int texnum, vec3_t color, float size, char name[MAX_QPATH], int type, float xang, float yang,
+	qboolean rotating);
+extern void R_DrawBeamSurface ( void );
+extern void R_ClearBeams(void);
 
 //Player icons
 extern float	scr_playericonalpha;
@@ -326,47 +337,45 @@ extern float	scr_playericonalpha;
 //Team colors
 int r_teamColor;
 
-void	Draw_GetPicSize (int *w, int *h, char *name);
-void	Draw_Pic (int x, int y, char *name);
-void	Draw_ScaledPic (int x, int y, float scale, char *pic);
-void	Draw_StretchPic (int x, int y, int w, int h, char *name);
-void	Draw_Char (int x, int y, int c);
-void	Draw_ColorChar (int x, int y, int num, vec4_t color);
-void	Draw_ScaledChar(float x, float y, int num, float scale, int from_menu);
-void	Draw_ScaledColorChar (float x, float y, int num, vec4_t color, float scale, int from_menu);
-void	Draw_TileClear (int x, int y, int w, int h, char *name);
-void	Draw_Fill (int x, int y, int w, int h, int c);
-void	Draw_FadeScreen (void);
-void	Draw_StretchRaw (int x, int y, int w, int h, int cols, int rows, byte *data);
+extern void	Draw_GetPicSize (int *w, int *h, char *name);
+extern void	Draw_Pic (int x, int y, char *name);
+extern void	Draw_ScaledPic (int x, int y, float scale, char *pic);
+extern void	Draw_StretchPic (int x, int y, int w, int h, char *name);
+extern void	Draw_Char (int x, int y, int c);
+extern void	Draw_ColorChar (int x, int y, int num, vec4_t color);
+extern void	Draw_ScaledChar(float x, float y, int num, float scale, int from_menu);
+extern void	Draw_ScaledColorChar (float x, float y, int num, vec4_t color, float scale, int from_menu);
+extern void	Draw_TileClear (int x, int y, int w, int h, char *name);
+extern void	Draw_Fill (int x, int y, int w, int h, int c);
+extern void	Draw_FadeScreen (void);
 
-void	R_BeginFrame( float camera_separation );
-void	R_SwapBuffers( int );
-void	R_SetPalette ( const unsigned char *palette);
+extern void	R_BeginFrame( float camera_separation );
+extern void	R_SwapBuffers( int );
+extern void	R_SetPalette ( const unsigned char *palette);
+extern int	Draw_GetPalette (void);
 
-int		Draw_GetPalette (void);
-
-void	GL_ResampleTexture (unsigned *in, int inwidth, int inheight, unsigned *out,  int outwidth, int outheight);
+extern void	GL_ResampleTexture (unsigned *in, int inwidth, int inheight, unsigned *out,  int outwidth, int outheight);
 
 image_t *R_RegisterSkin (char *name);
-image_t *R_RegisterParticlePic(char *name);
-image_t *R_RegisterParticleNormal(char *name);
-image_t *R_RegisterGfxPic(char *name);
+image_t *R_RegisterParticlePic(const char *name);
+image_t *R_RegisterParticleNormal(const char *name);
+image_t *R_RegisterGfxPic(const char *name);
 
-void	LoadPCX (char *filename, byte **pic, byte **palette, int *width, int *height);
-image_t *GL_LoadPic (char *name, byte *pic, int width, int height, imagetype_t type, int bits);
-image_t	*GL_FindImage (char *name, imagetype_t type);
-void	GL_TextureMode( char *string );
-void	GL_ImageList_f (void);
+extern void	LoadPCX (char *filename, byte **pic, byte **palette, int *width, int *height);
+extern image_t *GL_LoadPic (char *name, byte *pic, int width, int height, imagetype_t type, int bits);
+extern image_t *GL_GetImage( const char * name );
+extern image_t	*GL_FindImage (char *name, imagetype_t type);
+extern void	GL_FreeImage( image_t * image );
+extern void	GL_TextureMode( char *string );
+extern void	GL_ImageList_f (void);
 
-void	GL_SetTexturePalette( unsigned palette[256] );
+extern void	GL_InitImages (void);
+extern void	GL_ShutdownImages (void);
 
-void	GL_InitImages (void);
-void	GL_ShutdownImages (void);
+extern void	GL_FreeUnusedImages (void);
 
-void	GL_FreeUnusedImages (void);
-
-void	GL_TextureAlphaMode( char *string );
-void	GL_TextureSolidMode( char *string );
+extern void	GL_TextureAlphaMode( char *string );
+extern void	GL_TextureSolidMode( char *string );
 
 /*
 ** GL config stuff
@@ -454,11 +463,13 @@ typedef struct
 	qboolean	alpha_test;
 	qboolean	blend;
 	qboolean	texgen;
-	qboolean	fragment_program; 
+	qboolean	fragment_program;
 	qboolean	glsl_shaders;
 	qboolean	separateStencil;
 	qboolean	stencil_wrap;
 	qboolean	vbo;
+	qboolean	fbo;
+	qboolean	hasFBOblit;
 
 } glstate_t;
 
@@ -466,8 +477,9 @@ extern glconfig_t  gl_config;
 extern glstate_t   gl_state;
 
 // vertex arrays
+extern int KillFlags;
 
-#define MAX_ARRAY MAX_PARTICLES*4
+#define MAX_ARRAY (MAX_PARTICLES*4)
 
 #define VA_SetElem2(v,a,b)		((v)[0]=(a),(v)[1]=(b))
 #define VA_SetElem3(v,a,b,c)	((v)[0]=(a),(v)[1]=(b),(v)[2]=(c))
@@ -476,19 +488,17 @@ extern glstate_t   gl_state;
 extern float	tex_array[MAX_ARRAY][2];
 extern float	vert_array[MAX_ARRAY][3];
 extern float	col_array[MAX_ARRAY][4];
-extern float	norm_array[MAX_ARRAY][3];
 
-#define MAX_VARRAY_VERTS MAX_VERTS + 2
+#define MAX_VARRAY_VERTS (MAX_VERTS + 2)
 #define MAX_VARRAY_VERTEX_SIZE 11
 
-#define MAX_VERTICES		16384
-#define MAX_INDICES		MAX_VERTICES * 4
-#define MAX_SHADOW_VERTS	16384
+#define MAX_VERTICES 16384
+#define MAX_INDICES	(MAX_VERTICES * 4)
+#define MAX_SHADOW_VERTS 16384
 
 extern float VArrayVerts[MAX_VARRAY_VERTS * MAX_VARRAY_VERTEX_SIZE];
 extern int VertexSizes[];
 extern float *VArray;
-static vec3_t NormalsArray[MAX_TRIANGLES*3];
 extern vec3_t ShadowArray[MAX_SHADOW_VERTS];
 
 // define our vertex types
@@ -503,6 +513,7 @@ extern vec3_t ShadowArray[MAX_SHADOW_VERTS];
 #define VERT_BUMPMAPPED_COLOURED		8		// verts and st for 1 tmu, 2 texoord pointers and colour
 #define VERT_NORMAL_COLOURED_TEXTURED	9		// verts and st for 1tmu and color, with normals
 
+#if 0
 // vertex array kill flags
 #define KILL_TMU0_POINTER	1
 #define KILL_TMU1_POINTER	2
@@ -510,23 +521,37 @@ extern vec3_t ShadowArray[MAX_SHADOW_VERTS];
 #define KILL_TMU3_POINTER	4
 #define KILL_RGBA_POINTER	5
 #define KILL_NORMAL_POINTER 6
+#else
+// looks like these should be bit flags (2010-08)
+#define KILL_TMU0_POINTER	0x01
+#define KILL_TMU1_POINTER	0x02
+#define KILL_TMU2_POINTER	0x04
+#define KILL_TMU3_POINTER	0x08
+#define KILL_RGBA_POINTER	0x10
+#define KILL_NORMAL_POINTER 0x20
+#endif
 
 // vertex array subsystem
-void R_InitVArrays (int varraytype);
-void R_KillVArrays (void);
-void R_InitQuadVarrays(void);
-void R_AddSurfToVArray (msurface_t *surf);
-void R_AddTexturedSurfToVArray (msurface_t *surf, float scroll);
-void R_AddLightMappedSurfToVArray (msurface_t *surf, float scroll);
-void R_AddGLSLShadedSurfToVArray (msurface_t *surf, float scroll);
-void R_AddGLSLShadedWarpSurfToVArray (msurface_t *surf, float scroll);
-void R_KillNormalTMUs(void);
+extern void R_InitVArrays (int varraytype);
+extern void R_KillVArrays (void);
+extern void R_InitQuadVarrays(void);
+extern void R_AddSurfToVArray (msurface_t *surf);
+extern void R_AddTexturedSurfToVArray (msurface_t *surf, float scroll);
+extern void R_AddLightMappedSurfToVArray (msurface_t *surf, float scroll);
+extern void R_AddGLSLShadedWarpSurfToVArray (msurface_t *surf, float scroll);
+extern void R_KillNormalTMUs(void);
 
 //shadows
 extern	cvar_t		*r_shadowmapratio;
 extern  int			r_lightgroups;
 extern  image_t		*r_depthtexture;
-extern GLuint   fboId;
+extern  image_t		*r_colorbuffer;
+extern  image_t		*r_shadowbuffer;
+extern	image_t		*r_shadowbufferBlur;
+extern GLuint   fboId[2];
+extern GLuint	rboId;
+extern vec3_t	r_worldLightVec;
+extern qboolean have_stencil;
 typedef struct	LightGroup {
 	vec3_t	group_origin;
 	vec3_t	accum_origin;
@@ -534,9 +559,20 @@ typedef struct	LightGroup {
 	float	dist;
 } LightGroup_t;
 extern			LightGroup_t LightGroups[MAX_LIGHTS];
-extern void		R_DrawAliasModelCaster (entity_t *e);
+
+extern void		R_GenerateShadowFBO(void);
+extern void		R_InitShadowSubsystem(void);
+extern void		MD2_DrawCaster (void);
+extern void		IQM_DrawCaster (void);
+extern void		IQM_DrawRagDollCaster (int);
 extern void		R_DrawDynamicCaster(void);
 extern void		R_CastShadow(void);
+extern float	SHD_ShadowLight (vec3_t pos, vec3_t angles, vec3_t lightAdd, int type);
+int				FB_texture_width, FB_texture_height;
+
+//shader programs
+extern void R_LoadARBPrograms(void);
+extern void	R_LoadGLSLPrograms(void);
 
 //arb fragment
 extern unsigned int g_water_program_id;
@@ -546,12 +582,14 @@ extern GLhandleARB	g_programObj;
 extern GLhandleARB	g_waterprogramObj;
 extern GLhandleARB	g_meshprogramObj;
 extern GLhandleARB	g_fbprogramObj;
+extern GLhandleARB	g_blurprogramObj;
+extern GLhandleARB	g_rblurprogramObj;
 
 extern GLhandleARB	g_vertexShader;
 extern GLhandleARB	g_fragmentShader;
 
 //standard bsp surfaces
-extern GLuint		g_location_testTexture;
+extern GLuint		g_location_surfTexture;
 extern GLuint		g_location_eyePos;
 extern GLuint		g_tangentSpaceTransform;
 extern GLuint		g_location_heightTexture;
@@ -581,28 +619,67 @@ extern GLuint		g_location_fogamount;
 
 //mesh
 extern GLuint		g_location_meshlightPosition;
-extern GLuint		g_location_meshnormal;
 extern GLuint		g_location_baseTex;
 extern GLuint		g_location_normTex;
 extern GLuint		g_location_fxTex;
 extern GLuint		g_location_color;
+extern GLuint		g_location_minLight;
 extern GLuint		g_location_meshNormal;
-extern GLuint		g_location_meshTangent;
 extern GLuint		g_location_meshTime;
 extern GLuint		g_location_meshFog;
 extern GLuint		g_location_useFX;
 extern GLuint		g_location_useGlow;
 
-//fullscreen
+//fullscreen distortion effects
 extern GLuint		g_location_framebuffTex;
 extern GLuint		g_location_distortTex;
-extern GLuint		g_location_frametime;
-extern GLuint		g_location_fxType;
+extern GLuint		g_location_dParams;
 extern GLuint		g_location_fxPos;
-extern GLuint		g_location_fxColor;
-extern GLuint		g_location_fbSampleSize;
 
-#define TURBSCALE2 (256.0 / (2 * M_PI)) 
+//gaussian blur
+extern GLuint		g_location_scale;
+extern GLuint		g_location_source;
+
+//radial blur	
+extern GLuint		g_location_rscale;
+extern GLuint		g_location_rsource;
+extern GLuint		g_location_rparams;
+
+//MD2
+extern void Mod_LoadMD2Model (model_t *mod, void *buffer);
+
+//Shared mesh items
+extern vec3_t	shadelight;
+extern vec3_t	shadevector;
+extern int		model_dlights_num;
+extern m_dlight_t model_dlights[128];
+extern image_t	*r_mirrortexture;
+extern cvar_t	*cl_gun;
+vec3_t lightPosition;
+float  dynFactor;
+extern void		R_GetLightVals(vec3_t origin, qboolean RagDoll, qboolean dynamic);
+extern void R_ModelViewTransform(const vec3_t in, vec3_t out);
+extern void GL_BlendFunction (GLenum sfactor, GLenum dfactor);
+
+//iqm
+#define pi 3.14159265
+extern float modelpitch;
+extern double degreeToRadian(double degree);
+extern qboolean Mod_INTERQUAKEMODEL_Load(model_t *mod, void *buffer);
+extern qboolean IQM_ReadSkinFile(char skin_file[MAX_OSPATH], char *skinpath);
+extern void R_DrawINTERQUAKEMODEL(void);
+extern void IQM_AnimateFrame(float curframe, int nextframe);
+extern qboolean IQM_InAnimGroup(int frame, int oldframe);
+extern int IQM_NextFrame(int frame);
+extern void IQM_AnimateRagdoll(int RagDollID);
+extern void IQM_DrawRagDollFrame(int RagDollID, int skinnum, float shellAlpha, int shellEffect);
+extern void IQM_DrawShadow(vec3_t origin);
+
+//Ragdoll
+int r_DrawingRagDoll;
+int r_SurfaceCount;
+
+#define TURBSCALE2 (256.0 / (2 * M_PI))
 
 // reduce runtime calcs
 #define TURBSCALE 40.743665431525205956834243423364
@@ -616,14 +693,14 @@ IMPLEMENTATION SPECIFIC FUNCTIONS
 ====================================================================
 */
 
-void		GLimp_BeginFrame( float camera_separation );
-void		GLimp_EndFrame( void );
-int 		GLimp_Init( void *hinstance, void *hWnd );
-void		GLimp_Shutdown( void );
-int     	GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen );
-void		GLimp_AppActivate( qboolean active );
-void		GLimp_EnableLogging( qboolean enable );
-void		GLimp_LogNewFrame( void );
+extern void		GLimp_BeginFrame( float camera_separation );
+extern void		GLimp_EndFrame( void );
+extern qboolean	GLimp_Init( void *hinstance, void *hWnd );
+extern void		GLimp_Shutdown( void );
+extern rserr_t    	GLimp_SetMode( unsigned *pwidth, unsigned *pheight, int mode, qboolean fullscreen );
+extern void		GLimp_AppActivate( qboolean active );
+extern void		GLimp_EnableLogging( qboolean enable );
+extern void		GLimp_LogNewFrame( void );
 
 /*
 ====================================================================
