@@ -117,6 +117,9 @@ typedef struct rs_stage_s
 	
 	qboolean				beam;			// for adding light beams
 	int						beamtype;		// the type of beam(up vs down)
+	float					xang;			// beam pitch
+	float					yang;			// beam roll
+	qboolean				rotating;		//rotating beams(moving spotlights, etc).
 	
 	qboolean				fx;				// for glsl effect layer
 	qboolean				glow;			// for glsl effect layer
@@ -130,12 +133,6 @@ typedef struct rs_stagekey_s
 	void (*func)(rs_stage_t *shader, char **token);
 } rs_stagekey_t;
 
-typedef struct
-{
-	qboolean enable;
-	int width;
-	int height;
-} rs_picsize_t;
 
 // Base script
 typedef struct rscript_s 
@@ -143,16 +140,6 @@ typedef struct rscript_s
 	char				name[MAX_OSPATH];	// name of script
 	unsigned int			hash_key;		// hash key for the script's name
 	
-	unsigned char			subdivide;	// Heffo - chop the surface up this much for vertex warping
-	float					warpdist;	// Heffo - vertex warping distance;
-	float					warpsmooth;	// Heffo - vertex warping smoothness;
-	float					warpspeed;	// Heffo - vertex warping speed;
-
-	qboolean				mirror;		// mirror
-	qboolean				model;		// model hack
-
-	rs_picsize_t			picsize;	//force pic size for hud etc
-
 	qboolean				dontflush;	// dont flush from memory on map change
 	qboolean				ready;		// readied by the engine?
 	rs_stage_t				*stage;		// first rendering stage
@@ -160,12 +147,6 @@ typedef struct rscript_s
 
 } rscript_t;
 
-typedef struct rs_scriptkey_s
-{
-	char *script;
-	void (*func)(rscript_t *rs, char **token);
-} rs_scriptkey_t;
-
 void RS_SetEnvmap (vec3_t v, float *os, float *ot);
 void RS_LoadScript(char *script);
 void RS_FreeAllScripts(void);
@@ -180,7 +161,7 @@ void RS_UpdateRegistration(void);
 void RS_DrawSurface (msurface_t *surf, qboolean lightmap);
 void RS_SetTexcoords (rs_stage_t *stage, float *os, float *ot, msurface_t *fa);
 void RS_SetTexcoords2D (rs_stage_t *stage, float *os, float *ot);
-void RS_SpecialSurface (msurface_t *surf);
+void RS_Surface (msurface_t *surf);
 void RS_LoadSpecialScripts(void);
 float RS_AlphaFuncAlias (int alphafunc, float alpha, vec3_t normal, vec3_t org);
 
