@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -16,7 +16,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 - 1307, USA.
 
-*/ 
+*/
 
 /*
 ==========================================================================================================================================
@@ -31,7 +31,12 @@ has to take place at least every time the primitive type changes (that's vertex
 ==========================================================================================================================================
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "r_local.h"
+#include "r_ragdoll.h"
 
 // this must be equal to MAX_VERTS as it's possible for a single MDL to be composed of only one triangle fan or strip.
 // the storage overhead is only in the order of 100K anyway, so it's no big deal.
@@ -42,8 +47,9 @@ float VArrayVerts[MAX_VARRAY_VERTS * MAX_VARRAY_VERTEX_SIZE];
 // pointer for dynamic vert allocation
 float *VArray = &VArrayVerts[0];
 
-// array for dynamic normal allocation
-static vec3_t NormalsArray[MAX_TRIANGLES*3];
+// arrays for normalmapping in glsl
+static vec3_t NormalsArray[MAX_VERTICES];
+// static vec4_t TangentsArray[MAX_VERTICES]; // unused
 
 // number of verts allocated
 static int VertexCounter = 0;
@@ -51,7 +57,6 @@ static int VertexCounter = 0;
 float	tex_array[MAX_ARRAY][2];
 float	vert_array[MAX_ARRAY][3];
 float	col_array[MAX_ARRAY][4];
-float	norm_array[MAX_ARRAY][3];
 
 // sizes of our vertexes.  the vertex type can be used as an index into this array
 int VertexSizes[] = {5, 5, 7, 7, 9, 11, 5, 3, 12, 5};
@@ -147,13 +152,13 @@ void R_InitVArrays (int varraytype)
 		// uses array indices 5, 6, 7, 8
 		qglEnableClientState (GL_COLOR_ARRAY);
 		qglColorPointer (4, GL_FLOAT, sizeof (float) * VertexSizes[VERT_BUMPMAPPED_COLOURED], &VArrayVerts[5]);
-		
+
 		KillFlags |= (KILL_TMU0_POINTER | KILL_TMU1_POINTER | KILL_RGBA_POINTER);
 
 		return;
 	}
 
-	// a standard 2 tmu multitexture needs 2 texcoord pointers.
+	// a standard 2 tmu multitexture needs 2 texcoord pointers. to do - for bsp surface VBO, we will have some changes here
 	if (varraytype == VERT_MULTI_TEXTURED)
 	{
 		// uses array indices 3, 4
@@ -239,7 +244,7 @@ void R_InitVArrays (int varraytype)
 
 		// normal data
 		qglEnableClientState( GL_NORMAL_ARRAY );
-		
+
 		KillFlags |= (KILL_TMU0_POINTER | KILL_TMU1_POINTER | KILL_TMU2_POINTER | KILL_NORMAL_POINTER);
 
 		return;
@@ -295,7 +300,7 @@ void R_KillVArrays (void)
 void R_AddSurfToVArray (msurface_t *surf)
 {
 	glpoly_t *p = surf->polys;
-	float	*v;	
+	float	*v;
 	int i;
 
 	for (; p; p = p->chain)
@@ -335,7 +340,7 @@ It's assumed that the programmer has set up the vertex arrays properly before ca
 void R_AddTexturedSurfToVArray (msurface_t *surf, float scroll)
 {
 	glpoly_t *p = surf->polys;
-	float	*v;	
+	float	*v;
 	int i;
 
 	for (; p; p = p->chain)
@@ -379,153 +384,80 @@ It's assumed that the programmer has set up the vertex arrays properly before ca
 void R_AddLightMappedSurfToVArray (msurface_t *surf, float scroll)
 {
 	glpoly_t *p = surf->polys;
-	float	*v;	
-	int i;
-
-	for (; p; p = p->chain)
-	{
-		// reset pointer and counter
-		VArray = &VArrayVerts[0];
-		VertexCounter = 0;
-
-		for (v = p->verts[0], i = 0 ; i < p->numverts; i++, v += VERTEXSIZE)
-		{
-			// copy in vertex data
-			VArray[0] = v[0];
-			VArray[1] = v[1];
-			VArray[2] = v[2];
-
-			// world texture coords
-			VArray[3] = v[3] + scroll;
-			VArray[4] = v[4];
-
-			// lightmap texture coords
-			VArray[5] = v[5];
-			VArray[6] = v[6];
-
-			// nothing else is needed
-			// increment pointer and counter
-			VArray += VertexSizes[VERT_MULTI_TEXTURED];
-			VertexCounter++;
-		}
-
-		// draw the poly
-		qglDrawArrays (GL_POLYGON, 0, VertexCounter);
-
-		/*
-		 * Mapping tool. Outline the light-mapped polygons.
-		 *  gl_showpolys == 1 : perform depth test.
-		 *  gl_showpolys == 2 : disable depth test. everything in "visible set"
-		 */
-		if (gl_showpolys->value) // restricted cvar, maxclients = 1
-		{
-			qglDisable (GL_TEXTURE_2D);
-			if (gl_showpolys->value > 1.9f)
-			{ // lots of lines so make them narrower
-				qglDisable(GL_DEPTH_TEST);
-				qglLineWidth (2.0f);
-			}
-			else
-			{ // less busy, wider line
-				qglLineWidth (3.0f);
-			}
-			qglColor4f (1.0f, 1.0f, 1.0f, 1.0f);
-			qglBegin (GL_LINE_LOOP);
-			for (v = p->verts[0], i = 0; i < p->numverts; i++, v += VERTEXSIZE) {
-				qglVertex3fv(p->verts[i]);
-			}
-			qglEnd();
-			qglEnable (GL_DEPTH_TEST);
-			qglEnable (GL_TEXTURE_2D);
-		}
-
-	}
-}
-
-void R_AddGLSLShadedSurfToVArray (msurface_t *surf, float scroll)
-{
-	glpoly_t *p = surf->polys;
-	vec3_t	lightVec, lightAdd, temp;
-	float	dist, weight;
-	int		numlights;
-	float	*v;	
-	int		i, j;
-
-	//send these to the shader program
-	glUniformMatrix3fvARB( g_tangentSpaceTransform,	1, GL_FALSE, surf->tangentSpaceTransform );
-	glUniform3fARB( g_location_eyePos, r_origin[0], r_origin[1], r_origin[2] );
-	glUniform1iARB( g_location_fog, map_fog);
-
-	//get light position relative to player's position
-	numlights = 0;
-	VectorClear(lightAdd);
-	for (i = 0; i < r_lightgroups; i++) {	
-		VectorSubtract(r_origin, LightGroups[i].group_origin, temp);
-		dist = VectorLength(temp);
-		if(dist == 0) 
-			dist = 1;
-		dist = dist*dist;
-		weight = (int)250000/(dist/(LightGroups[i].avg_intensity+1.0f));
-		for(j = 0; j < 3; j++) 
-			lightAdd[j] += LightGroups[i].group_origin[j]*weight;
-		numlights+=weight;				
-	}
-
-	if(numlights > 0.0) {
-		for(i = 0; i < 3; i++) 
-			lightVec[i] = (lightAdd[i]/numlights + r_origin[i])/2.0;
-	}
-
-	glUniform3fARB( g_location_staticLightPosition, lightVec[0], lightVec[1], lightVec[2]);
-
-	for (; p; p = p->chain)
-	{
-		// reset pointer and counter
-		VArray = &VArrayVerts[0];
-		VertexCounter = 0;	
-
-		for (v = p->verts[0], i = 0 ; i < p->numverts; i++, v += VERTEXSIZE)
-		{
-			// copy in vertex data
-			VArray[0] = v[0];
-			VArray[1] = v[1];
-			VArray[2] = v[2];
-
-			// world texture coords
-			VArray[3] = v[3] + scroll;
-			VArray[4] = v[4];
-
-			// lightmap texture coords
-			VArray[5] = v[5];
-			VArray[6] = v[6];
+	float	*v;
+	int		i;
 	
-			// nothing else is needed
-			// increment pointer and counter
-			VArray += VertexSizes[VERT_MULTI_TEXTURED];
-			VertexCounter++;
-		}	
-		// draw the poly
-		qglDrawArrays (GL_POLYGON, 0, VertexCounter);
+	// reset pointer and counter
+	VArray = &VArrayVerts[0];
+	VertexCounter = 0;
+
+	//non warped surfaces only have one poly
+	for (v = p->verts[0], i = 0 ; i < p->numverts; i++, v += VERTEXSIZE)
+	{
+		// copy in vertex data
+		VArray[0] = v[0];
+		VArray[1] = v[1];
+		VArray[2] = v[2];
+
+		// world texture coords
+		VArray[3] = v[3] + scroll;
+		VArray[4] = v[4];
+
+		// lightmap texture coords
+		VArray[5] = v[5];
+		VArray[6] = v[6];
+
+		// nothing else is needed
+		// increment pointer and counter
+		VArray += VertexSizes[VERT_MULTI_TEXTURED];
+		VertexCounter++;
 	}
+
+	/*
+	 * Mapping tool. Outline the light-mapped polygons.
+	 *  gl_showpolys == 1 : perform depth test.
+	 *  gl_showpolys == 2 : disable depth test. everything in "visible set"
+	 */
+	if (gl_showpolys->value) // restricted cvar, maxclients = 1
+	{
+		qglDisable (GL_TEXTURE_2D);
+		if (gl_showpolys->value > 1.9f)
+		{ // lots of lines so make them narrower
+			qglDisable(GL_DEPTH_TEST);
+			qglLineWidth (2.0f);
+		}
+		else
+		{ // less busy, wider line
+			qglLineWidth (3.0f);
+		}
+		qglColor4f (1.0f, 1.0f, 1.0f, 1.0f);
+		qglBegin (GL_LINE_LOOP);
+		for (v = p->verts[0], i = 0; i < p->numverts; i++, v += VERTEXSIZE) {
+			qglVertex3fv(p->verts[i]);
+		}
+		qglEnd();
+		qglEnable (GL_DEPTH_TEST);
+		qglEnable (GL_TEXTURE_2D);
+	}
+	
+	// draw the polys
+	qglDrawArrays (GL_POLYGON, 0, VertexCounter);
 }
 
 void R_AddGLSLShadedWarpSurfToVArray (msurface_t *surf, float scroll)
 {
 	glpoly_t *p = surf->polys;
-	float	*v;	
+	float	*v;
 	int		i;
 
 	for (; p; p = p->chain)
 	{
-		vec3_t	tangent, lightPos;
-
 		// reset pointer and counter
 		VArray = &VArrayVerts[0];
 		VertexCounter = 0;
 
 		for (v = p->verts[0], i = 0 ; i < p->numverts; i++, v += VERTEXSIZE)
 		{
-
 			// copy in vertex data
 			VArray[0] = v[0];
 			VArray[1] = v[1];
@@ -541,26 +473,13 @@ void R_AddGLSLShadedWarpSurfToVArray (msurface_t *surf, float scroll)
 			// increment pointer and counter
 			VArray += VertexSizes[VERT_NORMAL_COLOURED_TEXTURED];
 			VertexCounter++;
-		}
-
-		qglNormalPointer(GL_FLOAT, 0, NormalsArray);
-
-		AngleVectors(surf->plane->normal, NULL, tangent, NULL);
-
-		//send these to the shader program
-		glUniform3fARB( g_location_tangent, tangent[0], tangent[1], tangent[2]);
-
-		for(i=0; i<3; i++) 
-			lightPos[i] = r_origin[i];
-		lightPos[2] += 512;
-
-		glUniform3fARB( g_location_lightPos, lightPos[0], lightPos[1], lightPos[2]);
-		glUniform1iARB( g_location_fogamount, map_fog);
-		glUniform1fARB( g_location_time, rs_realtime);
-	
-		// draw the poly
-		qglDrawArrays (GL_POLYGON, 0, VertexCounter);
+		}				
 	}
+
+	qglNormalPointer(GL_FLOAT, 0, NormalsArray);
+
+	// draw the polys
+	qglDrawArrays (GL_POLYGON, 0, VertexCounter);
 }
 
 
@@ -576,7 +495,7 @@ void R_InitQuadVarrays(void) {
 	qglEnableClientState (GL_VERTEX_ARRAY);
 	qglEnableClientState (GL_TEXTURE_COORD_ARRAY);
 
-	qglTexCoordPointer (2, GL_FLOAT, sizeof(tex_array[0]), tex_array[0]); 
+	qglTexCoordPointer (2, GL_FLOAT, sizeof(tex_array[0]), tex_array[0]);
 	qglVertexPointer (3, GL_FLOAT, sizeof(vert_array[0]), vert_array[0]);
 	qglColorPointer (4, GL_FLOAT, sizeof(col_array[0]), col_array[0]);
 
