@@ -1,5 +1,6 @@
 /*
 Copyright (C) 1997-2001 Id Software, Inc.
+Copyright (C) 2011 COR Entertainment, LLC.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -8,7 +9,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -19,6 +20,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 // r_warp.c -- sky and water polygons
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "r_local.h"
 
 extern	model_t	*loadmodel;
@@ -153,14 +158,14 @@ void SubdividePolygon (int numverts, float *verts)
 
 /*
 ================
-GL_SubdivideSurface
+R_SubdivideSurface
 
 Breaks a polygon up along axial 64 unit
 boundaries so that turbulent and sky warps
 can be done reasonably.
 ================
 */
-void GL_SubdivideSurface (msurface_t *fa)
+void R_SubdivideSurface (msurface_t *fa)
 {
 	vec3_t		verts[64];
 	int			numverts;
@@ -208,9 +213,7 @@ EmitWaterPolys
 Does a water warp on the pre-fragmented glpoly_t chain
 =============
 */
-
-extern int KillFlags;
-void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY)
+void R_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY)
 {
 	glpoly_t	*p;
 	float		*v;
@@ -218,23 +221,16 @@ void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY
 	float		s, t, os, ot;
 	float		scroll;
 	float		rdt = r_newrefdef.time;
-	vec3_t		nv;  
-	qboolean	fod;
+	vec3_t		nv, tangent;
 
 	if (fa->texinfo->flags & SURF_FLOWING)
 		scroll = -64.0f * ((r_newrefdef.time * 0.5f) - (int)(r_newrefdef.time * 0.5f));
 	else
 		scroll = 0.0f;
-	
-	//special case - note one day we should find a way to check for contents such as mist to do this.
-	if(!Q_stricmp(fa->texinfo->image->name, "textures/arena6/fodblue.wal") || !Q_stricmp(fa->texinfo->image->name, "textures/arena5/fod.wal"))
-		fod = true;
-	else
-		fod = false;
+	  
+	if(gl_state.glsl_shaders && gl_glsl_shaders->value
+		&& strcmp(fa->texinfo->normalMap->name, fa->texinfo->image->name)) {
 
-	if(!fod && gl_state.glsl_shaders && gl_glsl_shaders->value  
-			&& strcmp(fa->texinfo->normalMap->name, fa->texinfo->image->name)) {
-		
 		if (SurfaceIsAlphaBlended(fa))
 			qglEnable( GL_ALPHA_TEST );
 
@@ -243,15 +239,16 @@ void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY
 		glUseProgramObjectARB( g_waterprogramObj );
 
 		GL_EnableMultitexture( true );
-    	
-		qglActiveTextureARB(GL_TEXTURE1);
-		qglBindTexture (GL_TEXTURE_2D, fa->texinfo->image->texnum);
-		glUniform1iARB( g_location_baseTexture, 1); 
-		KillFlags |= KILL_TMU1_POINTER;
 
-		glUniform1iARB( g_location_normTexture, 2);
+		qglActiveTextureARB(GL_TEXTURE0);
+		qglBindTexture (GL_TEXTURE_2D, fa->texinfo->image->texnum);
+		glUniform1iARB( g_location_baseTexture, 0);
+		KillFlags |= KILL_TMU0_POINTER;
+
+		//note - moving this to tmu2 fixed a very odd, obsure bug.  It isn't clear yet why it fixes it, but it does
 		qglActiveTextureARB(GL_TEXTURE2);
 		qglBindTexture(GL_TEXTURE_2D, fa->texinfo->normalMap->texnum);
+		glUniform1iARB( g_location_normTexture, 2);
 		KillFlags |= KILL_TMU2_POINTER;
 
 		if(fa->texinfo->flags &(SURF_TRANS33|SURF_TRANS66))
@@ -259,15 +256,25 @@ void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY
 		else
 			glUniform1iARB( g_location_trans, 0);
 
-		if(texnum) {
+		if(texnum)
+		{
 			qglActiveTextureARB(GL_TEXTURE3);
 			qglBindTexture(GL_TEXTURE_2D, texnum);
-			glUniform1iARB( g_location_refTexture, 3); 
+			glUniform1iARB( g_location_refTexture, 3);
+			KillFlags |= KILL_TMU3_POINTER;
 			glUniform1iARB( g_location_reflect, 1);
 		}
 		else
 			glUniform1iARB( g_location_reflect, 0);
 			
+		AngleVectors(fa->plane->normal, NULL, tangent, NULL);
+
+		//send these to the shader program	
+		glUniform3fARB( g_location_tangent, tangent[0], tangent[1], tangent[2]);
+		glUniform3fARB( g_location_lightPos, r_worldLightVec[0], r_worldLightVec[1], r_worldLightVec[2]);
+		glUniform1iARB( g_location_fogamount, map_fog);
+		glUniform1fARB( g_location_time, rs_realtime);
+
 		R_AddGLSLShadedWarpSurfToVArray (fa, scroll);
 
 		glUseProgramObjectARB( 0 );
@@ -279,11 +286,11 @@ void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY
 		if (SurfaceIsAlphaBlended(fa))
 			qglDisable( GL_ALPHA_TEST);
 
-		GL_MBind(GL_TEXTURE0, fa->texinfo->image->texnum);
+		return;
 	}
 	else {
 
-		if (gl_state.fragment_program && !fod)
+		if (gl_state.fragment_program && strcmp(fa->texinfo->normalMap->name, fa->texinfo->image->name))
 		{
 			qglEnable(GL_FRAGMENT_PROGRAM_ARB);
 			qglBindProgramARB(GL_FRAGMENT_PROGRAM_ARB, g_water_program_id);
@@ -293,10 +300,10 @@ void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY
 				rs_realtime * -0.2f, 10.0f, 1.0f, 1.0f);
 			qglProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 2,
 				(fa->polys[0].verts[0][3]-r_newrefdef.vieworg[0]), (fa->polys[0].verts[0][4]-r_newrefdef.vieworg[1]), (fa->polys[0].verts[0][4]-r_newrefdef.vieworg[2]), 1.0f);
-			
-			GL_MBind(GL_TEXTURE1, r_distort->texnum); 
+
+			GL_MBind(GL_TEXTURE1, r_distort->texnum);
 		}
-		
+
 		GL_MBind(GL_TEXTURE0, fa->texinfo->image->texnum);
 
 		for (p=fa->polys ; p ; p=p->next)
@@ -307,25 +314,19 @@ void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY
 				os = v[3];
 				ot = v[4];
 
-	#if !id386
 				s = os + r_turbsin[(int)((ot*0.125+r_newrefdef.time) * TURBSCALE) & 255];
-	#else
-				s = os + r_turbsin[Q_ftol( ((ot*0.125+rdt) * TURBSCALE) ) & 255];
-	#endif
+
 				s += scroll;
 				s *= (1.0/64);
 
-	#if !id386
 				t = ot + r_turbsin[(int)((os*0.125+rdt) * TURBSCALE) & 255];
-	#else
-				t = ot + r_turbsin[Q_ftol( ((os*0.125+rdt) * TURBSCALE) ) & 255];
-	#endif
+
 				t *= (1.0/64);
 
-				if (gl_state.fragment_program && !fod)
+				if (gl_state.fragment_program)
 				{
-					qglMTexCoord2fSGIS(GL_TEXTURE0, s, t);
-					qglMTexCoord2fSGIS(GL_TEXTURE1, 20*s, 20*t);
+					qglMTexCoord2fARB(GL_TEXTURE0, s, t);
+					qglMTexCoord2fARB(GL_TEXTURE1, 20*s, 20*t);
 				}
 				else
 					qglTexCoord2f (s, t);
@@ -333,19 +334,13 @@ void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY
 				if (!(fa->texinfo->flags & SURF_FLOWING))
 
 				{
-
 					nv[0] =v[0];
 					nv[1] =v[1];
 
-					#if !id386
 					nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+r_newrefdef.time)*sin(v[2]*0.05+r_newrefdef.time)
 
 							+ r_wave->value *sin(v[1]*0.025+r_newrefdef.time*2)*sin(v[2]*0.05+r_newrefdef.time);
-					#else
-					nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+rdt)*sin(v[2]*0.05+r_newrefdef.time)
 
-							+ r_wave->value *sin(v[1]*0.025+rdt*2)*sin(v[2]*0.05+rdt);
-					#endif
 					qglVertex3fv (nv);
 				}
 				else
@@ -354,19 +349,16 @@ void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY
 			qglEnd ();
 		}
 
-		if (gl_state.fragment_program && !fod)
+		if (gl_state.fragment_program)
 			qglDisable(GL_FRAGMENT_PROGRAM_ARB);
 	}
 
-	if(fod || (gl_state.glsl_shaders && gl_glsl_shaders->value))
-		return;
-
 	//env map if specified by shader
 	if(texnum)
 		GL_Bind(texnum);
-	else 
+	else
 		return;
-		
+
 	for (p=fa->polys ; p ; p=p->next)
 	{
 		qglBegin (GL_TRIANGLE_FAN);
@@ -377,19 +369,14 @@ void GL_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY
 
 			if(texnum)
 				qglTexCoord2f(1.0/512*scaleX*os, 1.0/512*scaleY*ot);
-				
+
 			if (!(fa->texinfo->flags & SURF_FLOWING))
 			{
 				nv[0] =v[0];
 				nv[1] =v[1];
 
-				#if !id386
 				nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+r_newrefdef.time)*sin(v[2]*0.05+r_newrefdef.time)
 						+ r_wave->value *sin(v[1]*0.025+r_newrefdef.time*2)*sin(v[2]*0.05+r_newrefdef.time);
-				#else
-				nv[2] =v[2] + r_wave->value *sin(v[0]*0.025+rdt)*sin(v[2]*0.05+r_newrefdef.time)
-						+ r_wave->value *sin(v[1]*0.025+rdt*2)*sin(v[2]*0.05+rdt);
-				#endif
 
 				qglVertex3fv (nv);
 			}
@@ -406,7 +393,7 @@ vec3_t	skyclip[6] = {
 	{0,-1,1},
 	{0,1,1},
 	{1,0,1},
-	{-1,0,1} 
+	{-1,0,1}
 };
 
 // 1 = s, 2 = t, 3 = 2048
@@ -653,9 +640,9 @@ void MakeSkyVec (float s, float t, int axis, float *tex_s, float *tex_t, float *
 	vec3_t		v, b;
 	int			j, k;
 
-	b[0] = s * size; 
-	b[1] = t * size; 
-	b[2] = size;  
+	b[0] = s * size;
+	b[1] = t * size;
+	b[2] = size;
 
 	for (j=0 ; j<3 ; j++)
 	{
@@ -691,7 +678,6 @@ void MakeSkyVec (float s, float t, int axis, float *tex_s, float *tex_t, float *
 R_DrawSkyBox
 ==============
 */
-extern  void GL_BlendFunction (GLenum sfactor, GLenum dfactor);
 int	skytexorder[6] = {0,2,1,3,4,5};
 void R_DrawSkyBox (void)
 {
@@ -765,10 +751,10 @@ void R_DrawSkyBox (void)
 		{
 			rs=(rscript_t *)sky_images[skytexorder[i]]->script;
 
-			if(rs) {	
-				
+			if(rs) {
+
 				stage=rs->stage;
-				while (stage) 
+				while (stage)
 				{
 					qglDepthMask( GL_FALSE );	 	// no z buffering
 					qglEnable( GL_BLEND);
@@ -777,42 +763,42 @@ void R_DrawSkyBox (void)
 
 					GL_Bind (stage->texture->texnum);
 
-					if (stage->blendfunc.blend) 
+					if (stage->blendfunc.blend)
 					{
 						GL_BlendFunction(stage->blendfunc.source,stage->blendfunc.dest);
 						GLSTATE_ENABLE_BLEND
-					} 
-					else 
+					}
+					else
 					{
 						GLSTATE_DISABLE_BLEND
 					}
 
-					if (stage->alphashift.min || stage->alphashift.speed) 
+					if (stage->alphashift.min || stage->alphashift.speed)
 					{
 						alpha=0.0f;
 
-						if (!stage->alphashift.speed && stage->alphashift.min > 0) 
+						if (!stage->alphashift.speed && stage->alphashift.min > 0)
 						{
 							alpha=stage->alphashift.min;
-						} 
-						else if (stage->alphashift.speed) 
+						}
+						else if (stage->alphashift.speed)
 						{
 							alpha=sin(rs_realtime * stage->alphashift.speed);
 							alpha=(alpha+1)*0.5f;
 							if (alpha > stage->alphashift.max) alpha=stage->alphashift.max;
 							if (alpha < stage->alphashift.min) alpha=stage->alphashift.min;
 						}
-					} 
+					}
 					else
 						alpha=1.0f;
 
 					qglColor4f(1,1,1,alpha);
 
-					if (stage->alphamask) 
+					if (stage->alphamask)
 					{
 						GLSTATE_ENABLE_ALPHATEST
-					} 
-					else 
+					}
+					else
 					{
 						GLSTATE_DISABLE_ALPHATEST
 					}
@@ -845,10 +831,10 @@ void R_DrawSkyBox (void)
 					qglVertex3fv (point);
 
 					qglEnd();
-		
+
 					stage=stage->next;
 				}
-			}		
+			}
 		}
 		// restore the original blend mode
 		GLSTATE_DISABLE_ALPHATEST
@@ -884,10 +870,7 @@ void R_SetSky (char *name, float rotate, vec3_t axis)
 		if (gl_skymip->value || skyrotate)
 			gl_picmip->value++;
 
-		if ( qglColorTableEXT && gl_ext_palettedtexture->value )
-			Com_sprintf (pathname, sizeof(pathname), "env/%s%s.pcx", skyname, suf[i]);
-		else
-			Com_sprintf (pathname, sizeof(pathname), "env/%s%s.tga", skyname, suf[i]);
+		Com_sprintf (pathname, sizeof(pathname), "env/%s%s.tga", skyname, suf[i]);
 
 		sky_images[i] = GL_FindImage (pathname, it_sky);
 		if (!sky_images[i])
@@ -899,7 +882,7 @@ void R_SetSky (char *name, float rotate, vec3_t axis)
 				sky_images[i]->script = RS_FindScript(pathname);
 				if(sky_images[i]->script)
 					RS_ReadyScript(sky_images[i]->script);
-			} 
+			}
 		}
 
 		if (strstr(pathname, "space")) {
@@ -925,7 +908,7 @@ void R_SetSky (char *name, float rotate, vec3_t axis)
 			sky_min = 1.0/256;
 			sky_max = 255.0/256;
 		}
-		else	
+		else
 		{
 			sky_min = 1.0/512;
 			sky_max = 511.0/512;
