@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -18,8 +18,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "server.h"
 
+static size_t szr; // just for quieting unused result warnings
 
 /*
 ===============================================================================
@@ -81,6 +86,9 @@ qboolean SV_SetPlayer (void)
 	if (Cmd_Argc() < 2)
 		return false;
 
+	if ( svs.clients == NULL )
+		return false; // unlikely, but possible, to call here before initialized
+
 	s = Cmd_Argv(1);
 
 	// numeric values are just slot numbers
@@ -152,7 +160,7 @@ void SV_Map_f (void)
 		Com_sprintf (expanded, sizeof(expanded), "maps/%s.bsp", map);
 		if (FS_LoadFile (expanded, NULL) == -1)
 		{
-			Com_Printf ("Can't find %s\n", expanded);
+			Com_Printf ("Cannot find %s\n", expanded);
 			return;
 		}
 	}
@@ -175,7 +183,7 @@ void SV_StartMap_f (void)
 		Com_sprintf (expanded, sizeof(expanded), "maps/%s.bsp", map);
 		if (FS_LoadFile (expanded, NULL) == -1)
 		{
-			Com_Printf ("Can't find %s\n", expanded);
+			Com_Printf ("Cannot find %s\n", expanded);
 			return;
 		}
 	}
@@ -228,10 +236,12 @@ SV_Status_f
 */
 void SV_Status_f (void)
 {
-	int			i, j, l;
+	int		i, j, k , l;
 	client_t	*cl;
 	char		*s;
-	int			ping;
+	int		ping;
+	qboolean	expectColor;
+
 	if (!svs.clients)
 	{
 		Com_Printf ("No server running.\n");
@@ -259,7 +269,24 @@ void SV_Status_f (void)
 		}
 
 		Com_Printf ("%s", cl->name);
-		l = 16 - strlen(cl->name);
+		l = strlen( cl->name );
+		expectColor = false;
+		for ( j = k = 0 ; j < l ; j ++ ) {
+			if ( expectColor ) {
+				if ( cl->name[ j ] == '^' ) {
+					k ++;
+				}
+				expectColor = false;
+			} else if ( cl->name[ j ] == '^' ) {
+				expectColor = true;
+			} else {
+				k ++;
+			}
+		}
+		if ( expectColor ) {
+			k ++;
+		}
+		l = 16 - k;
 		for (j=0 ; j<l ; j++)
 			Com_Printf (" ");
 
@@ -270,7 +297,7 @@ void SV_Status_f (void)
 		l = 22 - strlen(s);
 		for (j=0 ; j<l ; j++)
 			Com_Printf (" ");
-		
+
 		Com_Printf ("%5i", cl->netchan.qport);
 
 		Com_Printf ("\n");
@@ -418,7 +445,7 @@ void SV_ServerRecord_f (void)
 	//
 	// write a single giant fake message with all the startup info
 	//
-	SZ_Init (&buf, buf_data, sizeof(buf_data));
+	SZ_Init (&buf, (byte *)buf_data, (int)(sizeof(buf_data)));
 	SZ_SetName (&buf, "Giant fake msg buffer", true);
 
 	//
@@ -447,8 +474,8 @@ void SV_ServerRecord_f (void)
 	// write it to the demo file
 	Com_DPrintf ("signon message length: %i\n", buf.cursize);
 	len = LittleLong (buf.cursize);
-	fwrite (&len, 4, 1, svs.demofile);
-	fwrite (buf.data, buf.cursize, 1, svs.demofile);
+	szr = fwrite (&len, 4, 1, svs.demofile);
+	szr = fwrite (buf.data, buf.cursize, 1, svs.demofile);
 
 	// the rest of the demo file will be individual frames
 }
