@@ -18,6 +18,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "server.h"
 
 master_sv_t	master_status[MAX_MASTERS];	// status of master servers
@@ -59,6 +63,8 @@ cvar_t	*sv_iplimit;
 
 cvar_t	*sv_downloadurl;
 
+cvar_t	*sv_iplogfile;		// Log file by IP address
+
 int		sv_numbots;
 
 void Master_Shutdown (void);
@@ -68,6 +74,34 @@ short   ShortSwap (short l);
 //============================================================================
 
 
+/*
+=====================
+SV_LogEvent
+
+Logs an event to the IP log.
+=====================
+*/
+static void SV_LogEvent( netadr_t address , const char * event , const char * name )
+{
+	FILE * file;
+
+	if ( !( sv_iplogfile && sv_iplogfile->string[0] ) )
+		return;
+
+
+	file = fopen( sv_iplogfile->string , "a" );
+	if ( !file ) {
+		Com_DPrintf( "Failed to write to IP log file '%s'\n" , sv_iplogfile->string );
+		return;
+	}
+	fprintf( file , "%s\t%s\t%d\t%s\r\n" , NET_AdrToString(address) , event ,
+			( name != NULL ) , ( name != NULL ) ? name : "" );
+	fclose( file );
+}
+
+
+
+
 /*
 =====================
 SV_DropClient
@@ -96,6 +130,7 @@ void SV_DropClient (client_t *drop)
 		drop->download = NULL;
 	}
 
+	SV_LogEvent( drop->netchan.remote_address , "DCN" , drop->name );
 	drop->state = cs_zombie;		// become free in a few seconds
 	drop->name[0] = 0;
 }
@@ -141,46 +176,7 @@ char	*SV_StatusString (void)
 		cl = &svs.clients[i];
 		if (cl->state == cs_connected || cl->state == cs_spawned )
 		{
-			name = cl->name; 
-#ifdef NOTUSED
-			//handle color chars
-			nametxt[0] = 0;
-			k = 0;
-			while(j = *name) {
-				if ( Q_IsColorString( name ) ) {
-					name +=2;
-					continue;
-				}
-				nametxt[k] = j;
-				name++;
-				k++;
-				//failsafe - break at 32 chars
-				if(k>30)
-					break;
-			}
-			nametxt[k]=0;
-#else		
-			//allow color chars to be sent
-			strcpy(nametxt, name);
-			nametxt[31] = '\0'; //failsafe
-#endif
-			//s = NET_AdrToString ( cl->netchan.remote_address); //fuck you Luigi
-			Com_sprintf (player, sizeof(player), "%i %i \"%s\" \"127.0.0.1\"\n",
-				cl->edict->client->ps.stats[STAT_FRAGS], cl->ping, nametxt);
-			playerLength = strlen(player);
-			if (statusLength + playerLength >= sizeof(status) )
-				break;		// can't hold any more
-			strcpy (status + statusLength, player);
-			statusLength += playerLength;
-
-		}
-	}
-	//bot score info
-	cl = &svs.clients[0]; //get the bots info from the first client
-	if(cl->edict->client->ps.botnum) {
-		for(i = 0; i < cl->edict->client->ps.botnum; i++) {
-
-			name = cl->edict->client->ps.bots[i].name; 
+			name = cl->name;
 #ifdef NOTUSED
 			//handle color chars
 			nametxt[0] = 0;
@@ -200,20 +196,63 @@ char	*SV_StatusString (void)
 			nametxt[k]=0;
 #else
 			//allow color chars to be sent
-			strcpy(nametxt, name);
-			nametxt[31] = '\0'; //failsafe
+			Q_strncpyz2( nametxt, name, sizeof(nametxt) );
 #endif
-
+			//s = NET_AdrToString ( cl->netchan.remote_address); //fuck you Luigi
 			Com_sprintf (player, sizeof(player), "%i %i \"%s\" \"127.0.0.1\"\n",
-				cl->edict->client->ps.bots[i].score, 0, nametxt);
+				cl->edict->client->ps.stats[STAT_FRAGS], cl->ping, nametxt);
 			playerLength = strlen(player);
 			if (statusLength + playerLength >= sizeof(status) )
 				break;		// can't hold any more
 			strcpy (status + statusLength, player);
 			statusLength += playerLength;
+
+		}
+	}
+	//bot score info
+	for (i=0 ; i<maxclients->value ; i++)
+	{
+		cl = &svs.clients[i];
+
+		if(cl->edict->client->ps.botnum) {
+			for(i = 0; i < cl->edict->client->ps.botnum; i++) {
+
+				name = cl->edict->client->ps.bots[i].name;
+#ifdef NOTUSED
+				//handle color chars
+				nametxt[0] = 0;
+				k = 0;
+				while(j = *name) {
+					if ( Q_IsColorString( name ) ) {
+						name +=2;
+						continue;
+					}
+					nametxt[k] = j;
+					name++;
+					k++;
+					//failsafe - break at 32 chars
+					if(k>30)
+						break;
+				}
+				nametxt[k]=0;
+#else
+				//allow color chars to be sent
+				Q_strncpyz2( nametxt, name, sizeof(nametxt) );
+#endif
+
+				Com_sprintf (player, sizeof(player), "%i %i \"%s\" \"127.0.0.1\"\n",
+					cl->edict->client->ps.bots[i].score, 0, nametxt);
+				playerLength = strlen(player);
+				if (statusLength + playerLength >= sizeof(status) )
+					break;		// can't hold any more
+				strcpy (status + statusLength, player);
+				statusLength += playerLength;
+			}
+			break;
 		}
 	}
 	//end bot score info
+	
 	return status;
 }
 
@@ -340,13 +379,20 @@ void SVC_Info (void)
 		for (i=0 ; i<maxclients->value ; i++)
 			if (svs.clients[i].state >= cs_connected)
 				count++;
+
 		//bot score info
-		cl = &svs.clients[0];
-		if(cl->edict->client->ps.botnum > 0)
-			count += cl->edict->client->ps.botnum; //add the bots
+		for (i=0 ; i<maxclients->value ; i++)
+		{
+			cl = &svs.clients[i];
+			if(cl->edict->client->ps.botnum > 0)
+			{
+				count += cl->edict->client->ps.botnum; //add the bots
+				break;
+			}
+		}
 		//end bot score info
 
-		Com_sprintf (string, sizeof(string), "%16s %8s %2i/%2i\n", hostname->string, sv.name, count, (int)maxclients->value);
+		Com_sprintf (string, sizeof(string), "%16s %8s %2i/%2i\n", hostname->string, sv.name, count, maxclients->integer);
 	}
 
 	Netchan_OutOfBandPrint (NS_SERVER, net_from, "info\n%s", string);
@@ -448,8 +494,9 @@ void SVC_DirectConnect (void)
 	version = atoi(Cmd_Argv(1));
 	if (version != PROTOCOL_VERSION)
 	{
-		Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nServer is version %4.2f.\n", VERSION);
+		Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nServer is version %s\n", VERSION);
 		Com_DPrintf ("    rejected connect from version %i\n", version);
+		SV_LogEvent( adr , "RVR" , NULL );
 		return;
 	}
 
@@ -461,7 +508,7 @@ void SVC_DirectConnect (void)
 
 	//limit connections from a single IP
 	previousclients = 0;
-	for (i=0,cl=svs.clients ; i<maxclients->integer ; i++,cl++)
+	for (i=0,cl=svs.clients ; i<maxclients->value ; i++,cl++)
 	{
 		if (cl->state == cs_free)
 			continue;
@@ -479,6 +526,7 @@ void SVC_DirectConnect (void)
 	{
 		Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nToo many connections from your host.\n");
 		Com_DPrintf ("    too many connections\n");
+		SV_LogEvent( adr , "R00" , NULL );
 		return;
 	}
 
@@ -491,12 +539,14 @@ void SVC_DirectConnect (void)
 	{
 		Com_DPrintf ("    userinfo length exceeded\n");
 		Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nUserinfo string length exceeded.\n");
+		SV_LogEvent( adr , "R01" , NULL );
 		return;
 	}
 	else if (!userinfo[0])
 	{
 		Com_DPrintf ("    empty userinfo string\n");
 		Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nBad userinfo string.\n");
+		SV_LogEvent( adr , "R02" , NULL );
 		return;
 	}
 
@@ -509,6 +559,7 @@ void SVC_DirectConnect (void)
 		if (ptr < userinfo)
 			ptr = userinfo;
 		Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nConnection refused due to attempted exploit!\n");
+		SV_LogEvent( adr , "R03" , NULL );
 		return;
 	}
 	if (Info_KeyExists (userinfo, "ip"))
@@ -516,6 +567,7 @@ void SVC_DirectConnect (void)
 		char	*p;
 		p = Info_ValueForKey(userinfo, "ip");
 		Com_Printf ("EXPLOIT: Client %s attempted to spoof IP address: %s\n", Info_ValueForKey (userinfo, "name"), NET_AdrToString(adr));
+		SV_LogEvent( adr , "R04" , NULL );
 		return;
 	}
 
@@ -529,6 +581,7 @@ void SVC_DirectConnect (void)
 		{
 			Com_Printf ("Remote connect in attract loop.  Ignored.\n");
 			Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nConnection refused.\n");
+			SV_LogEvent( adr , "R05" , NULL );
 			return;
 		}
 	}
@@ -543,12 +596,14 @@ void SVC_DirectConnect (void)
 				if (challenge == svs.challenges[i].challenge)
 					break;		// good
 				Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nBad challenge.\n");
+				SV_LogEvent( adr , "R06" , NULL );
 				return;
 			}
 		}
 		if (i == MAX_CHALLENGES)
 		{
 			Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nNo challenge for address.\n");
+			SV_LogEvent( adr , "R07" , NULL );
 			return;
 		}
 	}
@@ -571,15 +626,18 @@ void SVC_DirectConnect (void)
 			{
 				Com_DPrintf ("    client already found\n");
 				Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nPlayer '%s' is already connected from %s.\n", cl->name, NET_AdrToString(adr));
+				SV_LogEvent( adr , "R08" , cl->name );
 				return;
 			}
 
 			if (!NET_IsLocalAddress (adr) && (svs.realtime - cl->lastconnect) < ((int)sv_reconnect_limit->integer * 1000))
 			{
 				Com_DPrintf ("%s:reconnect rejected : too soon\n", NET_AdrToString (adr));
+				SV_LogEvent( adr , "R09" , NULL );
 				return;
 			}
 			Com_Printf ("%s:reconnect\n", NET_AdrToString (adr));
+			SV_LogEvent( adr , "RCN" , NULL );
 
 			newcl = cl;
 			goto gotnewcl;
@@ -587,8 +645,16 @@ void SVC_DirectConnect (void)
 	}
 
 	// find a client slot
-	cl = &svs.clients[0]; //get the active bots info from the first client
-	botnum = cl->edict->client->ps.botnum;
+
+	//get number of bots
+	for (i=0 ; i<maxclients->value ; i++)
+	{
+		cl = &svs.clients[i]; 
+		botnum = cl->edict->client->ps.botnum;
+		if(botnum > 0)
+			break;
+	}
+
 	//still need to reserve one slot
 	newcl = NULL;
 
@@ -597,7 +663,7 @@ void SVC_DirectConnect (void)
 
 	//prevent client slot overwrites with bots rejoining after map change
 	if(botkick) {
-		
+
 		if(botkick < sv_numbots)
 			botnum = botkick;
 		else
@@ -616,10 +682,13 @@ void SVC_DirectConnect (void)
 	{
 		Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nServer is full.\n");
 		Com_DPrintf ("Rejected a connection.\n");
+		SV_LogEvent( adr , "R10" , NULL );
 		return;
 	}
+	SV_LogEvent( adr , "NCN" , NULL );
 
 gotnewcl:
+
 	// build a new connection
 	// accept the new client
 	// this is the only place a client_t is ever initialized
@@ -640,13 +709,15 @@ gotnewcl:
 				Info_ValueForKey (userinfo, "rejmsg"));
 		else
 			Netchan_OutOfBandPrint (NS_SERVER, adr, "print\nConnection refused.\n" );
+		SV_LogEvent( adr , "GRJ" , NULL );
 		Com_DPrintf ("Game rejected a connection.\n");
 		return;
 	}
 
 	// parse some info from the info strings
-	strncpy (newcl->userinfo, userinfo, sizeof(newcl->userinfo)-1);
+	Q_strncpyz2( newcl->userinfo, userinfo, sizeof(newcl->userinfo) );
 	SV_UserinfoChanged (newcl);
+	SV_LogEvent( adr , "UUS" , newcl->name );
 
 	// send the connect packet to the client
 	Netchan_OutOfBandPrint(NS_SERVER, adr, "client_connect %s", sv_downloadurl->string);
@@ -1255,7 +1326,7 @@ void SV_UserinfoChanged (client_t *cl)
 	ge->ClientUserinfoChanged (cl->edict, cl->userinfo, 0);
 
 	// name for C code
-	strncpy (cl->name, Info_ValueForKey (cl->userinfo, "name"), sizeof(cl->name)-1);
+	Q_strncpyz2( cl->name, Info_ValueForKey (cl->userinfo, "name"), sizeof(cl->name) );
 	// mask off high bit
 	for (i=0 ; i<sizeof(cl->name) ; i++)
 		cl->name[i] &= 127;
@@ -1301,7 +1372,7 @@ void SV_Init (void)
 	Cvar_Get ("skill", "1", 0);
 	Cvar_Get ("deathmatch", "1", CVAR_LATCH); //Alien Arena is *always* deathmatch
 	Cvar_Get ("ctf", "0", CVAR_LATCH);
-	Cvar_Get ("dmflags", va("%i", DF_INSTANT_ITEMS), CVAR_SERVERINFO);
+	Cvar_Get ("dmflags", va("%i", DF_INSTANT_ITEMS+DF_BOT_LEVELAD), CVAR_SERVERINFO);
 	Cvar_Get ("fraglimit", "0", CVAR_SERVERINFO);
 	Cvar_Get ("timelimit", "0", CVAR_SERVERINFO);
 	Cvar_Get ("cheats", "0", CVAR_SERVERINFO|CVAR_LATCH);
@@ -1321,6 +1392,8 @@ void SV_Init (void)
 	allow_download_maps	  = Cvar_Get ("allow_download_maps", "1", CVAR_ARCHIVE);
 	sv_downloadurl = Cvar_Get("sv_downloadurl", "http://icculus.org/alienarena/sv_downloadurl", CVAR_SERVERINFO);
 
+	sv_iplogfile = Cvar_Get("sv_iplogfile" , "" , CVAR_ARCHIVE);
+
 	sv_noreload = Cvar_Get ("sv_noreload", "0", 0);
 
 	sv_airaccelerate = Cvar_Get("sv_airaccelerate", "0", CVAR_LATCH);
