@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -17,53 +17,64 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
-/*
-** GLW_IMP.C
-**
-** This file contains ALL Linux specific stuff having to do with the
-** OpenGL refresh.  When a port is being made the following functions
-** must be implemented by the port:
-**
-** GLimp_EndFrame
-** GLimp_Init
-** GLimp_Shutdown
-**
-*/
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <termios.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
-#ifdef __linux__
-#include <sys/vt.h>
-#endif
 #include <stdarg.h>
 #include <stdio.h>
+#if defined HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <signal.h>
+#if defined HAVE_DLFCN_H
 #include <dlfcn.h>
+#endif
 
-#include "../ref_gl/r_local.h"
-
-#include "../client/keys.h"
-
-#include "../unix/glw_unix.h"
+#include "qcommon/qcommon.h"
+#include "ref_gl/r_local.h"
+#include "client/keys.h"
+#include "unix/glw_unix.h"
 
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <X11/keysym.h>
 #include <X11/cursorfont.h>
-
-#ifdef HAVE_X11_EXTENSIONS_XXF86DGA_H
-#include <X11/extensions/Xxf86dga.h>
-#else
-// default to obsolete header
-#include <X11/extensions/xf86dga.h>
-#endif
+#if defined HAVE_XXF86VM
 #include <X11/extensions/xf86vmode.h>
+#endif // defined HAVE_XXF86VM
+#if defined HAVE_XXF86DGA
+# if defined HAVE_X11_EXTENSIONS_XXF86DGA_H
+#include <X11/extensions/Xxf86dga.h>
+# else // defined HAVE_X11_EXTENSIONS_XXF86DGA_H
+#include <X11/extensions/xf86dga.h>
+# endif // defined HAVE_X11_EXTENSIONS_XXF86DGA_H
+#endif
 
 #include <GL/glx.h>
 
+/* extern globals */
+// using include files for these has some problems
 extern cursor_t cursor;
+extern float rs_realtime;
+extern viddef_t vid;
+
+void		GLimp_BeginFrame( float camera_separation );
+void		GLimp_EndFrame( void );
+qboolean	GLimp_Init( void *hinstance, void *hWnd );
+void		GLimp_Shutdown( void );
+rserr_t    	GLimp_SetMode( unsigned *pwidth, unsigned *pheight, int mode, qboolean fullscreen );
+void		GLimp_AppActivate( qboolean active );
+void		GLimp_EnableLogging( qboolean enable );
+void		GLimp_LogNewFrame( void );
+
+
+//---------------------------------------------------------------------------
+
 
 glwstate_t glw_state;
 
@@ -92,8 +103,9 @@ static cvar_t	*r_fakeFullscreen;
 extern cvar_t	*in_dgamouse;
 static int win_x, win_y;
 
+#if defined HAVE_XXF86VM
 static XF86VidModeModeInfo **vidmodes;
-static int num_vidmodes;
+#endif // defined HAVE_XXF86VM
 static qboolean vidmode_active = false;
 
 qboolean mouse_active = false;
@@ -102,7 +114,7 @@ qboolean vidmode_ext = false;
 
 static Cursor CreateNullCursor(Display *display, Window root)
 {
-    Pixmap cursormask; 
+    Pixmap cursormask;
     XGCValues xgc;
     GC gc;
     XColor dummycolour;
@@ -124,6 +136,19 @@ static Cursor CreateNullCursor(Display *display, Window root)
 
 void install_grabs(void)
 {
+
+#if defined DEBUG_GDB_NOGRAB
+// for running on gdb debug. prevents "lockup".
+	Cvar_Set( "in_dgamouse", "0" );
+	dgamouse = false;
+	mouse_active = true;
+#else // defined DEBUG_GDB_NOGRAB
+# if !defined HAVE_XXF86DGA
+	XGrabPointer(dpy, win, True, 0, GrabModeAsync, GrabModeAsync, win, None, CurrentTime);
+	XWarpPointer(dpy, None, win, 0, 0, 0, 0, vid.width / 2, vid.height / 2);
+	Cvar_Set( "in_dgamouse", "0" );
+	dgamouse = false;
+# else // !defined HAVE_XXF86DGA
 	XGrabPointer(dpy, win, True, 0, GrabModeAsync, GrabModeAsync, win, None, CurrentTime);
 
 	if (in_dgamouse->integer)
@@ -135,19 +160,21 @@ void install_grabs(void)
 			XF86DGADirectVideo(dpy, DefaultScreen(dpy), XF86DGADirectMouse);
 			dgamouse = true;
 		} else {
-			// unable to query, probalby not supported
+			// unable to query, probably not supported
 			Com_Printf ( "Failed to detect XF86DGA Mouse\n" );
 			Cvar_Set( "in_dgamouse", "0" );
 			dgamouse = false;
+			XWarpPointer(dpy, None, win, 0, 0, 0, 0, vid.width / 2, vid.height / 2);
 		}
 	} else {
 		XWarpPointer(dpy, None, win, 0, 0, 0, 0, vid.width / 2, vid.height / 2);
 	}
+# endif // !defined HAVE_XXF86DGA
 
 	XGrabKeyboard(dpy, win, False, GrabModeAsync, GrabModeAsync, CurrentTime);
 
 	mouse_active = true;
-
+#endif // defined DEBUG_GDB_NOGRAB
 }
 
 void uninstall_grabs(void)
@@ -155,10 +182,12 @@ void uninstall_grabs(void)
 	if (!dpy || !win)
 		return;
 
+#if defined HAVE_XXF86DGA
 	if (dgamouse) {
 		dgamouse = false;
 		XF86DGADirectVideo(dpy, DefaultScreen(dpy), 0);
 	}
+#endif
 
 	XUngrabPointer(dpy, CurrentTime);
 	XUngrabKeyboard(dpy, CurrentTime);
@@ -166,7 +195,7 @@ void uninstall_grabs(void)
 	mouse_active = false;
 }
 
-static void IN_DeactivateMouse( void ) 
+static void IN_DeactivateMouse( void )
 {
 	if (!dpy || !win)
 		return;
@@ -177,7 +206,7 @@ static void IN_DeactivateMouse( void )
 	}
 }
 
-static void IN_ActivateMouse( void ) 
+static void IN_ActivateMouse( void )
 {
 	if (!dpy || !win)
 		return;
@@ -201,242 +230,445 @@ void IN_Activate(qboolean active)
 /* KEYBOARD                                                                  */
 /*****************************************************************************/
 
-static int XLateKey(XKeyEvent *ev)
+static int XLateKey( XKeyEvent *ev )
 {
 
 	int key;
 	char buf[64];
+	int buflen;
 	KeySym keysym;
 
 	key = 0;
+	buflen = XLookupString( ev, buf, sizeof buf, &keysym, 0 );
 
-	XLookupString(ev, buf, sizeof buf, &keysym, 0);
-
-	switch(keysym)
+	switch ( keysym )
 	{
-		case XK_KP_Page_Up:	 key = K_KP_PGUP; break;
-		case XK_Page_Up:	 key = K_PGUP; break;
 
-		case XK_KP_Page_Down: key = K_KP_PGDN; break;
-		case XK_Page_Down:	 key = K_PGDN; break;
+	case XK_KP_Page_Up:
+		key = K_KP_PGUP;
+		break;
 
-		case XK_KP_Home: key = K_KP_HOME; break;
-		case XK_Home:	 key = K_HOME; break;
+	case XK_Page_Up:
+		key = K_PGUP;
+		break;
 
-		case XK_KP_End:  key = K_KP_END; break;
-		case XK_End:	 key = K_END; break;
+	case XK_KP_Page_Down:
+		key = K_KP_PGDN;
+		break;
 
-		case XK_KP_Left: key = K_KP_LEFTARROW; break;
-		case XK_Left:	 key = K_LEFTARROW; break;
+	case XK_Page_Down:
+		key = K_PGDN;
+		break;
 
-		case XK_KP_Right: key = K_KP_RIGHTARROW; break;
-		case XK_Right:	key = K_RIGHTARROW;		break;
+	case XK_KP_Home:
+		key = K_KP_HOME;
+		break;
 
-		case XK_KP_Down: key = K_KP_DOWNARROW; break;
-		case XK_Down:	 key = K_DOWNARROW; break;
+	case XK_Home:
+		key = K_HOME;
+		break;
 
-		case XK_KP_Up:   key = K_KP_UPARROW; break;
-		case XK_Up:		 key = K_UPARROW;	 break;
+	case XK_KP_End:
+		key = K_KP_END;
+		break;
 
-		case XK_Escape: key = K_ESCAPE;		break;
+	case XK_End:
+		key = K_END;
+		break;
 
-		case XK_KP_Enter: key = K_KP_ENTER;	break;
-		case XK_Return: key = K_ENTER;		 break;
+	case XK_KP_Left:
+		key = K_KP_LEFTARROW;
+		break;
 
-		case XK_Tab:		key = K_TAB;			 break;
+	case XK_Left:
+		key = K_LEFTARROW;
+		break;
 
-		case XK_F1:		 key = K_F1;				break;
+	case XK_KP_Right:
+		key = K_KP_RIGHTARROW;
+		break;
 
-		case XK_F2:		 key = K_F2;				break;
+	case XK_Right:
+		key = K_RIGHTARROW;
+		break;
 
-		case XK_F3:		 key = K_F3;				break;
+	case XK_KP_Down:
+		key = K_KP_DOWNARROW;
+		break;
 
-		case XK_F4:		 key = K_F4;				break;
+	case XK_Down:
+		key = K_DOWNARROW;
+		break;
 
-		case XK_F5:		 key = K_F5;				break;
+	case XK_KP_Up:
+		key = K_KP_UPARROW;
+		break;
 
-		case XK_F6:		 key = K_F6;				break;
+	case XK_Up:
+		key = K_UPARROW;
+		break;
 
-		case XK_F7:		 key = K_F7;				break;
+	case XK_Escape:
+		key = K_ESCAPE;
+		break;
 
-		case XK_F8:		 key = K_F8;				break;
+	case XK_KP_Enter:
+		key = K_KP_ENTER;
+		break;
 
-		case XK_F9:		 key = K_F9;				break;
+	case XK_Return:
+		key = K_ENTER;
+		break;
 
-		case XK_F10:		key = K_F10;			 break;
+	case XK_Tab:
+		key = K_TAB;
+		break;
 
-		case XK_F11:		key = K_F11;			 break;
+	case XK_F1:
+		key = K_F1;
+		break;
 
-		case XK_F12:		key = K_F12;			 break;
+	case XK_F2:
+		key = K_F2;
+		break;
 
-		case XK_BackSpace: key = K_BACKSPACE; break;
+	case XK_F3:
+		key = K_F3;
+		break;
 
-		case XK_KP_Delete: key = K_KP_DEL; break;
-		case XK_Delete: key = K_DEL; break;
+	case XK_F4:
+		key = K_F4;
+		break;
 
-		case XK_Pause:	key = K_PAUSE;		 break;
+	case XK_F5:
+		key = K_F5;
+		break;
 
-		case XK_Shift_L:
-		case XK_Shift_R:	key = K_SHIFT;		break;
+	case XK_F6:
+		key = K_F6;
+		break;
 
-		case XK_Execute: 
-		case XK_Control_L: 
-		case XK_Control_R:	key = K_CTRL;		 break;
+	case XK_F7:
+		key = K_F7;
+		break;
 
-		case XK_Alt_L:	
-		case XK_Meta_L: 
-		case XK_Alt_R:	
-		case XK_Meta_R: key = K_ALT;			break;
+	case XK_F8:
+		key = K_F8;
+		break;
 
-		case XK_KP_Begin: key = K_KP_5;	break;
+	case XK_F9:
+		key = K_F9;
+		break;
 
-		case XK_Insert:key = K_INS; break;
-		case XK_KP_Insert: key = K_KP_INS; break;
+	case XK_F10:
+		key = K_F10;
+		break;
 
-		case XK_KP_Multiply: key = '*'; break;
-		case XK_KP_Add:  key = K_KP_PLUS; break;
-		case XK_KP_Subtract: key = K_KP_MINUS; break;
-		case XK_KP_Divide: key = K_KP_SLASH; break;
+	case XK_F11:
+		key = K_F11;
+		break;
 
-		default:
+	case XK_F12:
+		key = K_F12;
+		break;
+
+	case XK_BackSpace:
+		key = K_BACKSPACE;
+		break;
+
+	case XK_KP_Delete:
+		key = K_KP_DEL;
+		break;
+
+	case XK_Delete:
+		key = K_DEL;
+		break;
+
+	case XK_Pause:
+		key = K_PAUSE;
+		break;
+
+	case XK_Shift_L:
+	case XK_Shift_R:
+		key = K_SHIFT;
+		break;
+
+	case XK_Execute:
+	case XK_Control_L:
+	case XK_Control_R:
+		key = K_CTRL;
+		break;
+
+	case XK_Alt_L:
+	case XK_Meta_L:
+	case XK_Alt_R:
+	case XK_Meta_R:
+		key = K_ALT;
+		break;
+
+	case XK_KP_Begin:
+		key = K_KP_5;
+		break;
+
+	case XK_Insert:
+		key = K_INS;
+		break;
+
+	case XK_KP_Insert:
+		key = K_KP_INS;
+		break;
+
+	case XK_KP_Multiply:
+		key = '*';
+		break;
+
+	case XK_KP_Add:
+		key = K_KP_PLUS;
+		break;
+
+	case XK_KP_Subtract:
+		key = K_KP_MINUS;
+		break;
+
+	case XK_KP_Divide:
+		key = K_KP_SLASH;
+		break;
+
+	default:
+		if ( buflen == 1 )
+		{
 			key = *(unsigned char*)buf;
-			if (key >= 'A' && key <= 'Z')
+
+			if ( key >= 'A' && key <= 'Z' )
 				key = key - 'A' + 'a';
-			if (key >= 1 && key <= 26) /* ctrl+alpha */
+
+			if ( key >= 1 && key <= 26 ) /* ctrl+alpha */
 				key = key + 'a' - 1;
-			break;
-	} 
+		}
+		break;
+	}
 
 	return key;
 }
 
-
-void HandleEvents(void)
+void HandleEvents( void )
 {
 	XEvent event;
 	qboolean dowarp = false;
-	int mwx = vid.width/2;
-	int mwy = vid.height/2;
+	int mwx = vid.width / 2;
+	int mwy = vid.height / 2;
 	int multiclicktime = 750;
 	int mouse_button;
-	
-	if (!dpy)
+
+	float f_sys_msecs;
+	unsigned u_sys_msecs;
+
+	if ( !dpy )
 		return;
 
-	while (XPending(dpy)) {
+	// do one read of time for consistency
+	// theory is that all pending events occurring before this point in time
+	// should be considered occurring at this single point in time.
+	u_sys_msecs = (unsigned)Sys_Milliseconds();
+	f_sys_msecs = (float)u_sys_msecs;
 
-		XNextEvent(dpy, &event);
-		
-		if(event.xbutton.button == 2)
-			mouse_button = 2;
-		else if(event.xbutton.button == 3)
-			mouse_button = 1;
-		else
-			mouse_button = event.xbutton.button - 1;
+	while ( XPending( dpy ) )
+	{
+		XNextEvent( dpy, &event );
+
+		// TODO: check for errors here, maybe
+
+		switch ( event.type )
+		{
 
-		switch(event.type) {
 		case KeyPress:
+			Key_Event( XLateKey( &event.xkey ), true, u_sys_msecs );
+			break;
+
 		case KeyRelease:
-			Key_Event (XLateKey(&event.xkey), event.type == KeyPress, Sys_Milliseconds());
+			Key_Event( XLateKey( &event.xkey ), false, u_sys_msecs );
 			break;
 
 		case MotionNotify:
-			if (mouse_active) {
-				if (dgamouse) {
+			if ( mouse_active )
+			{
+				if ( dgamouse )
+				{ // TODO: find documentation for DGA mouse, explain this
 					mx += (event.xmotion.x + (vidmode_active ? 0 : win_x)) * 2;
 					my += (event.xmotion.y + (vidmode_active ? 0 : win_y)) * 2;
-				} 
-				else 
-				{
+				}
+				else
+				{ // add the delta from the current position to the center
+					//  to the pointer motion accumulator
 					mx += ((int)event.xmotion.x - mwx);
 					my += ((int)event.xmotion.y - mwy);
 
-					if (mx || my)
-						dowarp = true;
+					// flag to recenter pointer
+					dowarp = (mx != 0 || my != 0 );
 				}
 			}
 			else
-			{
-				// allow mouse movement on menus in windowed mode
+			{ // allow mouse movement on menus in windowed mode
 				mx = event.xmotion.x;
 				my = event.xmotion.y;
 			}
 			break;
 
-
 		case ButtonPress:
-			
-			if (event.xbutton.button) {
-				if (Sys_Milliseconds()-cursor.buttontime[mouse_button] < multiclicktime)
+			if ( event.xbutton.button )
+			{
+				mouse_button = event.xbutton.button - 1;
+				switch ( mouse_button )
+				{ // index swap, buttons 2 & 3
+				case 1:
+					mouse_button = 2;
+					break;
+				case 2:
+					mouse_button = 1;
+					break;
+				}
+
+				if ( (f_sys_msecs - cursor.buttontime[mouse_button])
+						< multiclicktime )
 					cursor.buttonclicks[mouse_button] += 1;
 				else
 					cursor.buttonclicks[mouse_button] = 1;
 
-				if (cursor.buttonclicks[mouse_button]>3)
+				if ( cursor.buttonclicks[mouse_button] > 3 )
 					cursor.buttonclicks[mouse_button] = 3;
 
-				cursor.buttontime[mouse_button] = Sys_Milliseconds();
+				cursor.buttontime[mouse_button] = f_sys_msecs;
 
 				cursor.buttondown[mouse_button] = true;
 				cursor.buttonused[mouse_button] = false;
 				cursor.mouseaction = true;
+
+				switch ( event.xbutton.button )
+				{
+				case 1:
+					Key_Event( K_MOUSE1, true, u_sys_msecs );
+					break;
+				case 2:
+					Key_Event( K_MOUSE3, true, u_sys_msecs );
+					break;
+				case 3:
+					Key_Event( K_MOUSE2, true, u_sys_msecs );
+					break;
+				case 4:
+					Key_Event( K_MWHEELUP, true, u_sys_msecs );
+					break;
+				case 5:
+					Key_Event( K_MWHEELDOWN, true, u_sys_msecs );
+					break;
+				case 6:
+					Key_Event( K_MOUSE4, true, u_sys_msecs );
+					break;
+				case 7:
+					Key_Event( K_MOUSE5, true, u_sys_msecs );
+					break;
+				case 8:
+					Key_Event( K_MOUSE6, true, u_sys_msecs );
+					break;
+				case 9:
+					Key_Event( K_MOUSE7, true, u_sys_msecs );
+					break;
+				case 10:
+					Key_Event( K_MOUSE8, true, u_sys_msecs );
+					break;
+				case 11:
+					Key_Event( K_MOUSE9, true, u_sys_msecs );
+					break;
+				}
 			}
-			
-			if (event.xbutton.button == 1) Key_Event(K_MOUSE1, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 2) Key_Event(K_MOUSE3, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 3) Key_Event(K_MOUSE2, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 4) Key_Event(K_MWHEELUP, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 5) Key_Event(K_MWHEELDOWN, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 6) Key_Event(K_MOUSE4, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 7) Key_Event(K_MOUSE5, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 8) Key_Event(K_MOUSE6, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 9) Key_Event(K_MOUSE7, event.type == ButtonPress, Sys_Milliseconds());
 			break;
-			
+
 		case ButtonRelease:
-			if (event.xbutton.button) {
+			if ( event.xbutton.button )
+			{
+				mouse_button = event.xbutton.button - 1;
+				switch ( mouse_button )
+				{ // index swap, buttons 2 & 3
+				case 1:
+					mouse_button = 2;
+					break;
+				case 2:
+					mouse_button = 1;
+					break;
+				}
+
 				cursor.buttondown[mouse_button] = false;
 				cursor.buttonused[mouse_button] = false;
 				cursor.mouseaction = true;
+
+				switch ( event.xbutton.button )
+				{
+				case 1:
+					Key_Event( K_MOUSE1, false, u_sys_msecs );
+					break;
+				case 2:
+					Key_Event( K_MOUSE3, false, u_sys_msecs );
+					break;
+				case 3:
+					Key_Event( K_MOUSE2, false, u_sys_msecs );
+					break;
+				case 4:
+					Key_Event( K_MWHEELUP, false, u_sys_msecs );
+					break;
+				case 5:
+					Key_Event( K_MWHEELDOWN, false, u_sys_msecs );
+					break;
+				case 6:
+					Key_Event( K_MOUSE4, false, u_sys_msecs );
+					break;
+				case 7:
+					Key_Event( K_MOUSE5, false, u_sys_msecs );
+					break;
+				case 8:
+					Key_Event( K_MOUSE6, false, u_sys_msecs );
+					break;
+				case 9:
+					Key_Event( K_MOUSE7, false, u_sys_msecs );
+					break;
+				case 10:
+					Key_Event( K_MOUSE8, false, u_sys_msecs );
+					break;
+				case 11:
+					Key_Event( K_MOUSE9, false, u_sys_msecs );
+					break;
+				}
 			}
-			if (event.xbutton.button == 1) Key_Event(K_MOUSE1, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 2) Key_Event(K_MOUSE3, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 3) Key_Event(K_MOUSE2, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 4) Key_Event(K_MWHEELUP, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 5) Key_Event(K_MWHEELDOWN, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 6) Key_Event(K_MOUSE4, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 7) Key_Event(K_MOUSE5, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 8) Key_Event(K_MOUSE6, event.type == ButtonPress, Sys_Milliseconds());
-			else if (event.xbutton.button == 9) Key_Event(K_MOUSE7, event.type == ButtonPress, Sys_Milliseconds());
 			break;
 
-		case CreateNotify :
+		case CreateNotify:
 			win_x = event.xcreatewindow.x;
 			win_y = event.xcreatewindow.y;
 			break;
 
-		case ConfigureNotify :
+		case ConfigureNotify:
 			win_x = event.xconfigure.x;
 			win_y = event.xconfigure.y;
 			break;
 
 		case ClientMessage:
-			if (event.xclient.data.l[0] == wmDeleteWindow)
-				Cbuf_ExecuteText(EXEC_NOW, "quit");
+			if ( event.xclient.data.l[0] == wmDeleteWindow )
+				Cbuf_ExecuteText( EXEC_NOW, "quit" );
 			break;
 		}
 	}
-		  
-	if (dowarp) {
-		/* move the mouse to the window center again */
-		XWarpPointer(dpy,None,win,0,0,0,0, vid.width/2,vid.height/2);
+
+	if ( dowarp )
+	{ /* move the pointer back to the window center */
+		XWarpPointer( dpy, None, win, 0, 0, 0, 0, mwx, mwy );
 	}
+
 }
 
 /*****************************************************************************/
 
 qboolean GLimp_InitGL (void);
 
+// TODO: modernize signal handler
+
 static void signal_handler(int sig)
 {
 	printf("Received signal %d, exiting...\n", sig);
@@ -460,17 +692,17 @@ static void InitSig(void)
 /*
 ** GLimp_SetMode
 */
-int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
+rserr_t GLimp_SetMode( unsigned *pwidth, unsigned *pheight, int mode, qboolean fullscreen )
 {
 	int width, height;
 	int attrib[] = {
-		GLX_RGBA, 
-		GLX_DOUBLEBUFFER, 
-		GLX_RED_SIZE, 4, 
-		GLX_GREEN_SIZE, 4, 
-		GLX_BLUE_SIZE, 4, 
-		GLX_DEPTH_SIZE, 24, 
-		GLX_STENCIL_SIZE, 8, 
+		GLX_RGBA,
+		GLX_DOUBLEBUFFER,
+		GLX_RED_SIZE, 4,
+		GLX_GREEN_SIZE, 4,
+		GLX_BLUE_SIZE, 4,
+		GLX_DEPTH_SIZE, 24,
+		GLX_STENCIL_SIZE, 8,
 		None
 	};
 	int attrib2[] = { //no stencil buffer, original settings
@@ -488,9 +720,11 @@ int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
 	XSetWindowAttributes attr;
 	XSizeHints *sizehints;
 	unsigned long mask;
+#if defined HAVE_XXF86VM
 	int MajorVersion, MinorVersion;
 	int actualWidth, actualHeight;
 	int i;
+#endif
 
 	r_fakeFullscreen = Cvar_Get( "r_fakeFullscreen", "0", CVAR_ARCHIVE);
 
@@ -521,14 +755,18 @@ int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
 	root = RootWindow(dpy, scrnum);
 
 	// Get video mode list
+#if defined HAVE_XXF86VM
 	MajorVersion = MinorVersion = 0;
-	if (!XF86VidModeQueryVersion(dpy, &MajorVersion, &MinorVersion)) { 
+	if (!XF86VidModeQueryVersion(dpy, &MajorVersion, &MinorVersion)) {
 		vidmode_ext = false;
 	} else {
 		Com_Printf ( "Using XFree86-VidModeExtension Version %d.%d\n",
 			MajorVersion, MinorVersion);
 		vidmode_ext = true;
 	}
+#else // defined HAVE_XXF86VM
+	vidmode_ext = false;
+#endif // defined HAVE_XXF86VM
 
 	visinfo = qglXChooseVisual(dpy, scrnum, attrib);
 	if (!visinfo) {
@@ -543,9 +781,10 @@ int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
 		have_stencil = true;
 
 	vidmode_active = false;
+#if defined HAVE_XXF86VM
 	if (vidmode_ext) {
-		int best_fit, best_dist, dist, x, y;
-		
+		int best_fit, best_dist, dist, x, y, num_vidmodes;
+
 		XF86VidModeGetAllModeLines(dpy, scrnum, &num_vidmodes, &vidmodes);
 
 		// Are we going fullscreen?  If so, let's change video mode
@@ -581,6 +820,7 @@ int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
 				fullscreen = 0;
 		}
 	}
+#endif // defined HAVE_XXF86VM
 
 	/* window attributes */
 	attr.background_pixel = 0;
@@ -588,7 +828,7 @@ int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
 	attr.colormap = XCreateColormap(dpy, root, visinfo->visual, AllocNone);
 	attr.event_mask = X_MASK;
 	if (vidmode_active) {
-		mask = CWBackPixel | CWColormap | CWSaveUnder | CWBackingStore | 
+		mask = CWBackPixel | CWColormap | CWSaveUnder | CWBackingStore |
 			CWEventMask | CWOverrideRedirect;
 		attr.override_redirect = True;
 		attr.backing_store = NotUseful;
@@ -608,7 +848,7 @@ int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
 		sizehints->max_height = height;
 		sizehints->base_width = width;
 		sizehints->base_height = vid.height;
-		
+
 		sizehints->flags = PMinSize | PMaxSize | PBaseSize;
 	}
 
@@ -627,6 +867,7 @@ int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
 
 	XMapWindow(dpy, win);
 
+#if defined HAVE_XXF86VM
 	if (vidmode_active) {
 		XMoveWindow(dpy, win, 0, 0);
 		XRaiseWindow(dpy, win);
@@ -635,6 +876,7 @@ int GLimp_SetMode( int *pwidth, int *pheight, int mode, qboolean fullscreen )
 		// Move the viewport to top left
 		XF86VidModeSetViewPort(dpy, scrnum, 0, 0);
 	}
+#endif // defined HAVE_XXF86VM
 
 	XFlush(dpy);
 
@@ -677,8 +919,10 @@ void GLimp_Shutdown( void )
 			qglXDestroyContext(dpy, ctx);
 		if (win)
 			XDestroyWindow(dpy, win);
+#if defined HAVE_XXF86VM
 		if (vidmode_active)
 			XF86VidModeSwitchToMode(dpy, scrnum, vidmodes[0]);
+#endif // defined HAVE_XXF86VM
 		XUngrabKeyboard(dpy, CurrentTime);
 		XCloseDisplay(dpy);
 	}
@@ -691,9 +935,9 @@ void GLimp_Shutdown( void )
 ** GLimp_Init
 **
 ** This routine is responsible for initializing the OS specific portions
-** of OpenGL.  
+** of OpenGL.
 */
-int GLimp_Init( void *hinstance, void *wndproc )
+qboolean GLimp_Init( void *hinstance, void *wndproc )
 {
 	InitSig();
 
@@ -709,7 +953,7 @@ void GLimp_BeginFrame( float camera_seperation )
 
 /*
 ** GLimp_EndFrame
-** 
+**
 ** Responsible for doing a swapbuffers and possibly for other stuff
 ** as yet to be determined.  Probably better not to make this a GLimp
 ** function and instead do a call to GLimp_SwapBuffers.
@@ -719,7 +963,7 @@ void GLimp_EndFrame (void)
 	qglXSwapBuffers(dpy, win); // does glFlush()
 
 	// rscript - MrG
-	rs_realtime=Sys_Milliseconds() * 0.0005f;
+	rs_realtime = (float)Sys_Milliseconds() * 0.0005f;
 }
 
 /*
@@ -746,7 +990,6 @@ void Fake_glColorTableEXT( GLenum target, GLenum internalformat,
 	qgl3DfxSetPaletteEXT((GLuint *)temptable);
 }
 
-
 /*------------------------------------------------*/
 /* X11 Input Stuff				  */
 /*------------------------------------------------*/
@@ -806,6 +1049,6 @@ char *Sys_GetClipboardData(void)
 
 	XDeleteProperty(dpy, win, cor_clipboard);
 
-	return output;
+	return (char*)output;
 }
 
