@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -17,7 +17,12 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
-#include "../client/client.h"
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "client/client.h"
 
 extern int mx, my;
 extern qboolean mouse_active;
@@ -31,13 +36,14 @@ cvar_t	*m_filter;
 cvar_t	*in_mouse;
 cvar_t	*in_dgamouse;
 cvar_t	*in_joystick;
+cvar_t	*m_accel;
 
-void IN_MLookDown (void) 
-{ 
+void IN_MLookDown (void)
+{
 	mlooking = true;
 }
 
-void IN_MLookUp (void) 
+void IN_MLookUp (void)
 {
 	mlooking = false;
 	if (!freelook->integer && lookspring->integer)
@@ -56,8 +62,8 @@ void IN_Init(void)
 	Cmd_AddCommand ("+mlook", IN_MLookDown);
 	Cmd_AddCommand ("-mlook", IN_MLookUp);
 
-	mx = my = 0.0;  
-	mouse_avail = true;	
+	mx = my = 0.0;
+	mouse_avail = true;
 
 	// Knightmare- added Psychospaz's menu mouse support
 	refreshCursorMenu();
@@ -94,13 +100,19 @@ IN_Move
 */
 void IN_Move (usercmd_t *cmd)
 {
+	float fmx;
+	float fmy;
+
 	if (!mouse_avail)
 		return;
 
+	fmx = (float)mx;
+	fmy = (float)my;
+
 	if (m_filter->integer)
 	{
-		mx = (mx + old_mouse_x) * 0.5;
-		my = (my + old_mouse_y) * 0.5;
+		fmx = (fmx + (float)old_mouse_x) * 0.5f;
+		fmy = (fmy + (float)old_mouse_y) * 0.5f;
 	}
 
 	old_mouse_x = mx;
@@ -114,14 +126,14 @@ void IN_Move (usercmd_t *cmd)
 
 		if ( mouse_active )
 		{
-			cursor.x += mx * .25;//sensitivity->value/10;
-			cursor.y += my * .25;//sensitivity->value/10;
+			cursor.x += (int)((fmx * menu_sensitivity->value/10) + 0.5f);
+			cursor.y += (int)((fmy * menu_sensitivity->value/10) + 0.5f);
 			mx = my = 0;
 		}
 		else
 		{
-			cursor.x = mx;
-			cursor.y = my;
+			cursor.x = (int)(fmx + 0.5f);
+			cursor.y = (int)(fmy + 0.5f);
 		}
 
 		if (cursor.x!=cursor.oldx || cursor.y!=cursor.oldy)
@@ -148,26 +160,26 @@ void IN_Move (usercmd_t *cmd)
 			float adjustment;
 			extern cvar_t* cl_maxfps;
 			adjustment = sensitivity->value / (cls.frametime * cl_maxfps->value);
-			mx *= adjustment;
-			my *= adjustment;
+			fmx *= adjustment;
+			fmy *= adjustment;
 		}
 		else
 		{
-			mx *= sensitivity->value;
-			my *= sensitivity->value;
+			fmx *= sensitivity->value;
+			fmy *= sensitivity->value;
 		}
 
 		// add mouse X/Y movement to cmd
 		if ((in_strafe.state & 1) || (lookstrafe->integer && mlooking))
-			cmd->sidemove += m_side->value * mx;
+			cmd->sidemove += (short)((m_side->value * fmx) + 0.5f);
 		else
-			cl.viewangles[YAW] -= m_yaw->value * mx;
+			cl.viewangles[YAW] -= m_yaw->value * fmx;
 
 		//if ((mlooking || freelook->integer) && !(in_strafe.state & 1))
 		if ((mlooking || freelook->value) && !(in_strafe.state & 1))
-			cl.viewangles[PITCH] += m_pitch->value * my;
+			cl.viewangles[PITCH] += m_pitch->value * fmy;
 		else
-			cmd->forwardmove -= m_forward->value * my;
+			cmd->forwardmove -= (short)((m_forward->value * fmy) + 0.5f);
 
 		mx = my = 0;
 	}
