@@ -17,13 +17,19 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#if defined HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <signal.h>
 #include <stdlib.h>
 #include <limits.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#include <unistd.h>
 #include <fcntl.h>
 #include <stdarg.h>
 #include <stdio.h>
@@ -35,12 +41,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <sys/wait.h>
 #include <sys/mman.h>
 #include <errno.h>
-
+#if defined HAVE_DLFCN_H
 #include <dlfcn.h>
+#endif
 
-#include "../qcommon/qcommon.h"
-
-#include "../unix/rw_unix.h"
+#include "qcommon/qcommon.h"
+#include "unix/rw_unix.h"
 
 cvar_t *nostdout;
 
@@ -49,18 +55,62 @@ unsigned	sys_frame_time;
 uid_t saved_euid;
 qboolean stdin_active = true;
 
+// attachment to statically linked game library
+extern void *GetGameAPI ( void *import);
+
+
 // =======================================================================
 // General routines
 // =======================================================================
 
+// Added ANSI color-escape output based on/inspired by Warsow. -M
 void Sys_ConsoleOutput (char *string)
 {
-	if (nostdout && nostdout->value)
+#if defined ANSI_COLOR
+
+	static int  q3ToAnsi[ 8 ] =
+	{
+		30, // COLOR_BLACK
+		31, // COLOR_RED
+		32, // COLOR_GREEN
+		33, // COLOR_YELLOW
+		34, // COLOR_BLUE
+		36, // COLOR_CYAN
+		35, // COLOR_MAGENTA
+		0   // COLOR_WHITE
+	};
+
+	if ( nostdout && nostdout->integer )
 		return;
 
-	fputs(string, stdout);
+    while (*string) {
+        if (*string == '^' && string[1]) {
+            int colornum = (string[1]-'0')&7;
+            printf ("\033[%dm", q3ToAnsi[colornum]);
+            string += 2;
+            continue;
+        }
+        if (*string == '\n')
+            printf ("\033[0m\n");
+        else if (*string == ' ')
+            printf ("\033[0m ");
+        else
+            printf ("%c", *string);
+        string++;
+    }
+
+#else
+
+    if ( nostdout == NULL || !nostdout->integer )
+	{
+		fputs( string, stdout );
+	}
+
+#endif
 }
 
+#if 0
+// not currently used in Unix/Linux
 void Sys_Printf (const char *fmt, ...)
 {
 	va_list		argptr;
@@ -82,6 +132,7 @@ void Sys_Printf (const char *fmt, ...)
 			putc(*p, stdout);
 	}
 }
+#endif
 
 void Sys_Quit (void)
 {
@@ -93,9 +144,6 @@ void Sys_Quit (void)
 
 void Sys_Init(void)
 {
-#if id386
-//	Sys_SetFPCW();
-#endif
 }
 
 //void Sys_Error (const char *error, ...)
@@ -188,7 +236,7 @@ char *Sys_ConsoleInput(void)
 
 /*****************************************************************************/
 
-static void *game_library;
+static void *game_library = NULL;
 
 /*
 =================
@@ -197,7 +245,7 @@ Sys_UnloadGame
 */
 void Sys_UnloadGame (void)
 {
-	if (game_library)
+	if ( game_library != NULL )
 		dlclose (game_library);
 	game_library = NULL;
 }
@@ -206,34 +254,47 @@ void Sys_UnloadGame (void)
 =================
 Sys_GetGameAPI
 
-Loads the game dll
+Loads the game module
+
+2010-08 : Implements a statically linked game module. Loading a game module lib
+  is supported if it exists.
+  To prevent problems with attempting to load an older, incompatible version,
+    a lib will not be loaded from arena/ nor data1/
 =================
 */
 void *Sys_GetGameAPI (void *parms)
 {
-	void	*(*GetGameAPI) (void *);
+	void	*(*ptrGetGameAPI) (void *) = NULL;
 
 	FILE	*fp;
 	char	name[MAX_OSPATH];
 	char	*path;
+	size_t  pathlen;
 	char	*str_p;
 	const char *gamename = "game.so";
 
 	setreuid(getuid(), getuid());
 	setegid(getgid());
 
-	if (game_library)
+	if (game_library != NULL)
 		Com_Error (ERR_FATAL, "Sys_GetGameAPI without Sys_UnloadingGame");
 
-	Com_Printf("------- Loading %s -------\n", gamename);
-
 	// now run through the search paths
 	path = NULL;
 	while (1)
 	{
 		path = FS_NextPath (path);
 		if (!path)
-			return NULL;		// couldn't find one anywhere
+			break; // Search did not turn up a game shared library
+
+		pathlen = strlen( path );
+		// old game lib in data1 is a problem
+		if ( !Q_strncasecmp( "data1", &path[ pathlen-5 ], 5 ) )
+			continue;
+		// may want to have a game lib in arena, but disable for now
+		if ( !Q_strncasecmp( "arena", &path[ pathlen-5 ], 5 ) )
+			continue;
+
 		snprintf (name, MAX_OSPATH, "%s/%s", path, gamename);
 
 		/* skip it if it just doesn't exist */
@@ -243,14 +304,14 @@ void *Sys_GetGameAPI (void *parms)
 		fclose(fp);
 
 		game_library = dlopen (name, RTLD_NOW);
-		if (game_library)
+		if (game_library != NULL )
 		{
-			Com_Printf ("LoadLibrary (%s)\n",name);
+			Com_Printf("------- Loading %s -------\n", gamename);
 			break;
 		}
 		else
 		{
-			Com_Printf ("LoadLibrary (%s):", name);
+			Com_DPrintf ("LoadLibrary (%s):", name);
 
 			path = dlerror();
 			str_p = strchr(path, ':'); // skip the path (already shown)
@@ -259,20 +320,32 @@ void *Sys_GetGameAPI (void *parms)
 			else
 				str_p++;
 
-			Com_Printf ("%s\n", str_p);
+			Com_DPrintf ("%s\n", str_p);
 
-			return NULL;
+			break; // file opened but did not dlopen
 		}
 	}
 
-	GetGameAPI = (void *)dlsym (game_library, "GetGameAPI");
-	if (!GetGameAPI)
+	if ( game_library != NULL )
+	{ // game module from dlopen'd shared library
+		ptrGetGameAPI = (void *)dlsym (game_library, "GetGameAPI");
+	}
+
+	/*
+	 * No game shared library found, use statically linked game
+	 */
+	if ( ptrGetGameAPI == NULL )
 	{
+		ptrGetGameAPI = &GetGameAPI;
+	}
+
+	if ( ptrGetGameAPI == NULL )
+	{ // program error
 		Sys_UnloadGame ();
 		return NULL;
 	}
 
-	return GetGameAPI (parms);
+	return ptrGetGameAPI (parms);
 }
 
 /*****************************************************************************/
@@ -321,9 +394,9 @@ int main (int argc, char **argv)
 			time = newtime - oldtime;
 		} while (time < 1);
 		// curtime setting moved from Sys_Milliseconds()
-		//   so it consistent for entire frame 
-		curtime = newtime; 
-		
+		//   so it consistent for entire frame
+		curtime = newtime;
+
         Qcommon_Frame (time);
 		oldtime = newtime;
     }
