@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -20,7 +20,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // in_win.c -- windows 95 mouse and joystick code
 // 02/21/97 JCB Added extended DirectInput code to support external controllers.
 
-#include "../client/client.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "client/client.h"
 #include "winquake.h"
 
 extern	unsigned	sys_msg_time;
@@ -106,6 +110,7 @@ void IN_JoyMove (usercmd_t *cmd);
 
 // mouse variables
 cvar_t	*m_filter;
+cvar_t	*m_accel;
 
 qboolean	mlooking;
 
@@ -127,7 +132,7 @@ qboolean	mouseactive;	// false when not focus app
 
 qboolean	restore_spi;
 qboolean	mouseinitialized;
-int		originalmouseparms[3], newmouseparms[3] = {0, 0, 1};
+int		originalmouseparms[3], newmouseparms[3] = {0, 0, 1}, noaccelmouseparms[3] = {0, 0, 0};
 qboolean	mouseparmsvalid;
 
 int			window_center_x, window_center_y;
@@ -157,8 +162,17 @@ void IN_ActivateMouse (void)
 
 	mouseactive = true;
 
-	if (mouseparmsvalid)
-		restore_spi = SystemParametersInfo (SPI_SETMOUSE, 0, newmouseparms, 0);
+	if (mouseparmsvalid) {
+		switch(m_accel->integer) {
+			case 0:
+				restore_spi = SystemParametersInfo (SPI_SETMOUSE, 0, noaccelmouseparms, 0);
+				break;
+			case 1:
+			default:
+				restore_spi = SystemParametersInfo (SPI_SETMOUSE, 0, newmouseparms, 0);
+				break;
+		}
+	}
 
 	width = GetSystemMetrics (SM_CXSCREEN);
 	height = GetSystemMetrics (SM_CYSCREEN);
@@ -227,8 +241,8 @@ void IN_StartupMouse (void)
 	cvar_t		*cv;
 
 	cv = Cvar_Get ("in_initmouse", "1", CVAR_NOSET);
-	if ( !cv->value ) 
-		return; 
+	if ( !cv->value )
+		return;
 
 	// Knightmare- added Psychospaz's menu mouse support
 	refreshCursorMenu();
@@ -238,7 +252,7 @@ void IN_StartupMouse (void)
 
 	mouseinitialized = true;
 	mouseparmsvalid = SystemParametersInfo (SPI_GETMOUSE, 0, originalmouseparms, 0);
-	mouse_buttons = 3;
+	mouse_buttons = 7; /* TODO: Are 9 possible? Do 7 work now? */
 }
 
 /*
@@ -268,8 +282,8 @@ void IN_MouseEvent (int mstate)
 		{
 				Key_Event (K_MOUSE1 + i, false, sys_msg_time);
 		}
-	}	
-	
+	}
+
 	//set menu cursor buttons
 	if (cls.key_dest == key_menu)
 	{
@@ -301,8 +315,8 @@ void IN_MouseEvent (int mstate)
 				cursor.buttonused[i] = false;
 				cursor.mouseaction = true;
 			}
-		}			
-	}	
+		}
+	}
 
 	mouse_oldbuttonstate = mstate;
 }
@@ -346,8 +360,29 @@ void IN_MouseMove (usercmd_t *cmd)
 	old_mouse_x = mx;
 	old_mouse_y = my;
 
-	mouse_x *= sensitivity->value;
-	mouse_y *= sensitivity->value;
+
+	if ( m_smoothing->value )
+	{   // reduce sensitivity when frames per sec is below maximum setting
+		// cvar mouse sensitivity * ( current measured fps / cvar set maximum fps )
+		float adjustment;
+		extern cvar_t* cl_maxfps;
+		adjustment = sensitivity->value / (cls.frametime * cl_maxfps->value);
+		mouse_x *= adjustment;
+		mouse_y *= adjustment;
+	}
+	else
+	{
+		if (cls.key_dest == key_menu)
+		{
+			mouse_x *= menu_sensitivity->value;
+			mouse_y *= menu_sensitivity->value;
+		}
+		else
+		{
+			mouse_x *= sensitivity->value;
+			mouse_y *= sensitivity->value;
+		}
+	}
 
 	//now to set the menu cursor
 	if (cls.key_dest == key_menu)
@@ -355,8 +390,8 @@ void IN_MouseMove (usercmd_t *cmd)
 		cursor.oldx = cursor.x;
 		cursor.oldy = cursor.y;
 
-		cursor.x += mouse_x * .25;//sensitivity->value/10;
-		cursor.y += mouse_y * .25;//sensitivity->value/10;
+		cursor.x += mouse_x * .35;
+		cursor.y += mouse_y * .35;
 
 		if (cursor.x!=cursor.oldx || cursor.y!=cursor.oldy)
 			cursor.mouseaction = true;
@@ -373,7 +408,7 @@ void IN_MouseMove (usercmd_t *cmd)
 
 		//mouse_x *= sensitivity->value;
 		//mouse_y *= sensitivity->value;
-		
+
 	// add mouse X/Y movement to cmd
 		if ( (in_strafe.state & 1) || (lookstrafe->value && mlooking ))
 			cmd->sidemove += m_side->value * mouse_x;
@@ -497,7 +532,7 @@ void IN_Frame (void)
 		IN_DeactivateMouse ();
 		return;
 	}
-	
+
 	if ( !cl.refresh_prepped && cls.key_dest != key_menu || cls.key_dest == key_console)
 	{
 		// temporarily deactivate if in fullscreen
@@ -523,7 +558,7 @@ void IN_Move (usercmd_t *cmd)
 	// Knightmare- added Psychospaz's mouse support
 	if (cls.key_dest == key_menu && cls.key_dest != key_console) // Knightmare added
 		M_Think_MouseCursor();
-	
+
 	if (ActiveApp)
 		IN_JoyMove (cmd);
 }
@@ -550,26 +585,26 @@ JOYSTICK
 =========================================================================
 */
 
-/* 
-=============== 
-IN_StartupJoystick 
-=============== 
-*/  
-void IN_StartupJoystick (void) 
-{ 
+/*
+===============
+IN_StartupJoystick
+===============
+*/
+void IN_StartupJoystick (void)
+{
 	int			numdevs;
 	JOYCAPS		jc;
 	MMRESULT	mmr;
 	cvar_t		*cv;
 
  	// assume no joystick
-	joy_avail = false; 
+	joy_avail = false;
 
 	// abort startup if user requests no joystick
 	cv = Cvar_Get ("in_initjoy", "1", CVAR_NOSET);
-	if ( !cv->value ) 
-		return; 
- 
+	if ( !cv->value )
+		return;
+
 	// verify joystick driver is present
 	if ((numdevs = joyGetNumDevs ()) == 0)
 	{
@@ -586,7 +621,7 @@ void IN_StartupJoystick (void)
 
 		if ((mmr = joyGetPosEx (joy_id, &ji)) == JOYERR_NOERROR)
 			break;
-	} 
+	}
 
 	// abort startup if we didn't find a valid joystick
 	if (mmr != JOYERR_NOERROR)
@@ -600,7 +635,7 @@ void IN_StartupJoystick (void)
 	memset (&jc, 0, sizeof(jc));
 	if ((mmr = joyGetDevCaps (joy_id, &jc, sizeof(jc))) != JOYERR_NOERROR)
 	{
-		Com_Printf ("\njoystick not found -- invalid joystick capabilities (%x)\n\n", mmr); 
+		Com_Printf ("\njoystick not found -- invalid joystick capabilities (%x)\n\n", mmr);
 		return;
 	}
 
@@ -614,10 +649,10 @@ void IN_StartupJoystick (void)
 	// mark the joystick as available and advanced initialization not completed
 	// this is needed as cvars are not available during initialization
 
-	joy_avail = true; 
+	joy_avail = true;
 	joy_advancedinit = false;
 
-	Com_Printf ("\njoystick detected\n\n"); 
+	Com_Printf ("\njoystick detected\n\n");
 }
 
 
@@ -735,7 +770,7 @@ void IN_Commands (void)
 		return;
 	}
 
-	
+
 	// loop through the joystick buttons
 	// key a joystick event or auxillary event for higher number buttons for each state change
 	buttonstate = ji.dwButtons;
@@ -790,11 +825,11 @@ void IN_Commands (void)
 }
 
 
-/* 
-=============== 
+/*
+===============
 IN_ReadJoystick
-=============== 
-*/  
+===============
+*/
 qboolean IN_ReadJoystick (void)
 {
 
@@ -840,16 +875,16 @@ void IN_JoyMove (usercmd_t *cmd)
 	// verify joystick is available and that the user wants to use it
 	if (!joy_avail || !in_joystick->value)
 	{
-		return; 
+		return;
 	}
- 
+
 	// collect the joystick data, if possible
 	if (IN_ReadJoystick () != true)
 	{
 		return;
 	}
 
-	if ( (in_speed.state & 1) ^ (int)cl_run->value)
+	if ( (in_speed.state & 1) ^ cl_run->integer)
 		speed = 2;
 	else
 		speed = 1;
@@ -863,7 +898,7 @@ void IN_JoyMove (usercmd_t *cmd)
 		// move centerpoint to zero
 		fAxisValue -= 32768.0;
 
-		// convert range from -32768..32767 to -1..1 
+		// convert range from -32768..32767 to -1..1
 		fAxisValue /= 32768.0;
 
 		switch (dwAxisMap[i])
@@ -873,7 +908,7 @@ void IN_JoyMove (usercmd_t *cmd)
 			{
 				// user wants forward control to become look control
 				if (fabs(fAxisValue) > joy_pitchthreshold->value)
-				{		
+				{
 					// if mouse invert is on, invert the joystick pitch value
 					// only absolute control support here (joy_advanced is false)
 					if (m_pitch->value < 0.0)
