@@ -17,9 +17,13 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
-// sys_win.h
+// sys_win.c
 
-#include "../qcommon/qcommon.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "qcommon/qcommon.h"
 #include "winquake.h"
 #include "resource.h"
 #include <errno.h>
@@ -28,8 +32,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <stdio.h>
 #include <direct.h>
 #include <io.h>
-#include <conio.h>
-#include "../win32/conproc.h"
+
+#include "conproc.h"
 
 #define MINIMUM_WIN_MEMORY	0x0a00000
 #define MAXIMUM_WIN_MEMORY	0x1000000
@@ -38,7 +42,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 qboolean s_win95;
 
-int			starttime;
 int			ActiveApp;
 qboolean	Minimized;
 
@@ -47,9 +50,10 @@ static HANDLE		hinput, houtput;
 unsigned	sys_msg_time;
 unsigned	sys_frame_time;
 
-#ifndef __unix__
+// attachment to statically linked game library
+extern void *GetGameAPI ( void *import);
+
 extern void Q_strncpyz( char *dest, const char *src, size_t size );
-#endif
 
 static HANDLE		qwclsemaphore;
 
@@ -57,8 +61,6 @@ static HANDLE		qwclsemaphore;
 int			argc;
 char		*argv[MAX_NUM_ARGVS];
 
-#ifndef __unix__
-
 #define CONSOLE_WINDOW_CLASS_NAME	"CRX Console"
 #define CONSOLE_WINDOW_NAME			"Alien Arena Console"
 #define CONSOLE_WINDOW_STYLE		(WS_OVERLAPPED|WS_BORDER|WS_CAPTION|WS_SYSMENU|WS_MINIMIZEBOX|WS_CLIPCHILDREN|WS_GROUP)
@@ -176,7 +178,7 @@ void Sys_Error (char *error, ...)
 	Qcommon_Shutdown ();
 
 	va_start (argptr, error);
-	vsprintf (text, error, argptr);
+	vsnprintf (text, sizeof(text), error, argptr);
 	va_end (argptr);
 
 	MessageBox(NULL, text, "Error", 0 /* MB_OK */ );
@@ -524,7 +526,6 @@ void Sys_PumpMessages (void){
 	// Grab frame time
 	sys_frameTime = timeGetTime();	// FIXME: should this be at start?
 }
-#endif
 
 void Sys_Quit (void)
 {
@@ -594,10 +595,8 @@ void Sys_Init (void)
 #endif
 
 	timeBeginPeriod( 1 );
-#ifndef __unix__
 	Cvar_Get("sys_hInstance", va("%i", sys_hInstance), CVAR_ROM);
 	Cvar_Get("sys_wndProc", va("%i", MainWndProc), CVAR_ROM);
-#endif
 
 	vinfo.dwOSVersionInfoSize = sizeof(vinfo);
 
@@ -611,19 +610,7 @@ void Sys_Init (void)
 	else if ( vinfo.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS )
 		s_win95 = true;
 
-#ifdef __unix__
-	if (dedicated->value)
-	{
-		if (!AllocConsole ())
-			Sys_Error ("Couldn't create dedicated server console");
-		hinput = GetStdHandle (STD_INPUT_HANDLE);
-		houtput = GetStdHandle (STD_OUTPUT_HANDLE);
-
-		// let QHOST hook in
-		InitConProc (argc, argv);
 	}
-#endif
-}
 
 
 static char	console_text[256];
@@ -820,7 +807,7 @@ GAME DLL
 ========================================================================
 */
 
-static HINSTANCE	game_library;
+static HINSTANCE	game_library = NULL;
 
 /*
 =================
@@ -829,8 +816,11 @@ Sys_UnloadGame
 */
 void Sys_UnloadGame (void)
 {
+	if ( game_library != NULL )
+	{
 	if (!FreeLibrary (game_library))
 		Com_Error (ERR_FATAL, "FreeLibrary failed for game library");
+	}
 	game_library = NULL;
 }
 
@@ -838,44 +828,40 @@ void Sys_UnloadGame (void)
 =================
 Sys_GetGameAPI
 
-Loads the game dll
+Loads the game module
+
+2010-08 : Implements a statically linked game module. Loading a game module DLL
+  is supported if it exists.
+  To prevent problems with attempting to load an older, incompatible version,
+    a DLL will not be loaded from arena/ nor data1/
+
 =================
 */
 void *Sys_GetGameAPI (void *parms)
 {
-	void	*(*GetGameAPI) (void *);
+	void	*(*ptrGetGameAPI) (void *) = NULL;
 	char	name[MAX_OSPATH];
 	char	*path;
-	char	cwd[MAX_OSPATH];
-#if defined _M_IX86
+	size_t pathlen;
+//	char	cwd[MAX_OSPATH];
 
-const char *gamename = "gamex86.dll";
+	const char *gamename = "gamex86.dll";
 
+/*
 #ifdef NDEBUG
 	const char *debugdir = "release";
 #else
 	const char *debugdir = "debug";
 #endif
 
-#elif defined _M_ALPHA
-	const char *gamename = "gameaxp.dll";
-
-#ifdef NDEBUG
-	const char *debugdir = "releaseaxp";
-#else
-	const char *debugdir = "debugaxp";
-#endif
-
-#endif
-
-	if (game_library)
+	if (game_library != NULL)
 		Com_Error (ERR_FATAL, "Sys_GetGameAPI without Sys_UnloadingGame");
 
 	// check the current debug directory first for development purposes
 	_getcwd (cwd, sizeof(cwd));
 	Com_sprintf (name, sizeof(name), "%s/%s/%s", cwd, debugdir, gamename);
 	game_library = LoadLibrary ( name );
-	if (game_library)
+	if (game_library != NULL )
 	{
 		Com_DPrintf ("LoadLibrary (%s)\n", name);
 	}
@@ -893,12 +879,14 @@ const char *gamename = "gamex86.dll";
 #endif
 		{
 			// now run through the search paths
+
 			path = NULL;
 			while (1)
 			{
 				path = FS_NextPath (path);
 				if (!path)
-					return NULL;		// couldn't find one anywhere
+					break; // Search did not turn up a game DLL
+
 				Com_sprintf (name, sizeof(name), "%s/%s", path, gamename);
 				game_library = LoadLibrary (name);
 				if (game_library)
@@ -909,15 +897,57 @@ const char *gamename = "gamex86.dll";
 			}
 		}
 	}
+*/
 
-	GetGameAPI = (void *)GetProcAddress (game_library, "GetGameAPI");
-	if (!GetGameAPI)
+// 2010-08
+
+	if (game_library != NULL)
+		Com_Error (ERR_FATAL, "Sys_GetGameAPI without Sys_UnloadingGame");
+
+	path = NULL;
+	for (;;)
 	{
+		path = FS_NextPath( path );
+		if ( !path )
+			break;
+
+		pathlen = strlen( path );
+		// old game DLL in data1 is a problem
+		if ( !Q_strncasecmp( "data1", &path[ pathlen-5 ], 5 ) )
+			continue;
+		// may want to have a game DLL in arena, but disable for now
+		if ( !Q_strncasecmp( "arena", &path[ pathlen-5 ], 5 ) )
+			continue;
+
+		Com_sprintf (name, sizeof(name), "%s/%s", path, gamename);
+		game_library = LoadLibrary (name);
+		if (game_library)
+		{ // found a game module DLL
+			break;
+		}
+	}
+
+	if ( game_library != NULL )
+	{ // game module from DLL
+		Com_Printf ("LoadLibrary (%s)\n",name);
+		ptrGetGameAPI = (void *)GetProcAddress (game_library, "GetGameAPI");
+	}
+
+	/*
+	 * No game DLL found, use statically linked game
+	 */
+	if ( ptrGetGameAPI == NULL )
+	{
+		ptrGetGameAPI = &GetGameAPI;
+	}
+
+	if ( ptrGetGameAPI == NULL )
+	{ // program error
 		Sys_UnloadGame ();
 		return NULL;
 	}
 
-	return GetGameAPI (parms);
+	return ptrGetGameAPI (parms);
 }
 
 //=======================================================================
@@ -1000,6 +1030,9 @@ int WINAPI WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLin
 			newtime = Sys_Milliseconds();
 			time = newtime - oldtime;
 		} while (time < 1);
+		// curtime setting moved from Sys_Milliseconds()
+		//   so it consistent for entire frame
+		curtime = newtime;
 
 		_controlfp(_PC_24, _MCW_PC);
 
